@@ -243,6 +243,11 @@ public class DocumentBackupManager implements DocumentBackupController, StoreOpe
 
     @Override
     public boolean updateDocumentInitState(final DocRestoreID docRestoreId, final int osn) {
+        if (docRestoreId == null) {
+            LOG.debug("RT connection: DocumentBackupManager called with DocRestoreId set to null, ignore request!");
+            return false;
+        }
+
         try {
             DocumentState storedDocState;
             synchronized(sync) {
@@ -272,6 +277,11 @@ public class DocumentBackupManager implements DocumentBackupController, StoreOpe
 
     @Override
     public boolean deregisterDocument(final DocRestoreID docRestoreId) {
+        if (docRestoreId == null) {
+            LOG.debug("RT connection: DocumentBackupManager called with DocRestoreId set to null, ignore request!");
+            return false;
+        }
+
         try {
             DocumentState storedDocState;
             synchronized(sync) {
