@@ -111,7 +111,7 @@ public class IndexedNodeList<E> implements List<E> {
 
 	public void setNodes(IndexedNode<E> oldNode, IndexedNodeList<E> newNodes) {
 
-		final Object newParent = ((Child)oldNode.getData()).getParent();
+		final Object newParent = oldNode.getData() instanceof Child ? ((Child)oldNode.getData()).getParent() : null;
 
 		int destIndex = oldNode.getIndex();
 		int sourceIndex = 0;
@@ -159,7 +159,15 @@ public class IndexedNodeList<E> implements List<E> {
 
 	public static void moveNodes(IndexedNodeList<Object> source, IndexedNodeList<Object> dest, int sourceIndex, int destIndex, int count, Object newParent) {
 
-		final boolean sourceIndexIncreasing = source==dest&&destIndex<sourceIndex;
+		boolean sourceIndexIncreasing = false; 
+		if(source==dest) {
+			if(destIndex < sourceIndex) {
+				sourceIndexIncreasing = true;
+			}
+			else {
+				destIndex += count;
+			}
+		}
 		for(int i=0;i<count;i++) {
 			final IndexedNode<Object> node = source.getNode(sourceIndex+i);
 			if(newParent!=null) {
