@@ -212,7 +212,7 @@ public class TraversalUtil {
         List<Object> tmpArtificialList = new ArrayList<Object>();
         if (graphicData.getPic() != null) {
             //GraphicData can have a hyperlink reference, which can be found this way
-            CTNonVisualDrawingProps picNonVisual = graphicData.getPic().getCNvPr();
+            CTNonVisualDrawingProps picNonVisual = graphicData.getPic().getNonVisualDrawingProperties(false);
             if (picNonVisual != null) {
                 handleCTNonVisualDrawingProps(picNonVisual, tmpArtificialList);
             }
@@ -250,7 +250,7 @@ public class TraversalUtil {
 	public static List<Object> getChildrenImpl(Object o) {
 
 		if (o==null) {
-			log.warn("null passed to getChildrenImpl");
+			log.info("null passed to getChildrenImpl");
 			return null;
 		}
 
@@ -268,7 +268,7 @@ public class TraversalUtil {
 		} else if (o instanceof org.docx4j.dml.wordprocessingDrawing.Anchor) {
             org.docx4j.dml.wordprocessingDrawing.Anchor anchor = (org.docx4j.dml.wordprocessingDrawing.Anchor) o;
             List<Object> artificialList = new ArrayList<Object>();
-            CTNonVisualDrawingProps drawingProps = anchor.getDocPr();
+            CTNonVisualDrawingProps drawingProps = anchor.getNonVisualDrawingProperties(false);
             if (drawingProps != null) {
                 handleCTNonVisualDrawingProps(drawingProps, artificialList);
             }
@@ -284,7 +284,7 @@ public class TraversalUtil {
         } else if (o instanceof org.docx4j.dml.wordprocessingDrawing.Inline) {
             org.docx4j.dml.wordprocessingDrawing.Inline inline = (org.docx4j.dml.wordprocessingDrawing.Inline) o;
             List<Object> artificialList = new ArrayList<Object>();
-            CTNonVisualDrawingProps drawingProps = inline.getDocPr();
+            CTNonVisualDrawingProps drawingProps = inline.getNonVisualDrawingProperties(false);
             if (drawingProps != null) {
                 handleCTNonVisualDrawingProps(drawingProps, artificialList);
             }
@@ -479,45 +479,6 @@ public class TraversalUtil {
 
 	public static void replaceChildren(Object o, List<Object> newChildren) {
 
-		// Available if you need something like this.  Would be used with
-		// something like:
-
-		/*
-		 * 	  public void walkJAXBElements(Object parent){
-		  // Breadth first
-
-			  List<Object> newChildren = new ArrayList<Object>();
-
-				List children = getChildren(parent);
-				if (children==null) {
-					log.warn("no children: " + parent.getClass().getName() );
-				} else {
-					for (Object o : getChildren(parent) ) {
-
-						// if its wrapped in javax.xml.bind.JAXBElement, get its value
-						o = XmlUtils.unwrap(o);
-
-						newChildren.addAll(this.apply(o));
-					}
-				}
-				// Replace list, so we'll traverse all the new sdts we've just created
-				replaceChildren(parent, newChildren);
-
-
-				for (Object o : getChildren(parent) ) {
-
-					this.apply(o);
-
-					if ( this.shouldTraverse(o) ) {
-						walkJAXBElements(o);
-					}
-
-				}
-
-			}
-
-		 */
-
 		log.debug("Clearing " + o.getClass().getName() );
 
 		if (o instanceof org.docx4j.wml.ContentAccessor) {
@@ -537,12 +498,12 @@ public class TraversalUtil {
 
 		} else {
 
-			log.warn("Don't know how to replaceChildren in " + o.getClass().getName() );
+			log.info("Don't know how to replaceChildren in " + o.getClass().getName() );
 
 			if (o instanceof org.w3c.dom.Node) {
-				log.warn(" IGNORED " + ((org.w3c.dom.Node) o).getNodeName());
+				log.info(" IGNORED " + ((org.w3c.dom.Node) o).getNodeName());
 			} else {
-//				log.warn(" IGNORED " + o.getClass().getName());
+//				log.info(" IGNORED " + o.getClass().getName());
 			}
 
 		}
