@@ -463,7 +463,7 @@ public class XmlUtils {
 	       String key = wmlTemplateString.substring(startKey + 2, keyEnd);
 	       String val = mappings.get(key);
 	       if (val==null) {
-	    	   log.warn("Invalid key '" + key + "' or key not mapped to a value");
+	    	   log.info("Invalid key '" + key + "' or key not mapped to a value");
 	    	   strB.append(key );
 	       } else {
 	    	   strB.append(val  );
@@ -970,7 +970,7 @@ public class XmlUtils {
 				if (pairs.getKey().equals("customXsltTemplates")) continue;
 
 				if (pairs.getValue() == null) {
-					log.warn("parameter '" + pairs.getKey() + "' was null.");
+					log.info("parameter '" + pairs.getKey() + "' was null.");
 				} else {
 					xformer.setParameter((String) pairs.getKey(), pairs
 							.getValue());
@@ -1149,7 +1149,7 @@ public class XmlUtils {
 
     	  public void warning(TransformerException exception) {
 
-    	    log.warn(exception.getMessage(), exception);
+    	    log.info(exception.getMessage(), exception);
 
     	    // Don't throw an exception and stop the processor
     	    // just for a warning; but do log the problem
