@@ -169,7 +169,7 @@ public abstract class AbstractVisitorExporterGenerator<CC extends AbstractWmlCon
 				parentNode.appendChild( currentP  );
 			}
 
-			pPr = ((P)o).getPPr();
+			pPr = ((P)o).getPPr(false);
 			currentP = handlePPr(conversionContext, pPr, false, currentP);
 
 		} else if (o instanceof org.docx4j.wml.R) {
