@@ -830,11 +830,11 @@ public class Differencer {
 
 
         org.docx4j.wml.P newLeftP = wmlFactory.createP();
-        newLeftP.setPPr(pl.getPPr());
+        newLeftP.setPPr(pl.getPPr(false));
         newLeftP.getContent().addAll(pLeftReplacement);
 
         org.docx4j.wml.P newRightP = wmlFactory.createP();
-        newRightP.setPPr(pr.getPPr());
+        newRightP.setPPr(pr.getPPr(false));
         newRightP.getContent().addAll(pRightReplacement);
 
 		log.debug("\n\n Left input \n\n" );
