@@ -66,7 +66,7 @@ import javax.xml.bind.annotation.XmlType;
     "scene3D",
     "extLst"
 })
-public class CTGroupShapeProperties implements IFillProperties {
+public class CTGroupShapeProperties implements IFillProperties, ITransform2DAccessor {
 
     protected CTGroupTransform2D xfrm;
     protected CTNoFillProperties noFill;
@@ -91,22 +91,14 @@ public class CTGroupShapeProperties implements IFillProperties {
      *     {@link CTGroupTransform2D }
      *
      */
-    public CTGroupTransform2D getXfrm() {
+    @Override
+    public CTGroupTransform2D getXfrm(boolean forceCreate) {
+    	if(xfrm==null&&forceCreate) {
+    		xfrm = new CTGroupTransform2D();
+    	}
         return xfrm;
     }
 
-    /**
-     * Sets the value of the xfrm property.
-     *
-     * @param value
-     *     allowed object is
-     *     {@link CTGroupTransform2D }
-     *
-     */
-    public void setXfrm(CTGroupTransform2D value) {
-        this.xfrm = value;
-    }
-
     /**
      * Gets the value of the noFill property.
      *
