@@ -49,27 +49,7 @@
 
 package org.docx4j.dml;
 
-public interface IShape extends INonVisualDrawingProperties {
-
-    /**
-     * Gets the value of the cNvSpPr property.
-     *
-     * @return
-     *     possible object is
-     *     {@link CTNonVisualDrawingShapeProps }
-     *
-     */
-    public CTNonVisualDrawingShapeProps getCNvSpPr();
-
-    /**
-     * Sets the value of the cNvSpPr property.
-     *
-     * @param value
-     *     allowed object is
-     *     {@link CTNonVisualDrawingShapeProps }
-     *
-     */
-    public void setCNvSpPr(CTNonVisualDrawingShapeProps value);
+public interface IShape extends INonVisualDrawingPropertyAccess, INonVisualDrawingShapePropertyAccess {
 
     /**
      * Gets the value of the spPr property.
