@@ -32,7 +32,9 @@ import org.docx4j.dml.CTNonVisualDrawingProps;
 import org.docx4j.dml.CTNonVisualPictureProperties;
 import org.docx4j.dml.CTShapeProperties;
 import org.docx4j.dml.CTShapeStyle;
+import org.docx4j.dml.CTTransform2D;
 import org.docx4j.dml.IPicture;
+import org.docx4j.dml.ITransform2DAccessor;
 
 /**
  * <p>Java class for CT_Picture complex type.
@@ -65,7 +67,7 @@ import org.docx4j.dml.IPicture;
     "spPr",
     "style"
 })
-public class CTPicture implements IPicture {
+public class CTPicture implements ITransform2DAccessor, IPicture {
 
     @XmlElement(required = true)
     protected CTPictureNonVisual nvPicPr;
@@ -79,6 +81,10 @@ public class CTPicture implements IPicture {
     @XmlAttribute
     protected Boolean fPublished;
 
+    public CTTransform2D getXfrm(boolean forceCreate) {
+    	return spPr.getXfrm(forceCreate);
+    }
+
     /**
      * Gets the value of the blipFill property.
      * 
@@ -206,42 +212,32 @@ public class CTPicture implements IPicture {
     public void setFPublished(Boolean value) {
         this.fPublished = value;
     }
-	@Override
-	public CTNonVisualDrawingProps getCNvPr() {
+
+    @Override
+	public CTNonVisualDrawingProps getNonVisualDrawingProperties(boolean createIfMissing) {
+		if(nvPicPr==null&&createIfMissing) {
+			nvPicPr = new CTPictureNonVisual();
+		}
 		if(nvPicPr!=null) {
+			if(nvPicPr.getCNvPr()==null&&createIfMissing) {
+				nvPicPr.setCNvPr(new CTNonVisualDrawingProps());
+			}
 			return nvPicPr.getCNvPr();
 		}
 		return null;
 	}
+
 	@Override
-	public void setCNvPr(CTNonVisualDrawingProps value) {
-		if(nvPicPr==null) {
-			if(value!=null) {
-				nvPicPr = new CTPictureNonVisual();
-				nvPicPr.setCNvPr(value);
-			}
+	public CTNonVisualPictureProperties getNonVisualDrawingShapeProperties(boolean createIfMissing) {
+		if(nvPicPr==null&&createIfMissing) {
+			nvPicPr = new CTPictureNonVisual();
 		}
-		else {
-			nvPicPr.setCNvPr(value);
-		}
-	}
-	@Override
-	public CTNonVisualPictureProperties getCNvPicPr() {
 		if(nvPicPr!=null) {
+			if(nvPicPr.getCNvPicPr()==null&&createIfMissing) {
+				nvPicPr.setCNvPicPr(new CTNonVisualPictureProperties());
+			}
 			return nvPicPr.getCNvPicPr();
 		}
 		return null;
 	}
-	@Override
-	public void setCNvPicPr(CTNonVisualPictureProperties value) {
-		if(nvPicPr==null) {
-			if(value!=null) {
-				nvPicPr = new CTPictureNonVisual();
-				nvPicPr.setCNvPicPr(value);
-			}
-		}
-		else {
-			nvPicPr.setCNvPicPr(value);
-		}
-	}
 }
