@@ -34,10 +34,11 @@ import org.docx4j.dml.CTShapeProperties;
 import org.docx4j.dml.CTShapeStyle;
 import org.docx4j.dml.CTTextBody;
 import org.docx4j.dml.CTTextBodyProperties;
+import org.docx4j.dml.CTTransform2D;
 import org.docx4j.dml.IShape;
+import org.docx4j.dml.ITransform2DAccessor;
 import org.docx4j.jaxb.Context;
 
-
 /**
  * <p>Java class for CT_Shape complex type.
  * 
@@ -71,7 +72,7 @@ import org.docx4j.jaxb.Context;
     "style",
     "txBody"
 })
-public class CTShape implements IShape {
+public class CTShape implements ITransform2DAccessor, IShape {
 
     @XmlElement(required = true)
     protected CTShapeNonVisual nvSpPr;
@@ -88,6 +89,10 @@ public class CTShape implements IShape {
     @XmlAttribute
     protected Boolean fPublished;
 
+    public CTTransform2D getXfrm(boolean forceCreate) {
+    	return spPr.getXfrm(forceCreate);
+    }
+
     /**
      * Gets the value of the nvSpPr property.
      * 
@@ -289,47 +294,33 @@ public class CTShape implements IShape {
     }
 
 	@Override
-	public CTNonVisualDrawingProps getCNvPr() {
+	public CTNonVisualDrawingProps getNonVisualDrawingProperties(boolean createIfMissing) {
+		if(nvSpPr==null&&createIfMissing) {
+			nvSpPr = new CTShapeNonVisual();
+		}
 		if(nvSpPr!=null) {
+			if(nvSpPr.getCNvPr()==null&&createIfMissing) {
+				nvSpPr.setCNvPr(new CTNonVisualDrawingProps());
+			}
 			return nvSpPr.getCNvPr();
 		}
 		return null;
 	}
 
 	@Override
-	public void setCNvPr(CTNonVisualDrawingProps value) {
-		if(nvSpPr==null) {
-			if(value!=null) {
-				nvSpPr = new CTShapeNonVisual();
-				nvSpPr.setCNvPr(value);
-			}
+	public CTNonVisualDrawingShapeProps getNonVisualDrawingShapeProperties(boolean createIfMissing) {
+		if(nvSpPr==null&&createIfMissing) {
+			nvSpPr = new CTShapeNonVisual();
 		}
-		else {
-			nvSpPr.setCNvPr(value);
-		}
-	}
-
-	@Override
-	public CTNonVisualDrawingShapeProps getCNvSpPr() {
 		if(nvSpPr!=null) {
+			if(nvSpPr.getCNvSpPr()==null&&createIfMissing) {
+				nvSpPr.setCNvSpPr(new CTNonVisualDrawingShapeProps());
+			}
 			return nvSpPr.getCNvSpPr();
 		}
 		return null;
 	}
 
-	@Override
-	public void setCNvSpPr(CTNonVisualDrawingShapeProps value) {
-		if(nvSpPr==null) {
-			if(value!=null) {
-				nvSpPr = new CTShapeNonVisual();
-				nvSpPr.setCNvSpPr(value);
-			}
-		}
-		else {
-			nvSpPr.setCNvSpPr(value);
-		}
-	}
-
 	/* check if the txBody is valid */
     public void beforeMarshal(Marshaller marshaller) {
     	if(txBody!=null) {
@@ -358,6 +349,7 @@ public class CTShape implements IShape {
 			}
 			final CTTextBodyProperties txBodyPr = Context.getDmlObjectFactory().createCTTextBodyProperties();
 			txBody.setBodyPr(txBodyPr);
+			return txBodyPr;
 		}
 		return null;
 	}
