@@ -58,10 +58,12 @@ import javax.xml.bind.annotation.XmlType;
 
 import org.docx4j.IndexedNodeList;
 import org.docx4j.dml.CTGroupShapeProperties;
+import org.docx4j.dml.CTGroupTransform2D;
 import org.docx4j.dml.CTNonVisualDrawingProps;
 import org.docx4j.dml.CTNonVisualGroupDrawingShapeProps;
 import org.docx4j.dml.CTOfficeArtExtensionList;
 import org.docx4j.dml.IGroupShape;
+import org.docx4j.dml.ITransform2DAccessor;
 import org.docx4j.dml.picture.Pic;
 import org.docx4j.dml.wordprocessingShape2010.CTWordprocessingShape;
 import org.docx4j.w14.CTWordContentPart;
@@ -106,7 +108,7 @@ import org.docx4j.wml.ContentAccessor;
     "wspOrGrpSpOrGraphicFrame",
     "extLst"
 })
-public class CTWordprocessingGroup implements IGroupShape, ContentAccessor {
+public class CTWordprocessingGroup implements ITransform2DAccessor, IGroupShape, ContentAccessor {
 
     protected CTNonVisualDrawingProps cNvPr;
     @XmlElement(required = true)
@@ -123,6 +125,17 @@ public class CTWordprocessingGroup implements IGroupShape, ContentAccessor {
     protected IndexedNodeList<Object> wspOrGrpSpOrGraphicFrame;
     protected CTOfficeArtExtensionList extLst;
 
+    /**
+     * Gets the value of the xfrm property.
+     *
+     * @return
+     *     possible object is
+     *     {@link CTGroupTransform2D }
+     *
+     */
+    public CTGroupTransform2D getXfrm(boolean forceCreate) {
+    	return grpSpPr.getXfrm(forceCreate);
+    }
 
     /**
      * Gets the value of the wspOrGrpSpOrGraphicFrame property.
@@ -166,22 +179,13 @@ public class CTWordprocessingGroup implements IGroupShape, ContentAccessor {
      *     {@link CTNonVisualDrawingProps }
      *
      */
-    public CTNonVisualDrawingProps getCNvPr() {
+	public CTNonVisualDrawingProps getNonVisualDrawingProperties(boolean createIfMissing) {
+		if(cNvPr==null&&createIfMissing) {
+			cNvPr = new CTNonVisualDrawingProps();
+		}
         return cNvPr;
     }
 
-    /**
-     * Sets the value of the cNvPr property.
-     *
-     * @param value
-     *     allowed object is
-     *     {@link CTNonVisualDrawingProps }
-     *
-     */
-    public void setCNvPr(CTNonVisualDrawingProps value) {
-        this.cNvPr = value;
-    }
-
     /**
      * Gets the value of the cNvGrpSpPr property.
      *
@@ -190,7 +194,10 @@ public class CTWordprocessingGroup implements IGroupShape, ContentAccessor {
      *     {@link CTNonVisualGroupDrawingShapeProps }
      *
      */
-    public CTNonVisualGroupDrawingShapeProps getCNvGrpSpPr() {
+	public CTNonVisualGroupDrawingShapeProps getNonVisualDrawingShapeProperties(boolean createIfMissing) {
+		if(cNvGrpSpPr==null&&createIfMissing) {
+			cNvGrpSpPr = new CTNonVisualGroupDrawingShapeProps();
+		}
         return cNvGrpSpPr;
     }
 
