@@ -49,7 +49,6 @@
 
 package org.docx4j.dml.wordprocessingShape2010;
 
-import javax.xml.bind.Marshaller;
 import javax.xml.bind.annotation.XmlAccessType;
 import javax.xml.bind.annotation.XmlAccessorType;
 import javax.xml.bind.annotation.XmlAttribute;
@@ -64,10 +63,11 @@ import org.docx4j.dml.CTOfficeArtExtensionList;
 import org.docx4j.dml.CTShapeProperties;
 import org.docx4j.dml.CTShapeStyle;
 import org.docx4j.dml.CTTextBodyProperties;
+import org.docx4j.dml.CTTransform2D;
 import org.docx4j.dml.IShape;
+import org.docx4j.dml.ITransform2DAccessor;
 import org.docx4j.jaxb.Context;
 
-
 /**
  * <p>Java class for CT_WordprocessingShape complex type.
  *
@@ -113,7 +113,7 @@ import org.docx4j.jaxb.Context;
     "linkedTxbx",
     "bodyPr"
 })
-public class CTWordprocessingShape implements IShape {
+public class CTWordprocessingShape implements ITransform2DAccessor, IShape {
 
     protected CTNonVisualDrawingProps cNvPr;
     protected CTNonVisualDrawingShapeProps cNvSpPr;
@@ -129,53 +129,17 @@ public class CTWordprocessingShape implements IShape {
     @XmlAttribute(name = "normalEastAsianFlow")
     protected Boolean normalEastAsianFlow;
 
-    /**
-     * Gets the value of the cNvPr property.
-     *
-     * @return
-     *     possible object is
-     *     {@link CTNonVisualDrawingProps }
-     *
-     */
-    public CTNonVisualDrawingProps getCNvPr() {
-        return cNvPr;
+    public CTTransform2D getXfrm(boolean forceCreate) {
+    	return spPr.getXfrm(forceCreate);
     }
 
-    /**
-     * Sets the value of the cNvPr property.
-     *
-     * @param value
-     *     allowed object is
-     *     {@link CTNonVisualDrawingProps }
-     *
-     */
-    public void setCNvPr(CTNonVisualDrawingProps value) {
-        this.cNvPr = value;
-    }
-
-    /**
-     * Gets the value of the cNvSpPr property.
-     *
-     * @return
-     *     possible object is
-     *     {@link CTNonVisualDrawingShapeProps }
-     *
-     */
-    public CTNonVisualDrawingShapeProps getCNvSpPr() {
-        return cNvSpPr;
-    }
-
-    /**
-     * Sets the value of the cNvSpPr property.
-     *
-     * @param value
-     *     allowed object is
-     *     {@link CTNonVisualDrawingShapeProps }
-     *
-     */
-    public void setCNvSpPr(CTNonVisualDrawingShapeProps value) {
-        this.cNvSpPr = value;
-    }
+	@Override
+	public CTNonVisualDrawingProps getNonVisualDrawingProperties(boolean createIfMissing) {
+		if(cNvPr==null&&createIfMissing) {
+			cNvPr = new CTNonVisualDrawingProps();
+		}
+		return cNvPr;
+	}
 
     /**
      * Gets the value of the cNvCnPr property.
@@ -185,8 +149,11 @@ public class CTWordprocessingShape implements IShape {
      *     {@link CTNonVisualConnectorProperties }
      *
      */
-    public CTNonVisualConnectorProperties getCNvCnPr() {
-        return cNvCnPr;
+	public CTNonVisualDrawingShapeProps getNonVisualDrawingShapeProperties(boolean createIfMissing) {
+		if(cNvSpPr==null&&createIfMissing) {
+			cNvSpPr = new CTNonVisualDrawingShapeProps();
+		}
+		return cNvSpPr;
     }
 
     /**
