@@ -33,8 +33,8 @@ public class SectPrFinder extends CallbackImpl {
 		
 		if (o instanceof P) {
 			P p = (P)o;
-			if ( p.getPPr()!=null && p.getPPr().getSectPr()!=null ) {
-				sectPrList.add(p.getPPr().getSectPr());
+			if ( p.getPPr(false)!=null && p.getPPr(false).getSectPr()!=null ) {
+				sectPrList.add(p.getPPr(false).getSectPr());
 			}
 		}
 		return null;
