@@ -407,16 +407,12 @@ public class OpenDoPEHandler {
 				} else {
 					Object block = bodyChildren
 							.get(indexIntoBody.intValue() - 1);
-					if (block instanceof P && ((P) block).getPPr() != null
-							&& ((P) block).getPPr().getSectPr() != null) {
-						makeContinuous(((P) block).getPPr().getSectPr());
+					if (block instanceof P && ((P) block).getPPr(false) != null
+							&& ((P) block).getPPr(false).getSectPr() != null) {
+						makeContinuous(((P) block).getPPr(false).getSectPr());
 					} else if (block instanceof P) {
 						// More likely
-						PPr ppr = ((P) block).getPPr();
-						if (ppr == null) {
-							ppr = Context.getWmlObjectFactory().createPPr();
-							((P) block).setPPr(ppr);
-						}
+						PPr ppr = ((P) block).getPPr(true);
 						SectPr newSectPr = Context.getWmlObjectFactory()
 								.createSectPr();
 						SectPr.Type type = Context.getWmlObjectFactory()
