@@ -131,7 +131,7 @@ public class FieldsPreprocessor {
 	private P canonicaliseInstance(P p) {
 
 		P newP = Context.getWmlObjectFactory().createP();
-		newP.setPPr(p.getPPr());
+		newP.setPPr(p.getPPr(false));
 
 		newR = Context.getWmlObjectFactory().createR();
 //		fieldRPr = null;
