@@ -219,11 +219,8 @@ public class MailMerger {
 				lastP = Context.getWmlObjectFactory().createP();
 				target.getMainDocumentPart().getContent().add(lastP);	
 			}
-			if (lastP.getPPr()==null) {
-				lastP.setPPr(Context.getWmlObjectFactory().createPPr());				
-			}
 			SectPr thisSection = XmlUtils.deepCopy(documentSeparator);
-			lastP.getPPr().setSectPr(thisSection);
+			lastP.getPPr(true).setSectPr(thisSection);
 			
 			if (processHeadersAndFooters) {
 				for( CTRel ctRel : hfTemplates.keySet()) {
@@ -280,9 +277,9 @@ public class MailMerger {
 			   List all = template.getMainDocumentPart().getContent();
 		    	Object last = all.get( all.size()-1 );
 		    	if (last instanceof P) {
-		    		if (((P) last).getPPr()!=null 
-		    				&& ((P) last).getPPr().getSectPr() !=null) {
-		    			sectPr = ((P) last).getPPr().getSectPr();
+		    		if (((P) last).getPPr(false)!=null 
+		    				&& ((P) last).getPPr(false).getSectPr() !=null) {
+		    			sectPr = ((P) last).getPPr(false).getSectPr();
 		    		}
 		    	}			   
 		   }
