@@ -454,19 +454,19 @@ public class WordXmlPictureE20 extends AbstractWordXmlPicture {
     private CTNonVisualDrawingProps getDocPr() {
 
     	if (inline!=null) {
-        	if (inline.getDocPr()==null) {
+        	if (inline.getNonVisualDrawingProperties(false)==null) {
         		log.error("DocPr missing!!");
         		return null;
         	}
-        	return inline.getDocPr();
+        	return inline.getNonVisualDrawingProperties(false);
     	}
 
     	if (anchor!=null) {
-        	if (anchor.getDocPr()==null) {
+        	if (anchor.getNonVisualDrawingProperties(false)==null) {
         		log.error("DocPr missing!!");
         		return null;
         	}
-        	return anchor.getDocPr();
+        	return anchor.getNonVisualDrawingProperties(false);
     	}
 
     	log.error("Anchor and inline both null!");
