@@ -458,7 +458,7 @@ public class ContentTypeManager  {
 			// Simple minded detection of XML content.
 			// If it turns out not to be XML, the zip loader
 			// will catch the error and load it as a binary part instead.
-			log.warn("DefaultPart used for part '" + partName
+			log.info("DefaultPart used for part '" + partName
 					+ "' of content type '" + contentType + "'");
 			return CreateDefaultXmlPartObject(partName );
 		} else {
