@@ -299,8 +299,12 @@ public class ContentTypes {
 	public final static String DRAWINGML_CHART =
 		"application/vnd.openxmlformats-officedocument.drawingml.chart+xml";
 
+	// /xl/charts/style1.xml
+    public final static String CHART_STYLE =
+        "application/vnd.ms-office.chartstyle+xml";
+	
 	// /xl/charts/colors1.xml
-    public final static String DRAWINGML_CHART_COLOR =
+    public final static String CHART_COLOR_STYLE =
         "application/vnd.ms-office.chartcolorstyle+xml";
 
 	// /xl/drawings/drawing1.xml
