@@ -643,7 +643,7 @@ public class LoadFromZipNG extends Load {
 
 					} catch (javax.xml.bind.UnmarshalException ue) {
 
-						log.warn("No JAXB model for this CustomXmlDataStorage part; " + ue.getMessage()  );
+						log.info("No JAXB model for this CustomXmlDataStorage part; " + ue.getMessage()  );
 
 						CustomXmlDataStorage data = getCustomXmlDataStorageClass().factory();
 						is.reset();
@@ -681,7 +681,7 @@ public class LoadFromZipNG extends Load {
 				log.error("PartUnrecognisedException shouldn't happen anymore!", e);
 				// Try to get it as a binary part
 				part = getBinaryPart(partByteArrays, ctm, resolvedPartUri);
-				log.warn("Using BinaryPart for " + resolvedPartUri);
+				log.info("Using BinaryPart for " + resolvedPartUri);
 
 				((BinaryPart)part).setBinaryData(is);
 			}
