@@ -357,7 +357,7 @@ public class SaveToZipFile {
 				// As at 1 May 2008, we don't have a Part for these;
 				// there is just the relationship.
 
-				log.warn("Encountered external resource " + r.getTarget()
+				log.info("Encountered external resource " + r.getTarget()
 						   + " of type " + r.getType() );
 
 				// So
@@ -398,7 +398,7 @@ public class SaveToZipFile {
 					}
 
 					if (!part.getPackage().equals(p)) {
-						log.warn("Part " + resolvedPartUri + " is attached to some other package");
+						log.info("Part " + resolvedPartUri + " is attached to some other package");
 					}
 
 					savePart(out, part);
