@@ -500,7 +500,7 @@ public class Load3 extends Load {
 
 					} catch (javax.xml.bind.UnmarshalException ue) {
 
-						log.warn("No JAXB model for this CustomXmlDataStorage part; " + ue.getMessage()  );
+						log.info("No JAXB model for this CustomXmlDataStorage part; " + ue.getMessage()  );
 
 						CustomXmlDataStorage data = getCustomXmlDataStorageClass().factory();
 						is.reset();
@@ -540,7 +540,7 @@ public class Load3 extends Load {
 				log.error("PartUnrecognisedException shouldn't happen anymore!", e);
 				// Try to get it as a binary part
 				part = getBinaryPart(ctm, resolvedPartUri);
-				log.warn("Using BinaryPart for " + resolvedPartUri);
+				log.info("Using BinaryPart for " + resolvedPartUri);
 
 //				is = partStore.loadPart( resolvedPartUri);
 //				((BinaryPart)part).setBinaryData(is);
