@@ -58,6 +58,8 @@ import org.docx4j.relationships.Relationships;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
+import com.openexchange.office.tools.parser.CharMatcher;
+
 
 /**
  * Save a Package object using the PartStore
@@ -77,7 +79,7 @@ public class Save {
 		PartStore targetPartStore;
 		if (p.getSourcePartStore()==null) // eg a newly created package
 		{
-			log.warn("sourcePartStore undefined");
+			log.info("sourcePartStore undefined");
 			targetPartStore = new ZipPartStore();
 		} else {
 			targetPartStore = p.getSourcePartStore();
@@ -92,7 +94,7 @@ public class Save {
 		this.p = p;
 //		sourcePartStore = p.getSourcePartStore();
 		if (p.getSourcePartStore()==null) {
-			log.warn("sourcePartStore undefined");
+			log.info("sourcePartStore undefined");
 		} else {
 			targetPartStore.setSourcePartStore(p.getSourcePartStore());
 		}
@@ -175,31 +177,12 @@ public class Save {
                 final ByteArrayOutputStream outputStream = new ByteArrayOutputStream();
                 ((org.docx4j.openpackaging.parts.JaxbXmlPart<?>)part).marshal(outputStream);
 
-                // searching and collecting each "rId
-                final HashSet<String> ids = new HashSet<String>();
+                // searching and collecting each "rId                
                 final byte[] out = outputStream.toByteArray();
                 final byte[] pattern = {'"', 'r', 'I', 'd'};
-                int index = 0;
-                do {
-                    index = indexOfBytes(out, pattern, index);
-                    if(index!=-1) {
-                        // we found a "rId
-                        index += pattern.length;
-                        int length = 0;
-                        while(index<out.length&&out[index]!='"') {
-                            length++;
-                            index++;
-                        }
-                        if(length!=0) {
-                            length += 3;
-                            ids.add(new String(out, index - length, length));
-                        }
-                    }
-                }
-                while (index!=-1);
+                final Set<String> ids = CharMatcher.findAllMatches(out, pattern, '"', 3);		
 
                 // now each rId used within our part is kept within ids
-
                 for(int i = 0; i<relationshipList.size();i++) {
                     final Relationship relShip = relationshipList.get(i);
                     if(checkRelations.contains(relShip.getType())&&!ids.contains(relShip.getId())) {
@@ -456,7 +439,7 @@ public class Save {
 				// As at 1 May 2008, we don't have a Part for these;
 				// there is just the relationship.
 
-				log.warn("Encountered external resource " + r.getTarget()
+				log.info("Encountered external resource " + r.getTarget()
 						   + " of type " + r.getType() );
 
 				// So
@@ -495,7 +478,7 @@ public class Save {
 					} else {
 
 						if (!part.getPackage().equals(p)) {
-							log.warn("Part " + resolvedPartUri + " is attached to some other package");
+							log.info("Part " + resolvedPartUri + " is attached to some other package");
 						}
 						savePart(part);
 					}
