@@ -328,7 +328,7 @@ public class WordprocessingMLPackage extends OpcPackage {
 			FontTablePart fontTablePart= this.getMainDocumentPart().getFontTablePart();
 
 			if (fontTablePart==null) {
-				log.warn("FontTable missing; creating default part.");
+				log.info("FontTable missing; creating default part.");
 				fontTablePart= new org.docx4j.openpackaging.parts.WordprocessingML.FontTablePart();
 				fontTablePart.unmarshalDefaultFonts();
 				fontTablePart.processEmbeddings();
