@@ -191,13 +191,13 @@ public final class CustomXmlDataStoragePart extends Part implements CustomXmlPar
 			Relationship r = this.getRelationshipsPart().getRelationshipByType(
 					Namespaces.CUSTOM_XML_DATA_STORAGE_PROPERTIES);
 			if (r==null) {
-				log.warn(".. but that doesn't point to a  customXmlProps part");
+				log.info(".. but that doesn't point to a  customXmlProps part");
 				return null;
 			}
 			CustomXmlDataStoragePropertiesPart customXmlProps = 
 				(CustomXmlDataStoragePropertiesPart)this.getRelationshipsPart().getPart(r);
 			if (customXmlProps==null) {
-				log.warn(".. but the target seems to be missing?");
+				log.info(".. but the target seems to be missing?");
 				return null;
 			} else {
 				return customXmlProps.getItemId().toLowerCase();
