@@ -77,7 +77,7 @@ public class Chart extends JaxbDmlPart<CTChartSpace> {
     public boolean setPartShortcut(Part part, String relationshipType) {
 
 		if (relationshipType==null) {
-			log.warn("trying to set part shortcut against a null relationship type.");
+			log.info("trying to set part shortcut against a null relationship type.");
 			return false;
 		}
 		if (relationshipType.equals(Namespaces.SPREADSHEETML_CHART_STYLE)) {
