@@ -21,7 +21,6 @@ package org.docx4j.openpackaging.parts;
 
 import javax.xml.bind.JAXBElement;
 import javax.xml.bind.JAXBException;
-import javax.xml.bind.Unmarshaller;
 import javax.xml.xpath.XPath;
 
 import org.docx4j.XmlUtils;
@@ -88,6 +87,9 @@ public class PeoplePart extends JaxbXmlPart<CTPeople> {
 		try {
 
 			setJAXBContext(jc);
+
+			log.debug("unmarshalling " + this.getClass().getName());
+
 			jaxbElement = ((JAXBElement<CTPeople>) XmlUtils.unmarshal(is, jc, new org.docx4j.jaxb.JaxbValidationEventHandler())).getValue();
 
 		} catch (Exception e ) {
