@@ -125,13 +125,13 @@ public class BinaryPart extends Part {
 
 			res = (this.bbRef != null) ? this.bbRef.get() : null;
 			if (this.getPackage()==null) {
-				log.warn("No package owns this part.");
+				log.info("No package owns this part.");
 				return null;				
 			}
 			// no cached buffer, try to load part data now			
 			PartStore partStore = this.getPackage().getSourcePartStore();
 			if (partStore==null) {
-				log.warn("No PartStore configured for this package");
+				log.info("No PartStore configured for this package");
 				return null;
 			} if (res == null) {
 				InputStream is=null;
@@ -145,7 +145,7 @@ public class BinaryPart extends Part {
 					
 					is = partStore.loadPart( name.substring(1));
 					if (is==null) {
-						log.warn(name + " missing from part store");
+						log.info(name + " missing from part store");
 					} else {
 						res = BufferUtil.readInputStream(is);
 						// Store buffer thru soft reference so it could be
