@@ -307,7 +307,7 @@ public abstract class BinaryPartAbstractImage extends BinaryPart {
         if (tmpImageFile.delete()) {
             log.debug(".. deleted " + tmpImageFile.getAbsolutePath());
 		} else {
-			log.warn("Couldn't delete tmp file " + tmpImageFile.getAbsolutePath());
+			log.info("Couldn't delete tmp file " + tmpImageFile.getAbsolutePath());
 			tmpImageFile.deleteOnExit();
 			// If that doesn't work, see "Clean Up Your Mess: Managing Temp Files in Java Apps"
 			// at devx.com
@@ -389,7 +389,7 @@ public abstract class BinaryPartAbstractImage extends BinaryPart {
 		
 		String ext = mimeToExt(mime);
 		if (mime==null || ext==null) {
-			log.warn("Null or unknown mime type; image introspection required!");
+			log.info("Null or unknown mime type; image introspection required!");
 			return createImagePart(
 					 opcPackage,
 					 sourcePart,  bytes);
@@ -530,7 +530,7 @@ public abstract class BinaryPartAbstractImage extends BinaryPart {
 				// There is no preloader for eg PDFs.
 				// (To use an image natively, we do need a preloader)
 				imagePreloaderFound = false;
-                log.warn(e.getMessage());
+                log.info(e.getMessage());
 			}
 			
             if (imagePreloaderFound
