@@ -327,7 +327,7 @@ public class MainDocumentPart extends DocumentPart<org.docx4j.wml.Document> impl
 		public void fontAction(String fontname) {
 
 			if (fontname==null) {
-				log.warn("Got null", new Throwable());
+				log.info("Got null", new Throwable());
 				return;
 			}
 
@@ -477,7 +477,7 @@ public class MainDocumentPart extends DocumentPart<org.docx4j.wml.Document> impl
 		public List<Object> apply(Object o) {
 
 			if (o instanceof org.docx4j.wml.P) {
-				pPr = ((P)o).getPPr();
+				pPr = ((P)o).getPPr(false);
 				if (stylesInUse != null) { //do the styles
 					boolean customPStyle = false;
 					if (pPr != null) {
@@ -705,12 +705,12 @@ public class MainDocumentPart extends DocumentPart<org.docx4j.wml.Document> impl
 
 	        if (styleDefinitionsPart==null) {
 
-	        	log.warn("Style definitions part was null!");
+	        	log.info("Style definitions part was null!");
 
 	        } else if (getPropertyResolver().activateStyle(styleName)) {
 	        	// Cool
 	        } else {
-	        	log.warn(styleName + " couldn't be activated!");
+	        	log.info(styleName + " couldn't be activated!");
 	        }
 
 	    }
