@@ -261,7 +261,7 @@ public final class StyleDefinitionsPart extends JaxbXmlPartXPathAware<Styles> {
 		DocDefaults docDefaults = this.getJaxbElement().getDocDefaults();
 
 		if (docDefaults == null) {
-			log.warn("No DocDefaults present");
+			log.info("No DocDefaults present");
 			// The only way this can happen is if the
 			// styles definition part is missing the docDefaults element
 			// (these are present in docs created from Word, and
@@ -280,7 +280,7 @@ public final class StyleDefinitionsPart extends JaxbXmlPartXPathAware<Styles> {
 		// Setup documentDefaultPPr
 		PPr documentDefaultPPr;
 		if (docDefaults.getPPrDefault() == null) {
-			log.warn("No PPrDefault present");
+			log.info("No PPrDefault present");
 			try {
 				documentDefaultPPr = (PPr) XmlUtils
 						.unmarshalString(pPrDefaultsString);
@@ -309,7 +309,7 @@ public final class StyleDefinitionsPart extends JaxbXmlPartXPathAware<Styles> {
 		// Setup documentDefaultRPr
 		RPr documentDefaultRPr;
 		if (docDefaults.getRPrDefault() == null) {
-			log.warn("No RPrDefault present");
+			log.info("No RPrDefault present");
 			try {
 				documentDefaultRPr = (RPr) XmlUtils
 						.unmarshalString(rPrDefaultsString);
@@ -345,7 +345,7 @@ public final class StyleDefinitionsPart extends JaxbXmlPartXPathAware<Styles> {
 		// Now point Normal at this
 		Style normal = getDefaultParagraphStyle();
 		if (normal==null) {
-			log.warn("No default paragraph style!!");
+			log.info("No default paragraph style!!");
 			normal = Context.getWmlObjectFactory().createStyle();
 			normal.setType("paragraph");
 			normal.setStyleId("Normal");
@@ -525,13 +525,13 @@ public final class StyleDefinitionsPart extends JaxbXmlPartXPathAware<Styles> {
 
 		Style rStyle = getStyleById(rStyleVal);
 		if (rStyle==null) {
-			log.warn("Couldn't find rStyle " + rStyleVal);
+			log.info("Couldn't find rStyle " + rStyleVal);
 			return null;
 		} else {
 			// We have a run level style.  Is there a linked pStyle?
 			Style.Link linkedStyle = rStyle.getLink();
 			if (linkedStyle==null) {
-				log.warn("No linked style for rStyle " + rStyleVal);
+				log.info("No linked style for rStyle " + rStyleVal);
 				return null;
 			} else {
 				String pStyleVal = linkedStyle.getVal();
@@ -539,7 +539,7 @@ public final class StyleDefinitionsPart extends JaxbXmlPartXPathAware<Styles> {
 				Style pStyle = getStyleById(pStyleVal);
 
 				if (pStyle==null) {
-					log.warn("Couldn't find linked pStyle " + pStyleVal
+					log.info("Couldn't find linked pStyle " + pStyleVal
 							+ " for rStyle " + rStyleVal);
 				}
 				return pStyle;
