@@ -311,18 +311,5 @@ public class Comments implements Child, ContentAccessor
         public void setInitials(String value) {
             this.initials = value;
         }
-
-        /**
-         * This method is invoked by the JAXB implementation on each instance when unmarshalling completes.
-         * 
-         * @param parent
-         *     The parent object in the object tree.
-         * @param unmarshaller
-         *     The unmarshaller that generated the instance.
-         */
-        public void afterUnmarshal(Unmarshaller unmarshaller, Object parent) {
-            setParent(parent);
-        }
-
     }
 }
