@@ -138,7 +138,11 @@ public class P implements Child, ContentAccessor, ISimpleFieldCollection
      *     {@link PPr }
      *     
      */
-    public PPr getPPr() {
+    public PPr getPPr(boolean forceCreate) {
+    	if(pPr==null&&forceCreate) {
+    		pPr = new PPr();
+    		pPr.setParent(this);
+    	}
         return pPr;
     }
 
