@@ -83,9 +83,9 @@ public class R implements Child, ContentAccessor
         @XmlElementRef(name = "endnoteRef", namespace = "http://schemas.openxmlformats.org/wordprocessingml/2006/main", type = JAXBElement.class),
         @XmlElementRef(name = "pgNum", namespace = "http://schemas.openxmlformats.org/wordprocessingml/2006/main", type = JAXBElement.class),
         @XmlElementRef(name = "softHyphen", namespace = "http://schemas.openxmlformats.org/wordprocessingml/2006/main", type = JAXBElement.class),
-        @XmlElementRef(name = "pict", namespace = "http://schemas.openxmlformats.org/wordprocessingml/2006/main", type = JAXBElement.class),
-        @XmlElementRef(name = "tab", namespace = "http://schemas.openxmlformats.org/wordprocessingml/2006/main", type = JAXBElement.class),
-        @XmlElementRef(name = "drawing", namespace = "http://schemas.openxmlformats.org/wordprocessingml/2006/main", type = JAXBElement.class),
+        @XmlElementRef(name = "pict", namespace = "http://schemas.openxmlformats.org/wordprocessingml/2006/main", type = Pict.class),
+        @XmlElementRef(name = "tab", namespace = "http://schemas.openxmlformats.org/wordprocessingml/2006/main", type = R.Tab.class),
+        @XmlElementRef(name = "drawing", namespace = "http://schemas.openxmlformats.org/wordprocessingml/2006/main", type = Drawing.class),
         @XmlElementRef(name = "br", namespace = "http://schemas.openxmlformats.org/wordprocessingml/2006/main", type = Br.class),
         @XmlElementRef(name = "separator", namespace = "http://schemas.openxmlformats.org/wordprocessingml/2006/main", type = JAXBElement.class),
         @XmlElementRef(name = "lastRenderedPageBreak", namespace = "http://schemas.openxmlformats.org/wordprocessingml/2006/main", type = JAXBElement.class),
@@ -101,9 +101,9 @@ public class R implements Child, ContentAccessor
         @XmlElementRef(name = "annotationRef", namespace = "http://schemas.openxmlformats.org/wordprocessingml/2006/main", type = JAXBElement.class),
         @XmlElementRef(name = "cr", namespace = "http://schemas.openxmlformats.org/wordprocessingml/2006/main", type = JAXBElement.class),
         @XmlElementRef(name = "yearShort", namespace = "http://schemas.openxmlformats.org/wordprocessingml/2006/main", type = JAXBElement.class),
-        @XmlElementRef(name = "fldChar", namespace = "http://schemas.openxmlformats.org/wordprocessingml/2006/main", type = JAXBElement.class),
+        @XmlElementRef(name = "fldChar", namespace = "http://schemas.openxmlformats.org/wordprocessingml/2006/main", type = FldChar.class),
         @XmlElementRef(name = "sym", namespace = "http://schemas.openxmlformats.org/wordprocessingml/2006/main", type = JAXBElement.class),
-        @XmlElementRef(name = "commentReference", namespace = "http://schemas.openxmlformats.org/wordprocessingml/2006/main", type = JAXBElement.class),
+        @XmlElementRef(name = "commentReference", namespace = "http://schemas.openxmlformats.org/wordprocessingml/2006/main", type = R.CommentReference.class),
         @XmlElementRef(name = "delInstrText", namespace = "http://schemas.openxmlformats.org/wordprocessingml/2006/main", type = JAXBElement.class),
         @XmlElementRef(name = "footnoteRef", namespace = "http://schemas.openxmlformats.org/wordprocessingml/2006/main", type = JAXBElement.class),
         @XmlElementRef(name = "dayLong", namespace = "http://schemas.openxmlformats.org/wordprocessingml/2006/main", type = JAXBElement.class),
@@ -169,9 +169,9 @@ public class R implements Child, ContentAccessor
      * {@link JAXBElement }{@code <}{@link R.EndnoteRef }{@code >}
      * {@link JAXBElement }{@code <}{@link R.PgNum }{@code >}
      * {@link JAXBElement }{@code <}{@link R.SoftHyphen }{@code >}
-     * {@link JAXBElement }{@code <}{@link Pict }{@code >}
-     * {@link JAXBElement }{@code <}{@link R.Tab }{@code >}
-     * {@link JAXBElement }{@code <}{@link Drawing }{@code >}
+     * {@link Pict }
+     * {@link R.Tab }
+     * {@link Drawing }
      * {@link Br }
      * {@link JAXBElement }{@code <}{@link R.Separator }{@code >}
      * {@link JAXBElement }{@code <}{@link R.LastRenderedPageBreak }{@code >}
@@ -187,9 +187,9 @@ public class R implements Child, ContentAccessor
      * {@link JAXBElement }{@code <}{@link R.AnnotationRef }{@code >}
      * {@link JAXBElement }{@code <}{@link R.Cr }{@code >}
      * {@link JAXBElement }{@code <}{@link R.YearShort }{@code >}
-     * {@link JAXBElement }{@code <}{@link FldChar }{@code >}
+     * {@link FldChar }
      * {@link JAXBElement }{@code <}{@link R.Sym }{@code >}
-     * {@link JAXBElement }{@code <}{@link R.CommentReference }{@code >}
+     * {@link R.CommentReference }
      * {@link JAXBElement }{@code <}{@link Text }{@code >}
      * {@link JAXBElement }{@code <}{@link R.FootnoteRef }{@code >}
      * {@link DelText }
