@@ -23,9 +23,6 @@ package org.docx4j.wml;
 
 import org.jvnet.jaxb2_commons.ppp.Child;
 
-import java.util.ArrayList;
-import java.util.List;
-
 import javax.xml.bind.JAXBElement;
 import javax.xml.bind.Unmarshaller;
 import javax.xml.bind.annotation.XmlAccessType;
