@@ -87,7 +87,7 @@ public final class SlideLayoutPart extends JaxbPmlPart<SldLayout> implements Con
 		Relationship masterRel = getRelationshipsPart().getRelationshipByType(
 				Namespaces.PRESENTATIONML_SLIDE_MASTER);
 		if (masterRel==null) {
-			log.warn(this.partName.getName() + " has no master!");
+			log.info(this.partName.getName() + " has no master!");
 		} else {
 			master = (SlideMasterPart)getRelationshipsPart().getPart(masterRel);
 		}
