@@ -120,9 +120,9 @@ public final class SlideMasterPart extends JaxbPmlPart<SldMaster> implements Con
 		
 		entry.setId( new Long(this.getSlideLayoutOrMasterId()) );
 		entry.setRid(rel.getId());
-		
-		this.getJaxbElement().getSldLayoutIdLst().getSldLayoutId().add(entry);
-		
+
+		this.getJaxbElement().getSldLayoutIdLst(true).getSldLayoutId().add(entry);
+
 		return entry;
 	}
 	
