@@ -328,7 +328,7 @@ public final class SlidePart extends JaxbPmlPart<Sld> implements ContentAccessor
 		// will not necessary correspond to the info in the rel!
 		
 		if (relationshipType==null) {
-			log.warn("trying to set part shortcut against a null relationship type.");
+			log.info("trying to set part shortcut against a null relationship type.");
 			return false;
 		}
 		
