@@ -5,7 +5,6 @@ import java.io.ByteArrayOutputStream;
 import javax.xml.bind.JAXBContext;
 import javax.xml.bind.JAXBElement;
 import javax.xml.bind.JAXBException;
-import javax.xml.parsers.DocumentBuilderFactory;
 import javax.xml.parsers.ParserConfigurationException;
 import javax.xml.transform.Result;
 import javax.xml.transform.Source;
@@ -510,9 +509,9 @@ public class SvgExporter {
     public static Document CxnSpToSVG(CxnSp cxnSp) {
     	
     	// Geometrical transforms
-    	CTTransform2D xfrm = cxnSp.getSpPr().getXfrm();
-    	Box b = new Box(xfrm.getOff().getX(), xfrm.getOff().getY(),
-    			xfrm.getExt().getCx(), xfrm.getExt().getCy() );
+    	CTTransform2D xfrm = cxnSp.getSpPr().getXfrm(true);
+    	Box b = new Box(xfrm.getOff(true).getX(), xfrm.getOff(true).getY(),
+    			xfrm.getExt(true).getCx(), xfrm.getExt(true).getCy() );
     	
     	if (xfrm.getRot()!=0) {
     		b.rotate(xfrm.getRot());
