@@ -152,7 +152,7 @@ public class ResolvedLayout implements Cloneable {
 		Relationship rel = slidePart.getRelationshipsPart().getRelationshipByType(
 				Namespaces.PRESENTATIONML_SLIDE_LAYOUT);
 		if (rel==null) {
-			log.warn(slidePart.partName.getName() + " has no explicit layout!");
+			log.info(slidePart.partName.getName() + " has no explicit layout!");
 			// This happens at least some of the time.
 			// eg for title slide 
 			// That case is ok, since CTR_TITLE and SUB_TITLE only occur
@@ -241,11 +241,7 @@ public class ResolvedLayout implements Cloneable {
 	}
 
 	private static void handleSpPr(CTShapeProperties sp, CTShapeProperties layoutShape) {
-		
-		// a:xrm
-		if (sp.getXfrm()==null && layoutShape.getXfrm()!=null) {
-			sp.setXfrm( XmlUtils.deepCopy(layoutShape.getXfrm(), Context.jcPML ));
-		}
+
 	}
 	
 	private static void handleTxBody(CTTextBody sp, CTTextBody layoutShape) {
@@ -253,7 +249,7 @@ public class ResolvedLayout implements Cloneable {
 		// a slide layout p:sp/p:txBody can override, with a <a:lstStyle> element
 		// so copy a:lstStyle over
 		if (sp.getLstStyle()!=null) {
-			log.warn("Slide shape contains lstStyle! (Not expected at that level)");
+			log.info("Slide shape contains lstStyle! (Not expected at that level)");
 			log.debug(XmlUtils.marshaltoString(sp.getLstStyle(), false, true, Context.jcPML,
 					"FIXME", "lstStyle", CTTextListStyle.class));
 		}		
