@@ -29,13 +29,15 @@ import javax.xml.bind.annotation.XmlType;
 
 import org.docx4j.IndexedNodeList;
 import org.docx4j.dml.CTGroupShapeProperties;
+import org.docx4j.dml.CTGroupTransform2D;
 import org.docx4j.dml.CTNonVisualDrawingProps;
 import org.docx4j.dml.CTNonVisualGroupDrawingShapeProps;
+import org.docx4j.dml.CTTransform2D;
 import org.docx4j.dml.IGroupShape;
+import org.docx4j.dml.ITransform2DAccessor;
 import org.docx4j.wml.ContentAccessor;
 import org.jvnet.jaxb2_commons.ppp.Child;
 
-
 /**
  * <p>Java class for CT_GroupShape complex type.
  * 
@@ -84,7 +86,7 @@ import org.jvnet.jaxb2_commons.ppp.Child;
     "content",
     "extLst"
 })
-public class GroupShape implements Child, IGroupShape, ContentAccessor {
+public class GroupShape implements Child, ITransform2DAccessor, IGroupShape, ContentAccessor {
 
     @XmlElement(required = true)
     protected GroupShape.NvGrpSpPr nvGrpSpPr;
@@ -103,6 +105,10 @@ public class GroupShape implements Child, IGroupShape, ContentAccessor {
     @XmlTransient
     private Object parent;
 
+    public CTGroupTransform2D getXfrm(boolean forceCreate) {
+    	return grpSpPr.getXfrm(forceCreate);
+    }
+
     /**
      * Gets the value of the nvGrpSpPr property.
      * 
@@ -321,47 +327,33 @@ public class GroupShape implements Child, IGroupShape, ContentAccessor {
     }
 
 	@Override
-	public CTNonVisualDrawingProps getCNvPr() {
+	public CTNonVisualDrawingProps getNonVisualDrawingProperties(boolean createIfMissing) {
+		if(nvGrpSpPr==null&&createIfMissing) {
+			nvGrpSpPr = new NvGrpSpPr();
+		}
 		if(nvGrpSpPr!=null) {
+			if(nvGrpSpPr.getCNvPr()==null&&createIfMissing) {
+				nvGrpSpPr.setCNvPr(new CTNonVisualDrawingProps());
+			}
 			return nvGrpSpPr.getCNvPr();
 		}
 		return null;
 	}
 
 	@Override
-	public void setCNvPr(CTNonVisualDrawingProps value) {
-		if(nvGrpSpPr==null) {
-			if(value!=null) {
-				nvGrpSpPr = new NvGrpSpPr();
-				nvGrpSpPr.setCNvPr(value);
-			}
+	public CTNonVisualGroupDrawingShapeProps getNonVisualDrawingShapeProperties(boolean createIfMissing) {
+		if(nvGrpSpPr==null&&createIfMissing) {
+			nvGrpSpPr = new NvGrpSpPr();
 		}
-		else {
-			nvGrpSpPr.setCNvPr(value);
-		}
-	}
-
-	@Override
-	public CTNonVisualGroupDrawingShapeProps getCNvGrpSpPr() {
 		if(nvGrpSpPr!=null) {
+			if(nvGrpSpPr.getCNvGrpSpPr()==null&&createIfMissing) {
+				nvGrpSpPr.setCNvGrpSpPr(new CTNonVisualGroupDrawingShapeProps());
+			}
 			return nvGrpSpPr.getCNvGrpSpPr();
 		}
 		return null;
 	}
 
-	@Override
-	public void setCNvGrpSpPr(CTNonVisualGroupDrawingShapeProps value) {
-		if(nvGrpSpPr==null) {
-			if(value!=null) {
-				nvGrpSpPr = new NvGrpSpPr();
-				nvGrpSpPr.setCNvGrpSpPr(value);;
-			}
-		}
-		else {
-			nvGrpSpPr.setCNvGrpSpPr(value);
-		}
-	}
-
 	/**
      * Gets the parent object in the object tree representing the unmarshalled xml document.
      * 
