@@ -31,10 +31,11 @@ import org.docx4j.dml.CTNonVisualDrawingProps;
 import org.docx4j.dml.CTNonVisualPictureProperties;
 import org.docx4j.dml.CTShapeProperties;
 import org.docx4j.dml.CTShapeStyle;
+import org.docx4j.dml.CTTransform2D;
 import org.docx4j.dml.IPicture;
+import org.docx4j.dml.ITransform2DAccessor;
 import org.jvnet.jaxb2_commons.ppp.Child;
 
-
 /**
  * <p>Java class for CT_Picture complex type.
  * 
@@ -78,7 +79,7 @@ import org.jvnet.jaxb2_commons.ppp.Child;
     "style",
     "extLst"
 })
-public class Pic implements Child, IPicture {
+public class Pic implements Child, ITransform2DAccessor, IPicture {
 
     @XmlElement(required = true)
     protected Pic.NvPicPr nvPicPr;
@@ -91,6 +92,18 @@ public class Pic implements Child, IPicture {
     @XmlTransient
     private Object parent;
 
+    /**
+     * Gets the value of the xfrm property.
+     *
+     * @return
+     *     possible object is
+     *     {@link CTTransform2D }
+     *
+     */
+    public CTTransform2D getXfrm(boolean forceCreate) {
+    	return spPr.getXfrm(forceCreate);
+    }
+
     /**
      * Gets the value of the nvPicPr property.
      * 
@@ -322,48 +335,34 @@ public class Pic implements Child, IPicture {
 
     }
 
-    @Override
-	public CTNonVisualDrawingProps getCNvPr() {
+	@Override
+	public CTNonVisualDrawingProps getNonVisualDrawingProperties(boolean createIfMissing) {
+		if(nvPicPr==null&&createIfMissing) {
+			nvPicPr = new NvPicPr();
+		}
 		if(nvPicPr!=null) {
+			if(nvPicPr.getCNvPr()==null&&createIfMissing) {
+				nvPicPr.setCNvPr(new CTNonVisualDrawingProps());
+			}
 			return nvPicPr.getCNvPr();
 		}
 		return null;
 	}
 
-    @Override
-	public void setCNvPr(CTNonVisualDrawingProps value) {
-		if(nvPicPr==null) {
-			if(value!=null) {
-				nvPicPr = new NvPicPr();
-				nvPicPr.setCNvPr(value);
-			}
+	@Override
+	public CTNonVisualPictureProperties getNonVisualDrawingShapeProperties(boolean createIfMissing) {
+		if(nvPicPr==null&&createIfMissing) {
+			nvPicPr = new NvPicPr();
 		}
-		else {
-			nvPicPr.setCNvPr(value);
-		}
-	}
-
-    @Override
-	public CTNonVisualPictureProperties getCNvPicPr() {
 		if(nvPicPr!=null) {
+			if(nvPicPr.getCNvPicPr()==null&&createIfMissing) {
+				nvPicPr.setCNvPicPr(new CTNonVisualPictureProperties());
+			}
 			return nvPicPr.getCNvPicPr();
 		}
 		return null;
 	}
 
-    @Override
-	public void setCNvPicPr(CTNonVisualPictureProperties value) {
-		if(nvPicPr==null) {
-			if(value!=null) {
-				nvPicPr = new NvPicPr();
-				nvPicPr.setCNvPicPr(value);
-			}
-		}
-		else {
-			nvPicPr.setCNvPicPr(value);
-		}
-	}
-
     /**
      * Gets the parent object in the object tree representing the unmarshalled xml document.
      * 
