@@ -37,13 +37,14 @@ import org.docx4j.dml.CTShapeProperties;
 import org.docx4j.dml.CTShapeStyle;
 import org.docx4j.dml.CTTextBody;
 import org.docx4j.dml.CTTextBodyProperties;
+import org.docx4j.dml.CTTransform2D;
 import org.docx4j.dml.IShape;
+import org.docx4j.dml.ITransform2DAccessor;
 import org.docx4j.dml.ObjectFactory;
 import org.docx4j.jaxb.Context;
 import org.docx4j.wml.ContentAccessor;
 import org.jvnet.jaxb2_commons.ppp.Child;
 
-
 /**
  * <p>Java class for CT_Shape complex type.
  * 
@@ -89,7 +90,7 @@ import org.jvnet.jaxb2_commons.ppp.Child;
     "extLst"
 })
 @XmlRootElement(name="sp")
-public class Shape implements Child, IShape, ContentAccessor {
+public class Shape implements Child, ITransform2DAccessor, IShape, ContentAccessor {
 
     @XmlElement(required = true)
     protected Shape.NvSpPr nvSpPr;
@@ -103,6 +104,10 @@ public class Shape implements Child, IShape, ContentAccessor {
     @XmlTransient
     private Object parent;
 
+    public CTTransform2D getXfrm(boolean forceCreate) {
+    	return spPr.getXfrm(forceCreate);
+    }
+
     /**
      * Gets the value of the nvSpPr property.
      * 
@@ -361,48 +366,34 @@ public class Shape implements Child, IShape, ContentAccessor {
         }
     }
 
-    @Override
-	public CTNonVisualDrawingProps getCNvPr() {
+	@Override
+	public CTNonVisualDrawingProps getNonVisualDrawingProperties(boolean createIfMissing) {
+		if(nvSpPr==null&&createIfMissing) {
+			nvSpPr = new NvSpPr();
+		}
 		if(nvSpPr!=null) {
+			if(nvSpPr.getCNvPr()==null&&createIfMissing) {
+				nvSpPr.setCNvPr(new CTNonVisualDrawingProps());
+			}
 			return nvSpPr.getCNvPr();
 		}
 		return null;
 	}
 
-    @Override
-	public void setCNvPr(CTNonVisualDrawingProps value) {
-		if(nvSpPr==null) {
-			if(value!=null) {
-				nvSpPr = new NvSpPr();
-				nvSpPr.setCNvPr(value);
-			}
+	@Override
+	public CTNonVisualDrawingShapeProps getNonVisualDrawingShapeProperties(boolean createIfMissing) {
+		if(nvSpPr==null&&createIfMissing) {
+			nvSpPr = new NvSpPr();
 		}
-		else {
-			nvSpPr.setCNvPr(value);
-		}
-	}
-
-    @Override
-	public CTNonVisualDrawingShapeProps getCNvSpPr() {
 		if(nvSpPr!=null) {
+			if(nvSpPr.getCNvSpPr()==null&&createIfMissing) {
+				nvSpPr.setCNvSpPr(new CTNonVisualDrawingShapeProps());
+			}
 			return nvSpPr.getCNvSpPr();
 		}
 		return null;
 	}
 
-    @Override
-	public void setCNvSpPr(CTNonVisualDrawingShapeProps value) {
-		if(nvSpPr==null) {
-			if(value!=null) {
-				nvSpPr = new NvSpPr();
-				nvSpPr.setCNvSpPr(value);
-			}
-		}
-		else {
-			nvSpPr.setCNvSpPr(value);
-		}
-	}
-
     @Override
 	public List<Object> getContent() {
     	if(txBody==null) {
@@ -468,10 +459,9 @@ public class Shape implements Child, IShape, ContentAccessor {
 			final CTTextBodyProperties txBodyPr = Context.getDmlObjectFactory().createCTTextBodyProperties();
 			txBody.setBodyPr(txBodyPr);
 		}
-		return null;
+		return txBody!=null ? txBody.getBodyPr() : null;
 	}
 
-	@Override
 	public void setTextBody(CTTextBodyProperties textBodyProperties) {
 		if(txBody==null) {
 			txBody = Context.getDmlObjectFactory().createCTTextBody();
