@@ -50,7 +50,9 @@ public class Context {
 
             			jcSML = JAXBContext.newInstance("org.xlsx4j.sml:" +
             					"org.xlsx4j.schemas.microsoft.com.office.excel_2006.main:" +
-            					"org.xlsx4j.schemas.microsoft.com.office.excel_2008_2.main",classLoader );
+            					"org.xlsx4j.schemas.microsoft.com.office.excel_2008_2.main:" +
+            					"org.xlsx4j.schemas.microsoft.com.office.spreadsheetml_2009_9.main:" +
+            					"org.xlsx4j.schemas.microsoft.com.office.spreadsheetml_2010_11.main" ,classLoader );
 
             			if (jcSML.getClass().getName().equals("org.eclipse.persistence.jaxb.JAXBContext")) {
             				log.debug("MOXy JAXB implementation is in use!");
