@@ -21,10 +21,13 @@ package org.xlsx4j.sml;
 
 import java.util.ArrayList;
 import java.util.List;
+
+import javax.xml.bind.Unmarshaller;
 import javax.xml.bind.annotation.XmlAccessType;
 import javax.xml.bind.annotation.XmlAccessorType;
 import javax.xml.bind.annotation.XmlAttribute;
 import javax.xml.bind.annotation.XmlElement;
+import javax.xml.bind.annotation.XmlTransient;
 import javax.xml.bind.annotation.XmlType;
 
 /**
@@ -54,9 +57,8 @@ import javax.xml.bind.annotation.XmlType;
     "cfRule",
     "extLst"
 })
-public class CTConditionalFormatting
+public class CTConditionalFormatting implements IConditionalFormatting
 {
-
     @XmlElement(required = true)
     protected List<CTCfRule> cfRule;
     protected CTExtensionList extLst;
@@ -64,6 +66,8 @@ public class CTConditionalFormatting
     protected Boolean pivot;
     @XmlAttribute(name = "sqref")
     protected List<String> sqref;
+    @XmlTransient
+    private Object parent;
 
     /**
      * Gets the value of the cfRule property.
@@ -94,6 +98,10 @@ public class CTConditionalFormatting
         return this.cfRule;
     }
 
+    public CTCfRule createCfRule() {
+    	return new CTCfRule();
+    }
+
     /**
      * Gets the value of the extLst property.
      * 
@@ -168,10 +176,42 @@ public class CTConditionalFormatting
      * 
      * 
      */
-    public List<String> getSqref() {
+    public List<String> getSqrefList() {
         if (sqref == null) {
             sqref = new ArrayList<String>();
         }
         return this.sqref;
     }
+
+    public void setSqrefList(List<String> sqref) {
+    	this.sqref = sqref;
+    }
+
+    /**
+     * Gets the parent object in the object tree representing the unmarshalled xml document.
+     *
+     * @return
+     *     The parent object.
+     */
+    @Override
+    public Object getParent() {
+        return this.parent;
+    }
+
+    @Override
+    public void setParent(Object parent) {
+        this.parent = parent;
+    }
+
+    /**
+     * This method is invoked by the JAXB implementation on each instance when unmarshalling completes.
+     *
+     * @param parent
+     *     The parent object in the object tree.
+     * @param unmarshaller
+     *     The unmarshaller that generated the instance.
+     */
+    public void afterUnmarshal(Unmarshaller unmarshaller, Object parent) {
+        setParent(parent);
+    }
 }
