@@ -64,7 +64,9 @@ public class CTExtension
 {
     @XmlAnyElement(lax = true)
     @XmlElementRefs({
-    	@XmlElementRef(name="dataValidations", namespace="http://schemas.microsoft.com/office/spreadsheetml/2009/9/main", type=JAXBElement.class)
+    	@XmlElementRef(name="dataValidations", namespace="http://schemas.microsoft.com/office/spreadsheetml/2009/9/main", type=JAXBElement.class),
+    	@XmlElementRef(name="conditionalFormattings", namespace="http://schemas.microsoft.com/office/spreadsheetml/2009/9/main", type=JAXBElement.class),
+    	@XmlElementRef(name="id", namespace="http://schemas.microsoft.com/office/spreadsheetml/2009/9/main", type=JAXBElement.class)
     })
     protected Object any;
     @XmlAttribute(name = "uri")
