@@ -98,7 +98,7 @@ public class CTFonts
      */
     public int getOrApply(CTFont ctFont) {
         if(fontHelper==null) {
-            fontHelper = new JAXBListHelper<CTFont>(this.font, Context.jcSML);
+            fontHelper = new JAXBListHelper<CTFont>(getFont(), Context.jcSML);
         }
         return fontHelper.getOrApply(ctFont);
     }
