@@ -20,11 +20,12 @@
 package org.xlsx4j.sml;
 
 import java.util.List;
+import java.util.Map;
+
 import javax.xml.bind.annotation.XmlAccessType;
 import javax.xml.bind.annotation.XmlAccessorType;
 import javax.xml.bind.annotation.XmlRootElement;
 import javax.xml.bind.annotation.XmlType;
-import org.xlsx4j.jaxb.Context;
 
 /**
  * <p>Java class for CT_Stylesheet complex type.
@@ -84,6 +85,16 @@ public class CTStylesheet
     protected CTColors colors;
     protected CTExtensionList extLst;
 
+    /**
+     * Returns the list of all number format codes.
+     */
+    public CTNumFmts getNumberFormats(boolean forceCreate) {
+    	if (forceCreate && numFmts==null) {
+    		numFmts = new CTNumFmts();
+    	}
+        return numFmts;
+    }
+
     /**
      * Returns the CTNumFmt by Id, if the Id matches a predefined
      * numberFormat then null might be returned.
@@ -100,62 +111,19 @@ public class CTStylesheet
         return null;
     }
 
-    public CTNumFmt getNumberFormatByFormatCode(String formatCode) {
-        if(numFmts!=null) {
-            final List<CTNumFmt> numFmtList = numFmts.getNumFmt();
-            for (CTNumFmt numFmt:numFmtList) {
-                if(formatCode.equals(numFmt.getFormatCode())) {
-                    return numFmt;
-                }
-            }
-
-        }
-        return null;
+    public void insertNumberFormat(long formatId, String formatCode) {
+    	getNumberFormats(true).insertNumberFormat(formatId, formatCode);
     }
 
-    public void applyNumberFormat(CTNumFmt numFmt) {
-        if(numFmts==null) {
-            numFmts = Context.getsmlObjectFactory().createCTNumFmts();
-        }
-        int i = 0;
-        final List<CTNumFmt> numFmtList = numFmts.getNumFmt();
-        while(i<numFmtList.size()) {
-            long id = numFmtList.get(i).getNumFmtId();
-            if(id==numFmt.getNumFmtId()) {
-                numFmtList.set(i, numFmt);
-                return;
-            }
-            else if(id>numFmt.getNumFmtId()) {
-                numFmtList.add(i, numFmt);
-                return;
-            }
-            i++;
-        }
-        numFmtList.add(numFmt);
+    public void insertNumberFormats(Map<Long, String> formatCodes) {
+    	CTNumFmts numFmts = getNumberFormats(true);
+    	for (Map.Entry<Long, String> entry : formatCodes.entrySet()) {
+    		numFmts.insertNumberFormat(entry.getKey(), entry.getValue());
+		}
     }
 
-    public CTNumFmt getOrApplyNumberFormatByFormatCode(String formatCode) {
-
-        CTNumFmt numFmt = getNumberFormatByFormatCode(formatCode);
-        if(numFmt!=null) {
-            return numFmt;
-        }
-        if(numFmts==null) {
-            numFmts = Context.getsmlObjectFactory().createCTNumFmts();
-        }
-        long newNumberFormatId = 164;
-        List<CTNumFmt> numFmtList = numFmts.getNumFmt();
-        if(numFmtList.size()>0) {
-            long lastFormatId = numFmtList.get(numFmtList.size()-1).getNumFmtId();
-            if(lastFormatId>=newNumberFormatId) {
-                newNumberFormatId = lastFormatId + 1;
-            }
-        }
-        numFmt = Context.getsmlObjectFactory().createCTNumFmt();
-        numFmt.setNumFmtId(newNumberFormatId);
-        numFmt.setFormatCode(formatCode);
-        numFmtList.add(numFmt);
-        return numFmt;
+    public void deleteNumberFormat(long formatId) {
+    	if (numFmts != null) { numFmts.deleteNumberFormat(formatId); }
     }
 
     /**
