@@ -50,6 +50,7 @@
 package org.xlsx4j.sml;
 
 import java.util.ArrayList;
+import java.util.Arrays;
 import java.util.List;
 import java.util.zip.CRC32;
 import javax.xml.bind.JAXBContext;
@@ -67,34 +68,34 @@ public class JAXBListHelper<T> {
         this.jc = jc;
     }
 
-    private static int getHash(String data) {
+    private static int getHash(byte[] data) {
         final CRC32 crc32 = new CRC32();
-        crc32.update(data.getBytes());
+        crc32.update(data);
         return (int)crc32.getValue() | 1;
     }
 
     public int getOrApply(T t) {
 
-        final String sourceData = XmlUtils.marshaltoString(t, true, jc);
+        final byte[] sourceData = XmlUtils.marshalToByteArray(t, true, jc);
         final int sourceHash = getHash(sourceData);
 
         int i;
         for(i = 0; i<values.size();i++) {
 
-            String destData = null;
+            byte[] destData = null;
             T dest = values.get(i);
 
             // creating hash
             if(i>=hashedValues.size()) {
-                destData = XmlUtils.marshaltoString(dest, true, jc);
+                destData = XmlUtils.marshalToByteArray(dest, true, jc);
                 hashedValues.add(getHash(destData));
             }
             if(sourceHash==hashedValues.get(i)) {
                 // hash found... now check for identity
                 if(destData==null) {
-                    destData = XmlUtils.marshaltoString(dest, true, jc);
+                    destData = XmlUtils.marshalToByteArray(dest, true, jc);
                 }
-                if(sourceData.equals(destData)) {
+                if(Arrays.equals(sourceData, destData)) {
                     return i;
                 }
             }
