@@ -342,7 +342,10 @@ public class Workbook
      *     {@link CTCalcPr }
      *     
      */
-    public CTCalcPr getCalcPr() {
+    public CTCalcPr getCalcPr(boolean forceCreate) {
+    	if (forceCreate && calcPr==null) {
+    		calcPr = new CTCalcPr();
+    	}
         return calcPr;
     }
 
