@@ -20,14 +20,26 @@
 package org.xlsx4j.sml;
 
 import java.util.ArrayList;
+import java.util.HashMap;
+import java.util.HashSet;
+import java.util.Iterator;
 import java.util.List;
+import java.util.Map;
+import java.util.UUID;
 
+import javax.xml.bind.JAXBElement;
+import javax.xml.bind.Marshaller;
+import javax.xml.bind.Unmarshaller;
 import javax.xml.bind.annotation.XmlAccessType;
 import javax.xml.bind.annotation.XmlAccessorType;
 import javax.xml.bind.annotation.XmlElement;
 import javax.xml.bind.annotation.XmlRootElement;
+import javax.xml.bind.annotation.XmlTransient;
 import javax.xml.bind.annotation.XmlType;
 
+import org.apache.commons.lang.mutable.MutableInt;
+import org.xlsx4j.sml.CfRule.CfRuleIter;
+
 
 /**
  * <p>Java class for CT_Worksheet complex type.
@@ -171,6 +183,8 @@ public class Worksheet
     protected CTWebPublishItems webPublishItems;
     protected CTTableParts tableParts;
     protected CTExtensionList extLst;
+    @XmlTransient
+    private HashMap<String, CfRule> conditionalFormattingRules = null;
 
     /**
      * Gets the value of the sheetPr property.
@@ -561,35 +575,6 @@ public class Worksheet
         this.phoneticPr = value;
     }
 
-    /**
-     * Gets the value of the conditionalFormatting property.
-     * 
-     * <p>
-     * This accessor method returns a reference to the live list,
-     * not a snapshot. Therefore any modification you make to the
-     * returned list will be present inside the JAXB object.
-     * This is why there is not a <CODE>set</CODE> method for the conditionalFormatting property.
-     * 
-     * <p>
-     * For example, to add a new item, do as follows:
-     * <pre>
-     *    getConditionalFormatting().add(newItem);
-     * </pre>
-     * 
-     * 
-     * <p>
-     * Objects of the following type(s) are allowed in the list
-     * {@link CTConditionalFormatting }
-     * 
-     * 
-     */
-    public List<CTConditionalFormatting> getConditionalFormatting() {
-        if (conditionalFormatting == null) {
-            conditionalFormatting = new ArrayList<CTConditionalFormatting>();
-        }
-        return this.conditionalFormatting;
-    }
-
     /**
      * Gets the value of the dataValidations property.
      * 
@@ -1102,8 +1087,11 @@ public class Worksheet
      *     {@link CTExtensionList }
      *     
      */
-    public CTExtensionList getExtLst() {
-        return extLst;
+    public CTExtensionList getExtLst(boolean forceCreate) {
+    	if(extLst==null&&forceCreate) {
+    		extLst = new CTExtensionList();
+    	}
+    	return extLst;
     }
 
     /**
@@ -1117,4 +1105,218 @@ public class Worksheet
     public void setExtLst(CTExtensionList value) {
         this.extLst = value;
     }
+
+    public HashMap<String, CfRule> getConditionalFormattingRules() {
+    	if(conditionalFormattingRules==null) {
+    		conditionalFormattingRules = new HashMap<String, CfRule>();
+    	}
+    	return conditionalFormattingRules;
+    }
+
+    public void beforeMarshal(Marshaller marshaller) {
+
+    	// deleting conditional formatting elements, they will newly be constructed
+    	conditionalFormatting = null;
+		final CTExtensionList lst = getExtLst(false);
+		if(lst!=null) {
+			final CTExtension ext = lst.getExtensionByUri("{78C0D931-6437-407d-A8EE-F0AAD7539E65}", false);
+			if(ext!=null) {
+				lst.getExt().remove(ext);
+			}
+		}
+
+    	// filling the cfMap, key is now the range
+		final Map<String, List<CfRule>> cfMap = new HashMap<String, List<CfRule>>();
+    	final Iterator<CfRule> conditionalFormattingRuleIter = getConditionalFormattingRules().values().iterator();
+    	while(conditionalFormattingRuleIter.hasNext()) {
+    		final CfRule cfRule = conditionalFormattingRuleIter.next();
+    		final String ranges = cfRule.getRanges().toString();
+    		List<CfRule> cfRuleList = cfMap.get(ranges);
+    		if(cfRuleList==null) {
+    			cfRuleList = new ArrayList<CfRule>();
+    			cfMap.put(ranges, cfRuleList);
+    		}
+    		cfRuleList.add(cfRule);
+    	}
+
+    	// now creating and filling the conditonalFormatting container
+    	final Iterator<List<CfRule>> rulesIter = cfMap.values().iterator();
+    	org.xlsx4j.schemas.microsoft.com.office.spreadsheetml_2009_9.main.CTConditionalFormattings cf2 = null;
+
+    	while(rulesIter.hasNext()) {
+    		final List<CfRule> rules = rulesIter.next();
+    		CTConditionalFormatting lst1 = null;
+    		org.xlsx4j.schemas.microsoft.com.office.spreadsheetml_2009_9.main.CTConditionalFormatting lst2 = null;
+    		for(CfRule cfRule:rules) {
+    			final CfRuleIter ruleIter = cfRule.iterator();
+    			while(ruleIter.hasNext()) {
+    				final ICfRule iCfRule = ruleIter.next();
+    				if(iCfRule instanceof CTCfRule) {
+    					final CTCfRule ctCfRule = (CTCfRule)iCfRule;
+    					if(conditionalFormatting==null) {
+    						conditionalFormatting = new ArrayList<CTConditionalFormatting>();
+    					}
+    					if(lst1==null) {
+    						lst1 = new CTConditionalFormatting();
+    						conditionalFormatting.add(lst1);
+    						lst1.setSqrefList(cfRule.getRanges());
+    					}
+    					lst1.getCfRule().add(ctCfRule);
+    				}
+    				else if(iCfRule instanceof org.xlsx4j.schemas.microsoft.com.office.spreadsheetml_2009_9.main.CTCfRule) {
+    					final org.xlsx4j.schemas.microsoft.com.office.spreadsheetml_2009_9.main.CTCfRule ctCfRule
+    						= (org.xlsx4j.schemas.microsoft.com.office.spreadsheetml_2009_9.main.CTCfRule)iCfRule;
+    					if(cf2==null) {
+        		    		final CTExtension ext = getExtLst(true).getExtensionByUri("{78C0D931-6437-407d-A8EE-F0AAD7539E65}", true);
+        		    		cf2 = new org.xlsx4j.schemas.microsoft.com.office.spreadsheetml_2009_9.main.CTConditionalFormattings();
+        		    		ext.setAny(new org.xlsx4j.schemas.microsoft.com.office.spreadsheetml_2009_9.main.ObjectFactory().createConditionalFormattings(cf2));
+    					}
+    					if(lst2==null) {
+    						lst2 = new org.xlsx4j.schemas.microsoft.com.office.spreadsheetml_2009_9.main.CTConditionalFormatting();
+    						cf2.getConditionalFormatting().add(lst2);
+    						lst2.setSqrefList(cfRule.getRanges());
+    					}
+    					lst2.getCfRule().add(ctCfRule);
+    				}
+    			}
+    		}
+    	}
+
+    	// check if there are no extensions, then we have to remove this element
+    	if(extLst!=null) {
+    		if(extLst.getExt().isEmpty()) {
+    			extLst = null;
+    		}
+    	}
+    }
+
+    /*
+     * Bringing together conditonalFormatting and extLst->conditionalFormatting,
+     * Only rules will be available then via getConditionalFormattingRules()
+     * Each rule which does not have an id will get a new unique id.
+     *
+     */
+    final public void afterUnmarshal(Unmarshaller unmarshaller, Object parent) {
+    	if(conditionalFormattingRules==null) {
+    		conditionalFormattingRules = getConditionalFormattingRules();
+
+    		HashSet<String> ids = null;
+    		final MutableInt uuIdCurrent = new MutableInt(0x10000000);
+
+    		// first we will collect the old standard conditional formattings
+    		if(conditionalFormatting!=null) {
+	    		for(CTConditionalFormatting cf:conditionalFormatting) {
+    				final List<String> ranges = cf.getSqrefList();
+    				if(!ranges.isEmpty()) {
+		    			final List<CTCfRule> cfRuleList = cf.getCfRule();
+		    			for(CTCfRule cfRule:cfRuleList) {
+		    				String id = cfRule.getId();
+		    				if(!checkUUID(id)) {
+		    					if(ids==null) {
+		    						ids = collectIds(this);
+		    					}
+		    					id = createUUID(ids, uuIdCurrent);
+		        				cfRule.setId(id);
+		    				}
+	    					conditionalFormattingRules.put(id, new CfRule(cfRule, new ArrayList<String>(ranges)));
+		    			}
+    				}
+	    		}
+	    		conditionalFormatting = null;
+	    	}
+
+    		// second is to collect conditionals from the extension
+    		final CTExtensionList lst = getExtLst(false);
+    		if(lst!=null) {
+    			final CTExtension ext = lst.getExtensionByUri("{78C0D931-6437-407d-A8EE-F0AAD7539E65}", false);
+    			if(ext!=null) {
+    				final org.xlsx4j.schemas.microsoft.com.office.spreadsheetml_2009_9.main.CTConditionalFormattings conditionalFormatting
+    					=  (org.xlsx4j.schemas.microsoft.com.office.spreadsheetml_2009_9.main.CTConditionalFormattings)((JAXBElement<?>)ext.getAny()).getValue();
+    				for(org.xlsx4j.schemas.microsoft.com.office.spreadsheetml_2009_9.main.CTConditionalFormatting cf:conditionalFormatting.getConditionalFormatting()) {
+	    				final List<String> ranges = cf.getSqrefList();
+	    				if(!ranges.isEmpty()) {
+	    					final List<org.xlsx4j.schemas.microsoft.com.office.spreadsheetml_2009_9.main.CTCfRule> cfRuleList = cf.getCfRule();
+	    					for(org.xlsx4j.schemas.microsoft.com.office.spreadsheetml_2009_9.main.CTCfRule cfRule:cfRuleList) {
+	    						String id = cfRule.getId();
+	    						if(!checkUUID(id)) {
+	    							if(ids==null) {
+	    								ids = collectIds(this);
+	    							}
+			    					id = createUUID(ids, uuIdCurrent);
+			        				cfRule.setId(id);
+	    						}
+	    						final CfRule rule = conditionalFormattingRules.get(id);
+    							if(rule!=null) {
+    								rule.setR2(cfRule);
+    							}
+    							else {
+    								conditionalFormattingRules.put(id, new CfRule(cfRule, new ArrayList<String>(ranges)));
+    							}
+	    					}
+	    				}
+	    			}
+    				lst.getExt().remove(ext);
+    			}
+    		}
+    	}
+    }
+
+    private HashSet<String> collectIds(Worksheet worksheet) {
+    	final HashSet<String> ids = new HashSet<String>();
+		if(conditionalFormatting!=null) {
+    		for(CTConditionalFormatting cf:conditionalFormatting) {
+    			final List<CTCfRule> cfRuleList = cf.getCfRule();
+    			for(CTCfRule cfRule:cfRuleList) {
+    				final String id = cfRule.getId();
+    				if(id!=null&&!id.isEmpty()) {
+    					ids.add(id.toUpperCase());
+    				}
+    			}
+    		}
+		}
+		final CTExtensionList lst = getExtLst(false);
+		if(lst!=null) {
+			final CTExtension ext = lst.getExtensionByUri("{78C0D931-6437-407d-A8EE-F0AAD7539E65}", false);
+			if(ext!=null) {
+				final org.xlsx4j.schemas.microsoft.com.office.spreadsheetml_2009_9.main.CTConditionalFormattings conditionalFormatting
+					=  (org.xlsx4j.schemas.microsoft.com.office.spreadsheetml_2009_9.main.CTConditionalFormattings)((JAXBElement<?>)ext.getAny()).getValue();
+				for(org.xlsx4j.schemas.microsoft.com.office.spreadsheetml_2009_9.main.CTConditionalFormatting cf:conditionalFormatting.getConditionalFormatting()) {
+					final List<org.xlsx4j.schemas.microsoft.com.office.spreadsheetml_2009_9.main.CTCfRule> cfRuleList = cf.getCfRule();
+					for(org.xlsx4j.schemas.microsoft.com.office.spreadsheetml_2009_9.main.CTCfRule cfRule:cfRuleList) {
+						final String id = cfRule.getId();
+						if(id!=null&&!id.isEmpty()) {
+							ids.add(id.toUpperCase());
+						}
+					}
+				}
+			}
+		}
+    	return ids;
+    }
+
+    private String createUUID(HashSet<String> ids, MutableInt uuIdCurrent) {
+    	final String uId = "{00112233-0011-0011-0011-0011";
+    	String nextId;
+    	do {
+    		uuIdCurrent.increment();
+    		nextId = uId + Integer.toHexString(uuIdCurrent.intValue()) + "}";
+    	}
+    	while (ids.contains(nextId));
+    	return nextId;
+    }
+
+    private boolean checkUUID(String id) {
+    	if(id!=null&&id.length()==38) {
+    		try {
+	    		UUID.fromString(id.substring(1, 36));
+	    		if(id.charAt(0)=='{'&&id.charAt(37)=='}') {
+	    			return true;
+	    		}
+    		}
+    		catch(IllegalArgumentException e) {
+    			
+    		}
+    	}
+    	return false;
+    }
 }
