@@ -49,6 +49,7 @@
 
 package com.openexchange.office.hazelcast.serialization.document;
 
+import com.hazelcast.nio.serialization.ClassDefinition;
 import com.hazelcast.nio.serialization.Portable;
 import com.openexchange.hazelcast.serialization.AbstractCustomPortableFactory;
 
@@ -71,4 +72,8 @@ public class PortableMemberPredicateFactory extends AbstractCustomPortableFactor
        return PortableMemberPredicate.CLASS_ID;
    }
 
+   @Override
+   public ClassDefinition getClassDefinition() {
+       return PortableMemberPredicate.CLASS_DEFINITION;
+   }
 }
