@@ -99,7 +99,7 @@ public class HazelcastOfficeActivator extends HousekeepingActivator {
 
 	@Override
     protected void startBundle() throws Exception {
-       LOG.info("Starting bundle: " + getClass().getCanonicalName());
+       LOG.debug("Starting bundle: " + getClass().getCanonicalName());
        Services.setServiceLookup(this);
 
        final ManagementHouseKeeper managementHouseKeeper = ManagementHouseKeeper.getInstance();
@@ -170,7 +170,7 @@ public class HazelcastOfficeActivator extends HousekeepingActivator {
     @Override
     public void stop(BundleContext bundleContext) throws Exception {
        if (isStopped.compareAndSet(false, true)) {
-           LOG.info("Stopping bundle: " + getClass().getCanonicalName());
+           LOG.debug("Stopping bundle: " + getClass().getCanonicalName());
            ManagementHouseKeeper.getInstance().cleanup();
 
            Services.setServiceLookup(null);
@@ -181,7 +181,7 @@ public class HazelcastOfficeActivator extends HousekeepingActivator {
    @Override
    protected void handleAvailability(Class<?> clazz) {
        if (allAvailable()) {
-           LOG.info("HazelcastOfficeActivator regained needed service " + clazz.getSimpleName() + ". Going to start bundle.");
+           LOG.debug("HazelcastOfficeActivator regained needed service " + clazz.getSimpleName() + ". Going to start bundle.");
            try {
                startBundle();
            } catch (Exception e) {
