@@ -52,16 +52,14 @@ import java.io.ByteArrayInputStream;
 import java.io.InputStream;
 import java.util.HashMap;
 import java.util.Map;
-
 import org.apache.commons.io.IOUtils;
+import org.apache.commons.lang.StringUtils;
 import org.apache.commons.logging.Log;
 import org.json.JSONException;
 import org.json.JSONObject;
-
 import com.openexchange.ajax.requesthandler.AJAXRequestData;
 import com.openexchange.ajax.requesthandler.AJAXRequestResult;
-import com.openexchange.documentconverter.Feature;
-import com.openexchange.documentconverter.IManager;
+import com.openexchange.documentconverter.IDocumentConverter;
 import com.openexchange.documentconverter.Properties;
 import com.openexchange.exception.OXException;
 import com.openexchange.file.storage.DefaultFile;
@@ -246,10 +244,15 @@ public class CreateDefaultDocumentAction extends DocumentFilterAction {
      * @throws FilterException
      */
     private JSONObject impl_createDefaultDocument(ServerSession session, AJAXRequestData request) throws Exception {
-        MissingParameter.hasMissing(request, "target_folder_id", "document_type", "target_filename");
-        
         JSONObject jsonResult = null;
 
+        // check mandatory args and bail out with argument error, if required arg is missing
+        final String missedReqParameter = MissingParameter.hasMissing(request, "target_folder_id", "document_type", "target_filename");
+        if (StringUtils.isNotEmpty(missedReqParameter)) {
+            jsonResult = ErrorCode.GENERAL_ARGUMENTS_ERROR.getAsJSONResultObject();
+            return jsonResult;
+        }
+
         InputStream inputStream = null;
         InputStream resourceInputStream = null;
         final IResourceProvider resourceProvider = m_services.getService(com.openexchange.office.IResourceProvider.class);
@@ -259,6 +262,7 @@ public class CreateDefaultDocumentAction extends DocumentFilterAction {
         String targetFolderId = request.getParameter("target_folder_id");
         final String initialFileName = request.getParameter("target_filename");
         final String initialSheetname = request.getParameter("initial_sheetname");
+        final String initialFormats = request.getParameter("initial_formats");
         // will be needed for speed-up access if creating a new empty document
         String htmlDoc = null;
         JSONObject documentOperations = null;
@@ -305,6 +309,9 @@ public class CreateDefaultDocumentAction extends DocumentFilterAction {
                         if (initialSheetname != null) {
                             docProps.put(DocumentProperties.PROP_INITIAL_SHEETNAME, initialSheetname);
                         }
+                        if (initialFormats != null) {
+                            docProps.put(DocumentProperties.PROP_INITIAL_FORMATS, initialFormats);
+                        }
                     }
                     inputStream = importer.getDefaultDocument(resourceInputStream, docProps);
                 }
@@ -328,18 +335,27 @@ public class CreateDefaultDocumentAction extends DocumentFilterAction {
                 // initialize json result object
                 jsonResult = new JSONObject();
             }
-            
+
             try
             {
                 inputStream = DynamicFields.insertOptionalFields(inputStream, extensionType, request, jsonResult, session, m_services);
             }
             catch (Exception e)
             {
-                LOG.error("Handling optional fields is broken " + ErrorCode.GENERAL_UNKNOWN_ERROR.getDescription(), e);                
+                LOG.debug("Handling optional fields is broken " + ErrorCode.GENERAL_ARGUMENTS_ERROR.getDescription(), e);
+
+                try
+                {
+                    jsonResult.put("error",  ErrorCode.GENERAL_ARGUMENTS_ERROR.getAsJSONResultObject().get("error"));
+                }
+                catch (final Exception je)
+                {
+                    LOG.debug("Couldn't create JSON object while creating new document from template");
+                }
             }
 
             ErrorCode errorCode = ErrorCode.NO_ERROR;
-            if (module.equalsIgnoreCase("text") && (null == cacheData) && (null != inputStream)) {
+            if ((module.equalsIgnoreCase("text") /*|| module.equalsIgnoreCase("presentation")*/) && (null == cacheData) && (null != inputStream)) {
                 // just continue with the slower way - no cache hit
                 OXDocumentHelper oxDocHelper = new OXDocumentHelper(m_services, session, inputStream, new ResourceManager(m_services));
                 documentOperations = oxDocHelper.getOperations(session, importer);
@@ -350,9 +366,9 @@ public class CreateDefaultDocumentAction extends DocumentFilterAction {
                 // now we have to create the new document file using the input stream
                 errorCode = FileHelper.createFileAndWriteStream(m_services, session, null, file, inputStream);
                 if (!errorCode.isError()) {
-                    if (GenericHtmlDocumentBuilder.isFastLoadActive(m_services, session)) {
+                    if (GenericHtmlDocumentBuilder.isFastLoadActive(module, m_services, session)) {
                         // OperationReducer.reduceOperationCount(documentOperations);
-                        htmlDoc = GenericHtmlDocumentBuilder.buildHtmlDocument(documentOperations, file, m_services, session);
+                        htmlDoc = GenericHtmlDocumentBuilder.buildHtmlDocument(module, documentOperations, file, m_services, session);
                         defaultDocCache.setDocData(module,
                             defaultDocCache.new EmptyDocData(htmlDoc,
                                 documentOperations.getJSONArray("operations"),
@@ -410,6 +426,14 @@ public class CreateDefaultDocumentAction extends DocumentFilterAction {
      */
     private TemplateResult impl_createDocumentOnTemplate(ServerSession session, AJAXRequestData request) throws Exception {
         TemplateResult result = null;
+        DocumentType eventDocumentType = DocumentType.NONE;
+
+        // check mandatory args and bail out with argument error, if required arg is missing
+        final String missedReqParameter = MissingParameter.hasMissing(request, "file_id", "target_folder_id");
+        if (StringUtils.isNotEmpty(missedReqParameter)) {
+            result = new TemplateResult(ErrorCode.GENERAL_ARGUMENTS_ERROR.getAsJSONResultObject(), eventDocumentType);
+            return result;
+        }
 
         final File file = new DefaultFile();
         final String fileId = request.getParameter("file_id");
@@ -420,17 +444,12 @@ public class CreateDefaultDocumentAction extends DocumentFilterAction {
         final String templateAccessId = fileId;
         String version = (null != versionStr) ? versionStr : "";
         InputStream inputStm = null;
-        DocumentType eventDocumentType = DocumentType.NONE;
 
         // determine requested document type and corresponding extensionType
         HashMap<String, String> conversionFormat = null;
         String extensionType;
         String mimeType;
 
-        // create document on template must have a template id
-        if ((null == fileId) || fileId.length() < 1)
-            return new TemplateResult(new JSONObject().put("error", ErrorCode.GENERAL_ARGUMENTS_ERROR), eventDocumentType);
-
         // Create document based on template file. It could be that we have to
         // convert the template document to the related ODF document format.
         if (version.length() == 0) {
@@ -449,9 +468,9 @@ public class CreateDefaultDocumentAction extends DocumentFilterAction {
         conversionFormat = DocumentFormatHelper.getConversionFormatInfo(mimeType, extensionType);
 
         if (conversionFormat != null) {
-            final IManager dcManager = m_services.getService(IManager.class);
+            final IDocumentConverter documentConverter = m_services.getService(IDocumentConverter.class);
 
-            if ((null != dcManager) && dcManager.hasFeature(Feature.DOCUMENTCONVERTER)) {
+            if (null != documentConverter) {
                 AJAXRequestData loadRequest = new AJAXRequestData();
                 loadRequest.putParameter("id", fileId);
                 loadRequest.putParameter("folder_id", templateFile.getFolderId());
@@ -475,7 +494,7 @@ public class CreateDefaultDocumentAction extends DocumentFilterAction {
                         jobProperties.put(Properties.PROP_INFO_FILENAME, templateFileName);
                     }
 
-                    inputStm = dcManager.convert(filterShortName, jobProperties, resultProperties);
+                    inputStm = documentConverter.convert(filterShortName, jobProperties, resultProperties);
                     IOUtils.closeQuietly(documentInputStm);
                     streamInfo.close();
 
