@@ -51,20 +51,17 @@ package com.openexchange.office.json.actions;
 import java.io.InputStream;
 import java.util.ArrayList;
 import java.util.HashMap;
-
 import org.apache.commons.io.IOUtils;
 import org.apache.commons.lang.StringUtils;
 import org.apache.commons.logging.Log;
 import org.json.JSONException;
 import org.json.JSONObject;
-
 import com.openexchange.ajax.requesthandler.AJAXRequestData;
 import com.openexchange.ajax.requesthandler.AJAXRequestResult;
 import com.openexchange.documentation.RequestMethod;
 import com.openexchange.documentation.annotations.Action;
 import com.openexchange.documentation.annotations.Parameter;
-import com.openexchange.documentconverter.Feature;
-import com.openexchange.documentconverter.IManager;
+import com.openexchange.documentconverter.IDocumentConverter;
 import com.openexchange.documentconverter.Properties;
 import com.openexchange.exception.OXException;
 import com.openexchange.file.storage.DefaultFile;
@@ -185,10 +182,10 @@ public class CreateFromTemplateAction extends DocumentFilterAction {
 
                         if (conversionFormat != null) {
                             // conversion already sets the correct target document format
-                            final IManager dcManager = m_services.getService(IManager.class);
+                            final IDocumentConverter documentConverter = m_services.getService(IDocumentConverter.class);
                             ErrorCode errorCode = ErrorCode.NO_ERROR;
 
-                            if ((null != dcManager) && dcManager.hasFeature(Feature.DOCUMENTCONVERTER)) {
+                            if (null != documentConverter) {
                                 StreamInfo streamInfo = null;
                                 InputStream documentInputStm = null;
 
@@ -220,7 +217,7 @@ public class CreateFromTemplateAction extends DocumentFilterAction {
                                         jobProperties.put(Properties.PROP_INFO_FILENAME, templateFileName);
                                     }
 
-                                    inputStm = dcManager.convert(filterShortName, jobProperties, resultProperties);
+                                    inputStm = documentConverter.convert(filterShortName, jobProperties, resultProperties);
                                     IOUtils.closeQuietly(documentInputStm);
 
                                     if (null != streamInfo) {
@@ -300,8 +297,8 @@ public class CreateFromTemplateAction extends DocumentFilterAction {
                             }
                             catch (Exception e)
                             {
-                                ErrorCode errorCode = ErrorCode.GENERAL_UNKNOWN_ERROR;
-                                LOG.error("Handling optional fields is broken " + errorCode.getDescription(), e);
+                                ErrorCode errorCode = ErrorCode.GENERAL_ARGUMENTS_ERROR;
+                                LOG.debug("Handling optional fields is broken " + errorCode.getDescription(), e);
                                 try
                                 {
                                     requestResult = new AJAXRequestResult(createErrorObject(errorCode));
@@ -309,7 +306,7 @@ public class CreateFromTemplateAction extends DocumentFilterAction {
                                 }
                                 catch (final JSONException je)
                                 {
-                                    LOG.warn("Couldn't create JSON object while creating new document from template");
+                                    LOG.debug("Couldn't create JSON object while creating new document from template");
                                 }
                             }
 
