@@ -68,7 +68,7 @@ import com.openexchange.exception.OXException;
 import com.openexchange.log.LogFactory;
 import com.openexchange.office.tools.SessionUtils;
 import com.openexchange.office.tools.StatusProperties;
-import com.openexchange.office.tools.actions.ActionParameters;
+import com.openexchange.office.tools.actions.RTActionParameters;
 import com.openexchange.office.tools.error.ErrorCode;
 import com.openexchange.office.tools.rt.EncodeUtility;
 import com.openexchange.realtime.dispatch.MessageDispatcher;
@@ -221,7 +221,7 @@ public abstract class DocumentFilterAction implements AJAXActionService {
         final String fileId = request.getParameter("id");
         final String sharedResId = request.getParameter("com.openexchange.realtime.resourceID");
         final String appType = request.getParameter("app");
-        final String rtData = request.getParameter(ActionParameters.KEY_RTDATA);
+        final String rtData = request.getParameter(RTActionParameters.KEY_RTDATA);
         final JSONObject requestData = getJSONObjectFromServerSession(session);
         JSONObject resultData = null;
         Stanza resultStanza = null;
@@ -241,7 +241,7 @@ public abstract class DocumentFilterAction implements AJAXActionService {
                     resource));
                 message.addPayload(ActionHandler.getMethodCall(methodName));
                 message.addPayload(new PayloadTree(PayloadTreeNode.builder().withPayload(
-                    new JSONObject(rtData), "json", ActionParameters.KEY_OFFICE, ActionParameters.KEY_RTDATA).build()));
+                    new JSONObject(rtData), "json", RTActionParameters.KEY_OFFICE, RTActionParameters.KEY_RTDATA).build()));
 
                 if (null != messageData) {
                     for (final Iterator<String> keys = messageData.keys(); keys.hasNext();) {
@@ -342,8 +342,8 @@ public abstract class DocumentFilterAction implements AJAXActionService {
         final JSONObject rtData = new JSONObject();
 
         try {
-            rtData.put(ActionParameters.KEY_RTID, rtId);
-            rtData.put(ActionParameters.KEY_SESSION, SessionUtils.getSessionId(session));
+            rtData.put(RTActionParameters.KEY_RTID, rtId);
+            rtData.put(RTActionParameters.KEY_SESSION, SessionUtils.getSessionId(session));
         } catch (Exception e) {
             // TODO: return null or empty object??
         }
