@@ -53,8 +53,7 @@ import org.json.JSONException;
 import org.json.JSONObject;
 import com.openexchange.ajax.requesthandler.AJAXRequestData;
 import com.openexchange.ajax.requesthandler.AJAXRequestResult;
-import com.openexchange.documentconverter.Feature;
-import com.openexchange.documentconverter.IManager;
+import com.openexchange.documentconverter.IDocumentConverter;
 import com.openexchange.exception.OXException;
 import com.openexchange.server.ServiceLookup;
 import com.openexchange.tools.session.ServerSession;
@@ -85,9 +84,9 @@ public class GetFeaturesAction extends DocumentFilterAction {
         final JSONObject resultObj = new JSONObject(1);
 
         // check for existence of documentconverter
-        final IManager documentConverterManager = m_services.getService(IManager.class);
+        final IDocumentConverter documentConverter = m_services.getService(IDocumentConverter.class);
 
-        if ((null != documentConverterManager) && documentConverterManager.hasFeature(Feature.DOCUMENTCONVERTER)) {
+        if (null != documentConverter) {
             featureBuilder.append("documentconverter");
         }
 
