@@ -73,8 +73,7 @@ import org.apache.commons.lang.StringUtils;
 import com.openexchange.ajax.requesthandler.AJAXRequestData;
 import com.openexchange.ajax.requesthandler.AJAXRequestResult;
 import com.openexchange.ajax.requesthandler.DispatcherNotes;
-import com.openexchange.documentconverter.Feature;
-import com.openexchange.documentconverter.IManager;
+import com.openexchange.documentconverter.IDocumentConverter;
 import com.openexchange.documentconverter.Properties;
 import com.openexchange.file.storage.File;
 import com.openexchange.file.storage.FileStorageFileAccess;
@@ -209,7 +208,7 @@ public class GetFileAction extends DocumentFilterAction {
                         // This is just an information: a cleanly loaded document contains the images
                         // and does not provide it via managed file. The 3rd access should provide the
                         // image. Therefore change this LOG into info.
-                        LOG.info("AjaxRequest GetFileAction exception caught while trying to create managed resource.",  e);
+                        LOG.debug("AjaxRequest GetFileAction exception caught while trying to create managed resource.",  e);
                     }
                 }
 
@@ -335,9 +334,9 @@ public class GetFileAction extends DocumentFilterAction {
                             // we will do this for the formats "wmf and emf... TODO: the resulting graphic should
                             // somehow be part of the resourcemanager to prevent unnecessary graphic conversions
                             if (fileExtension.equals("emf") || fileExtension.equals("wmf") || (resourceName.indexOf("ObjectReplacements/") > -1)) {
-                                final IManager dcManager = m_services.getService(IManager.class);
+                                final IDocumentConverter documentConverter = m_services.getService(IDocumentConverter.class);
 
-                                if ((null != dcManager) && dcManager.hasFeature(Feature.DOCUMENTCONVERTER)) {
+                                if (null != documentConverter) {
                                     final HashMap<String, Object> jobProperties = new HashMap<String, Object>(8);
                                     final HashMap<String, Object> resultProperties = new HashMap<String, Object>(8);
                                     final InputStream inputStm = new ByteArrayInputStream(entryBuffer);
@@ -347,7 +346,7 @@ public class GetFileAction extends DocumentFilterAction {
                                     jobProperties.put(Properties.PROP_MIME_TYPE, "image/png");
                                     jobProperties.put(Properties.PROP_INFO_FILENAME, resourceName);
 
-                                    resultStm = dcManager.convert("graphic", jobProperties, resultProperties);
+                                    resultStm = documentConverter.convert("graphic", jobProperties, resultProperties);
                                     IOUtils.closeQuietly(inputStm);
                                     mimeType[0] = (String) resultProperties.get(Properties.PROP_RESULT_MIME_TYPE);
                                 }
@@ -414,7 +413,7 @@ public class GetFileAction extends DocumentFilterAction {
                             }
                             source = imageReader.read(imageReader.getMinIndex());
                             if(source!=null) {
-                                final Image scaledImage = source.getScaledInstance(newWidth, newHeight, BufferedImage.SCALE_DEFAULT);
+                                final Image scaledImage = source.getScaledInstance(newWidth, newHeight, Image.SCALE_SMOOTH); //Smooth scale as fix for Bug 45144
                                 if(scaledImage instanceof BufferedImage) {
                                     dest = (BufferedImage)scaledImage;
                                 }
