@@ -49,10 +49,12 @@
 package com.openexchange.office.json.tools;
 
 import java.util.HashMap;
+import java.util.logging.Level;
 import java.util.logging.Logger;
 
 import org.json.JSONArray;
 import org.json.JSONException;
+import org.json.JSONObject;
 
 public class EmptyDocumentCache {
     
@@ -86,14 +88,20 @@ public class EmptyDocumentCache {
                 result = emptyDocCache.get(key);
 
                 if (null == result) {
-                    LOG.info("DocumentCache no cached file found");
+                	LOG.log(Level.FINE, "DocumentCache no cached file found");
                     return null;
                 }
 
                 JSONArray ops = new JSONArray(result.operations);
 
                 try {
-                    ops.getJSONObject(0).getJSONObject("attrs").getJSONObject("character").put("language", lang);
+                    JSONObject attrs = ops.getJSONObject(0).getJSONObject("attrs");
+                    JSONObject character = attrs.optJSONObject("character");
+                    if (null == character) {
+                        character = new JSONObject();
+                        attrs.put("character", character);
+                    }
+                    character.put("language", lang);
                 } catch (JSONException e) {
                     throw new RuntimeException("error while trying to change language of operations", e);
                 }
@@ -104,7 +112,7 @@ public class EmptyDocumentCache {
 
                 long time = System.currentTimeMillis() - current;
 
-                LOG.info("DocumentCache changing language via copy operations takes " + time + "ms!");
+                LOG.log(Level.FINE, "DocumentCache changing language via copy operations takes " + time + "ms!");
             }
             return result;
         } else {
