@@ -121,7 +121,7 @@ public class OXDocumentHelper {
             try {
                 m_documentBuffer = IOUtils.toByteArray(documentStream);
             } catch (IOException e) {
-                LOG.error("RT connection: unable to retrieve document stream, exception catched", e);
+                LOG.error("RT connection: unable to retrieve document stream, exception caught", e);
             } finally {
                 IOUtils.closeQuietly(documentStream);
             }
@@ -148,14 +148,14 @@ public class OXDocumentHelper {
                             // read document identifier
                             extendedDataBuffer = IOUtils.toByteArray(zipInputStm);
                         } catch (IOException e) {
-                            LOG.error("RT connection: unable to retrieve extended data stream, exception catched", e);
+                            LOG.error("RT connection: unable to retrieve extended data stream, exception caught", e);
                         }
                     } else if (entryName.equals(DocFileHelper.OX_RESCUEDOCUMENT_DOCUMENTSTREAM_NAME)) {
                         try {
                             // read original document
                             documentBuffer = IOUtils.toByteArray(zipInputStm);
                         } catch (IOException e) {
-                            LOG.error("RT connection: unable to retrieve original document stream, exception catched", e);
+                            LOG.error("RT connection: unable to retrieve original document stream, exception caught", e);
                         }
                     } else if (entryName.equals(DocFileHelper.OX_RESCUEDOCUMENT_OPERATIONSSTREAM_NAME)) {
                         try {
@@ -164,7 +164,7 @@ public class OXDocumentHelper {
                             // non continuous osn numbers lead to a load error in the frontend, so we have to remove them as some operations are filtered by the calcengine
                             operationsBuffer = op.replaceAll("\\\"osn\\\":[0-9]+,?", "").getBytes();
                         } catch (IOException e) {
-                            LOG.error("RT connection: unable to retrieve operations stream, exception catched", e);
+                            LOG.error("RT connection: unable to retrieve operations stream, exception caught", e);
                         }
                     } else if (entryName.startsWith(DocFileHelper.OX_RESCUEDOCUMENT_RESOURCESTREAM_NAME_PREFIX)) {
                         // read resource and put into the resource manager, if not already contained
@@ -176,7 +176,7 @@ public class OXDocumentHelper {
                             try {
                                 resourceBuffer = IOUtils.toByteArray(zipInputStm);
                             } catch (IOException e) {
-                                LOG.error("RT connection: unable to retrieve resource document stream, exception catched", e);
+                                LOG.error("RT connection: unable to retrieve resource document stream, exception caught", e);
                             }
 
                             m_resourceManager.addResource(resourceBuffer);
@@ -186,7 +186,7 @@ public class OXDocumentHelper {
                     zipInputStm.closeEntry();
                 }
             } catch (IOException e) {
-                LOG.error("RT connection: Exception catched while reading the document stream", e);
+                LOG.error("RT connection: Exception caught while reading the document stream", e);
             } finally {
                 IOUtils.closeQuietly(zipInputStm);
 
