@@ -54,7 +54,10 @@ import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.Collection;
 import java.util.HashMap;
+import java.util.LinkedHashMap;
 import java.util.LinkedHashSet;
+import java.util.Map;
+import java.util.Map.Entry;
 import java.util.Set;
 
 import org.apache.commons.lang.StringUtils;
@@ -93,14 +96,20 @@ import com.openexchange.tools.session.ServerSession;
 
 public class TemplateFilesScanner {
 
+    @SuppressWarnings("deprecation")
     private static final Log LOG = com.openexchange.log.Log.loggerFor(TemplateFilesScanner.class);
 
-    private static boolean DISABLE_ODF_SPREADSHEET = false;
-    private static boolean DISABLE_BINARY_MS_FORMATS = true;
+    private static final boolean DISABLE_BINARY_MS_FORMATS = true;
 
     private ServiceLookup m_services = null;
     private LocalFileMappingManager m_localFileMapper = null;
     private ExtensionFilter m_extensionFilter = null;
+    private TemplateFilterType m_filterType = TemplateFilterType.ONLY_TEMPLATES;
+
+    public enum TemplateFilterType {
+    	ONLY_TEMPLATES,
+    	ALL_DOCUMENTS
+    };
 
     /**
      * A filter class to filter out language specific folders in the global
@@ -175,15 +184,30 @@ public class TemplateFilesScanner {
         }
     }
 
-    public TemplateFilesScanner(ServiceLookup services, LocalFileMappingManager localFileMapper) {
+    public TemplateFilesScanner(final ServiceLookup services, final LocalFileMappingManager localFileMapper, TemplateFilterType filterType) {
         m_services = services;
         m_localFileMapper = localFileMapper;
-        m_extensionFilter = new ExtensionFilter(MimeTypeHelper.EXCEL_TEMPLATE_EXTENSIONS,
-            MimeTypeHelper.WORD_TEMPLATE_EXTENSIONS,
-            MimeTypeHelper.POWERPOINT_TEMPLATE_EXTENSIONS,
-            MimeTypeHelper.ODF_CALC_TEMPLATE_EXTENSIONS,
-            MimeTypeHelper.ODF_IMPRESS_TEMPLATE_EXTENSIONS,
-            MimeTypeHelper.ODF_WRITER_TEMPLATE_EXTENSIONS);
+        m_filterType = filterType;
+
+        if (filterType == TemplateFilterType.ONLY_TEMPLATES) {
+        	// select only supported document template extensions
+	        m_extensionFilter = new ExtensionFilter(
+	        	MimeTypeHelper.EXCEL_TEMPLATE_EXTENSIONS,
+	            MimeTypeHelper.WORD_TEMPLATE_EXTENSIONS,
+	            MimeTypeHelper.POWERPOINT_TEMPLATE_EXTENSIONS,
+	            MimeTypeHelper.ODF_CALC_TEMPLATE_EXTENSIONS,
+	            MimeTypeHelper.ODF_IMPRESS_TEMPLATE_EXTENSIONS,
+	            MimeTypeHelper.ODF_WRITER_TEMPLATE_EXTENSIONS);
+        } else {
+        	// use all supported document extensions
+	        m_extensionFilter = new ExtensionFilter(
+	        	MimeTypeHelper.SPREADSHEET_EXTENSIONS,
+	            MimeTypeHelper.TEXT_EXTENSIONS,
+	            MimeTypeHelper.PRESENTATION_EXTENSIONS,
+	            MimeTypeHelper.ODF_CALC_TEMPLATE_EXTENSIONS,
+	            MimeTypeHelper.ODF_IMPRESS_TEMPLATE_EXTENSIONS,
+	            MimeTypeHelper.ODF_WRITER_TEMPLATE_EXTENSIONS);
+        }
     }
 
     /**
@@ -191,7 +215,7 @@ public class TemplateFilesScanner {
      * @return
      * @throws OXException
      */
-    public ErrorCode searchForTemplates(ServerSession session, String type, final JSONArray templates) throws OXException {
+    public ErrorCode searchForTemplates(final ServerSession session, String type, final JSONArray templates) throws OXException {
         ErrorCode errorCode = ErrorCode.NO_ERROR;
 
         if ((null != session) && (null != type) && (type.length() > 0)) {
@@ -220,17 +244,17 @@ public class TemplateFilesScanner {
                 userLangCode = DocFileHelper.mapUserLanguageToLangCode(user.getPreferredLanguage());
             }
 
-            Set<String> templateFolders = new LinkedHashSet<String>();
-            Set<String> templateFoldersFromContextAdmin = new LinkedHashSet<String>();
+            Map<String, Boolean> templateFolders = new LinkedHashMap<String, Boolean>();
+            Map<String, Boolean> templateFoldersFromContextAdmin = new LinkedHashMap<String, Boolean>();
             //LinkedHashSet keeps the put order
 
             //get User's template folder
-            templateFolders.add(ConfigurationHelper.getCascadeConfigurationValue(m_services, session, "io.ox/files", "folder/templates"));
+            templateFolders.put(ConfigurationHelper.getCascadeConfigurationValue(m_services, session, "io.ox/files", "folder/templates"), false);
 
             getUserData(session.getUserId(), session, "io.ox/office", "MyTemplateFolders", templateFolders, true);
             getUserData(session.getContext().getMailadmin(), session, "io.ox/office", "ContextTemplateFolders", templateFoldersFromContextAdmin, false);
 
-            templateFolders.addAll(templateFoldersFromContextAdmin);
+            templateFolders.putAll(templateFoldersFromContextAdmin);
 
             IDBasedFolderAccess folderAccess = folderFactory.createAccess(session);
 
@@ -240,14 +264,16 @@ public class TemplateFilesScanner {
                 IDBasedFileAccess fileAccess = fileFactory.createAccess(session);
 
                 ErrorCode err = null;
-                for (String folderId: templateFolders){
+                for (Entry<String, Boolean> folderDescriptor: templateFolders.entrySet()){
 
+                	boolean ignoreNoneTemplates = folderDescriptor.getValue();
+                	String folderId = folderDescriptor.getKey();
                     try{
                         // check if a user configured template folder is in the trash folder
                         final FileStorageFolder folder = folderAccess.getFolder(folderId);
 
                         if (!FolderHelper.isFolderTrashOrInTrash(folder)) {
-                            err = scanUserFolderForTemplates(fileAccess, templates, folderId, searchFilter);
+                            err = scanUserFolderForTemplates(fileAccess, templates, folderId, searchFilter, ignoreNoneTemplates);
                             if (ErrorCode.NO_ERROR != err && ErrorCode.NO_ERROR == errorCode) {
                                 errorCode = err;
                             }
@@ -288,13 +314,13 @@ public class TemplateFilesScanner {
                 for (int i = 0; i < templates.length(); i++) {
                     JSONObject template = templates.getJSONObject(i);
                     String folderId = template.getString("folder_id");
-                    
+
                     if (StringUtils.equals(template.getString("source"),"global")) {
-                        template.put("editable", false);                        
+                        template.put("editable", false);
                     } else {
                         template.put("editable", FolderHelper.folderHasWriteAccess(folderAccess, folderId));
                     }
-                    if (templateFoldersFromContextAdmin.contains(folderId)) {
+                    if (templateFoldersFromContextAdmin.containsKey(folderId)) {
                         template.put("source", "admin");
                     }
                 }
@@ -304,7 +330,7 @@ public class TemplateFilesScanner {
 
             // log time on info level
             long time2 = System.currentTimeMillis();
-            LOG.info("Scan template folders including delete folder detection: " + (time2 - time1) + "ms");
+            LOG.debug("Scan template folders including delete folder detection: " + (time2 - time1) + "ms");
         }
 
         return errorCode;
@@ -324,7 +350,7 @@ public class TemplateFilesScanner {
      * @param target
      * @throws OXException
      */
-    private void getUserData(int userId, Session realSession, String id, String key, Collection<String> target, boolean fromUser) throws OXException{
+    private void getUserData(int userId, Session realSession, String id, String key, Map<String, Boolean> target, boolean fromUser) throws OXException{
         Session session = new FakeSession(userId, realSession);
         UserConfigurationHelper userConfHelper = new UserConfigurationHelper(m_services, session, id, Mode.WRITE_BACK);
         JSONArray array = userConfHelper.getJSONArray(key);
@@ -362,7 +388,12 @@ public class TemplateFilesScanner {
         try{
             for (int i = 0; i < array.length(); i++){
                 String folderId = array.getString(i);
-                target.add(folderId);
+
+                boolean ignoreNoneTemplates = false;
+                if (StringUtils.equals(folderId, DocFileHelper.getUserFolderId(m_services.getService(FolderService.class), realSession))) {
+                	ignoreNoneTemplates = true;
+                }
+                target.put(folderId, ignoreNoneTemplates);
             }
         }
         catch (JSONException e){
@@ -416,15 +447,11 @@ public class TemplateFilesScanner {
                                 // use optional file extension filter to filter
                                 // out unwanted files.
                                 if ((null == extFilter) || ((null != extFilter) && extFilter.accept(file, fileName))) {
-                                    String fileMimeType = MimeTypeHelper.getMimeTypeFromTemplateExtension(ext);
+                                    String fileMimeType = getMimeTypeFromExtension(ext);
                                     long lastModified = file.lastModified();
 
-                                    if (DISABLE_ODF_SPREADSHEET && (MimeTypeHelper.MIMETYPE_VND_OASIS_OPENDOCUMENT_SPREADSHEET_TEMPLATE.equalsIgnoreCase(fileMimeType))) {
-                                        // filter out odf spreadsheet
-                                        addFile = false;
-                                    }
                                     if (addFile && DISABLE_BINARY_MS_FORMATS) {
-                                        addFile = !isBinaryMSTemplateMimeType(fileMimeType);
+                                        addFile = !isBinaryMSMimeType(fileMimeType);
                                     }
 
                                     if (addFile) {
@@ -620,7 +647,7 @@ public class TemplateFilesScanner {
      * @return
      *  ErrorCode.NONE on success or an error code if something went wrong.
      */
-    private ErrorCode scanUserFolderForTemplates(IDBasedFileAccess fileAccess, JSONArray templates, String folderId, DocumentType searchFilter) {
+    private ErrorCode scanUserFolderForTemplates(IDBasedFileAccess fileAccess, JSONArray templates, String folderId, DocumentType searchFilter, boolean ignoreNoneTemplates) {
         ErrorCode errorCode = ErrorCode.NO_ERROR;
 
         if ((null != folderId) && (null != fileAccess)) {
@@ -636,27 +663,21 @@ public class TemplateFilesScanner {
                         File file = iter.next();
                         String ext = FileHelper.getExtension(file.getFileName());
                         String fileMimeType = file.getFileMIMEType();
-                        String knownMimeType = MimeTypeHelper.getMimeTypeFromTemplateExtension(ext);
+                        String knownMimeType = MimeTypeHelper.getMimeTypeFromExtension(ext);
                         DocumentType fileDocType = DocumentType.NONE;
                         java.util.Date lastModifiedDate = file.getLastModified();
                         long lastModified = (null != lastModifiedDate) ? lastModifiedDate.getTime() : currentDate.getTime();
 
-                        // First use the extension to find template documents, second the
+                        // First use the extension to find (template) documents, second the
                         // mime type of the file. Special handling for binary ms document
-                        // template files as they share the same mime type as the normal
-                        // documents.
+                        // (template) files as they share the same mime type as the normal
+                        // documents. Dependent on the filter set at construction time only
+                        // templates or all supported document files are found (special case
+                        // that we want to ignore non-templates in special folders).
                         if (null != knownMimeType) {
-                            fileDocType = MimeTypeHelper.getDocumentTypeFromTemplateMimeType(knownMimeType);
-                        } else if (!isBinaryMSTemplateMimeType(fileMimeType)) {
-                            fileDocType = MimeTypeHelper.getDocumentTypeFromTemplateMimeType(fileMimeType);
-                        }
-
-                        if (isBinaryMSTemplateMimeType(knownMimeType) && DISABLE_BINARY_MS_FORMATS) {
-                            fileDocType = null;
-                        } else if (DISABLE_ODF_SPREADSHEET) {
-                            // filter out odf spreadsheet
-                            fileDocType = ((MimeTypeHelper.MIMETYPE_VND_OASIS_OPENDOCUMENT_SPREADSHEET_TEMPLATE.equalsIgnoreCase(knownMimeType)) ||
-                                           (MimeTypeHelper.MIMETYPE_VND_OASIS_OPENDOCUMENT_SPREADSHEET_TEMPLATE.equalsIgnoreCase(fileMimeType))) ? null : fileDocType;
+                            fileDocType = getDocumentTypeFromMimeType(knownMimeType, ignoreNoneTemplates);
+                        } else {
+                            fileDocType = getDocumentTypeFromMimeType(fileMimeType, ignoreNoneTemplates);
                         }
 
                         if ((null != fileDocType) && (DocumentType.NONE != fileDocType) &&
@@ -779,10 +800,48 @@ public class TemplateFilesScanner {
      *  TRUE if the mime type belongs to a binary document template format of
      *  MS Office.
      */
-    private boolean isBinaryMSTemplateMimeType(String mimeType) {
+    private boolean isBinaryMSMimeType(String mimeType) {
         return ((MimeTypeHelper.MIMETYPE_MSEXCEL.equalsIgnoreCase(mimeType)) ||
                 (MimeTypeHelper.MIMETYPE_MSPOWERPOINT.equalsIgnoreCase(mimeType)) ||
                 (MimeTypeHelper.MIMETYPE_MSWORD.equalsIgnoreCase(mimeType)));
     }
 
+    /**
+     * Provides the document type dependent on the mime type and filter set.
+     *
+     * @param mimeType
+     *  the mime type of the documents
+     *
+     * @param ignoreNoneTemplates
+     *  force to ignore non-template documents
+     *
+     * @return the document type of the mime type. Can be DocumentType.NONE if
+     *  the mime type is unknown or doesn't comply to the set document type filter.
+     *  @see TemplateFilterType
+     */
+    private DocumentType getDocumentTypeFromMimeType(final String mimeType, boolean ignoreNoneTemplates) {
+    	DocumentType result = DocumentType.NONE;
+
+    	if ((m_filterType == TemplateFilterType.ALL_DOCUMENTS) && !ignoreNoneTemplates) {
+    		result = MimeTypeHelper.getDocumentTypeFromMimeType(mimeType);
+    	}
+    	else {
+    		result = MimeTypeHelper.getDocumentTypeFromTemplateMimeType(mimeType);
+    	}
+		result = (DISABLE_BINARY_MS_FORMATS && isBinaryMSMimeType(mimeType)) ? DocumentType.NONE : result;
+
+    	return result;
+    }
+
+    /**
+     * Provides the mime type of a file extension if it's a supported document
+     * type and complies to the current filter settings.
+     *
+     * @param extension a file extension
+     * @return the mime type of the file or null if unknown
+     */
+    private String getMimeTypeFromExtension(final String extension) {
+    	return (m_filterType == TemplateFilterType.ALL_DOCUMENTS) ?
+        		MimeTypeHelper.getMimeTypeFromExtension(extension) : MimeTypeHelper.getMimeTypeFromTemplateExtension(extension);
+    }
 }
