@@ -34,12 +34,16 @@ import org.json.JSONTokener;
 import org.odftoolkit.odfdom.doc.OdfDocument;
 import org.odftoolkit.odfdom.doc.OdfSpreadsheetDocument;
 import org.odftoolkit.odfdom.doc.OdfTextDocument;
+import org.odftoolkit.odfdom.dom.OdfSchemaDocument;
 import org.odftoolkit.odfdom.dom.OdfSchemaDocument.OdfXMLFile;
+import org.odftoolkit.odfdom.pkg.OdfFileDom;
 import org.odftoolkit.odfdom.pkg.OdfPackage;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 import org.xml.sax.SAXException;
 
+import com.openexchange.office.DocumentProperties;
+import com.openexchange.office.FilterException;
 import com.openexchange.office.IResourceManager;
 
 /**
@@ -77,13 +81,20 @@ public class OdfOperationDocument {
     private int mMaxTableCellCount;
     private int mMaxSheetCount;
     private boolean isMetadataUpdated = false;
-
+	
     /**
      * Creates an empty ODF document.
      */
     private OdfOperationDocument() {
     }
 
+    // to be ... depending to the target the owner document might be also the StylesDom
+    public OdfFileDom getOwnerDocument()
+    	throws SAXException {
+
+    	return getDocument().getContentDom();
+    }
+
     /**
      * Creates a new ODT document from the default template
      */
@@ -230,6 +241,28 @@ public class OdfOperationDocument {
         return ops;
     }
 
+	public void initPartitioning(DocumentProperties documentProperties) {
+		mDocument.initPartitioning(documentProperties);
+	}
+
+	public Map<String, Object> getMetaData(DocumentProperties documentProperties)
+		throws Exception {
+
+		return mDocument.getMetaData(documentProperties);
+	}
+
+	public Map<String, Object> getActivePart(DocumentProperties documentProperties)
+		throws Exception {
+
+		return mDocument.getActivePart(documentProperties);
+	}
+
+	public Map<String, Object> getNextPart(DocumentProperties documentProperties)
+		throws Exception {
+
+		return mDocument.getNextPart(documentProperties);
+	}
+    
     /**
      * Applies the (known) operations to upon the latest state of the ODF text
      * document
@@ -298,7 +331,8 @@ public class OdfOperationDocument {
         mPackage.remove("Thumbnails/thumbnail.png");
     }
 
-    private void addOriginalOdfAsDebug() {
+    private void addOriginalOdfAsDebug() 
+    		throws SAXException {
         OdfPackage pkg = mDocument.getPackage();
         // if there is not already an orignal file being stored
         if (!pkg.contains(ORIGNAL_ODT_FILE)) {
