@@ -25,21 +25,38 @@ package org.odftoolkit.odfdom.doc;
 
 import java.io.File;
 import java.io.InputStream;
+import java.util.HashMap;
 import java.util.Map;
 import java.util.logging.Level;
 import java.util.logging.Logger;
+
+import org.json.JSONArray;
+import org.json.JSONException;
+import org.json.JSONObject;
+import org.odftoolkit.odfdom.component.OdfOperationDocument;
 import org.odftoolkit.odfdom.dom.OdfSettingsDom;
 
 import org.odftoolkit.odfdom.dom.element.office.OfficeTextElement;
 import org.odftoolkit.odfdom.incubator.doc.text.OdfTextParagraph;
 import org.odftoolkit.odfdom.pkg.MediaType;
+import org.odftoolkit.odfdom.pkg.OdfFileDom;
 import org.odftoolkit.odfdom.pkg.OdfPackage;
+import org.w3c.dom.Document;
 import org.w3c.dom.Element;
 import org.w3c.dom.Node;
 import org.w3c.dom.NodeList;
 import org.w3c.dom.Text;
 import org.xml.sax.SAXException;
 
+import com.openexchange.office.DocumentProperties;
+import com.openexchange.office.FilterException;
+import com.openexchange.office.FilterException.ErrorCode;
+import com.openexchange.office.odf.OdfOperationDoc;
+import com.openexchange.office.odf.Settings;
+import com.openexchange.office.ods.dom.ODSStyles;
+import com.openexchange.office.odt.dom.Content;
+import com.openexchange.office.odt.dom.ODTStyles;
+
 /**
  * This class represents an empty ODF text document.
  *
@@ -356,4 +373,58 @@ public class OdfTextDocument extends OdfDocument {
 		}
 		return hasTabsRelativeToIndent;
 	}
+
+	@Override
+    public OdfFileDom newFileDom(String packagePath) throws SAXException {
+
+		OdfFileDom newFileDom = null;
+        // before creating a new dom, make sure that there no DOM opened for this file already
+        Document existingDom = getPackage().getCachedDom(packagePath);
+        if (existingDom == null) {
+        	if(isOdt2()) {
+	            if (packagePath.equals("content.xml") || packagePath.endsWith("/content.xml")) {
+	                newFileDom = new Content(this, packagePath);
+	            }
+	            else if (packagePath.equals("styles.xml") || packagePath.endsWith("/styles.xml")) {
+	                newFileDom = new ODTStyles(this, packagePath);
+	            }
+	            else if (packagePath.equals("settings.xml") || packagePath.endsWith("/settings.xml")) {
+	            	newFileDom = new Settings(this, packagePath);
+	            }
+        	}
+        }
+        if(newFileDom==null) {
+        	newFileDom = super.newFileDom(packagePath);
+        }
+        return newFileDom;
+    }
+
+	@Override
+    public int applyOperations(OdfOperationDocument operationDoc, JSONArray ops)
+    	throws Exception {
+
+		if(isOdt2()) {
+			return new com.openexchange.office.odt.dom.JsonOperationConsumer(operationDoc).applyOperations(ops);
+		}
+		else {
+	    	return super.applyOperations(operationDoc, ops);
+		}
+    }
+
+	@Override
+    public JSONObject getOperations(OdfOperationDocument operationDoc)
+       	throws SAXException, JSONException {
+
+		if(isOdt2()) {
+			return new com.openexchange.office.odt.dom.JsonOperationProducer(operationDoc).getDocumentOperations();
+		}
+		else {
+			return super.getOperations(operationDoc);
+		}
+    }
+
+	private boolean isOdt2() {
+		final Object odt2 = getPackage().getRunTimeConfiguration().get("odt2");
+		return odt2 instanceof Boolean && ((Boolean)odt2).booleanValue();
+	}
 }
