@@ -29,9 +29,6 @@ import java.util.List;
 import java.util.logging.Level;
 import java.util.logging.Logger;
 
-import org.odftoolkit.odfdom.pkg.OdfElement;
-import org.odftoolkit.odfdom.pkg.OdfFileDom;
-import org.odftoolkit.odfdom.pkg.OdfName;
 import org.odftoolkit.odfdom.doc.OdfDocument;
 import org.odftoolkit.odfdom.dom.OdfDocumentNamespace;
 import org.odftoolkit.odfdom.dom.attribute.fo.FoTextAlignAttribute;
@@ -65,6 +62,9 @@ import org.odftoolkit.odfdom.incubator.doc.office.OdfOfficeAutomaticStyles;
 import org.odftoolkit.odfdom.incubator.doc.style.OdfStyle;
 import org.odftoolkit.odfdom.incubator.doc.text.OdfTextParagraph;
 import org.odftoolkit.odfdom.incubator.doc.text.OdfWhitespaceProcessor;
+import org.odftoolkit.odfdom.pkg.OdfElement;
+import org.odftoolkit.odfdom.pkg.OdfFileDom;
+import org.odftoolkit.odfdom.pkg.OdfName;
 import org.odftoolkit.odfdom.type.Color;
 import org.w3c.dom.NamedNodeMap;
 import org.w3c.dom.Node;
@@ -76,6 +76,7 @@ import org.w3c.dom.Node;
  *
  * @deprecated As of release 0.8.8, replaced by {@link org.odftoolkit.simple.table.Cell} in Simple API.
  */
+@Deprecated
 public class OdfTableCell {
 
 	TableTableCellElementBase mOdfElement;
@@ -1547,7 +1548,7 @@ public class OdfTableCell {
 				style = mDocument.getDocumentStyles().getNumberStyle(name);
 			}
 			if (style != null) {
-				return style.getFormat();
+				return style.getFormat(true);
 			}
 		} else if (typeValue == OfficeValueTypeAttribute.Value.DATE) {
 			String name = getDataDisplayStyleName();
@@ -1565,7 +1566,7 @@ public class OdfTableCell {
 				dataStyle = mDocument.getDocumentStyles().getCurrencyStyle(name);
 			}
 			if (dataStyle != null) {
-				return dataStyle.getFormat();
+				return dataStyle.getFormat(true);
 			}
 		} else if (typeValue == OfficeValueTypeAttribute.Value.PERCENTAGE) {
 			String name = getDataDisplayStyleName();
@@ -1574,7 +1575,7 @@ public class OdfTableCell {
 				style = mDocument.getDocumentStyles().getPercentageStyle(name);
 			}
 			if (style != null) {
-				return style.getFormat();
+				return style.getFormat(true);
 			}
 		}
 		return null;
