@@ -72,6 +72,11 @@ import org.w3c.dom.NodeList;
 import org.xml.sax.ErrorHandler;
 import org.xml.sax.SAXException;
 
+import com.openexchange.office.DocumentProperties;
+import com.openexchange.office.FilterException;
+import com.openexchange.office.odf.INodeAccessor;
+import com.openexchange.office.odf.OdfOperationDoc;
+
 /**
  * A document in ODF is from the package view a directory with a media type. If
  * the media type represents a document described by the ODF 1.2 Schema, certain
@@ -203,6 +208,32 @@ public abstract class OdfSchemaDocument extends OdfPackageDocument {
         return ops;
     }
 
+	public void initPartitioning(DocumentProperties documentProperties)
+		throws FilterException {
+	}
+
+	public Map<String, Object> getMetaData(DocumentProperties documentProperties)
+		throws Exception {
+
+		return new HashMap<String, Object>(1);
+	}
+
+	public Map<String, Object> getActivePart(DocumentProperties documentProperties)
+		throws Exception {
+
+		final HashMap<String, Object> activePart = new HashMap<String, Object>(1);
+		final OdfOperationDoc operationDocument = (OdfOperationDoc)documentProperties.get(DocumentProperties.PROP_DOCUMENT);
+		final JSONObject docOperations = getOperations(operationDocument.getOperationDocument());
+		activePart.put("operations", docOperations.getJSONArray("operations"));
+		return activePart;
+	}
+
+	public Map<String, Object> getNextPart(DocumentProperties documentProperties)
+		throws Exception {
+
+		return null;
+	}
+
     /**
      * The component tree is a high level abstraction of components (table,
      * paragraph, character, etc.) from the XML implementation details of the
@@ -725,4 +756,8 @@ public abstract class OdfSchemaDocument extends OdfPackageDocument {
     public OdfFileDom getFileDom(OdfXMLFile file) throws SAXException {
         return getFileDom(getXMLFilePath(file));
     }
+
+	public Map<String, INodeAccessor> getTargetNodes() {
+		return getPackage().getTargetNodes();
+	}
 }
