@@ -50,13 +50,6 @@ import org.odftoolkit.odfdom.dom.element.style.StyleTableColumnPropertiesElement
 import org.odftoolkit.odfdom.dom.element.style.StyleTablePropertiesElement;
 import org.odftoolkit.odfdom.dom.element.style.StyleTableRowPropertiesElement;
 import org.odftoolkit.odfdom.dom.element.style.StyleTextPropertiesElement;
-import org.odftoolkit.odfdom.dom.element.table.TableTableCellElement;
-import org.odftoolkit.odfdom.dom.element.table.TableTableColumnElement;
-import org.odftoolkit.odfdom.dom.element.table.TableTableElement;
-import org.odftoolkit.odfdom.dom.element.table.TableTableRowElement;
-import org.odftoolkit.odfdom.dom.element.text.TextHElement;
-import org.odftoolkit.odfdom.dom.element.text.TextPElement;
-import org.odftoolkit.odfdom.dom.element.text.TextSpanElement;
 import org.odftoolkit.odfdom.dom.style.OdfStyleFamily;
 import org.odftoolkit.odfdom.dom.style.OdfStylePropertySet;
 import org.odftoolkit.odfdom.dom.style.props.OdfStylePropertiesSet;
@@ -122,6 +115,7 @@ abstract public class OdfStyleBase extends OdfContainerElementBase implements Od
     /**
      * get a map containing all properties of this style and their values.
      * @return map of properties. 
+     * @Deprecated Broken by design as the same OdfStlyeProperty can occur multiple times and would be overwritten (e.g. background color exist 3times in cells).  
      */
     public Map<OdfStyleProperty, String> getStyleProperties() {
         TreeMap<OdfStyleProperty, String> result = new TreeMap<OdfStyleProperty, String>();
@@ -140,7 +134,8 @@ abstract public class OdfStyleBase extends OdfContainerElementBase implements Od
      * get a map containing all properties of this style and their values.
      * The map will also include any properties set by parent styles
      * @return  a map of all the properties.
-     */
+     * @Deprecated Broken by design as the same OdfStlyeProperty can occur multiple times and would be overwritten (e.g. background color exist 3times in cells). 
+     */  
     public Map<OdfStyleProperty, String> getStylePropertiesDeep() {
         TreeMap<OdfStyleProperty, String> result = new TreeMap<OdfStyleProperty, String>();
         OdfStyleBase style = this;
