@@ -272,6 +272,9 @@ public abstract class DataStyleElement extends OdfElement{
                 		numberText.setTextContent("%");
                 		this.appendChild(numberText);
                 	}
+                	else if(NumberFormatType.FORMAT_CURRENCY == type) {
+                		emitNumber(token.text, true);
+                	}
                 	else {
                 		emitNumber(token.text, false);
                 	}
