@@ -283,14 +283,18 @@ public class OdfNumberDateStyle extends NumberDateStyleElement {
 					i++;
 				}
 			} else {
-				textBuffer += ch;
-				i++;
-				//special handling "AM/PM"
-				if(textBuffer.length() >= 5 && textBuffer.substring(textBuffer.length() - 5).equalsIgnoreCase("AM/PM")){
-				    textBuffer = textBuffer.substring(0, textBuffer.length() - 5);
-	                NumberAmPmElement ampm = new NumberAmPmElement((OdfFileDom) this.getOwnerDocument());
-	                this.appendChild(ampm);
-				}
+                //special handling "AM/PM"
+                if(ch=='A' && format.startsWith("AM/PM", i)) {
+                    emitText(textBuffer);
+                    textBuffer = "";
+                    NumberAmPmElement ampm = new NumberAmPmElement((OdfFileDom) this.getOwnerDocument());
+                    this.appendChild(ampm);
+                    i+=5;
+                }
+                else {
+	                textBuffer += ch;
+	                i++;
+                }
 			}
 		}
         emitText(textBuffer);
