@@ -355,14 +355,17 @@ public class OdfOfficeAutomaticStyles extends OdfStylesBase {
         }
         return unique_name;
     }
-    private DataStyleElement createDataStyleElement(String numberFormatCode, String newDataStyleName) {
-        Value type = MapHelper.detectFormatType(numberFormatCode);
-        if(type == OfficeValueTypeAttribute.Value.VOID) {
+    private DataStyleElement createDataStyleElement(Value type, String numberFormatCode, String newDataStyleName) {
+    	Value t = type;
+    	if(t == OfficeValueTypeAttribute.Value.VOID) {
+    		t = MapHelper.detectFormatType(numberFormatCode);
+    	}
+    	if(t == OfficeValueTypeAttribute.Value.VOID) {
             return null;
         }
         OdfFileDom fileDom = (OdfFileDom) getOwnerDocument();
         DataStyleElement newStyle = null;
-        switch(type) {
+        switch(t) {
             case DATE:
                 newStyle = new OdfNumberDateStyle(fileDom, numberFormatCode, newDataStyleName);
             break;
@@ -390,7 +393,7 @@ public class OdfOfficeAutomaticStyles extends OdfStylesBase {
         }
         return newStyle;
     }
-    public DataStyleElement createDataStyle(String numberFormatCode, String newDataStyleName){
+    public DataStyleElement createDataStyle(Value type, String numberFormatCode, String newDataStyleName){
         /* conditional formats:
         - default conditions:
             tow parts: "value()>=0";"value()<0"
@@ -408,13 +411,13 @@ public class OdfOfficeAutomaticStyles extends OdfStylesBase {
         partArray.add(0, numberFormatCode);
 
         // this is the anchor style in case multiple parts are required
-        DataStyleElement newStyle = createDataStyleElement( partArray.get(partArray.size() - 1), newDataStyleName);
+        DataStyleElement newStyle = createDataStyleElement(type, partArray.get(partArray.size() - 1), newDataStyleName);
         if(partArray.size() > 1) {
             OdfFileDom fileDom = (OdfFileDom) getOwnerDocument();
             for( int partIndex = 0; partIndex < partArray.size() - 1; ++partIndex) {
                 String partStyleName = newDataStyleName + "P" + partIndex;
                 String part = partArray.get(partIndex);
-                DataStyleElement partStyle = createDataStyleElement( part, partStyleName );
+                DataStyleElement partStyle = createDataStyleElement(Value.VOID, part, partStyleName );
                 //generate an appropriate condition and add this style as sub style and make part style a volatile style
                 String condition = "value()";
                 // TODO: extract condition if available (e.g. '[>5]')
