@@ -54,6 +54,7 @@ import org.xml.sax.XMLReader;
 import org.xml.sax.helpers.DefaultHandler;
 
 import com.openexchange.office.FilterException;
+import com.openexchange.office.odf.INodeAccessor;
 
 /**
  * The DOM representation of an XML file within the ODF document.
@@ -543,4 +544,12 @@ public class OdfFileDom extends DocumentImpl implements NamespaceContext {
     public OdfNamespace setNamespace(NamespaceName name) {
         return setNamespace(name.getPrefix(), name.getUri());
     }
+
+	public Map<String, INodeAccessor> getTargetNodes() {
+		return getDocument().getPackage().getTargetNodes();
+	}
+
+	public String getNextMarkupId() {
+		return getDocument().getPackage().getNextMarkupId();
+	}
 }
