@@ -36,6 +36,7 @@ import java.lang.reflect.Constructor;
 import java.net.URI;
 import java.util.ArrayList;
 import java.util.Arrays;
+import java.util.Collections;
 import java.util.HashMap;
 import java.util.HashSet;
 import java.util.Iterator;
@@ -85,6 +86,9 @@ import org.xml.sax.SAXException;
 import org.xml.sax.SAXParseException;
 import org.xml.sax.XMLReader;
 
+import com.openexchange.office.odf.INodeAccessor;
+import com.openexchange.office.tools.parser.CharMatcher;
+
 /**
  * OdfPackage represents the package view to an OpenDocument document. The
  * OdfPackage will be created from an ODF document and represents a copy of the
@@ -108,7 +112,12 @@ public class OdfPackage implements Closeable {
 	private static final Pattern QUOTATION_PATTERN = Pattern.compile("\"");
 	private static final Pattern APOSTROPHE_PATTERN = Pattern.compile("'");
 	private static final Pattern CONTROL_CHAR_PATTERN = Pattern.compile("\\p{Cntrl}");
-	private static Set<String> mCompressedFileTypes;
+
+	private static final Set<String> COMPRESSEDFILETYPES;
+	private static final byte[] HREF_PATTERN = {'x', 'l', 'i', 'n', 'k', ':', 'h', 'r', 'e', 'f', '=', '"'}; // xlink:href="
+	private static final Set<String> CLEANUP_FILES;
+	
+
 	// some well known streams inside ODF packages
 	private String mMediaType;
 	private String mBaseURI;
@@ -119,13 +128,20 @@ public class OdfPackage implements Closeable {
 	private Map<String, OdfFileEntry> mManifestEntries;
 	// All opened documents from the same package are cached (including the root document)
 	private Map<String, OdfPackageDocument> mPkgDocuments;
+	// target nodes...
+	private Map<String, INodeAccessor> mTargetNodes;
+	// counter for ids that are not allowed to be saved (otherwise it is not guaranteed that this id is unique)
+	private int mTransientMarkupId = 0;
+
 	// Three different incarnations of a package file/data
 	// save() will check 1) mPkgDoms, 2) if not check mMemoryFileCache
 	private HashMap<String, Document> mPkgDoms;
 	private HashMap<String, byte[]> mMemoryFileCache;
-	private Map<String, Object> mConfiguration;
+	private Map<String, Object> mConfiguration = new HashMap<String, Object>();
 	private ErrorHandler mErrorHandler;
-    private String mManifestVersion;
+    private String mManifestVersion;    
+    
+    private Set<String> allUsedDrawings;
 
 	/* Commonly used files within the ODF Package */
 	public enum OdfFile {
@@ -148,11 +164,17 @@ public class OdfPackage implements Closeable {
 	}
 
 	static {
-		mCompressedFileTypes = new HashSet<String>();
+		HashSet<String> compressedFileTypes = new HashSet<String>();
 		String[] typelist = new String[]{"jpg", "gif", "png", "zip", "rar",
 			"jpeg", "mpe", "mpg", "mpeg", "mpeg4", "mp4", "7z", "ari",
 			"arj", "jar", "gz", "tar", "war", "mov", "avi"};
-		mCompressedFileTypes.addAll(Arrays.asList(typelist));
+		compressedFileTypes.addAll(Arrays.asList(typelist));
+		COMPRESSEDFILETYPES = Collections.unmodifiableSet(compressedFileTypes);
+		
+		HashSet<String> cleanUpFiles = new HashSet<>();
+		cleanUpFiles.add("styles.xml");
+		cleanUpFiles.add("content.xml");		
+		CLEANUP_FILES = Collections.unmodifiableSet(cleanUpFiles);
 	}
 
 	/**
@@ -163,6 +185,8 @@ public class OdfPackage implements Closeable {
 		mResolver = null;
 		mPkgDocuments = new HashMap<String, OdfPackageDocument>();
 		mPkgDoms = new HashMap<String, Document>();
+		mTargetNodes = new HashMap<String, INodeAccessor>();
+		mTransientMarkupId = 0;
 		mMemoryFileCache = new HashMap<String, byte[]>();
 		mManifestEntries = new HashMap<String, OdfFileEntry>();
 		// specify whether validation should be enabled and what SAX ErrorHandler should be used.
@@ -194,6 +218,7 @@ public class OdfPackage implements Closeable {
 		mOriginalZipEntries = null;
 		mManifestEntries = null;
 		mPkgDocuments = null;
+		mTargetNodes = null;
 		mPkgDoms = null;
 		mMemoryFileCache = null;
 		mConfiguration = null;
@@ -910,8 +935,10 @@ public class OdfPackage implements Closeable {
 	 *            - the path to the ODF package destination
 	 * @throws java.io.IOException
 	 *             - if the package could not be saved
+	 * @throws SAXException 
 	 */
-	public void save(String odfPath) throws IOException {
+	public void save(String odfPath) 
+			throws IOException, SAXException {
 		File f = new File(odfPath);
 		save(f);
 	}
@@ -923,8 +950,10 @@ public class OdfPackage implements Closeable {
 	 *            - the File to save the ODF package to
 	 * @throws java.lang.IOException
 	 *             - if the package could not be saved
+	 * @throws SAXException 
 	 */
-	public void save(File pkgFile) throws IOException {
+	public void save(File pkgFile) 
+			throws IOException, SAXException {
 		String baseURL = getBaseURLFromFile(pkgFile);
 //		if (baseURL.equals(mBaseURI)) {
 //			// save to the same file: cache everything first
@@ -944,8 +973,10 @@ public class OdfPackage implements Closeable {
 	 * Saves the package to a given {@link OutputStream}. The given stream is not closed by this method.
 	 * @param odfStream the output stream
 	 * @throws IOException if an I/O error occurs while saving the package
+	 * @throws SAXException 
 	 */
-	public void save(OutputStream odfStream) throws IOException {
+	public void save(OutputStream odfStream) 
+			throws IOException, SAXException {
 		save(odfStream, null);
 	}
 
@@ -956,8 +987,10 @@ public class OdfPackage implements Closeable {
 	 *            - the OutputStream to insert content to
 	 * @param baseURL defining the location of the package
 	 * @throws java.io.IOException if an I/O error occurs while saving the package
+	 * @throws SAXException 
 	 */
-	private void save(OutputStream odfStream, String baseURL) throws IOException {
+	private void save(OutputStream odfStream, String baseURL) 
+			throws IOException, SAXException {
 		mBaseURI = baseURL;
 		OdfFileEntry rootEntry = mManifestEntries.get(SLASH);
 		if (rootEntry == null) {
@@ -970,39 +1003,47 @@ public class OdfPackage implements Closeable {
 		try {
 			// remove mediatype path and use it as first
 			this.mManifestEntries.remove(OdfFile.MEDIA_TYPE.getPath());
-			Iterator<String> it = mManifestEntries.keySet().iterator();
-			String path = null;
-			boolean isFirstFile = true;
+			Set<String> keys = mManifestEntries.keySet();
+			Set<String> drawings = new HashSet<>();
+			
 			CRC32 crc = new CRC32();
 			long modTime = (new java.util.Date()).getTime();
-			while (it.hasNext() || isFirstFile) {
-				byte[] data = null;
-				// ODF requires the "mimetype" file to be at first in the package
-				if (isFirstFile) {
-					isFirstFile = false;
-					// create "mimetype" from current attribute value
-					data = mMediaType.getBytes("UTF-8");
-					createZipEntry(OdfFile.MEDIA_TYPE.getPath(), data, zos, modTime, crc);
-					// Create "META-INF/" directory
-					createZipEntry("META-INF/", null, zos, modTime, crc);
-					// Create "META-INF/manifest.xml" file
-					data = getBytes(OdfFile.MANIFEST.getPath());
-					createZipEntry(OdfFile.MANIFEST.getPath(), data, zos, modTime, crc);
-				} else {
-					path = it.next();
-					// not interested to reuse previous mediaType nor manifest from ZIP
-					if (!path.endsWith(SLASH) && !path.equals(OdfPackage.OdfFile.MANIFEST.getPath())
-							&& !path.equals(OdfPackage.OdfFile.MEDIA_TYPE.getPath())) {
-						data = getBytes(path);
-						createZipEntry(path, data, zos, modTime, crc);
-					}
+			
+			// ODF requires the "mimetype" file to be at first in the package
+			// create "mimetype" from current attribute value
+			createZipEntry(OdfFile.MEDIA_TYPE.getPath(), mMediaType.getBytes("UTF-8"), zos, modTime, crc);
+			// Create "META-INF/" directory
+			createZipEntry("META-INF/", null, zos, modTime, crc);
+			
+			for (String path : keys) {
+				if (path.startsWith("Pictures/") && !path.equals("Pictures/")) {
+					drawings.add(path);
+					continue;
 				}
+				createZipEntry(path, zos, modTime, crc, allUsedDrawings);							
 			}
+			
+			checkUnusedRelations(drawings, allUsedDrawings);		
+			
+			for (String path : drawings) {
+				createZipEntry(path, zos, modTime, crc, null);							
+			}
+			
+			// Create "META-INF/manifest.xml" file
+			createZipEntry(OdfFile.MANIFEST.getPath(), getBytes(OdfFile.MANIFEST.getPath()), zos, modTime, crc);
 		} finally {
 			zos.close();
 		}
 		odfStream.flush();
 	}
+	
+	private void createZipEntry(String path, ZipOutputStream zos, long modTime, CRC32 crc, Set<String> usedDrawings) 
+			throws IOException{
+		// not interested to reuse previous mediaType nor manifest from ZIP
+		if (!path.endsWith(SLASH) && !path.equals(OdfPackage.OdfFile.MANIFEST.getPath()) && !path.equals(OdfPackage.OdfFile.MEDIA_TYPE.getPath())) {
+			createZipEntry(path, getBytes(path, usedDrawings), zos, modTime, crc);
+		}
+	}
 
 	private void createZipEntry(String path, byte[] data, ZipOutputStream zos, long modTime, CRC32 crc)
 			throws IOException {
@@ -1049,7 +1090,7 @@ public class OdfPackage implements Closeable {
 		// see if the file was already compressed
 		if (internalPath.lastIndexOf(".") > 0) {
 			String suffix = internalPath.substring(internalPath.lastIndexOf(".") + 1, internalPath.length());
-			if (mCompressedFileTypes.contains(suffix.toLowerCase())) {
+			if (COMPRESSEDFILETYPES.contains(suffix.toLowerCase())) {
 				result = false;
 			}
 		}
@@ -1650,7 +1691,7 @@ public class OdfPackage implements Closeable {
 			return buf.toString();
 		}
 	}
-
+	
 	/**
 	 * Get package (sub-) content as byte array
 	 *
@@ -1658,6 +1699,16 @@ public class OdfPackage implements Closeable {
 	 * @return the unzipped package content as byte array
 	 */
 	public byte[] getBytes(String internalPath) {
+		return getBytes(internalPath, null);
+	}
+
+	/**
+	 * Get package (sub-) content as byte array
+	 *
+	 * @param internalPath relative documentURL to the package content
+	 * @return the unzipped package content as byte array
+	 */
+	public byte[] getBytes(String internalPath, Set<String> usedDrawings) {
 		// if path is null or empty return null
 		if (internalPath == null || internalPath.equals(EMPTY_STRING)) {
 			return null;
@@ -1710,10 +1761,10 @@ public class OdfPackage implements Closeable {
 				InputStream inputStream = null;
 				try {
 					inputStream = mZipFile.getInputStream(entry);
-					if (inputStream != null) {
+					if (inputStream != null) {					
 						ByteArrayOutputStream out = new ByteArrayOutputStream();
 						StreamHelper.transformStream(inputStream, out);
-						data = out.toByteArray();
+						data = out.toByteArray();						
 						// store for further usage; do not care about manifest: that
 						// is handled exclusively
 						mMemoryFileCache.put(internalPath, data);
@@ -1732,6 +1783,9 @@ public class OdfPackage implements Closeable {
 				}
 			}
 		}
+		if (null != data && null != usedDrawings && CLEANUP_FILES.contains(internalPath)) {
+			CharMatcher.findAllMatches(data, HREF_PATTERN, '"', usedDrawings, HREF_PATTERN.length);	
+		}
 		return data;
 	}
 
@@ -1749,7 +1803,12 @@ public class OdfPackage implements Closeable {
 				// acceptNode is called twice (beginNode and endNode) ... we will
 				// only write the object once
 				if(((++val)&1)!=0) {
-					((IElementWriter)nodeArg).writeObject(hdl);
+					try {
+						((IElementWriter)nodeArg).writeObject(hdl);
+					}
+					catch(SAXException e) {
+						
+					}
 				}
 				return LSParserFilter.FILTER_REJECT;
 			}
@@ -1856,8 +1915,10 @@ public class OdfPackage implements Closeable {
 	 * @return the ODF package as input stream
 	 * @throws java.io.IOException
 	 *             - if the package could not be read
+	 * @throws SAXException 
 	 */
-	public InputStream getInputStream() throws IOException {
+	public InputStream getInputStream() 
+			throws IOException, SAXException {
 		ByteArrayOutputStream out = new ByteArrayOutputStream();
 		save(out, mBaseURI);
 		return new ByteArrayInputStream(out.toByteArray());
@@ -2219,4 +2280,40 @@ public class OdfPackage implements Closeable {
 	String getManifestVersion(){
 		return mManifestVersion;
 	}
+
+	public void setCheckUnusedRelations(boolean checkUnusedRelations) {
+		if (checkUnusedRelations) {
+			allUsedDrawings = new HashSet<>();
+		} else {
+			allUsedDrawings = null;
+		}
+		
+	}
+	
+	private void checkUnusedRelations(Set<String> drawings, Set<String> usedDrawings) 
+			throws SAXException {
+		if (null != usedDrawings) {
+			Set<String> toDel = new HashSet<>();
+			
+			for(String draw : drawings) {
+				String search = "xlink:href=\"" + draw;
+				if (!usedDrawings.contains(search)) {
+					toDel.add(draw);
+					
+					mZipEntries.remove(draw);
+					mManifestEntries.remove(draw);
+				}
+			}
+			drawings.removeAll(toDel);
+		}
+		
+	}
+
+	public Map<String, INodeAccessor> getTargetNodes() {
+		return mTargetNodes;
+	}
+
+	public String getNextMarkupId() {
+		return Integer.toString(mTransientMarkupId++);
+	}
 }
