@@ -101,16 +101,12 @@ public class Exporter implements IExporter {
             OdfOperationDoc odtOperationDocument = null;
 
             try {
-                odtOperationDocument = new OdfOperationDoc(session, services,
-                        documentStm, resourceManager, documentProperties);
-                final OdfDocument odfDocument = odtOperationDocument
-                        .getDocument();
+                odtOperationDocument = new OdfOperationDoc(session, services, documentStm, resourceManager, documentProperties);
+                final OdfDocument odfDocument = odtOperationDocument.getDocument();
 
                 // Always overwrite uniqueDocumentID when writing changes..
                 if (documentProperties != null) {
-                    String statusId = documentProperties.optString(
-                            DocumentProperties.PROP_UNIQUE_DOCUMENT_IDENTIFIER,
-                            null);
+                    String statusId = documentProperties.optString(DocumentProperties.PROP_UNIQUE_DOCUMENT_IDENTIFIER, null);
                     if (statusId != null) {
                         odtOperationDocument.writeStatusID(statusId);
                     }
@@ -128,23 +124,24 @@ public class Exporter implements IExporter {
                         String initialCreator = metaDom.getInitialCreator();
                         if (metaDom != null) {
                             // only apply a change if the previous author was not the same
-                            if (lastModifiedBy != null
-                                    && (currentCreator == null || !currentCreator
-                                            .equals(lastModifiedBy))) {
+                            if (lastModifiedBy != null && (currentCreator == null || !currentCreator.equals(lastModifiedBy))) {
                                 metaDom.setCreator(lastModifiedBy);
                             }
-                            if (creator != null
-                                    && (initialCreator == null || !initialCreator
-                                    .equals(creator))) {
+                            if (creator != null && (initialCreator == null || !initialCreator.equals(creator))) {
                                 metaDom.setInitialCreator(creator);
                             }
                         }
                     }
                 }
-                odtOperationDocument.applyOperations(mergeOperations);
                 if (null != odfDocument) {
-                    final OdfPackage odfPackage = odfDocument.getPackage();
-
+                	odfDocument.getPackage().setCheckUnusedRelations(createFinalDocument);             
+                }
+                
+                odtOperationDocument.applyOperations(mergeOperations);
+              
+                if (null != odfDocument) {
+                	final OdfPackage odfPackage = odfDocument.getPackage();
+                		
                     if (null != odfPackage) {
                         resultStm = odfPackage.getInputStream();
                     }
