@@ -54,6 +54,7 @@ import java.io.ByteArrayInputStream;
 import java.io.IOException;
 import java.io.InputStream;
 import java.io.InputStreamReader;
+import java.util.Map;
 
 import org.json.JSONException;
 import org.json.JSONObject;
@@ -85,11 +86,9 @@ import com.openexchange.session.Session;
  */
 public class OdfOperationDoc {
 
-	private OdfOperationDocument mDocument;
 	private static final Logger LOG = LoggerFactory.getLogger(OdfOperationDoc.class);
     private static final String STATUS_ID_FILE = "debug/statusid.txt";
-    private MemoryListener memoryListener = null;
-
+    
     final private long FACTOR_FOR_REQUIRED_HEAPSPACE = 80;
     private static final String MODULE = "//module/";
     private static final String SPREADSHEET = "//spreadsheet/";
@@ -98,9 +97,13 @@ public class OdfOperationDoc {
     private static final String MAX_TABLE_ROWS = "maxTableRows";
     private static final String MAX_TABLE_CELLS = "maxTableCells";
     private static final String MAX_SHEETS = "maxSheets";
-    private final DocumentProperties documentProperties;
+
 	private static boolean lowMemoryAbort = false;
 	private static int successfulAppliedOperations = 0;
+	
+	private OdfOperationDocument mDocument;
+	private MemoryListener memoryListener = null;
+    private final DocumentProperties documentProperties;
 
     public OdfOperationDoc(Session session, ServiceLookup _services, InputStream _inputDocumentStream, IResourceManager resourceManager, DocumentProperties configuration) throws Exception {
     	try {
@@ -119,6 +122,8 @@ public class OdfOperationDoc {
 	        int maxSheets = ConfigurationHelper.getIntegerOfficeConfigurationValue(_services, session, SPREADSHEET + MAX_SHEETS, 256);
 	        configuration.put(MAX_SHEETS, maxSheets);
 
+	        configuration.put("odt2", Boolean.parseBoolean(ConfigurationHelper.getOfficeConfigurationValue(_services, session, MODULE + "odt2", "false")));
+
 	        // complexity check... TODO: distinguish between odt and odf
 	        final long maxAllowedXmlSizeMatchingComplexity = ConfigurationHelper.getIntegerOfficeConfigurationValue(_services, session, "//spreadsheet/maxCells", 500000) * 100;
         	final long maxAllowedXmlSizeMatchingMemory = configuration.optLong(DocumentProperties.PROP_MAX_MEMORY_USAGE, -1) / FACTOR_FOR_REQUIRED_HEAPSPACE;
@@ -183,7 +188,7 @@ public class OdfOperationDoc {
     // try to free up as much as possible ... the filter will then
     // most probably exit with an exception
     private void notifyLowMemory() {
-        LOG.info("ODF Filter: Low memory notification received");
+        LOG.debug("ODF Filter: Low memory notification received");
         setLowMemoryAbort(true);
         if(mDocument!=null) {
 	        // trying to free memory ...
@@ -217,13 +222,6 @@ public class OdfOperationDoc {
             ret = new FilterException("ODS FilterException...", ErrorCode.MEMORY_USAGE_MIN_FREE_HEAP_SPACE_REACHED);
         }
         else if(e instanceof FilterException) {
-    		final FilterException filterException = (FilterException)e;
-    		if(filterException.getErrorcode()==ErrorCode.COMPLEXITY_TOO_HIGH) {
-    			LOG.warn("could not load/save document, the document complexity is too high");
-    		}
-    		else if(filterException.getErrorcode()==ErrorCode.CRITICAL_ERROR) {
-    			LOG.error(e.getMessage(), e);
-    		}
     		ret = (FilterException)e;
     	}
     	else if (e instanceof java.util.zip.ZipException && e.getMessage().contains("only DEFLATED entries can have EXT descriptor")) {
@@ -233,7 +231,6 @@ public class OdfOperationDoc {
     		ret = new FilterException(e, ErrorCode.MEMORY_USAGE_MIN_FREE_HEAP_SPACE_REACHED);
     	}
     	else {
-    		LOG.error(e.getMessage(), e);
     		ret = new FilterException(e, ErrorCode.CRITICAL_ERROR);
     	}
     	ret.setOperationCount(OdfOperationDoc.getSuccessfulAppliedOperations());
@@ -251,13 +248,35 @@ public class OdfOperationDoc {
 
     	JSONObject ops = mDocument.getOperations();
         if (ops != null) {
-            LOG.info("\n\n*** ALL OPERATIONS:\n{0}", ops.toString());
+            LOG.debug("\n\n*** ALL OPERATIONS:\n{0}", ops.toString());
         } else {
-            LOG.info("\n\n*** ALL OPERATIONS:\n" + null);
+            LOG.debug("\n\n*** ALL OPERATIONS:\n" + null);
         }
         return ops;
     }
 
+	public void initPartitioning(DocumentProperties documentProperties) {
+		mDocument.initPartitioning(documentProperties);
+	}
+
+    public Map<String, Object> getMetaData(DocumentProperties documentProperties)
+		throws Exception {
+
+		return mDocument.getMetaData(documentProperties);
+	}
+
+	public Map<String, Object> getActivePart(DocumentProperties documentProperties)
+		throws Exception {
+
+		return mDocument.getActivePart(documentProperties);
+	}
+
+	public Map<String, Object> getNextPart(DocumentProperties documentProperties)
+		throws Exception {
+
+		return mDocument.getNextPart(documentProperties);
+	}
+
     /**
      * Applies the (known) operations to upon the latest state of the ODF text
      * document
@@ -276,7 +295,7 @@ public class OdfOperationDoc {
      */
     void writeStatusID(String statusId) {
         OdfPackage pkg = mDocument.getPackage();
-        LOG.info("Overwriting ODT document status ID " + STATUS_ID_FILE);
+        LOG.debug("Overwriting ODT document status ID " + STATUS_ID_FILE);
         pkg.insert(statusId.getBytes(), STATUS_ID_FILE, "text/plain");
     }
 
@@ -296,9 +315,9 @@ public class OdfOperationDoc {
                 try {
                     statusId = reader.readLine();
                 } catch (IOException e) {
-                    LOG.info("No existing status ID file found!");
+                    LOG.debug("No existing status ID file found!");
                 }
-                LOG.info("Found an existing status ID:{0}", statusId);
+                LOG.debug("Found an existing status ID:{0}", statusId);
             }
         }
         return statusId;
@@ -317,6 +336,10 @@ public class OdfOperationDoc {
         return mDocument.getDocument();
     }
 
+    public OdfOperationDocument getOperationDocument() {
+    	return mDocument;
+    }
+
     /**
      * Close the OdfPackage and release all temporary created data. After
      * execution of this method, this class is no longer usable. Do this as the
