@@ -53,14 +53,11 @@ import java.util.List;
 
 import org.apache.xerces.dom.ElementNSImpl;
 import org.apache.xml.serializer.SerializationHandler;
-import org.json.JSONException;
-import org.json.JSONObject;
-import org.odftoolkit.odfdom.Names;
 import org.odftoolkit.odfdom.doc.OdfDocument;
-import org.odftoolkit.odfdom.doc.OdfSpreadsheetDocument;
 import org.odftoolkit.odfdom.dom.OdfDocumentNamespace;
 import org.odftoolkit.odfdom.dom.attribute.office.OfficeBooleanValueAttribute;
 import org.odftoolkit.odfdom.dom.attribute.office.OfficeCurrencyAttribute;
+import org.odftoolkit.odfdom.dom.attribute.office.OfficeStringValueAttribute;
 import org.odftoolkit.odfdom.dom.attribute.office.OfficeValueAttribute;
 import org.odftoolkit.odfdom.dom.attribute.office.OfficeValueTypeAttribute;
 import org.odftoolkit.odfdom.dom.attribute.table.TableFormulaAttribute;
@@ -86,16 +83,31 @@ import org.odftoolkit.odfdom.pkg.OdfFileDom;
 import org.odftoolkit.odfdom.pkg.OdfName;
 import org.xml.sax.SAXException;
 
+import com.openexchange.office.odf.ElementNS;
+import com.openexchange.office.odf.SaxContextHandler;
 import com.openexchange.office.ods.dom.SmlUtils.CellRef;
 
 public class Cell implements Comparable<Cell> {
 
+	public static class ErrorCode {
+
+		final String errorCode;
+
+		public ErrorCode(String errorCode) {
+			this.errorCode = errorCode;
+		}
+		public String getError() {
+			return errorCode;
+		}
+	}
+
 	int column;
 	private String cellStyle = null;
 	private int repeated = 1;
 
 	// the cell content is stored in one of the two following variables
 	private Object content = null;				// immutable objects only, otherwise the clone needs to be changed
+	private String formula = null;
 	private ElementNS element = null;
 	private CellAttributesEnhanced cellAttributesEnhanced = null;
 
@@ -185,38 +197,30 @@ public class Cell implements Comparable<Cell> {
 			cellAttributesEnhanced.writeAttributes(output);
 		}
 		if(content!=null) {
+			if(formula!=null) {
+            	SaxContextHandler.addOdfAttribute(output, TableFormulaAttribute.ATTRIBUTE_NAME, null, "of:=".concat(formula));
+			}
 			if(content instanceof String) {
 				final String contentString = (String)content;
-				if(contentString.startsWith(Names.EQUATION)) {
-					// writing an equation
-                	SaxContextHandler.addOdfAttribute(output, TableFormulaAttribute.ATTRIBUTE_NAME, null, "of:".concat(contentString));
-				}
-				else if(!contentString.isEmpty()) {
+				if(!contentString.isEmpty()) {
 					SaxContextHandler.addOdfAttribute(output, OfficeValueTypeAttribute.ATTRIBUTE_NAME, null, "string");
 	            	SaxContextHandler.addOdfAttribute(output, CalcExtValueTypeAttributeName, null, "string");
-
-	            	final String[] paragraphs = contentString.split("\r\n|\n|\r");
-	            	for(int i=0; i<paragraphs.length; i++) {
-		            	// simply writing text ... what to do if the content is a error an starts with '#'
-	    	        	SaxContextHandler.startElement(output, TextPElement.ELEMENT_NAME);
-		            	final Hyperlink hyperlink = i==0 ? sheet.getHyperlink(column, row.getRow()) : null;
-		            	if(hyperlink!=null) {
-		            		SaxContextHandler.startElement(output, TextAElement.ELEMENT_NAME);
-		            		SaxContextHandler.addOdfAttribute(output, XlinkTypeAttribute.ATTRIBUTE_NAME, null, "simple");
-		            		SaxContextHandler.addOdfAttribute(output, XlinkHrefAttribute.ATTRIBUTE_NAME, null, hyperlink.getUrl());
-		            	}
-	    	        	output.characters(paragraphs[i]);
-	    	        	if(hyperlink!=null) {
-	    	        		SaxContextHandler.endElement(output, TextAElement.ELEMENT_NAME);
-	    	        	}
-	    	        	SaxContextHandler.endElement(output, TextPElement.ELEMENT_NAME);
-	            	}
+	            	writeContentString(output, sheet, row, contentString);
 				}
 			}
 			else if(content instanceof Boolean) {
             	SaxContextHandler.addOdfAttribute(output, OfficeValueTypeAttribute.ATTRIBUTE_NAME, null, "boolean");
             	SaxContextHandler.addOdfAttribute(output, CalcExtValueTypeAttributeName, null, "boolean");
             	SaxContextHandler.addOdfAttribute(output, OfficeBooleanValueAttribute.ATTRIBUTE_NAME, null, ((Boolean)content)?"true":"false");
+			}
+			else if(content instanceof ErrorCode) {
+            	SaxContextHandler.addOdfAttribute(output, OfficeValueTypeAttribute.ATTRIBUTE_NAME, null, "string");
+            	SaxContextHandler.addOdfAttribute(output, OfficeStringValueAttribute.ATTRIBUTE_NAME, null, "");
+            	SaxContextHandler.addOdfAttribute(output, CalcExtValueTypeAttributeName, null, "error");
+            	final String errorCode = ((ErrorCode)content).getError();
+            	if(errorCode!=null) {
+            		writeContentString(output, sheet, row, errorCode);
+            	}
 			}
 			else if(content instanceof Number) {
 				String valueType = "float";
@@ -234,6 +238,8 @@ public class Cell implements Comparable<Cell> {
 	            final OdfDocument odfDoc = (OdfDocument)xDoc.getDocument();
 	            final OdfOfficeStyles officeStyles = odfDoc.getStylesDom().getOfficeStyles();
 	            OdfStyle ownStyle = officeStyles.getStyle(styleName, OdfStyleFamily.TableCell);
+	            boolean officeValueAttributeRequired = true;
+
 	            if(ownStyle == null) {
 	                ownStyle = odfDoc.getContentDom().getAutomaticStyles().getStyle(styleName, OdfStyleFamily.TableCell);
 	            }
@@ -260,14 +266,17 @@ public class Cell implements Comparable<Cell> {
 		                		valueType = "date";
 		                	}
 		                	else if(dataStyle instanceof OdfNumberTimeStyle) {
-		                		// TODO: time-value instead of office-value should be created
+//		    	            	SaxContextHandler.addOdfAttribute(output, OfficeTimeValueAttribute.ATTRIBUTE_NAME, null, MapHelper.doubleToTime(((Number)content).doubleValue()));
+//		    	            	officeValueAttributeRequired = false;
 		                		valueType = "time";
 		                	}
 		                }
 		            }
 	            }
-	            SaxContextHandler.addOdfAttribute(output, OfficeValueAttribute.ATTRIBUTE_NAME, null, ((Number)content).toString());
-				SaxContextHandler.addOdfAttribute(output, OfficeValueTypeAttribute.ATTRIBUTE_NAME, null, valueType);
+	            if(officeValueAttributeRequired) {
+	            	SaxContextHandler.addOdfAttribute(output, OfficeValueAttribute.ATTRIBUTE_NAME, null, ((Number)content).toString());
+	            }
+	            SaxContextHandler.addOdfAttribute(output, OfficeValueTypeAttribute.ATTRIBUTE_NAME, null, valueType);
             	SaxContextHandler.addOdfAttribute(output, CalcExtValueTypeAttributeName, null, valueType);
 			}
 		}
@@ -283,7 +292,28 @@ public class Cell implements Comparable<Cell> {
 		SaxContextHandler.endElement(output, elementCellName);
 	}
 
-    public Object getCellContent() {
+	private void writeContentString(SerializationHandler output, Sheet sheet, Row row, String contentString)
+		throws SAXException {
+
+		final String[] paragraphs = contentString.split("\r\n|\n|\r");
+    	for(int i=0; i<paragraphs.length; i++) {
+        	// simply writing text ... what to do if the content is a error an starts with '#'
+        	SaxContextHandler.startElement(output, TextPElement.ELEMENT_NAME);
+        	final Hyperlink hyperlink = i==0 ? sheet.getHyperlink(column, row.getRow()) : null;
+        	if(hyperlink!=null) {
+        		SaxContextHandler.startElement(output, TextAElement.ELEMENT_NAME);
+        		SaxContextHandler.addOdfAttribute(output, XlinkTypeAttribute.ATTRIBUTE_NAME, null, "simple");
+        		SaxContextHandler.addOdfAttribute(output, XlinkHrefAttribute.ATTRIBUTE_NAME, null, hyperlink.getUrl());
+        	}
+        	output.characters(paragraphs[i]);
+        	if(hyperlink!=null) {
+        		SaxContextHandler.endElement(output, TextAElement.ELEMENT_NAME);
+        	}
+        	SaxContextHandler.endElement(output, TextPElement.ELEMENT_NAME);
+    	}
+	}
+
+	public Object getCellContent() {
 		return content;
     }
 
@@ -291,6 +321,14 @@ public class Cell implements Comparable<Cell> {
     	content = value;
     }
 
+    public String getCellFormula() {
+    	return formula;
+    }
+
+    public void setCellFormula(String formula) {
+    	this.formula = formula;
+    }
+
     public Cell clone(boolean cloneContent) {
     	final Cell clone = new Cell(column);
     	clone.setRepeated(getRepeated());
@@ -299,26 +337,16 @@ public class Cell implements Comparable<Cell> {
 	    	if(element!=null) {
 	    		clone.element = element.cloneNode(true);
 	    	}
-	    	else if(content!=null) {
-	    		clone.content = content;
+	    	else {
+	    		if(content!=null) {
+	    			clone.content = content;
+	    		}
+	    		clone.formula = formula;
 	    	}
     	}
     	return clone;
     }
 
-    public JSONObject createCellAttributes(Sheet sheet, String defaultCellStyle, OdfSpreadsheetDocument doc)
-       	throws JSONException, SAXException {
-
-    	final JSONObject attrs = new JSONObject();
-    	if(getCellStyle()!=null) {
-    		attrs.put("styleId", getCellStyle());
-    	}
-    	else if(defaultCellStyle!=null) {
-			attrs.put("styleId", defaultCellStyle);
-    	}
-    	return attrs.isEmpty()?null:attrs;
-    }
-
 	@Override
 	public int compareTo(Cell o) {
 		return column - o.getColumn();
