@@ -69,6 +69,9 @@ import org.odftoolkit.odfdom.type.Length.Unit;
 import org.w3c.dom.Element;
 import org.xml.sax.SAXException;
 
+import com.openexchange.office.odf.OfficeStyles;
+import com.openexchange.office.odf.SaxContextHandler;
+
 public class Column implements Comparable<Column>, IAttrs<Column>, IStyleAccess {
 
 	private String columnStyle;
@@ -205,9 +208,13 @@ public class Column implements Comparable<Column>, IAttrs<Column>, IStyleAccess
 	        		if(width!=null&&!width.isEmpty()) {
 	        			final Double dest = Length.getLength(width, Unit.MILLIMETER);
 	        			if(dest!=null) {
-	        				columnProperties.put("width", dest*100);
+	        				columnProperties.put("width", Math.round(dest*100));
 	        			}
 	        		}
+	        		final String customWidth = tableColumnProperties.getAttributeNS(OdfDocumentNamespace.STYLE.getUri(), "use-optimal-column-width");
+	        		if(customWidth!=null&&!customWidth.isEmpty()) {
+	                    columnProperties.put("customWidth", !Boolean.parseBoolean(customWidth));
+	        		}
         		}
         	}
         }
