@@ -49,9 +49,11 @@
 
 package com.openexchange.office.ods.dom;
 
-import java.util.ArrayList;
+import java.util.Iterator;
 import java.util.List;
+import java.util.Map.Entry;
 
+import org.apache.xerces.dom.ElementNSImpl;
 import org.odftoolkit.odfdom.doc.OdfSpreadsheetDocument;
 import org.odftoolkit.odfdom.dom.OdfContentDom;
 import org.odftoolkit.odfdom.dom.OdfDocumentNamespace;
@@ -60,6 +62,9 @@ import org.w3c.dom.Node;
 import org.xml.sax.SAXException;
 import org.xml.sax.XMLReader;
 
+import com.openexchange.office.odf.OfficeStyles;
+import com.openexchange.office.odf.Styles;
+
 /**
  * The DOM representation of the ODS content.xml file of an ODF document.
  */
@@ -71,6 +76,7 @@ public class Content extends OdfContentDom {
 	private NamedExpressions namedExpressions;
 	private DatabaseRanges databaseRanges;
 	private ContentValidations contentValidations;
+	private ElementNSImpl officeSpreadsheetElement;
 
 	/**
 	 * Creates the DOM representation of an XML file of an Odf document.
@@ -117,6 +123,7 @@ public class Content extends OdfContentDom {
 	// returns the sheetindex for the given name or -1 if this sheet was not found
 	public int getSheetIndex(String sheetName) {
 		if(sheetName!=null) {
+			sheetName = sheetName.replace("'", "");
 			for(int i=0; i<getSheets().size(); i++) {
 				final String name = getSheets().get(i).getSheetName();
 				if(sheetName.equals(name)) {
@@ -127,6 +134,14 @@ public class Content extends OdfContentDom {
 		return -1;
 	}
 
+	public void setSpreadsheet(ElementNSImpl element) {
+		officeSpreadsheetElement = element;
+	}
+
+	public void setNamedExpressions(NamedExpressions namedExpressions) {
+		this.namedExpressions = namedExpressions;
+	}
+
 	public NamedExpressions getNamedExpressions(boolean forceCreate) {
 		if(namedExpressions==null&&forceCreate) {
 			namedExpressions = new NamedExpressions(this);
@@ -137,22 +152,30 @@ public class Content extends OdfContentDom {
 				getSheets().get(0).getParentNode().insertBefore(namedExpressions, refNode);
 			}
 			else {
-				appendChild(namedExpressions);
+				officeSpreadsheetElement.appendChild(namedExpressions);
 			}
 		}
 		return namedExpressions;
 	}
 
+	public void setDatabaseRanges(DatabaseRanges databaseRanges) {
+		this.databaseRanges = databaseRanges;
+	}
+
 	public DatabaseRanges getDatabaseRanges(boolean forceCreate) {
 		if(databaseRanges==null&&forceCreate) {
 			databaseRanges = new DatabaseRanges(this);
 
-			if(!sheets.isEmpty()) {
+			if(namedExpressions!=null) {
+				// inserting database ranges behind named expressions, otherwise the document won't be opened by Excel
+				namedExpressions.getParentNode().insertBefore(databaseRanges, namedExpressions.getNextSibling());
+			}
+			else if(!sheets.isEmpty()) {
 				final Node refNode = getSheets().get(sheets.size()-1).getNextSibling();
 				getSheets().get(0).getParentNode().insertBefore(databaseRanges, refNode);
 			}
 			else {
-				appendChild(databaseRanges);
+				officeSpreadsheetElement.appendChild(databaseRanges);
 			}
 		}
 		return databaseRanges;
@@ -187,6 +210,18 @@ public class Content extends OdfContentDom {
 		final Sheet newSheet = new Sheet(this, null);
 		insertSheetNode(newSheet, sheetIndex);
 		newSheet.setSheetName(newName);
+
+		// update database ranges:
+		final DatabaseRanges databaseRanges = getDatabaseRanges(false);
+		if(databaseRanges!=null) {
+			final Iterator<Entry<String, DatabaseRange>> databaseRangeIter = databaseRanges.getDatabaseRangeList().entrySet().iterator();
+			while(databaseRangeIter.hasNext()) {
+				final Range range = databaseRangeIter.next().getValue().getRange();
+				if(range.getSheetIndex()>=sheetIndex) {
+					range.setSheetIndex(range.getSheetIndex()+1);
+				}
+			}
+		}
 	}
 
 	private void insertSheetNode(Sheet sheet, int sheetIndex) {
@@ -203,14 +238,50 @@ public class Content extends OdfContentDom {
 	}
 
 	public void moveSheet(int sheetIndex, int to) {
+		final Sheet sheet = getSheets().get(sheetIndex);
+		sheet.getParentNode().removeChild(sheet);
+		getSheets().remove(sheetIndex);
+        insertSheetNode(sheet, to);
 
-        insertSheetNode(deleteSheet(sheetIndex), to);
+        // update database ranges:
+        final DatabaseRanges databaseRanges = getDatabaseRanges(false);
+		if(databaseRanges!=null) {
+			final Iterator<Entry<String, DatabaseRange>> databaseRangeIter = databaseRanges.getDatabaseRangeList().entrySet().iterator();
+			while(databaseRangeIter.hasNext()) {
+				final Range range = databaseRangeIter.next().getValue().getRange();
+				if(range.getSheetIndex()==sheetIndex) {
+					range.setSheetIndex(to);
+					continue;
+				}
+				if(range.getSheetIndex()>sheetIndex) {
+					range.setSheetIndex(range.getSheetIndex()-1);
+				}
+				if(range.getSheetIndex()>=to) {
+					range.setSheetIndex(range.getSheetIndex()+1);
+				}
+			}
+		}
 	}
 
 	public Sheet deleteSheet(int sheetIndex) {
 		final Sheet sheet = getSheets().get(sheetIndex);
 		sheet.getParentNode().removeChild(sheet);
 		getSheets().remove(sheetIndex);
+
+		// update database ranges:
+		final DatabaseRanges databaseRanges = getDatabaseRanges(false);
+		if(databaseRanges!=null) {
+			final Iterator<Entry<String, DatabaseRange>> databaseRangeIter = databaseRanges.getDatabaseRangeList().entrySet().iterator();
+			while(databaseRangeIter.hasNext()) {
+				final Range range = databaseRangeIter.next().getValue().getRange();
+				if(range.getSheetIndex()==sheetIndex) {
+					databaseRangeIter.remove();
+				}
+				else if(range.getSheetIndex()>sheetIndex) {
+					range.setSheetIndex(range.getSheetIndex()-1);
+				}
+			}
+		}
 		return sheet;
 	}
 
