@@ -51,9 +51,8 @@ package com.openexchange.office.ods.dom;
 
 import java.util.List;
 
+import org.apache.xerces.dom.ElementNSImpl;
 import org.odftoolkit.odfdom.dom.OdfSchemaDocument;
-import org.slf4j.Logger;
-import org.slf4j.LoggerFactory;
 import org.w3c.dom.Node;
 import org.xml.sax.Attributes;
 import org.xml.sax.SAXException;
@@ -61,14 +60,16 @@ import org.xml.sax.XMLReader;
 
 import com.openexchange.office.FilterException;
 import com.openexchange.office.FilterException.ErrorCode;
+import com.openexchange.office.odf.DOMBuilder;
+import com.openexchange.office.odf.ElementNS;
+import com.openexchange.office.odf.OfficeAutomaticStylesHandler;
+import com.openexchange.office.odf.SaxContextHandler;
 
 /**
  * @author sven.jacobi@open-xchange.com
  */
 public class ContentHandler extends DOMBuilder {
 
-    private static final Logger LOG = LoggerFactory.getLogger(ContentHandler.class);
-
     // the empty XML file to which nodes will be added
     private final Content contentDom;
     private OdfSchemaDocument mSchemaDoc = null;
@@ -111,27 +112,29 @@ public class ContentHandler extends DOMBuilder {
 				}
     		}
     		final Sheet sheet = new Sheet(contentDom, sheetStyle);
-    		appendChild(ElementNS.addAttributes(getFileDom(), sheet, attributes));
+    		appendChild(ElementNS.addAttributes(sheet, attributes));
     		contentDom.getSheets().add(sheet);
     		return new SheetHandler(this, sheet);
     	}
     	else if(qName.equals("table:named-expressions")) {
-    		final NamedExpressions namedExpressions = contentDom.getNamedExpressions(true);
+    		final NamedExpressions namedExpressions = new NamedExpressions(contentDom);
+    		contentDom.setNamedExpressions(namedExpressions);
+    		appendChild(namedExpressions);
     		return new NamedExpressionsHandler(this, namedExpressions);
     	}
     	else if(qName.equals("table:database-ranges")) {
-    		final DatabaseRanges databaseRanges = contentDom.getDatabaseRanges(true);
+    		final DatabaseRanges databaseRanges = new DatabaseRanges(contentDom);
+    		contentDom.setDatabaseRanges(databaseRanges);
+    		appendChild(databaseRanges);
     		return new DatabaseRangesHandler(this, databaseRanges);
     	}
-/*
-    	else if(qName.equals("table:content-validations")) {
-    		final ContentValidations contentValidations = contentDom.getContentValidations(true);
-    		return new ContentValidationsHandler(this, contentValidations);
-    	}
-*/
-    	// if we come to this postion, the element is inserted normally into the dom...
+
+    	// if we come to this postion, a normal node is inserted into the dom...
     	final SaxContextHandler newContext = super.startElement(attributes, uri, localName, qName);
-    	if(qName.equals("office:automatic-styles")) {
+    	if(qName.equals("office:spreadsheet")) {
+    		getContentDom().setSpreadsheet((ElementNSImpl)getCurrentNode());
+    	}
+    	else if(qName.equals("office:automatic-styles")) {
     		// we want to have a special context for automatic styles
     		return new OfficeAutomaticStylesHandler(getCurrentNode(), newContext, this.getFileDom(), contentDom.getStyles());
     	}
@@ -141,6 +144,7 @@ public class ContentHandler extends DOMBuilder {
     @Override
     public void endElement(String localName, String qName)
     	throws SAXException {
+
     	super.endElement(localName, qName);
 
     	if(qName.equals("table:table")) {
