@@ -80,6 +80,9 @@ import org.odftoolkit.odfdom.pkg.OdfName;
 import org.w3c.dom.Node;
 import org.xml.sax.Attributes;
 
+import com.openexchange.office.odf.SaxContextHandler;
+import com.openexchange.office.ods.dom.SmlUtils.CellRefRange;
+
 public class DatabaseRange {
 
 	private String name;
@@ -165,7 +168,10 @@ public class DatabaseRange {
 	}
 
 	public void changeTableColumn(Content content, int col, JSONObject attrs) {
-		ElementNSImpl tableFilter = findAndRemoveColumn(col);
+        Node tableFilter = getFilterElementChild();
+        if(tableFilter!=null) {
+        	findAndRemoveColumn(tableFilter, col);
+        }
 		List<Object> entries = null;
         JSONObject filter = attrs.optJSONObject("filter");
         if(filter != null) {
@@ -185,14 +191,14 @@ public class DatabaseRange {
             if(tableFilter==null) {
                 //insert new filter
                 tableFilter = new TableFilterElement(content);
-                getChilds().add(0, tableFilter);
+                getChilds().add(0, (ElementNSImpl)tableFilter);
             }
             //insert new FilterOr with FilterCondition
             TableFilterOrElement tableFilterOr = new TableFilterOrElement(content);
             tableFilter.insertBefore(tableFilterOr, null);
             TableFilterConditionElement tableFilterCondition = new TableFilterConditionElement(content);
             tableFilterOr.insertBefore(tableFilterCondition, null);
-            tableFilterCondition.setAttributeNS(OdfDocumentNamespace.TABLE.getUri(), "table:field-number", Integer.toString(this.getRange().getCellRefRange().getStart().getColumn() + col));
+            tableFilterCondition.setAttributeNS(OdfDocumentNamespace.TABLE.getUri(), "table:field-number", Integer.toString(col));
             tableFilterCondition.setAttributeNS(OdfDocumentNamespace.TABLE.getUri(), "table:value", entries.get(0).toString() );
             tableFilterCondition.setAttributeNS(OdfDocumentNamespace.TABLE.getUri(), "table:operator", "=" );
             ListIterator<Object> entriesIt = entries.listIterator();
@@ -204,48 +210,73 @@ public class DatabaseRange {
         }
 	}
 
-	public void changeColumn(int position, int change) {
+	public void changeColumn(CellRefRange cellRefRange, int position, int change) {
         final Node tableFilter = getFilterElementChild();
         if(tableFilter!=null) {
-            Node filterChild = tableFilter.getFirstChild();
-            while(filterChild!=null) {
-                Node orChild = ((ElementNSImpl)filterChild).getFirstChild();
-            	if(orChild.getLocalName().equals("filter-condition")) {
-            		int column = Integer.parseInt(((ElementNSImpl)orChild).getAttributeNS(TableFieldNumberAttribute.ATTRIBUTE_NAME.getUri(), "field-number"));
-                	if(position<=column) {
-                		column+=change;
-                	}
-                	((ElementNSImpl)orChild).setAttributeNS(TableFieldNumberAttribute.ATTRIBUTE_NAME.getUri(), "table:field-number", Integer.toString(column));
-                }
-                filterChild = filterChild.getNextSibling();
-            }
+        	changeColumnChilds(tableFilter, cellRefRange, position, change);
         }
 	}
 
-	private ElementNSImpl findAndRemoveColumn(int col) {
-        final Node tableFilter = getFilterElementChild();
-        if(tableFilter!=null) {
-            // if it contains a TableFilterAnd -> remove it, it breaks our AutoFilter support ATM
-            Node filterChild = tableFilter.getFirstChild();
-            while(filterChild!=null) {
-                Node nextChild = filterChild.getNextSibling();
-                if(filterChild.getLocalName().equals("filter-and")) {
-                    tableFilter.removeChild(filterChild);
-                } else if(filterChild.getLocalName().equals("filter-or")) {
-                    Node orChild = ((ElementNSImpl)filterChild).getFirstChild();
-                    if(orChild.getLocalName().equals("filter-and")) {
-                        tableFilter.removeChild(filterChild);
-                    } else if(orChild.getLocalName().equals("filter-condition")) {
-                        String column = ((ElementNSImpl)orChild).getAttributeNS(TableFieldNumberAttribute.ATTRIBUTE_NAME.getUri(), "field-number");
-                        if(Integer.parseInt(column)==col) {
-                            tableFilter.removeChild(filterChild);
-                        }
-                    }
-                }
-                filterChild = nextChild;
-            }
+    private void changeColumnChilds(Node childNode, CellRefRange cellRefRange, int position, int change) {
+    	while(childNode!=null) {
+	    	Node nextChild = childNode.getNextSibling();
+	    	if(childNode.getLocalName().equals("filter-condition")) {
+	    		String fieldNumber = ((ElementNSImpl)childNode).getAttributeNS(TableFieldNumberAttribute.ATTRIBUTE_NAME.getUri(), "field-number");
+	    		if(!fieldNumber.isEmpty()) {
+	    			int column = Integer.parseInt(fieldNumber);
+	    			if(change>0) {
+	    				if((position>cellRefRange.getStart().getColumn())&&(position<=cellRefRange.getStart().getColumn()+column)) {
+	    					column+=change;
+	    				}
+	    			}
+	    			else {
+    					int delColStart = position - cellRefRange.getStart().getColumn();
+    					int delColEnd = (delColStart - change) - 1;
+
+    					if(column>=delColStart && column<=delColEnd) {
+							childNode.getParentNode().removeChild(childNode);
+							childNode = null;
+						}
+						else if (cellRefRange.getStart().getColumn() + column >= position) {
+							column+=change;
+    					}
+	    			}
+	    			if(childNode!=null) {
+	    				((ElementNSImpl)childNode).setAttributeNS(TableFieldNumberAttribute.ATTRIBUTE_NAME.getUri(), "table:field-number", Integer.toString(column));
+	    			}
+	    		}
+	    	}
+	    	if(childNode!=null) {
+	    		final Node childChild = childNode.getFirstChild();
+	        	if(childChild!=null) {
+	        		changeColumnChilds(childChild, cellRefRange, position, change);
+	        	}
+	    	}
+	    	childNode = nextChild;
+    	}
+    }
+
+	private void findAndRemoveColumn(Node node, int col) {
+        while(node!=null) {
+        	final Node nextNode = node.getNextSibling();
+        	if(node.getLocalName().equals("filter-condition")) {
+	            String column = ((ElementNSImpl)node).getAttributeNS(TableFieldNumberAttribute.ATTRIBUTE_NAME.getUri(), "field-number");
+	            if(Integer.parseInt(column)==col) {
+	            	node.getParentNode().removeChild(node);
+	            }
+        	}
+        	else {
+        		final Node child = node.getFirstChild();
+        		if(child!=null) {
+        			findAndRemoveColumn(child, col);
+        			// the filter node itself does not have a parent, so this node remains even if all childs are deleted        			
+        			if(!node.hasChildNodes()&&node.getParentNode()!=null) {
+        				node.getParentNode().removeChild(node);
+        			}
+        		}
+        	}
+            node = nextNode;
         }
-        return (ElementNSImpl)tableFilter;
     }
 
     private Node getFilterElementChild() {
@@ -280,7 +311,9 @@ public class DatabaseRange {
     	if(onUpdateKeepStyles!=null) {
         	SaxContextHandler.addOdfAttribute(output, TableOnUpdateKeepStylesAttribute.ATTRIBUTE_NAME, null, onUpdateKeepStyles);
     	}
-    	SaxContextHandler.addOdfAttribute(output, TableOrientationAttribute.ATTRIBUTE_NAME, null, orientation!=null?orientation:"column");
+    	if(orientation!=null) {
+    		SaxContextHandler.addOdfAttribute(output, TableOrientationAttribute.ATTRIBUTE_NAME, null, orientation);
+    	}
     	if(refreshDelay!=null) {
         	SaxContextHandler.addOdfAttribute(output, TableRefreshDelayAttribute.ATTRIBUTE_NAME, null, refreshDelay);
     	}
