@@ -50,6 +50,7 @@
 package com.openexchange.office.ods.dom;
 
 import java.util.List;
+import java.util.Map;
 import java.util.TreeSet;
 
 import org.apache.xml.serializer.SerializationHandler;
@@ -72,6 +73,8 @@ import org.odftoolkit.odfdom.type.Length.Unit;
 import org.w3c.dom.Element;
 import org.xml.sax.SAXException;
 
+import com.openexchange.office.odf.OfficeStyles;
+import com.openexchange.office.odf.SaxContextHandler;
 import com.openexchange.office.ods.dom.SmlUtils.CellRef;
 
 public class Row implements Comparable<Row>, IAttrs<Row>, IStyleAccess {
@@ -333,10 +336,18 @@ public class Row implements Comparable<Row>, IAttrs<Row>, IStyleAccess {
 	        		if(width!=null&&!width.isEmpty()) {
 	        			final Double dest = Length.getLength(width, Unit.MILLIMETER);
 	        			if(dest!=null) {
-	        				rowProperties.put("height", dest*100);
-	        				rowProperties.put("customHeight", true);
+	        				rowProperties.put("height", Math.round(dest*100));
 	        			}
 	        		}
+	        		final String optimalRowHeight = tableRowProperties.getAttributeNS(OdfDocumentNamespace.STYLE.getUri(), "use-optimal-row-height");
+	        		if(optimalRowHeight!=null&&!optimalRowHeight.isEmpty()) {
+	        			rowProperties.put("customHeight", !Boolean.parseBoolean(optimalRowHeight));
+	        		}
+	        		final String fillColor = tableRowProperties.getAttributeNS(OdfDocumentNamespace.FO.getUri(), "background-color");
+	        		if(fillColor!=null&&!fillColor.isEmpty()) {
+	                    Map<String, String> color = MapHelper.createColorMap(fillColor);
+	                    rowProperties.put("fillColor", color);
+	        		}
         		}
         	}
         }
