@@ -69,6 +69,8 @@ import org.w3c.dom.Attr;
 import org.w3c.dom.DOMException;
 import org.xml.sax.SAXException;
 
+import com.openexchange.office.odf.OfficeStyles;
+import com.openexchange.office.odf.SaxContextHandler;
 import com.openexchange.office.ods.dom.SmlUtils.CellRefRange;
 
 @SuppressWarnings("serial")
@@ -315,7 +317,7 @@ public class Sheet extends ElementNSImpl implements IElementWriter, IStyleAccess
 
     	// taking care of conditional formats
     	if(conditionalFormats!=null) {
-    		final Iterator<ConditionalFormat> conditionalFormatIter = conditionalFormats.getConditionalFormatList().iterator();
+    		final Iterator<Condition> conditionalFormatIter = conditionalFormats.getConditionalFormatList().values().iterator();
     		while(conditionalFormatIter.hasNext()) {
 				SmlUtils.insertRows(conditionalFormatIter.next().getRanges(), start, count, true);
     		}
@@ -373,7 +375,7 @@ public class Sheet extends ElementNSImpl implements IElementWriter, IStyleAccess
 
     	// taking care of conditional formats
     	if(conditionalFormats!=null) {
-    		final Iterator<ConditionalFormat> conditionalFormatIter = conditionalFormats.getConditionalFormatList().iterator();
+    		final Iterator<Condition> conditionalFormatIter = conditionalFormats.getConditionalFormatList().values().iterator();
     		while(conditionalFormatIter.hasNext()) {
     			final Ranges ranges = conditionalFormatIter.next().getRanges();
 				SmlUtils.deleteRows(ranges, start, count, false);
@@ -444,7 +446,7 @@ public class Sheet extends ElementNSImpl implements IElementWriter, IStyleAccess
 
     	// taking care of conditional formats
     	if(conditionalFormats!=null) {
-    		final Iterator<ConditionalFormat> conditionalFormatIter = conditionalFormats.getConditionalFormatList().iterator();
+    		final Iterator<Condition> conditionalFormatIter = conditionalFormats.getConditionalFormatList().values().iterator();
     		while(conditionalFormatIter.hasNext()) {
 				SmlUtils.insertColumns(conditionalFormatIter.next().getRanges(), start, count, true);
     		}
@@ -461,19 +463,17 @@ public class Sheet extends ElementNSImpl implements IElementWriter, IStyleAccess
 	    	final Iterator<Entry<String, DatabaseRange>> databaseRangeIter = databaseRanges.getDatabaseRangeList().entrySet().iterator();
 	    	while(databaseRangeIter.hasNext()) {
 	    		final DatabaseRange databaseRange = databaseRangeIter.next().getValue();
-	    		if(databaseRange.getName().startsWith("__Anonymous_Sheet_DB__")) {
-	    			final Range sheetRange = databaseRange.getRange();
-	    			if(sheetRange.getSheetIndex()==sheetIndex) {
-	    				final CellRefRange cellRefRange = sheetRange.getCellRefRange();
-	    				if(cellRefRange!=null) {
-	                        final SmlUtils.CellRefRange newCellRefRange = SmlUtils.CellRefRange.insertColumnRange(cellRefRange, start, count, false);
-	                        if(newCellRefRange!=null&&!newCellRefRange.equals(cellRefRange)) {
-	                        	databaseRange.setRange(new Range(sheetIndex, newCellRefRange));
-	                        	databaseRange.changeColumn(start, count);
-	                        }
+    			final Range sheetRange = databaseRange.getRange();
+    			if(sheetRange.getSheetIndex()==sheetIndex) {
+    				final CellRefRange cellRefRange = sheetRange.getCellRefRange();
+    				if(cellRefRange!=null) {
+                        final SmlUtils.CellRefRange newCellRefRange = SmlUtils.CellRefRange.insertColumnRange(cellRefRange, start, count, false);
+                        if(newCellRefRange!=null&&!newCellRefRange.equals(cellRefRange)) {
+                        	databaseRange.setRange(new Range(sheetIndex, newCellRefRange));
+                        	databaseRange.changeColumn(cellRefRange, start, count);
                         }
-	    			}
-	    		}
+                    }
+    			}
 	    	}
 	    }
     }
@@ -507,7 +507,7 @@ public class Sheet extends ElementNSImpl implements IElementWriter, IStyleAccess
 
     	// taking care of conditional formats
     	if(conditionalFormats!=null) {
-    		final Iterator<ConditionalFormat> conditionalFormatIter = conditionalFormats.getConditionalFormatList().iterator();
+    		final Iterator<Condition> conditionalFormatIter = conditionalFormats.getConditionalFormatList().values().iterator();
     		while(conditionalFormatIter.hasNext()) {
     			final Ranges ranges = conditionalFormatIter.next().getRanges();
 				SmlUtils.deleteColumns(ranges, start, count, false);
@@ -528,51 +528,52 @@ public class Sheet extends ElementNSImpl implements IElementWriter, IStyleAccess
 	    	final Iterator<Entry<String, DatabaseRange>> databaseRangeIter = databaseRanges.getDatabaseRangeList().entrySet().iterator();
 	    	while(databaseRangeIter.hasNext()) {
 	    		final DatabaseRange databaseRange = databaseRangeIter.next().getValue();
-	    		if(databaseRange.getName().startsWith("__Anonymous_Sheet_DB__")) {
-	    			final Range sheetRange = databaseRange.getRange();
-	    			if(sheetRange.getSheetIndex()==sheetIndex) {
-	    				final CellRefRange cellRefRange = sheetRange.getCellRefRange();
-	    				if(cellRefRange!=null) {
-	                        final SmlUtils.CellRefRange newCellRefRange = SmlUtils.CellRefRange.deleteColumnRange(cellRefRange, start, count);
-	                        if(newCellRefRange==null) {
-	                        	databaseRanges.deleteTable(((Content)getOwnerDocument()), sheetIndex, databaseRange.getName());
-	                        }
-	                        else if(!newCellRefRange.equals(cellRefRange)) {
-	                        	databaseRange.setRange(new Range(sheetIndex, newCellRefRange));
-	                        	databaseRange.changeColumn(start, -count);
-	                        }
+    			final Range sheetRange = databaseRange.getRange();
+    			if(sheetRange.getSheetIndex()==sheetIndex) {
+    				final CellRefRange cellRefRange = sheetRange.getCellRefRange();
+    				if(cellRefRange!=null) {
+                        final SmlUtils.CellRefRange newCellRefRange = SmlUtils.CellRefRange.deleteColumnRange(cellRefRange, start, count);
+                        if(newCellRefRange==null) {
+                        	databaseRanges.deleteTable(((Content)getOwnerDocument()), sheetIndex, databaseRange.getName());
                         }
-	    			}
-	    		}
+                        else if(!newCellRefRange.equals(cellRefRange)) {
+                        	databaseRange.setRange(new Range(sheetIndex, newCellRefRange));
+                        	databaseRange.changeColumn(cellRefRange, start, -count);
+                        }
+                    }
+    			}
 	    	}
 	    }
     }
 
-    public void clearCellRange(int r1, int r2, int c1, int c2, boolean remove) {
-    	if(remove) {
-	    	getRow(r1, false, true, false);
-	    	getRow(r2, false, false, true);
+    public void clearCellRange(int r1, int r2, int c1, int c2) {
 
-	    	final NavigableSet<Row> rowSelection = getRows().subSet(new Row(null, r1), true, new Row(null, r2), true);
-	        final Iterator<Row> rowIter = rowSelection.iterator();
-	        while(rowIter.hasNext()) {
-	        	final Row row = rowIter.next();
+    	getRow(r1, false, true, false);
+    	getRow(r2, false, false, true);
 
-	        	// creating cell entries....
-	        	row.getCell(c1, false, true, false);
-	        	row.getCell(c2, false, false, true);
+    	final NavigableSet<Row> rowSelection = getRows().subSet(new Row(null, r1), true, new Row(null, r2), true);
+        final Iterator<Row> rowIter = rowSelection.iterator();
+        while(rowIter.hasNext()) {
+        	final Row row = rowIter.next();
 
-	        	row.getCells().removeAll(row.getCells().subSet(new Cell(c1), true, new Cell(c2), true));
+        	// creating cell entries....
+        	row.getCell(c1, false, true, false);
+        	row.getCell(c2, false, false, true);
 
-	        	// check if we need to create empty repeated cells, only necessary if a ceilling cell is available
-	        	final Cell ceiling = row.getCell(c2+1, false, false, false);
-	        	if(ceiling!=null) {
-	        		final Cell newCell = new Cell(c1);
-	        		newCell.setRepeated((c2-c1)+1);
-	        		row.getCells().add(newCell);
-	        	}
-	        }
-    	}
+        	final Iterator<Cell> cellSubSetIter = row.getCells().subSet(new Cell(c1), true, new Cell(c2), true).iterator();
+        	while(cellSubSetIter.hasNext()) {
+        		cellSubSetIter.next();
+        		cellSubSetIter.remove();
+        	}
+
+        	// check if we need to create empty repeated cells, only necessary if a ceilling cell is available
+        	final Cell ceiling = row.getCell(c2+1, false, false, false);
+        	if(ceiling!=null) {
+        		final Cell newCell = new Cell(c1);
+        		newCell.setRepeated((c2-c1)+1);
+        		row.getCells().add(newCell);
+        	}
+        }
     }
 
     public NamedExpressions getNamedExpressions(boolean forceCreate) {
@@ -623,7 +624,8 @@ public class Sheet extends ElementNSImpl implements IElementWriter, IStyleAccess
 	}
 
 	@Override
-	public void writeObject(SerializationHandler output) {
+	public void writeObject(SerializationHandler output)
+		throws SAXException {
 
 		if(!getColumns().isEmpty()&&columnPlaceholderAvailable==false) {
 			getChilds().add(getColumns().first());
@@ -633,49 +635,46 @@ public class Sheet extends ElementNSImpl implements IElementWriter, IStyleAccess
 			getChilds().add(getRows().first());
 			rowPlaceholderAvailable = true;
 		}
-		try {
-			output.startElement(getNamespaceURI(), getLocalName(), getNodeName());
-			SaxContextHandler.addAttributes(output, getAttributes(), null);
 
-			// office forms needs to be written before shapes
-			if(officeForms!=null) {
-				SaxContextHandler.serializeElement(output, officeForms);
-			}
-			drawings.writeSheetDrawings(output);
-			for(Object child:getChilds()) {
-				if(child instanceof Column) {
-					// taking care of column-group-elements
-					int currentColumnGroupLevel = 0;
-					for(Column column:columns) {
-						currentColumnGroupLevel += Column.writeGroupDifference(output, currentColumnGroupLevel, column.getGroupLevel(), column.isStartingGroup());
-						column.writeObject(output);
-					}
-					Column.writeGroupDifference(output, currentColumnGroupLevel, 0, false);
-				}
-				else if(child instanceof Row) {
-					int currentRowGroupLevel = 0;
-					for(Row row:rows) {
-						currentRowGroupLevel += Row.writeGroupDifference(output, currentRowGroupLevel, row.getGroupLevel(), row.isStartingGroup());
-						row.writeObject(output, this);
-					}
-					Column.writeGroupDifference(output, currentRowGroupLevel, 0, false);
-				}
-				else if(child instanceof IElementWriter) {
-					((IElementWriter)child).writeObject(output);
-				}
-				else if(child instanceof ElementNSImpl) {
-					SaxContextHandler.serializeElement(output, (ElementNSImpl)child);
-				}
-			}
-			if(conditionalFormats!=null) {
-				conditionalFormats.writeObject(output);
-			}
-			if(namedExpressions!=null) {
-				namedExpressions.writeObject(output);
-			}
-			output.endElement(getNamespaceURI(), getLocalName(), getNodeName());
-		} catch (SAXException e) {
+		output.startElement(getNamespaceURI(), getLocalName(), getNodeName());
+		SaxContextHandler.addAttributes(output, getAttributes(), null);
 
+		// office forms needs to be written before shapes
+		if(officeForms!=null) {
+			SaxContextHandler.serializeElement(output, officeForms);
 		}
+		drawings.writeSheetDrawings(output);
+		for(Object child:getChilds()) {
+			if(child instanceof Column) {
+				// taking care of column-group-elements
+				int currentColumnGroupLevel = 0;
+				for(Column column:columns) {
+					currentColumnGroupLevel += Column.writeGroupDifference(output, currentColumnGroupLevel, column.getGroupLevel(), column.isStartingGroup());
+					column.writeObject(output);
+				}
+				Column.writeGroupDifference(output, currentColumnGroupLevel, 0, false);
+			}
+			else if(child instanceof Row) {
+				int currentRowGroupLevel = 0;
+				for(Row row:rows) {
+					currentRowGroupLevel += Row.writeGroupDifference(output, currentRowGroupLevel, row.getGroupLevel(), row.isStartingGroup());
+					row.writeObject(output, this);
+				}
+				Column.writeGroupDifference(output, currentRowGroupLevel, 0, false);
+			}
+			else if(child instanceof IElementWriter) {
+				((IElementWriter)child).writeObject(output);
+			}
+			else if(child instanceof ElementNSImpl) {
+				SaxContextHandler.serializeElement(output, (ElementNSImpl)child);
+			}
+		}
+		if(conditionalFormats!=null) {
+			conditionalFormats.writeObject(output);
+		}
+		if(namedExpressions!=null) {
+			namedExpressions.writeObject(output);
+		}
+		output.endElement(getNamespaceURI(), getLocalName(), getNodeName());
 	}
 }
