@@ -53,12 +53,13 @@ import java.io.ByteArrayInputStream;
 import java.io.IOException;
 import java.io.InputStream;
 import java.math.BigInteger;
+import java.util.HashMap;
 import java.util.List;
+import java.util.Map;
 import java.util.zip.ZipEntry;
 import java.util.zip.ZipInputStream;
 
 import org.apache.commons.io.IOUtils;
-import org.docx4j.dml.Theme;
 import org.docx4j.jaxb.Context;
 import org.docx4j.openpackaging.exceptions.InvalidFormatException;
 import org.docx4j.openpackaging.packages.OpcPackage;
@@ -144,11 +145,11 @@ public class DocxOperationDocument extends OperationDocument {
             opcPackage = WordprocessingMLPackage.createPackage();
 
             final MainDocumentPart mainDocumentPart = getPackage().getMainDocumentPart();
+            final ThemePart themePart = getDefaultThemePart(new PartName("/word/theme/theme1.xml"));
+            mainDocumentPart.addTargetPart(themePart);
             final Styles styles = mainDocumentPart.getStyleDefinitionsPart().getJaxbElement();
             resetDocumentLanguage(styles);
             insertPredefinedLatentStyles(styles);
-            final ThemePart themePart = getDefaultThemePart(new PartName("/word/theme/theme1.xml"));
-            mainDocumentPart.addTargetPart(themePart);
             final DocumentSettingsPart documentSettingsPart = getDefaultSettingsPart(new PartName("/word/settings.xml"));
             mainDocumentPart.addTargetPart(documentSettingsPart);
             final SectPr sectPr = Utils.getDocumentProperties(mainDocumentPart, true);
@@ -174,7 +175,62 @@ public class DocxOperationDocument extends OperationDocument {
         }
     }
 
-    private void setContext(String target) {
+    @Override
+    public JSONObject getOperations()
+        throws Exception {
+
+        final JSONObject aOperations = new JSONObject();
+        final JSONArray operationsArray = new JSONArray();
+
+        final DocxCreateOperationHelper createOperationHelper = new DocxCreateOperationHelper(this, operationsArray);
+        createOperationHelper.createDocumentDefaults(getUserLanguage());
+        createOperationHelper.CreateFontDescriptions();
+        createOperationHelper.CreateStyleOperations();
+        createOperationHelper.createThemeOperations(null, null);
+        createOperationHelper.CreateListOperations();
+        createOperationHelper.CreateHeaderFooterOperations();
+        createOperationHelper.createOperations();
+        createOperationHelper.createDocumentAuthors();
+        aOperations.put("operations", operationsArray);
+
+        return aOperations;
+    }
+
+	public Map<String, Object> getMetaData()
+		throws Exception {
+
+		final JSONArray operationsArray = new JSONArray();
+		final DocxCreateOperationHelper createOperationHelper = new DocxCreateOperationHelper(this, operationsArray);
+        createOperationHelper.createDocumentDefaults(getUserLanguage());
+        createOperationHelper.CreateFontDescriptions();
+        createOperationHelper.CreateStyleOperations();
+        createOperationHelper.createThemeOperations(null, null);
+        createOperationHelper.CreateListOperations();
+        createOperationHelper.CreateHeaderFooterOperations();
+        final Map<String, Object> operations = new HashMap<String, Object>(1);
+        operations.put("operations", operationsArray);
+        return operations;
+	}
+
+	public Map<String, Object> getActivePart()
+		throws Exception {
+
+		final JSONArray operationsArray = new JSONArray();
+		final DocxCreateOperationHelper createOperationHelper = new DocxCreateOperationHelper(this, operationsArray);
+		createOperationHelper.createOperations();
+        createOperationHelper.createDocumentAuthors();
+        final Map<String, Object> operations = new HashMap<String, Object>(1);
+        operations.put("operations", operationsArray);
+        return operations;
+	}
+
+	public Map<String, Object> getNextPart()
+		throws Exception {
+
+		return null;
+	}
+	
+	private void setContext(String target) {
         if(target.isEmpty()) {
             setContextPart(null);
         }
@@ -204,7 +260,8 @@ public class DocxOperationDocument extends OperationDocument {
                 for (i = 0; i < aOperations.length(); i++) {
                 	successfulAppliedOperations = i;
                     op = (JSONObject) aOperations.get(i);
-                    setContext(op.optString("target", ""));
+                    final String target = op.optString("target", "");
+                    setContext(target);
                     opName = op.getString("name");
                     switch(opName) {
                     	case "insertParagraph": {
@@ -216,7 +273,7 @@ public class DocxOperationDocument extends OperationDocument {
                     		break;
                     	}
                     	case "move": {
-                    		applyOperationHelper.move(op.getJSONArray("start"), op.optJSONArray("end"), op.getJSONArray("to"));
+                    		applyOperationHelper.move(op.getJSONArray("start"), target, op.optJSONArray("end"), op.getJSONArray("to"));
                     		break;
                     	}
                     	case "splitParagraph": {
@@ -308,7 +365,7 @@ public class DocxOperationDocument extends OperationDocument {
                     		break;
                     	}
                     	case "insertRange": {
-                    		applyOperationHelper.insertRange(op.getJSONArray("start"), op.getString("id"), op.optString("type", "comment"), op.optString("position", "start"), op.optJSONObject("attrs"));
+                    		applyOperationHelper.insertRange(op.getJSONArray("start"), op.optString("id", null), op.optString("type", "comment"), op.optString("position", "start"), op.optJSONObject("attrs"));
                     		break;
                     	}
                     	case "insertComplexField": {
@@ -353,31 +410,6 @@ public class DocxOperationDocument extends OperationDocument {
         }
     }
 
-    @Override
-    public JSONObject getOperations()
-        throws Exception {
-
-        final JSONObject aOperations = new JSONObject();
-        final JSONArray operationsArray = new JSONArray();
-
-        //set dummy for addSetDocumentAttributes-Operation called in createDocumentDefaults
-        final JSONObject noOpSync = new JSONObject();
-        noOpSync.put("name", "noOp");
-        operationsArray.put(noOpSync);
-
-        DocxCreateOperationHelper createOperationHelper = new DocxCreateOperationHelper(this, operationsArray);
-        createOperationHelper.CreateFontDescriptions();
-        createOperationHelper.CreateStyleOperations();
-        createOperationHelper.createThemeOperations(null, null);
-        createOperationHelper.CreateListOperations();
-        createOperationHelper.CreateHeaderFooterOperations();
-        createOperationHelper.createOperations();
-        createOperationHelper.createDocumentDefaults(getUserLanguage());
-        aOperations.put("operations", operationsArray);
-
-        return aOperations;
-    }
-
     @Override
     public WordprocessingMLPackage getPackage() {
         return opcPackage;
@@ -394,12 +426,15 @@ public class DocxOperationDocument extends OperationDocument {
     }
 
     @Override
-    public com.openexchange.office.ooxml.components.Component getRootComponent() {
+    public com.openexchange.office.ooxml.components.Component getRootComponent(String target) {
+    	if(target!=null) {
+    		setContext(target);
+    	}
     	return new RootComponent((ContentAccessor)getContextPart());
     }
-
+    
     @Override
-    public Theme getTheme(boolean createIfMissing)
+    public ThemePart getThemePart(boolean createIfMissing)
     	throws FilterException {
 
     	ThemePart themePart = getPackage().getMainDocumentPart().getThemePart();
@@ -412,7 +447,7 @@ public class DocxOperationDocument extends OperationDocument {
         		throw new FilterException("docx filter, could not create default theme", ErrorCode.CRITICAL_ERROR, e);
         	}
         }
-        return themePart!=null?themePart.getJaxbElement():null;
+        return themePart;
     }
 
     public Styles getStyles(boolean createIfMissing)
@@ -428,7 +463,7 @@ public class DocxOperationDocument extends OperationDocument {
     }
 
     public CTSettings getSettings(boolean createIfMissing)
-    	throws Exception {
+    	throws InvalidFormatException {
 
         DocumentSettingsPart settingsPart = getPackage().getMainDocumentPart().getDocumentSettingsPart();
         if(settingsPart==null&&createIfMissing) {
