@@ -265,8 +265,8 @@ public class ParagraphComponent extends DocxComponent implements IParagraph {
                 paragraphContent.add(newRun);
                 newChild.setParent(newRun);
                 newRun.getContent().add(newChild);
-                if(paragraph.getPPr()!=null) {
-                    final RPr rPr = TextUtils.cloneParaRPrToRPr(paragraph.getPPr().getRPr());
+                if(paragraph.getPPr(false)!=null) {
+                    final RPr rPr = TextUtils.cloneParaRPrToRPr(paragraph.getPPr(false).getRPr());
                     if(rPr!=null) {
                         rPr.setParent(newRun);
                         newRun.setRPr(rPr);
@@ -410,12 +410,7 @@ public class ParagraphComponent extends DocxComponent implements IParagraph {
 		}
 		try {
 	        final P paragraph = (P)getObject();
-	        PPr pPr = paragraph.getPPr();
-	        if (pPr==null) {
-	            pPr = Context.getWmlObjectFactory().createPPr();
-	            pPr.setParent(paragraph);
-	            paragraph.setPPr(pPr);
-	        }
+	        final PPr pPr = paragraph.getPPr(true);
 	        if(attrs.has("styleId")) {
 	            final Object styleId = attrs.get("styleId");
 	            if(styleId instanceof String) {
@@ -584,7 +579,7 @@ public class ParagraphComponent extends DocxComponent implements IParagraph {
 	public JSONObject createJSONAttrs(com.openexchange.office.ooxml.operations.CreateOperationHelper createOperationHelper, JSONObject attrs)
 		throws JSONException {
 
-		final PPr pPr = ((P)getObject()).getPPr();
+		final PPr pPr = ((P)getObject()).getPPr(false);
         if(pPr!=null) {
             final PPrBase.PStyle pStyle = pPr.getPStyle();
             if(pStyle!=null) {
@@ -730,8 +725,8 @@ public class ParagraphComponent extends DocxComponent implements IParagraph {
                 final R newRun = Context.getWmlObjectFactory().createR();
                 newRun.setParent(getObject());
                 paragraph.getContent().add(newRun);
-                if(paragraph.getPPr()!=null) {
-                    final RPr rPr = TextUtils.cloneParaRPrToRPr(paragraph.getPPr().getRPr());
+                if(paragraph.getPPr(false)!=null) {
+                    final RPr rPr = TextUtils.cloneParaRPrToRPr(paragraph.getPPr(false).getRPr());
                     if(rPr!=null) {
                         rPr.setParent(newRun);
                         newRun.setRPr(rPr);
@@ -777,7 +772,7 @@ public class ParagraphComponent extends DocxComponent implements IParagraph {
         destParagraph.setParent(paragraph.getParent());
         final IndexedNode<Object> destParagraphNode = new IndexedNode<Object>(destParagraph);
         Utils.getContent(paragraph.getParent()).addNode(getNode(), destParagraphNode, false);
-        final PPr sourceParagraphProperties = paragraph.getPPr();
+        final PPr sourceParagraphProperties = paragraph.getPPr(false);
         if(sourceParagraphProperties!=null){
             final PPr destParagraphProperties = XmlUtils.deepCopy(sourceParagraphProperties);
             // no inheritance for pageBreakBefore attribute... this attribute is always false
@@ -833,12 +828,7 @@ public class ParagraphComponent extends DocxComponent implements IParagraph {
         if(lastRPr!=null) {
 
             // if available, we have to get the character attributes from the last textrun
-            PPr paraProps = destParagraph.getPPr();
-            if(paraProps==null) {
-                paraProps = Context.getWmlObjectFactory().createPPr();
-                paraProps.setParent(destParagraph);
-                destParagraph.setPPr(paraProps);
-            }
+        	final PPr paraProps = destParagraph.getPPr(true);
 
             // 30793 ... only setting character attributes if no listStyle is used at the paragraph
             if(paraProps.getNumPr()==null||paraProps.getNumPr().getNumId()==null) {
