@@ -479,15 +479,17 @@ public class TableComponent extends DocxComponent implements ITable {
     public void deleteColumns(com.openexchange.office.ooxml.OperationDocument operationDocument, int gridStart, int gridEnd)
     	throws JSONException {
 
+		
     	Component trComponent = getNextChildComponent(null, null);
         while(trComponent!=null) {
         	IndexedNode<Object> startNode = null;
         	IndexedNode<Object> endNode = null;
             TcComponent tcComponent = (TcComponent)trComponent.getNextChildComponent(null, null);
             while(tcComponent!=null) {
-                if((tcComponent.getGridPosition()>=gridStart&&tcComponent.getGridPosition()<=gridEnd)||
-                    (tcComponent.getNextGridPosition()-1>=gridStart&&tcComponent.getNextGridPosition()-1<=gridEnd)){
-                	final ComponentContext contextChild = tcComponent.getContextChild(null);
+            	final int x1 = tcComponent.getGridPosition();
+            	final int x2 = tcComponent.getNextGridPosition();
+            	if(Math.max(x2, gridEnd + 1) - Math.min(x1, gridStart) < (x2 - x1) + ((gridEnd+1)-gridStart)) {
+            		final ComponentContext contextChild = tcComponent.getContextChild(null);
                 	if (startNode==null) {
                         startNode = contextChild.getNode();
                 	}
