@@ -85,7 +85,6 @@ import org.docx4j.wml.CTTblStylePr;
 import org.docx4j.wml.CommentRangeEnd;
 import org.docx4j.wml.CommentRangeStart;
 import org.docx4j.wml.Comments.Comment;
-import org.docx4j.wml.ContentAccessor;
 import org.docx4j.wml.DocDefaults;
 import org.docx4j.wml.DocDefaults.RPrDefault;
 import org.docx4j.wml.FooterReference;
@@ -185,7 +184,7 @@ public class DocxApplyOperationHelper extends ApplyOperationHelper {
                 return;
             endComponent = end.getInt(end.length()-1);
         }
-        Component component = Component.getComponent(getOperationDocument().getRootComponent(), start, start.length());
+        Component component = Component.getComponent(getOperationDocument().getRootComponent(null), start, start.length());
 		component.splitStart(startComponent, SplitMode.DELETE);
         component.delete(getOperationDocument(), (endComponent-startComponent)+1);
     }
@@ -198,58 +197,34 @@ public class DocxApplyOperationHelper extends ApplyOperationHelper {
      *
      */
 
-    public void move(JSONArray startPosition, JSONArray endPosition, JSONArray toPosition)
+    public void move(JSONArray startPosition, String target, JSONArray endPosition, JSONArray toPosition)
         throws JSONException {
 
-        if(startPosition.length()!=endPosition.length())
-            throw new JSONException("ooxml export: move operation, size of startPosition != size of endPosition");
-
-        final Component sourceBegComponent = Component.getComponent(getOperationDocument().getRootComponent(), startPosition, startPosition.length());
-        final Component sourceEndComponent = sourceBegComponent.getComponent(endPosition.getInt(startPosition.length()-1));
-        final IndexedNodeList<Object> sourceContent = (IndexedNodeList<Object>)((ContentAccessor)sourceBegComponent.getParentComponent().getNode().getData()).getContent();
-        sourceBegComponent.splitStart(startPosition.getInt(startPosition.length()-1), SplitMode.DELETE);
-        sourceEndComponent.splitEnd(endPosition.getInt(startPosition.length()-1), SplitMode.DELETE);
-
-        // destComponent is empty if the content is to be appended
-        final Component destComponent = Component.getComponent(getOperationDocument().getRootComponent(), toPosition, toPosition.length());
-        Component destParentComponent;
-        if(destComponent!=null) {
-        	destComponent.splitStart(toPosition.getInt(toPosition.length()-1), SplitMode.DELETE);
-        	destParentComponent = destComponent.getParentComponent();
-        }
-        else {
-        	destParentComponent = Component.getComponent(getOperationDocument().getRootComponent(), toPosition, toPosition.length()-1);
-        }
-        final int startIndex = sourceBegComponent.getContextChild(null).getNode().getIndex();
-        final int endIndex = sourceEndComponent.getContextChild(null).getNode().getIndex();
-
-        IndexedNodeList.moveNodes(sourceContent, (IndexedNodeList<Object>)((ContentAccessor)destParentComponent.getNode().getData()).getContent(), startIndex,
-        		destComponent!=null?destComponent.getContextChild(null).getNode().getIndex():((ContentAccessor)destParentComponent.getNode().getData()).getContent().size(),
-        				(endIndex - startIndex)+1, destParentComponent.getNode().getData());
+    	Component.move(getOperationDocument(), startPosition, target, endPosition, toPosition);
     }
 
     public void insertParagraph(JSONArray start, JSONObject attrs)
         throws JAXBException, InvalidFormatException, PartUnrecognisedException, JSONException {
 
-    	Component.getComponent(getOperationDocument().getRootComponent(), start, start.length()-1).insertChildComponent(operationDocument, start.getInt(start.length()-1), attrs, Component.Type.PARAGRAPH);
+    	Component.getComponent(getOperationDocument().getRootComponent(null), start, start.length()-1).insertChildComponent(operationDocument, start.getInt(start.length()-1), attrs, Component.Type.PARAGRAPH);
     }
 
     public void splitParagraph(JSONArray start)
         throws JSONException {
 
-        ((IParagraph)Component.getComponent(getOperationDocument().getRootComponent(), start, start.length()-1)).splitParagraph(start.getInt(start.length()-1));
+        ((IParagraph)Component.getComponent(getOperationDocument().getRootComponent(null), start, start.length()-1)).splitParagraph(start.getInt(start.length()-1));
     }
 
     public void mergeParagraph(JSONArray start) {
 
-    	((IParagraph)Component.getComponent(getOperationDocument().getRootComponent(), start, start.length())).mergeParagraph();
+    	((IParagraph)Component.getComponent(getOperationDocument().getRootComponent(null), start, start.length())).mergeParagraph();
     }
 
     public void insertText(JSONArray start, String text, JSONObject attrs)
         throws JAXBException, JSONException, InvalidFormatException, PartUnrecognisedException {
 
     	if(text.length()>0) {
-    		final Component component = Component.getComponent(getOperationDocument().getRootComponent(), start, start.length()-1);
+    		final Component component = Component.getComponent(getOperationDocument().getRootComponent(null), start, start.length()-1);
     		((IParagraph)component).insertText(operationDocument, start.getInt(start.length()-1), text, attrs);
     	}
     }
@@ -257,7 +232,7 @@ public class DocxApplyOperationHelper extends ApplyOperationHelper {
     public void insertTab(JSONArray start, JSONObject attrs)
         throws JAXBException, InvalidFormatException, PartUnrecognisedException, JSONException {
 
-    	Component.getComponent(getOperationDocument().getRootComponent(), start, start.length()-1)
+    	Component.getComponent(getOperationDocument().getRootComponent(null), start, start.length()-1)
     	    .insertChildComponent(operationDocument, start.getInt(start.length()-1), attrs, Type.TAB);
     }
 
@@ -271,7 +246,7 @@ public class DocxApplyOperationHelper extends ApplyOperationHelper {
 		else if(type.equals("column")) {
 			textRunChild = Type.HARDBREAK_COLUMN;
 		}
-    	Component.getComponent(getOperationDocument().getRootComponent(), start, start.length()-1)
+    	Component.getComponent(getOperationDocument().getRootComponent(null), start, start.length()-1)
 			.insertChildComponent(operationDocument, start.getInt(start.length()-1), attrs, textRunChild);
     }
 
@@ -291,49 +266,49 @@ public class DocxApplyOperationHelper extends ApplyOperationHelper {
             // we will create an AlternateContent for our group (drawingML + VML)
     	    childComponentType = Type.AC_IMAGE;
     	}
-    	Component.getComponent(getOperationDocument().getRootComponent(), start, start.length()-1).insertChildComponent(operationDocument, start.getInt(start.length()-1), attrs, childComponentType);
+    	Component.getComponent(getOperationDocument().getRootComponent(null), start, start.length()-1).insertChildComponent(operationDocument, start.getInt(start.length()-1), attrs, childComponentType);
     }
 
     public void insertTable(JSONArray start, JSONObject attrs)
         throws JSONException, JAXBException, InvalidFormatException, PartUnrecognisedException {
 
-    	Component.getComponent(getOperationDocument().getRootComponent(), start, start.length()-1).insertChildComponent(operationDocument, start.getInt(start.length()-1), attrs, Component.Type.TABLE);
+    	Component.getComponent(getOperationDocument().getRootComponent(null), start, start.length()-1).insertChildComponent(operationDocument, start.getInt(start.length()-1), attrs, Component.Type.TABLE);
     }
 
     public void splitTable(JSONArray start)
     	throws JSONException {
 
-    	((ITable)Component.getComponent(getOperationDocument().getRootComponent(), start, start.length()-1)).splitTable(start.getInt(start.length()-1));
+    	((ITable)Component.getComponent(getOperationDocument().getRootComponent(null), start, start.length()-1)).splitTable(start.getInt(start.length()-1));
     }
 
     public void mergeTable(JSONArray start) {
 
-    	((ITable)Component.getComponent(getOperationDocument().getRootComponent(), start, start.length())).mergeTable();
+    	((ITable)Component.getComponent(getOperationDocument().getRootComponent(null), start, start.length())).mergeTable();
     }
 
     public void insertRows(JSONArray start, int count, boolean insertDefaultCells, int referenceRow, JSONObject attrs)
         throws JSONException, JAXBException, InvalidFormatException, PartUnrecognisedException {
 
-    	((ITable)Component.getComponent(getOperationDocument().getRootComponent(), start, start.length()-1))
+    	((ITable)Component.getComponent(getOperationDocument().getRootComponent(null), start, start.length()-1))
     		.insertRows(operationDocument, start.getInt(start.length()-1), count, insertDefaultCells, referenceRow, attrs);
     }
 
     public void insertCells(JSONArray start, int count, JSONObject attrs)
         throws JSONException, JAXBException, InvalidFormatException, PartUnrecognisedException {
 
-    	((IRow)Component.getComponent(getOperationDocument().getRootComponent(), start, start.length()-1)).insertCells(operationDocument, start.getInt(start.length()-1), count, attrs);
+    	((IRow)Component.getComponent(getOperationDocument().getRootComponent(null), start, start.length()-1)).insertCells(operationDocument, start.getInt(start.length()-1), count, attrs);
     }
 
     public void insertColumn(JSONArray start, JSONArray tableGrid, int gridPosition, String insertMode)
         throws JSONException {
 
-    	((ITable)Component.getComponent(getOperationDocument().getRootComponent(), start, start.length())).insertColumn(operationDocument, tableGrid, gridPosition, insertMode);
+    	((ITable)Component.getComponent(getOperationDocument().getRootComponent(null), start, start.length())).insertColumn(operationDocument, tableGrid, gridPosition, insertMode);
     }
 
     public void deleteColumns(JSONArray position, int gridStart, int gridEnd)
         throws JSONException {
 
-    	((ITable)Component.getComponent(getOperationDocument().getRootComponent(), position, position.length())).deleteColumns(operationDocument, gridStart, gridEnd);
+    	((ITable)Component.getComponent(getOperationDocument().getRootComponent(null), position, position.length())).deleteColumns(operationDocument, gridStart, gridEnd);
     }
 
     public void setAttributes(JSONObject attrs, JSONArray start, JSONArray end)
@@ -350,7 +325,7 @@ public class DocxApplyOperationHelper extends ApplyOperationHelper {
                 return;
             endIndex = end.getInt(end.length()-1);
         }
-    	Component component = Component.getComponent(getOperationDocument().getRootComponent(), start, start.length());
+    	Component component = Component.getComponent(getOperationDocument().getRootComponent(null), start, start.length());
 		component.splitStart(startIndex, SplitMode.ATTRIBUTE);
         while(component!=null&&component.getComponentNumber()<=endIndex) {
         	if(component.getNextComponentNumber()>=endIndex+1) {
@@ -392,7 +367,7 @@ public class DocxApplyOperationHelper extends ApplyOperationHelper {
                 style.setRPr(null);
 
                 //change attrs
-                handleNewStyleSheet(style, type, styleName, attrs, parentId, hidden, uipriority, null, null);
+                handleNewStyleSheet(style, type, styleName.isEmpty() ? style.getName().getVal() : styleName, attrs, parentId, hidden, uipriority, null, null);
             } else {
                 //change name
                 Style.Name name = objectFactory.createStyleName();
@@ -734,7 +709,7 @@ public class DocxApplyOperationHelper extends ApplyOperationHelper {
             numList.add(num);
         }
         catch (NumberFormatException e) {
-            log.info("docx export insertListStyle: invalid listStyleId found!");
+            log.debug("docx export insertListStyle: invalid listStyleId found!");
         }
     }
 
@@ -976,7 +951,7 @@ public class DocxApplyOperationHelper extends ApplyOperationHelper {
     	}
     	final Relationship rel = mainDocumentPart.addTargetPart(part, AddPartBehaviour.RENAME_IF_NAME_EXISTS, id);
     	if(!rel.getId().equals(id)) {
-    		log.error("docx: insertHeaderFooter... Id:" + id + " is not unique!!!");
+    		log.debug("docx: insertHeaderFooter... Id:" + id + " is not unique!!!");
     	}
     	final SectPr sectPr = Utils.getDocumentProperties(mainDocumentPart, true);
     	ctRel.setParent(sectPr);
@@ -1001,7 +976,7 @@ public class DocxApplyOperationHelper extends ApplyOperationHelper {
     public void insertComment(JSONArray start, String id, String uid, String author, String date, JSONObject attrs)
     	throws UnsupportedOperationException, InvalidFormatException, PartUnrecognisedException, JAXBException, JSONException, DatatypeConfigurationException {
 
-    	final Component component = Component.getComponent(getOperationDocument().getRootComponent(), start, start.length()-1)
+    	final Component component = Component.getComponent(getOperationDocument().getRootComponent(null), start, start.length()-1)
     		.insertChildComponent(operationDocument, start.getInt(start.length()-1), attrs, Type.COMMENT_REFERENCE);
 
     	final BigInteger commentId = BigInteger.valueOf(Integer.parseInt(id.substring(3)));
@@ -1019,7 +994,7 @@ public class DocxApplyOperationHelper extends ApplyOperationHelper {
     	if(type.equals("comment")) {
         	final BigInteger cId = BigInteger.valueOf(Integer.parseInt(id.substring(3)));
         	final Component.Type rangeType = position.equals("start") ? Component.Type.COMMENT_RANGE_START : Component.Type.COMMENT_RANGE_END;
-	    	final Component component = Component.getComponent(getOperationDocument().getRootComponent(), start, start.length()-1)
+	    	final Component component = Component.getComponent(getOperationDocument().getRootComponent(null), start, start.length()-1)
 	    		.insertChildComponent(operationDocument, start.getInt(start.length()-1), attrs, rangeType);
 
 	    	final Object commentRangeObject = component.getObject();
@@ -1031,7 +1006,7 @@ public class DocxApplyOperationHelper extends ApplyOperationHelper {
 	    	}
     	}
     	else if(type.equals("field")) {
-    		Component.getComponent(getOperationDocument().getRootComponent(), start, start.length()-1)
+    		Component.getComponent(getOperationDocument().getRootComponent(null), start, start.length()-1)
 	    		.insertChildComponent(operationDocument, start.getInt(start.length()-1), attrs, position.equals("start") ? Component.Type.COMPLEX_FIELD_START : Component.Type.COMPLEX_FIELD_END);
     	}
     }
@@ -1039,7 +1014,7 @@ public class DocxApplyOperationHelper extends ApplyOperationHelper {
     public void insertComplexField(JSONArray start, String instruction, JSONObject attrs)
     	throws JSONException, JAXBException, InvalidFormatException, PartUnrecognisedException {
 
-    	final Component component = Component.getComponent(getOperationDocument().getRootComponent(), start, start.length()-1)
+    	final Component component = Component.getComponent(getOperationDocument().getRootComponent(null), start, start.length()-1)
     		.insertChildComponent(operationDocument,  start.getInt(start.length()-1), attrs, Type.COMPLEX_FIELD_SEPARATE);
 
     	if(component instanceof MultiComponent) {
@@ -1063,7 +1038,7 @@ public class DocxApplyOperationHelper extends ApplyOperationHelper {
     public void updateComplexField(JSONArray start, String instruction, JSONObject attrs)
     	throws JSONException, JAXBException, InvalidFormatException, PartUnrecognisedException {
 
-    	final Component component = Component.getComponent(getOperationDocument().getRootComponent(), start, start.length());
+    	final Component component = Component.getComponent(getOperationDocument().getRootComponent(null), start, start.length());
     	if(component instanceof MultiComponent) {
     		for(Component fldCharComponent:((MultiComponent)component).getComponentList()) {
     			if(instruction!=null) {
