@@ -179,24 +179,18 @@ public class DocxCreateOperationHelper extends CreateOperationHelper {
     private final WordprocessingMLPackage wordprocessingMLPackage;
     private final Map<String, String> conditionalTableAttrNames;
     private final HashSet<BigInteger> createdComments = new HashSet<BigInteger>();
-    private final Stack<ComplexFieldStackEntry> complexFieldIdStack = new Stack<ComplexFieldStackEntry>();
-    private int nextComplexFieldId = 0;
+    private final Stack<ComplexFieldStackEntry> complexFieldStack = new Stack<ComplexFieldStackEntry>();
 
     private class ComplexFieldStackEntry {
 
-    	final int fldId;
     	final FldCharComponent fldCharStart;
 
-    	public ComplexFieldStackEntry(int id, FldCharComponent component) {
+    	public ComplexFieldStackEntry(FldCharComponent component) {
     		fldCharStart = component;
-    		fldId = id;
     	}
     	public FldCharComponent getFldStart() {
     		return fldCharStart;
     	}
-    	public int getFldId() {
-    		return fldId;
-    	}
     }
 
     public DocxCreateOperationHelper(DocxOperationDocument _operationDocument, JSONArray mOperationsArray)
@@ -275,7 +269,7 @@ public class DocxCreateOperationHelper extends CreateOperationHelper {
 
     @Override
     public void createDocumentDefaults(String userLanguage)
-        throws Exception {
+    	throws InvalidFormatException, JSONException {
 
         final JSONObject documentAttributes = new JSONObject();
         final CTSettings settings = getOperationDocument().getSettings(false);
@@ -399,6 +393,19 @@ public class DocxCreateOperationHelper extends CreateOperationHelper {
             addSetDocumentAttributesOperation(documentAttributes);
     }
 
+    public void createDocumentAuthors()
+    	throws Exception {
+
+        final JSONArray authors = getOperationDocument().getChangeTrackAuthors();
+        if(authors!=null) {
+            final JSONObject documentAttributes = new JSONObject();
+            final JSONObject jsonDocumentSettings = new JSONObject();
+        	jsonDocumentSettings.put("changeTrackAuthors", authors);
+            documentAttributes.put("document", jsonDocumentSettings);
+            addSetDocumentAttributesOperation(documentAttributes);
+        }
+    }
+
     /**
      * @param aOperationsArray
      * @param nPara
@@ -506,13 +513,12 @@ public class DocxCreateOperationHelper extends CreateOperationHelper {
         	insertComplexField.put("target", target);
         }
         if(fieldStackEntry!=null) {
-	        insertComplexField.put("id", "fld" + Integer.toString(fieldStackEntry.getFldId()));
 	        insertComplexField.put("instruction", fieldStackEntry.getFldStart().getInstruction());
         }
         operationsArray.put(insertComplexField);
     }
 
-    public void AddInsertComplexFieldRangeOperation(final List<Integer> start, String target, int id, boolean startRange)
+    public void AddInsertComplexFieldRangeOperation(final List<Integer> start, String target, boolean startRange)
         throws JSONException {
 
         final JSONObject insertCommentRangeObject = new JSONObject();
@@ -523,7 +529,6 @@ public class DocxCreateOperationHelper extends CreateOperationHelper {
         	insertCommentRangeObject.put("target", target);
         }
         insertCommentRangeObject.put("position", startRange?"start":"end");
-        insertCommentRangeObject.put("id", "fld" + Integer.toString(id));
         operationsArray.put(insertCommentRangeObject);
     }
 
@@ -746,7 +751,7 @@ public class DocxCreateOperationHelper extends CreateOperationHelper {
                             JSONObject character = Character.createCharacterProperties(getOperationDocument().getThemeFonts(), rPr);
                             attrs.put("character", character);
                         }
-                        operationsArray.put(createInsertStyleSheetOperation("character", styleId, styleName, attrs, parentId, hidden, uipriority, isDefault, custom, false));
+                        operationsArray.put(createInsertStyleSheetOperation("character", styleId, styleName, attrs, parentId, hidden, uipriority, isDefault, custom));
                     }
                     else if (type.equals("paragraph")) {
                         rPr = style.getRPr();
@@ -774,7 +779,7 @@ public class DocxCreateOperationHelper extends CreateOperationHelper {
                         if (paragraph!=null) {
                             attrs.put("paragraph", paragraph);
                         }
-                        operationsArray.put(createInsertStyleSheetOperation("paragraph", styleId, styleName, attrs, parentId, hidden, uipriority, isDefault, custom, false));
+                        operationsArray.put(createInsertStyleSheetOperation("paragraph", styleId, styleName, attrs, parentId, hidden, uipriority, isDefault, custom));
                     }
                     else if (type.equals("table")) {
                         JSONObject attrs = new JSONObject();
@@ -787,7 +792,7 @@ public class DocxCreateOperationHelper extends CreateOperationHelper {
                                 attrName = conditionalTableAttrNames.get(attrName);
                             CreateConditionalTableStyle(attrs, attrName, conditionalStyle.getTblPr(), conditionalStyle.getTrPr(), conditionalStyle.getTcPr(), conditionalStyle.getPPr(), conditionalStyle.getRPr());
                         }
-                        operationsArray.put(createInsertStyleSheetOperation("table", styleId, styleName, attrs, parentId, hidden, uipriority, isDefault, custom, false));
+                        operationsArray.put(createInsertStyleSheetOperation("table", styleId, styleName, attrs, parentId, hidden, uipriority, isDefault, custom));
                     }
                 }
             }
@@ -865,21 +870,20 @@ public class DocxCreateOperationHelper extends CreateOperationHelper {
                 }
                 else if(component instanceof FldCharComponent) {
                 	final FldChar fldChar = (FldChar)((FldCharComponent)component).getObject();
-                	int id = 0;
                 	if(fldChar.getFldCharType()==STFldCharType.BEGIN) {
-                		complexFieldIdStack.push(new ComplexFieldStackEntry(++nextComplexFieldId, (FldCharComponent)component));
-                    	AddInsertComplexFieldRangeOperation(startPosition, target, nextComplexFieldId, true);
+                		complexFieldStack.push(new ComplexFieldStackEntry((FldCharComponent)component));
+                    	AddInsertComplexFieldRangeOperation(startPosition, target, true);
                 	}
                 	else if(fldChar.getFldCharType()==STFldCharType.END) {
-                		if(!complexFieldIdStack.isEmpty()) {
-                			id = complexFieldIdStack.pop().getFldId();
+                		if(!complexFieldStack.isEmpty()) {
+                			complexFieldStack.pop();
                 		}
-                    	AddInsertComplexFieldRangeOperation(startPosition, target, id, false);
+                    	AddInsertComplexFieldRangeOperation(startPosition, target, false);
                 	}
                 	else {
             			ComplexFieldStackEntry fieldStackEntry = null;
-                		if(!complexFieldIdStack.isEmpty()) {
-                			fieldStackEntry = complexFieldIdStack.peek();
+                		if(!complexFieldStack.isEmpty()) {
+                			fieldStackEntry = complexFieldStack.peek();
                 		}
                 		AddInsertComplexFieldOperation(startPosition, target, fieldStackEntry);
                 	}
