@@ -69,13 +69,13 @@ import org.json.JSONException;
 import org.json.JSONObject;
 
 import com.openexchange.office.FilterException;
-import com.openexchange.office.ooxml.docx.OperationDocument;
+import com.openexchange.office.ooxml.docx.DocxOperationDocument;
 import com.openexchange.office.ooxml.tools.Commons;
 import com.openexchange.office.ooxml.tools.ThemeFonts;
 
 public class Character {
 
-    public static void applyCharacterProperties(OperationDocument operationDocument, JSONObject characterProperties, RPrBase rPr )
+    public static void applyCharacterProperties(DocxOperationDocument operationDocument, JSONObject characterProperties, RPrBase rPr )
         throws FilterException, JSONException {
 
         if(characterProperties==null)
@@ -88,7 +88,6 @@ public class Character {
             if(attr.equals("bold")) {
                 if (value instanceof Boolean) {
                     final BooleanDefaultTrue booleanDefaultTrue = Context.getWmlObjectFactory().createBooleanDefaultTrue();
-                    booleanDefaultTrue.setParent(rPr);
                     booleanDefaultTrue.setVal(((Boolean) value).booleanValue());
                     rPr.setB(booleanDefaultTrue);
                 }
@@ -98,7 +97,6 @@ public class Character {
             else if(attr.equals("italic")) {
                 if (value instanceof Boolean) {
                     final BooleanDefaultTrue booleanDefaultTrue = Context.getWmlObjectFactory().createBooleanDefaultTrue();
-                    booleanDefaultTrue.setParent(rPr);
                     booleanDefaultTrue.setVal(((Boolean) value).booleanValue());
                     rPr.setI(booleanDefaultTrue);
                 }
@@ -181,6 +179,15 @@ public class Character {
                     rPr.setHighlight(null);
                 }
             }
+            else if (attr.equals("noProof")) {
+            	if(value instanceof Boolean) {
+            		final BooleanDefaultTrue noProof = Context.getWmlObjectFactory().createBooleanDefaultTrue();
+            		noProof.setVal(((Boolean)value).booleanValue());
+            	}
+            	else {
+            		rPr.setNoProof(null);
+            	}
+            }
             else if(attr.equals("language")){
                 if( value instanceof String){
                     CTLanguage lang = rPr.getLang();
@@ -252,7 +259,6 @@ public class Character {
             else if(attr.equals("strike")) {
                 if (value instanceof String) {
                     final BooleanDefaultTrue booleanDefaultTrue = Context.getWmlObjectFactory().createBooleanDefaultTrue();
-                    booleanDefaultTrue.setParent(rPr);
                     String sValue = (String)value;
                     boolean isNone = sValue.equals("none");
                     booleanDefaultTrue.setVal(!isNone);
@@ -319,6 +325,10 @@ public class Character {
                         Utils.createFillColor(shd));
                 }
             }
+            final BooleanDefaultTrue noProof = characterProperties.getNoProof();
+            if(noProof != null) {
+            	jsonCharacterProperties.put("noProof", noProof.isVal());
+            }
             CTLanguage lang = characterProperties.getLang();
             if(lang!= null){
                 jsonCharacterProperties.put("language", lang.getVal());
