@@ -61,7 +61,6 @@ import org.docx4j.IndexedNodeList;
 import org.docx4j.dml.CTGroupShapeProperties;
 import org.docx4j.dml.CTGroupTransform2D;
 import org.docx4j.dml.CTNonVisualDrawingProps;
-import org.docx4j.dml.CTNonVisualGroupDrawingShapeProps;
 import org.docx4j.dml.CTPoint2D;
 import org.docx4j.dml.CTPositiveSize2D;
 import org.docx4j.dml.Graphic;
@@ -254,16 +253,12 @@ public abstract class DrawingML {
 
         final org.docx4j.dml.wordprocessingGroup2010.ObjectFactory objectFactory = new org.docx4j.dml.wordprocessingGroup2010.ObjectFactory();
         final CTWordprocessingGroup group = objectFactory.createCTWordprocessingGroup();
-        final CTNonVisualDrawingProps cNvPr = Context.getDmlObjectFactory().createCTNonVisualDrawingProps();
+        final CTNonVisualDrawingProps cNvPr = group.getNonVisualDrawingProperties(true);
         cNvPr.setName("Group 1");
         cNvPr.setId(null);
-        group.setCNvPr(cNvPr);
-        final CTNonVisualGroupDrawingShapeProps cNvGrpPr = Context.getDmlObjectFactory().createCTNonVisualGroupDrawingShapeProps();
-        group.setCNvGrpSpPr(cNvGrpPr);
-        final CTGroupShapeProperties grpSpPr = Context.getDmlObjectFactory().createCTGroupShapeProperties();
-        group.setGrpSpPr(grpSpPr);
-        final CTGroupTransform2D grpXFrm = Context.getDmlObjectFactory().createCTGroupTransform2D();
-        grpSpPr.setXfrm(grpXFrm);
+        group.getNonVisualDrawingShapeProperties(true);
+        group.setGrpSpPr(Context.getDmlObjectFactory().createCTGroupShapeProperties());
+        group.getXfrm(true);
         return group;
     }
 
@@ -679,8 +674,8 @@ public abstract class DrawingML {
             Graphic graphic = anchor.getGraphic();
             Inline inline = createInline(true, "", 0, 0);
             inline.setParent(anchor.getParent());
-            inline.setCNvGraphicFramePr(anchor.getCNvGraphicFramePr());
-            inline.setDocPr(anchor.getDocPr());
+            inline.setNonVisualDrawingProperties(anchor.getNonVisualDrawingProperties(false));
+            inline.setNonVisualDrawingShapeProperties(anchor.getNonVisualDrawingShapeProperties(false));
             inline.setGraphic(graphic);
             inline.setExtent(anchor.getExtent());
             inline.setDistB(anchor.getDistB());
@@ -698,8 +693,8 @@ public abstract class DrawingML {
             Graphic graphic = inline.getGraphic();
             Anchor anchor = createAnchor(true, "", 0, 0);
             anchor.setParent(inline.getParent());
-            anchor.setCNvGraphicFramePr(inline.getCNvGraphicFramePr());
-            anchor.setDocPr(inline.getDocPr());
+            anchor.setNonVisualDrawingProperties(inline.getNonVisualDrawingProperties(false));
+            anchor.setNonVisualDrawingShapeProperties(inline.getNonVisualDrawingShapeProperties(false));
             anchor.setGraphic(graphic);
             anchor.setExtent(inline.getExtent());
             anchor.setDistB(inline.getDistB());
@@ -994,7 +989,8 @@ public abstract class DrawingML {
             }
 	        final GraphicBase anchor = getAnchorOrInline();
 
-	        DMLHelper.createJsonFromNonVisualDrawingProperties(attrs, anchor.getDocPr());
+	        DMLHelper.createJsonFromNonVisualDrawingProperties(attrs, anchor);
+	        DMLHelper.createJsonFromNonVisualDrawingShapeProperties(attrs, anchor);
 
 	        final JSONObject initialDrawingAttrs = attrs.optJSONObject("drawing");
 	        final JSONObject drawingAttrs = initialDrawingAttrs!=null ? initialDrawingAttrs : new JSONObject();
