@@ -234,7 +234,7 @@ public class Paragraph {
                     }
                     catch(NumberFormatException e) {
                         numIdValue = 0;
-                        log.info("docx export applyProperties: invalid listStyleId found!");
+                        log.debug("docx export applyProperties: invalid listStyleId found!");
                     }
                     if(numIdValue >= 0) {
                         PPrBase.NumPr.NumId numId = new PPrBase.NumPr.NumId();
