@@ -931,7 +931,7 @@ public class PictVML {
                             shapeAttrs.put("paddingRight", Double.valueOf(Math.round(VMLStyle.getLength(paddings[2], UnitType.EMU))).intValue());
                         }
                         if(paddings.length>=4&&!paddings[3].isEmpty()) {
-                            shapeAttrs.put("paddingRight", Double.valueOf(Math.round(VMLStyle.getLength(paddings[3], UnitType.EMU))).intValue());
+                            shapeAttrs.put("paddingBottom", Double.valueOf(Math.round(VMLStyle.getLength(paddings[3], UnitType.EMU))).intValue());
                         }
                     }
 
