@@ -59,10 +59,12 @@ import org.docx4j.XmlUtils;
 import org.docx4j.jaxb.Context;
 import org.docx4j.openpackaging.exceptions.InvalidFormatException;
 import org.docx4j.openpackaging.exceptions.PartUnrecognisedException;
+import org.docx4j.wml.CTMarkup;
 import org.docx4j.wml.CTRPrChange;
 import org.docx4j.wml.ContentAccessor;
 import org.docx4j.wml.DelText;
 import org.docx4j.wml.P;
+import org.docx4j.wml.PPr;
 import org.docx4j.wml.ParaRPr;
 import org.docx4j.wml.R;
 import org.docx4j.wml.RPr;
@@ -70,14 +72,18 @@ import org.docx4j.wml.RPrBase;
 import org.docx4j.wml.RStyle;
 import org.docx4j.wml.RunDel;
 import org.docx4j.wml.RunIns;
+import org.docx4j.wml.Tbl;
+import org.docx4j.wml.TblGrid;
+import org.docx4j.wml.TblPr;
+import org.docx4j.wml.TcPr;
 import org.docx4j.wml.Text;
+import org.docx4j.wml.TrPr;
 import org.json.JSONException;
 import org.json.JSONObject;
-import org.jvnet.jaxb2_commons.ppp.Child;
 
 import com.openexchange.office.FilterException;
-import com.openexchange.office.ooxml.docx.OperationDocument;
-import com.openexchange.office.ooxml.docx.tools.Component.TextRun_Base;
+import com.openexchange.office.ooxml.docx.DocxOperationDocument;
+import com.openexchange.office.ooxml.docx.components.TextRun_Base;
 import com.openexchange.office.ooxml.tools.Commons;
 
 public class TextUtils{
@@ -148,6 +154,68 @@ public class TextUtils{
         return rPr;
     }
 
+    // resetting id which has to be unique
+    public static void resetMarkupId(CTMarkup trackChange) {
+    	if(trackChange!=null) {
+    		trackChange.setId(null);
+    	}
+    }
+
+    // resetting id which has to be unique
+    public static void resetMarkupId(RPr rPr) {
+    	if(rPr!=null) {
+    		resetMarkupId(rPr.getRPrChange());
+    	}
+    }
+
+	// resetting id which has to be unique
+    public static void resetMarkupId(PPr pPr) {
+    	if(pPr!=null) {
+    		resetMarkupId(pPr.getPPrChange());
+	        final ParaRPr rPr = pPr.getRPr();
+	        if(rPr!=null) {
+	        	resetMarkupId(rPr.getRPrChange());
+	        	resetMarkupId(rPr.getDel());
+	        	resetMarkupId(rPr.getIns());
+	        	resetMarkupId(rPr.getMoveFrom());
+	        	resetMarkupId(rPr.getMoveTo());
+	        }
+    	}
+    }
+
+	// resetting id which has to be unique
+    public static void resetMarkupId(TrPr trPr) {
+    	if(trPr!=null) {
+    		resetMarkupId(trPr.getDel());
+    		resetMarkupId(trPr.getIns());
+    		resetMarkupId(trPr.getTrPrChange());
+    	}
+    }
+
+	// resetting id which has to be unique
+    public static void resetMarkupId(TcPr tcPr) {
+    	if(tcPr!=null) {
+    		resetMarkupId(tcPr.getCellDel());
+    		resetMarkupId(tcPr.getCellIns());
+    		resetMarkupId(tcPr.getCellMerge());
+    		resetMarkupId(tcPr.getTcPrChange());
+    	}
+    }
+
+	// resetting id which has to be unique (without tbl content)
+    public static void resetMarkupId(Tbl tbl) {
+    	if(tbl!=null) {
+    		final TblGrid tblGrid = tbl.getTblGrid();
+    		if(tblGrid!=null) {
+    			resetMarkupId(tblGrid.getTblGridChange());
+    		}
+    		final TblPr tblPr = tbl.getTblPr();
+    		if(tblPr!=null) {
+    			resetMarkupId(tblPr.getTblPrChange());
+    		}
+    	}
+    }
+
     private static void delTextToText(int index, Object o) {
     	if(o instanceof ContentAccessor) {
     		final List<Object> content = ((ContentAccessor)o).getContent();
@@ -193,12 +261,10 @@ public class TextUtils{
     	return attrs;
     }
 
-    public static void setTextRunAttributes(OperationDocument operationDocument, JSONObject attrs, TextRun_Base textRunComponent)
+    public static void setTextRunAttributes(DocxOperationDocument operationDocument, JSONObject attrs, TextRun_Base textRunComponent)
         throws FilterException, JAXBException, JSONException, InvalidFormatException, PartUnrecognisedException {
 
-    	final P paragraph = (P)textRunComponent.getParentComponent().getNode().getData();
-
-        int changeTrackFlags = Component.CT_NONE;
+        int changeTrackFlags = TextRun_Base.CT_NONE;
         Object attrsInserted = null;
         Object attrsRemoved  = null;
         Object attrsModified = null;
@@ -209,33 +275,33 @@ public class TextUtils{
 		        	attrsInserted = ((JSONObject)changes).opt("inserted");
 		        	if(attrsInserted!=null) {
 		        		if(attrsInserted instanceof JSONObject) {
-		        			changeTrackFlags |= Component.CT_INSERTED<<16|Component.CT_INSERTED;
+		        			changeTrackFlags |= TextRun_Base.CT_INSERTED<<16|TextRun_Base.CT_INSERTED;
 		        		}
 		        		else {
-		        			changeTrackFlags |= Component.CT_INSERTED;
+		        			changeTrackFlags |= TextRun_Base.CT_INSERTED;
 		        		}
 		        	}
 		        	attrsRemoved = ((JSONObject)changes).opt("removed");
 		        	if(attrsRemoved!=null) {
 		        		if(attrsRemoved instanceof JSONObject) {
-		        			changeTrackFlags |= Component.CT_DELETED<<16|Component.CT_DELETED;
+		        			changeTrackFlags |= TextRun_Base.CT_DELETED<<16|TextRun_Base.CT_DELETED;
 		        		}
 		        		else {
-		        			changeTrackFlags |= Component.CT_DELETED;
+		        			changeTrackFlags |= TextRun_Base.CT_DELETED;
 		        		}
 		        	}
 		        	attrsModified = ((JSONObject)changes).opt("modified");
 		        	if(attrsModified!=null) {
 		        		if(attrsModified instanceof JSONObject) {
-		        			changeTrackFlags |= Component.CT_MODIFIED<<16|Component.CT_MODIFIED;
+		        			changeTrackFlags |= TextRun_Base.CT_MODIFIED<<16|TextRun_Base.CT_MODIFIED;
 		        		}
 		        		else {
-		        			changeTrackFlags |= Component.CT_MODIFIED;
+		        			changeTrackFlags |= TextRun_Base.CT_MODIFIED;
 		        		}
 		        	}
         		}
         		else {
-        			changeTrackFlags = Component.CT_MODIFIED | Component.CT_DELETED | Component.CT_INSERTED;
+        			changeTrackFlags = TextRun_Base.CT_MODIFIED | TextRun_Base.CT_DELETED | TextRun_Base.CT_INSERTED;
         		}
         	}
         }
@@ -264,8 +330,8 @@ public class TextUtils{
                 }
             }
             final JSONObject characterAttributes = attrs.optJSONObject("character");
-            if((changeTrackFlags&Component.CT_MODIFIED)!=0) {
-            	if((changeTrackFlags&(Component.CT_MODIFIED<<16))!=0) {
+            if((changeTrackFlags&TextRun_Base.CT_MODIFIED)!=0) {
+            	if((changeTrackFlags&(TextRun_Base.CT_MODIFIED<<16))!=0) {
             		CTRPrChange rPrChange = rPr.getRPrChange();
             		if(rPrChange==null) {
 	                	rPrChange = Context.getWmlObjectFactory().createCTRPrChange();
@@ -306,56 +372,24 @@ public class TextUtils{
 
                 final Object url = characterAttributes.opt("url");
                 if(url!=null) {
-                	IndexedNode<Object> hyperlinkNode = textRunComponent.getHyperlinkNode();
-                	// retrieving childNode into the paragraph or hyperlink
-            		IndexedNode<Object> childNode = textRunNode;
-                	if(textRunComponent.getRunInsNode()!=null) {
-                		childNode = textRunComponent.getRunInsNode();
-                	}
-                	else if(textRunComponent.getRunDelNode()!=null) {
-                		childNode = textRunComponent.getRunDelNode();
-                	}
                 	if(url instanceof String) {
-	                	// applying url
-	                	if(hyperlinkNode==null) {
-	                        final P.Hyperlink hyperlink = Context.getWmlObjectFactory().createPHyperlink();
-	                        hyperlink.setParent(paragraph);
-	                        hyperlinkNode = new IndexedNode<Object>(hyperlink);
-	                        paragraph.getContent().setNode(childNode, hyperlinkNode);
-	                        hyperlink.getContent().addNode(childNode);
-	                        textRunComponent.insertHyperlink(hyperlinkNode);
-	                        ((Child)childNode.getData()).setParent(hyperlink);
-	                	}
+                		final IndexedNode<Object> hyperlinkNode = textRunComponent.getHyperlinkNode(true);
 	                	final P.Hyperlink hyperlink = (P.Hyperlink)hyperlinkNode.getData();
                         hyperlink.setId(Commons.setUrl(operationDocument.getContextPart(), hyperlink.getId(), (String)url));
 	                }
 	                else {
-	                	// removing url
-	                	if(hyperlinkNode!=null) {
-	                		paragraph.getContent().setNode(hyperlinkNode, childNode);
-	                		((Child)childNode.getData()).setParent(paragraph);
-	                		textRunComponent.removeHyperlink();
-	                	}
+	                	textRunComponent.removeHyperlink();
 	                }
                 }
             }
         }
 
-    	if((changeTrackFlags&Component.CT_DELETED)!=0) {
-
-    		IndexedNode<Object> delNode = textRunComponent.getRunDelNode();
-    		if((changeTrackFlags&(Component.CT_DELETED<<16))!=0) {
-
+    	if((changeTrackFlags&TextRun_Base.CT_DELETED)!=0) {
+    		IndexedNode<Object> delNode = textRunComponent.getRunDelNode(false);
+    		if((changeTrackFlags&(TextRun_Base.CT_DELETED<<16))!=0) {
     			// delNode is needed
     			if(delNode==null) {
-            		final RunDel runDel = Context.getWmlObjectFactory().createRunDel();
-            		final ContentAccessor textRunParent = (ContentAccessor)textRun.getParent();
-            		runDel.setParent(textRunParent);
-            		delNode = new IndexedNode<Object>(runDel);
-            		textRun.setParent(runDel);
-            		((IndexedNodeList<Object>)textRunParent.getContent()).setNode(textRunNode, delNode);
-            		runDel.getContent().addNode(textRunNode);
-            		textRunComponent.insertRunDelNode(delNode);
+    				delNode = textRunComponent.getRunDelNode(true);
 
         			// changing text to delText
         			final IndexedNodeList<Object> textRunContent = textRun.getContent();
@@ -373,52 +407,22 @@ public class TextUtils{
     			}
     			Utils.applyTrackInfoFromJSON(operationDocument, (JSONObject)attrsRemoved, (RunDel)delNode.getData());
     		}
-    		else {
-
+    		else if (delNode!=null) {
     			// delNode is to be removed
-    			if(delNode!=null) {
-	    			final ContentAccessor delNodeParent = (ContentAccessor)((Child)delNode.getData()).getParent();
-	    			final IndexedNodeList<Object> delNodeParentContent = (IndexedNodeList<Object>)delNodeParent.getContent();
-	    			final IndexedNodeList<Object> delNodeContent = (IndexedNodeList<Object>)((ContentAccessor)delNode.getData()).getContent();
-	    		    delTextToText(0, delNode.getData());
-	    		    delNodeParentContent.removeNodes(delNode, null);
-	    		    IndexedNodeList.moveNodes(delNodeContent, delNodeParentContent, 0, delNode.getIndex(), delNodeContent.size(), delNodeParent);
-	    			textRunComponent.removeRunDelNode();
-    			}
+    		    delTextToText(0, delNode.getData());
+    			textRunComponent.removeRunDelNode();
     		}
     	}
 
-    	if((changeTrackFlags&Component.CT_INSERTED)!=0) {
-
-    		IndexedNode<Object> insertNode = textRunComponent.getRunInsNode();
-    		IndexedNode<Object> delNode = textRunComponent.getRunDelNode();
-    		if((changeTrackFlags&(Component.CT_INSERTED<<16))!=0) {
-
+    	if((changeTrackFlags&TextRun_Base.CT_INSERTED)!=0) {
+    		if((changeTrackFlags&(TextRun_Base.CT_INSERTED<<16))!=0) {
     			// insertNode is needed
-    			if(insertNode==null) {
-            		final RunIns runIns = Context.getWmlObjectFactory().createRunIns();
-            		final IndexedNode<Object> newChildNode = delNode!=null?delNode:textRunNode;
-            		final ContentAccessor newParent = (ContentAccessor)((Child)(newChildNode.getData())).getParent();
-            		runIns.setParent(newParent);
-            		insertNode = new IndexedNode<Object>(runIns);
-            		((Child)newChildNode.getData()).setParent(runIns);
-            		((IndexedNodeList<Object>)newParent.getContent()).setNode(newChildNode, insertNode);
-            		runIns.getContent().addNode(newChildNode);
-            		textRunComponent.insertRunInsNode(insertNode);
-            	}
+    			final IndexedNode<Object> insertNode = textRunComponent.getRunInsNode(true);
     			Utils.applyTrackInfoFromJSON(operationDocument, (JSONObject)attrsInserted, (RunIns)insertNode.getData());
     		}
     		else {
-
     			// insertNode is to be removed
-    			if(insertNode!=null) {
-        			final ContentAccessor insertNodeParent = (ContentAccessor)((Child)insertNode.getData()).getParent();
-        			final IndexedNodeList<Object> insertNodeParentContent = (IndexedNodeList<Object>)insertNodeParent.getContent();
-        			final IndexedNodeList<Object> insertNodeContent = (IndexedNodeList<Object>)((ContentAccessor)insertNode.getData()).getContent();
-        			insertNodeParentContent.removeNodes(insertNode, null);
-        			IndexedNodeList.moveNodes(insertNodeContent, insertNodeParentContent, 0, insertNode.getIndex(), insertNodeContent.size(), insertNodeParent);
-        			textRunComponent.removeRunInsNode();
-    			}
+				textRunComponent.removeRunInsNode();
     		}
     	}
     }
