@@ -50,10 +50,10 @@
 package com.openexchange.office.ooxml.pptx;
 
 import java.io.InputStream;
+import java.util.HashMap;
 import java.util.List;
-import java.util.StringTokenizer;
+import java.util.Map;
 
-import org.docx4j.dml.Theme;
 import org.docx4j.openpackaging.exceptions.InvalidFormatException;
 import org.docx4j.openpackaging.packages.OpcPackage;
 import org.docx4j.openpackaging.packages.PresentationMLPackage;
@@ -71,10 +71,8 @@ import org.docx4j.relationships.Relationship;
 import org.json.JSONArray;
 import org.json.JSONObject;
 import org.json.JSONTokener;
-import org.pptx4j.pml.Presentation;
 import org.pptx4j.pml.Presentation.SldMasterIdLst;
 import org.pptx4j.pml.Presentation.SldMasterIdLst.SldMasterId;
-import org.pptx4j.pml.SldMaster;
 import org.pptx4j.pml.SlideLayoutIdList;
 import org.pptx4j.pml.SlideLayoutIdList.SldLayoutId;
 
@@ -92,7 +90,11 @@ import com.openexchange.session.Session;
 public class PptxOperationDocument extends com.openexchange.office.ooxml.OperationDocument {
 
     private PresentationMLPackage opcPackage;
-    private Theme theme = null;
+    private ThemePart themePart = null;
+
+    private String target = "";
+    private final HashMap<String, Part> idToPart = new HashMap<String, Part>();
+    private final HashMap<String, String> relTargetToId = new HashMap<String, String>();
 
     public PptxOperationDocument(Session session, ServiceLookup _services, InputStream _inputDocumentStream, IResourceManager _resourceManager, DocumentProperties _documentProperties)
         throws FilterException {
@@ -100,6 +102,8 @@ public class PptxOperationDocument extends com.openexchange.office.ooxml.Operati
         super(session, _services, _inputDocumentStream, _resourceManager, _documentProperties);
         try {
             opcPackage = (PresentationMLPackage)PresentationMLPackage.load(_inputDocumentStream);
+            themePart = null;
+            initIdTables();
         }
         catch(Throwable e) {
             removeMemoryListener();
@@ -114,6 +118,8 @@ public class PptxOperationDocument extends com.openexchange.office.ooxml.Operati
         super(null, _services, null, null, _documentProperties);
         try {
             opcPackage = PresentationMLPackage.createPackage();
+            themePart = null;
+            initIdTables();
         }
         catch(Throwable e) {
             removeMemoryListener();
@@ -121,60 +127,112 @@ public class PptxOperationDocument extends com.openexchange.office.ooxml.Operati
         }
     }
 
-    // - the target can be "" then a normal slide is addressed
-    // or target contains tokens separated by "."
-    // - if only one token is available, then a master page is addressed
-    // - if two tokens are available, then then first represents the master page
-    //   and the second the layout page
-    public void setContext(String target) {
-    	Part newContext = null;
-    	if(target!=null&&!target.isEmpty()) {
-        	final MainPresentationPart mainPresentationPart = getPackage().getMainPresentationPart();
-    		final Presentation mainPresentation = mainPresentationPart.getJaxbElement();
-    		StringTokenizer tokenizer = new StringTokenizer(target,".");
-    		while(tokenizer.hasMoreTokens()) {
-    			final String masterToken = tokenizer.nextToken();
-	    		final SldMasterIdLst slideMasterIds = mainPresentation.getSldMasterIdLst();
-				final List<SldMasterId> slideMasterIdList = slideMasterIds.getSldMasterId();
-				for(int i=0; i<slideMasterIdList.size(); i++) {
-	    			final SldMasterId masterId = slideMasterIdList.get(i);
-	    			if(masterToken.equals(masterId.getId().toString())) {
-	    				newContext = mainPresentationPart.getRelationshipsPart().getPart(masterId.getRid());
-	    				break;
-	    			}
-	    		}
-				if(tokenizer.hasMoreTokens()) {
-					final String layoutToken = tokenizer.nextToken();
-					// we have to set the layout context
-					final SldMaster slideMaster = ((SlideMasterPart)newContext).getJaxbElement();
-					final SlideLayoutIdList slideLayoutIds = slideMaster.getSldLayoutIdLst();
+    @Override
+    public JSONObject getOperations()
+        throws Exception {
+
+        final JSONObject aOperations = new JSONObject();
+        final JSONArray operationsArray = new JSONArray();
+
+        final PptxCreateOperationHelper createOperationHelper = new PptxCreateOperationHelper(this, operationsArray);
+        createOperationHelper.createDocumentDefaults(getUserLanguage());
+        createOperationHelper.createMasterSlides();
+        createOperationHelper.createSlides();
+        aOperations.put("operations", operationsArray);
+        return aOperations;
+    }
+
+	public Map<String, Object> getMetaData()
+		throws Exception {
+
+		final JSONArray operationsArray = new JSONArray();
+		final PptxCreateOperationHelper createOperationHelper = new PptxCreateOperationHelper(this, operationsArray);
+        createOperationHelper.createDocumentDefaults(getUserLanguage());
+		final Map<String, Object> operations = new HashMap<String, Object>(1);
+        operations.put("operations", operationsArray);
+        return operations;
+	}
+
+	public Map<String, Object> getActivePart()
+		throws Exception {
+
+		final JSONArray operationsArray = new JSONArray();
+		final PptxCreateOperationHelper createOperationHelper = new PptxCreateOperationHelper(this, operationsArray);
+        createOperationHelper.createMasterSlides();
+        createOperationHelper.createSlides();
+		final Map<String, Object> operations = new HashMap<String, Object>(1);
+        operations.put("operations", operationsArray);
+        return operations;
+	}
+
+	public Map<String, Object> getNextPart()
+		throws Exception {
+
+		return null;
+	}
+
+    private void initIdTables() {
+		final MainPresentationPart mainPresentationPart = opcPackage.getMainPresentationPart();
+		final SldMasterIdLst slideMasterIds = mainPresentationPart.getJaxbElement().getSldMasterIdLst();
+		if(slideMasterIds!=null) {
+			final List<SldMasterId> slideMasterIdList = slideMasterIds.getSldMasterId();
+			for(int i=0; i<slideMasterIdList.size(); i++) {
+				final SldMasterId slideMasterId = slideMasterIdList.get(i);
+				final SlideMasterPart slideMasterPart = (SlideMasterPart)mainPresentationPart.getRelationshipsPart().getPart(slideMasterId.getRid());
+				final String slideMasterIdString = slideMasterId.getId().toString();
+				idToPart.put(slideMasterIdString, slideMasterPart);
+				relTargetToId.put("../" + mainPresentationPart.getRelationshipsPart().getRelationshipByID(slideMasterId.getRid()).getTarget(), slideMasterIdString);
+
+				// retrieving layouts
+				final SlideLayoutIdList slideLayoutIds = slideMasterPart.getJaxbElement().getSldLayoutIdLst(false);
+				if(slideLayoutIds!=null) {
 					final List<SldLayoutId> slideLayoutIdList = slideLayoutIds.getSldLayoutId();
-					for(int i=0; i<slideLayoutIdList.size(); i++) {
-						final SldLayoutId slideLayoutId = slideLayoutIdList.get(i);
-						if(layoutToken.equals(slideLayoutId.getId().toString())) {
-							newContext = newContext.getRelationshipsPart().getPart(slideLayoutId.getRid());
-							break;
-						}
+					for(int j=0; j<slideLayoutIdList.size(); j++) {
+						final SldLayoutId slideLayoutId = slideLayoutIdList.get(j);
+						final String slideLayoutIdString = slideLayoutId.getId().toString();
+						idToPart.put(slideLayoutIdString, slideMasterPart.getRelationshipsPart().getPart(slideLayoutId.getRid()));
+						relTargetToId.put(slideMasterPart.getRelationshipsPart().getRelationshipByID(slideLayoutId.getRid()).getTarget(), slideLayoutIdString);
 					}
 				}
-				break;
-    		}
-        }
-    	setContextPart(newContext);
+			}
+		}
+    }
+
+    public HashMap<String, Part> getIdToPartMap() {
+    	return idToPart;
+    }
+
+    public HashMap<String, String> getRelTargetToIdMap() {
+    	return relTargetToId;
+    }
+
+    // - the target can be "" then a normal slide is addressed, otherwise it points to a layout or masterslide
+    public Part setContextPartByTarget(String target) {
+    	this.target = target;
+    	setContextPart(getPartByTarget(target));
+    	return contextPart;
     }
 
     @Override 
     public void setContextPart(Part part) {
     	if(contextPart!=part) {
     		contextPart = part;
-    		theme = null;
+    		themePart = null;
     		themeFonts = null;
     	}
     }
 
     @Override
     public Part getContextPart() {
-    	return contextPart!=null ? contextPart : getPackage().getMainPresentationPart();
+    	return contextPart;
+    }
+
+    public Part getPartByTarget(String target) {
+    	Part newContext = null;
+    	if(target!=null&&!target.isEmpty()) {
+    		newContext = idToPart.get(target);
+        }
+    	return newContext == null ? getPackage().getMainPresentationPart() : newContext;
     }
 
     @Override
@@ -190,39 +248,47 @@ public class PptxOperationDocument extends com.openexchange.office.ooxml.Operati
                 for (i = 0; i < aOperations.length(); i++) {
                 	successfulAppliedOperations = i;
                     op = (JSONObject) aOperations.get(i);
-                    setContext(op.optString("target", ""));
+                    final String target = op.optString("target", "");
                     opName = op.getString("name");
                     switch(opName) {
                     	case "insertParagraph" : {
-	                        applyOperationHelper.insertParagraph(op.getJSONArray("start"), op.optJSONObject("attrs"));
+	                        applyOperationHelper.insertParagraph(op.getJSONArray("start"), target, op.optJSONObject("attrs"));
 	                        break;
                     	}
                     	case "splitParagraph": {
-                    		applyOperationHelper.splitParagraph(op.getJSONArray("start"));
+                    		applyOperationHelper.splitParagraph(op.getJSONArray("start"), target);
                     		break;
                     	}
                     	case "mergeParagraph": {
-                            applyOperationHelper.mergeParagraph(op.getJSONArray("start"));
+                            applyOperationHelper.mergeParagraph(op.getJSONArray("start"), target);
                             break;
                     	}
                     	case "insertText": {
-                            applyOperationHelper.insertText(op.getJSONArray("start"), op.getString("text").replaceAll("\\p{C}", " "), op.optJSONObject("attrs"));
+                            applyOperationHelper.insertText(op.getJSONArray("start"), target, op.getString("text").replaceAll("\\p{C}", " "), op.optJSONObject("attrs"));
                             break;
                     	}
                     	case "delete": {
-                            applyOperationHelper.delete(op.getJSONArray("start"), op.optJSONArray("end"));
+                            applyOperationHelper.delete(op.getJSONArray("start"), target, op.optJSONArray("end"));
                             break;
                     	}
                     	case "setAttributes": {
-                            applyOperationHelper.setAttributes(op.getJSONObject("attrs"), op.getJSONArray("start"), op.optJSONArray("end"));
+                            applyOperationHelper.setAttributes(op.getJSONArray("start"), target, op.optJSONArray("end"), op.getJSONObject("attrs"));
                             break;
                     	}
                     	case "insertSlide": {
-                    		applyOperationHelper.insertSlide(op.getJSONArray("start"), op.optJSONObject("attrs"));
+                    		applyOperationHelper.insertSlide(op.getJSONArray("start"), target, op.optJSONObject("attrs"));
+                    		break;
+                    	}
+                    	case "insertMasterSlide": {
+                    		applyOperationHelper.insertMasterSlide(op.getString("id"), op.optInt("start"));
+                    		break;
+                    	}
+                    	case "insertLayoutSlide": {
+                    		applyOperationHelper.insertLayoutSlide(op.getString("id"), op.getString("target"), op.optInt("start"));
                     		break;
                     	}
                     	case "insertDrawing": {
-                    		applyOperationHelper.insertDrawing(op.getJSONArray("start"), op.getString("type").toUpperCase(), op.optJSONObject("attrs"));
+                    		applyOperationHelper.insertDrawing(op.getJSONArray("start"), target, op.getString("type").toUpperCase(), op.optJSONObject("attrs"));
                     		break;
                     	}
                     	case "setDocumentAttributes": {
@@ -230,13 +296,45 @@ public class PptxOperationDocument extends com.openexchange.office.ooxml.Operati
                     		break;
                     	}
                     	case "insertHardBreak": {
-                            applyOperationHelper.insertHardBreak(op.getJSONArray("start"), op.optJSONObject("attrs"));
+                            applyOperationHelper.insertHardBreak(op.getJSONArray("start"), target, op.optJSONObject("attrs"));
                             break;
                     	}
                     	case "changeLayout": {
-                    		applyOperationHelper.changeLayout(op.getJSONArray("start"));
+                    		applyOperationHelper.changeLayout(op.getJSONArray("start"), target);
                     		break;
                     	}
+                    	case "moveSlide": {
+                    		applyOperationHelper.moveSlide(op.getJSONArray("start"), op.getJSONArray("end"));
+                    		break;
+                    	}
+                    	case "moveLayoutSlide": {
+                    		applyOperationHelper.moveLayoutSlide(op.getString("id"), op.getInt("start"), target);
+                    		break;
+                    	}
+                    	case "insertTab": {
+                            applyOperationHelper.insertTab(op.getJSONArray("start"), target, op.optJSONObject("attrs"));
+                            break;
+                    	}
+                    	case "insertField": {
+                    		applyOperationHelper.insertField(op.getJSONArray("start"), target, op.getString("type"), op.getString("type"), op.optJSONObject("attrs"));
+                    		break;
+                    	}
+                    	case "updateField": {
+                    		applyOperationHelper.updateField(op.getJSONArray("start"), target, op.optString("type"), op.optString("type"), op.optJSONObject("attrs"));
+                    		break;
+                    	}
+                    	case "group": {
+                    		applyOperationHelper.group(op.getJSONArray("start"), target, op.getJSONArray("drawings"), op.getJSONObject("attrs"), op.optJSONArray("childAttrs"));
+                    		break;
+                    	}
+                    	case "ungroup": {
+                    		applyOperationHelper.ungroup(op.getJSONArray("start"), target, op.optJSONArray("drawings"));
+                    		break;
+                    	}
+                    	case "move": {
+                            applyOperationHelper.move(op.getJSONArray("start"), target, op.optJSONArray("end"), op.getJSONArray("to"));
+                            break;
+                    	}
                     }
                     
 /*
@@ -282,21 +380,6 @@ public class PptxOperationDocument extends com.openexchange.office.ooxml.Operati
         }
     }
 
-    @Override
-    public JSONObject getOperations()
-        throws Exception {
-
-        final JSONObject aOperations = new JSONObject();
-        final JSONArray operationsArray = new JSONArray();
-
-        final PptxCreateOperationHelper createOperationHelper = new PptxCreateOperationHelper(this, operationsArray);
-        createOperationHelper.createDocumentDefaults(getUserLanguage());
-        createOperationHelper.createMasterSlides();
-        createOperationHelper.createSlides();
-        aOperations.put("operations", operationsArray);
-        return aOperations;
-    }
-
     @Override
     public PresentationMLPackage getPackage() {
         return opcPackage;
@@ -308,16 +391,16 @@ public class PptxOperationDocument extends com.openexchange.office.ooxml.Operati
     }
 
     @Override
-	public Component getRootComponent() {
-    	return new RootComponent(this);
+	public Component getRootComponent(String target) {
+    	return new RootComponent(this, target);
 	}
 
     @Override
-    public Theme getTheme(boolean createIfMissing)
+    public ThemePart getThemePart(boolean createIfMissing)
     	throws FilterException {
 
     	try {
-	    	if(theme==null) {
+	    	if(themePart==null) {
 	    		Part context = contextPart;
 	    		if(context instanceof SlidePart) {
 	    			context = ((SlidePart)context).getSlideLayoutPart();
@@ -327,7 +410,6 @@ public class PptxOperationDocument extends com.openexchange.office.ooxml.Operati
 	    		}
 	    		final RelationshipsPart masterRelations = context.getRelationshipsPart();
 	    		final Relationship rel = masterRelations.getRelationshipByType(Namespaces.THEME);
-	    		ThemePart themePart = null;
 	    		if(rel!=null) {
 	    			themePart = (ThemePart)masterRelations.getPart(rel);
 	    		}
@@ -336,9 +418,8 @@ public class PptxOperationDocument extends com.openexchange.office.ooxml.Operati
 		    		themePart = getDefaultThemePart(themePartName);
 		    		context.addTargetPart(themePart, AddPartBehaviour.RENAME_IF_NAME_EXISTS);
 	    		}
-	    		theme = themePart!=null?themePart.getJaxbElement():null;
 	    	}
-	    	return theme;
+	    	return themePart;
     	}
     	catch(InvalidFormatException e) {
     		throw new FilterException("xlsx filter, could not create default theme", ErrorCode.CRITICAL_ERROR, e);
