@@ -73,7 +73,6 @@ import org.docx4j.openpackaging.parts.PresentationML.SlideMasterPart;
 import org.docx4j.wml.ContentAccessor;
 import org.json.JSONException;
 import org.json.JSONObject;
-import org.jvnet.jaxb2_commons.ppp.Child;
 import org.pptx4j.pml.CTPlaceholder;
 import org.pptx4j.pml.STPlaceholderType;
 import org.pptx4j.pml.Shape;
@@ -111,7 +110,7 @@ public class ParagraphComponent extends PptxComponent implements IParagraph {
             	}
             }
             else if(o instanceof CTTextField) {
-
+            	nextComponent = new TextFieldComponent(this, childNode, nextComponentNumber);
             }
             else if(o instanceof CTTextLineBreak) {
             	nextComponent = new HardBreakComponent(this, childNode, nextComponentNumber);
@@ -238,7 +237,7 @@ public class ParagraphComponent extends PptxComponent implements IParagraph {
 
 	@Override
 	public void applyAttrsFromJSON(OperationDocument operationDocument, JSONObject attrs)
-			throws JAXBException, JSONException, InvalidFormatException, PartUnrecognisedException {
+		throws JSONException, InvalidFormatException, PartUnrecognisedException {
 
 		if(attrs==null) {
 			return;
@@ -298,14 +297,23 @@ public class ParagraphComponent extends PptxComponent implements IParagraph {
 	private void applyHardFormatting(OperationDocument operationDocument, JSONObject attrs)
 		throws InvalidFormatException, PartUnrecognisedException, JSONException {
 
-		DMLHelper.applyTextParagraphPropertiesFromJson(((CTTextParagraph)getObject()).getPPr(true), attrs, operationDocument, operationDocument.getContextPart());
+		final CTTextParagraph textParagraph = (CTTextParagraph)getObject();
+		final Part part = operationDocument.getContextPart();
+		DMLHelper.applyTextParagraphPropertiesFromJson(textParagraph.getPPr(true), attrs, operationDocument, part);
+    	if(attrs.hasAndNotNull("character")) {
+    		DMLHelper.applyTextCharacterPropertiesFromJson(textParagraph.getEndParaRPr(true), attrs, part);
+    	}
 	}
 
 	@Override
 	public JSONObject createJSONAttrs(CreateOperationHelper createOperationHelper, JSONObject attrs)
 			throws JSONException, ParseException, FilterException {
 
-		DMLHelper.createJsonFromTextParagraphProperties(attrs, ((CTTextParagraph)getObject()).getPPr(false), createOperationHelper.getOperationDocument().getContextPart());
+		final CTTextParagraph textParagraph = (CTTextParagraph)getObject();
+		DMLHelper.createJsonFromTextParagraphProperties(attrs, textParagraph.getPPr(false), createOperationHelper.getOperationDocument().getContextPart());
+		if(textParagraph.getEndParaRPr(false)!=null&&textParagraph.getContent().isEmpty()) {
+			DMLHelper.createJsonFromTextCharacterProperties(attrs, textParagraph.getEndParaRPr(false), createOperationHelper.getOperationDocument().getContextPart());
+		}
 		return attrs;
 	}
 
@@ -323,12 +331,14 @@ public class ParagraphComponent extends PptxComponent implements IParagraph {
     public Component insertChildComponent(com.openexchange.office.ooxml.OperationDocument operationDocument, int textPosition, JSONObject attrs, Type childType)
         throws JSONException, JAXBException, InvalidFormatException, PartUnrecognisedException {
 
-        Child newChild = null;
+        Object newChild = null;
 
         CTTextCharacterProperties textCharacterProperties = null;
         if(childType == Type.HARDBREAK_DEFAULT) {
         	newChild = Context.getDmlObjectFactory().createCTTextLineBreak();
-        	newChild.setParent(getObject());
+        }
+        else if(childType == Type.SIMPLE_FIELD) {
+        	newChild = Context.getDmlObjectFactory().createCTTextField();
         }
         Component childComponent = getNextChildComponent(null, null);
         if(childComponent!=null) {
@@ -345,7 +355,7 @@ public class ParagraphComponent extends PptxComponent implements IParagraph {
         else {
         	final CTTextParagraph paragraph = (CTTextParagraph)getObject();
         	paragraph.getContent().addNode(new IndexedNode<Object>(newChild));
-        	textCharacterProperties = paragraph.getEndParaRPr();
+        	textCharacterProperties = paragraph.getEndParaRPr(false);
         }
         if(textPosition>0) {
             childComponent = childComponent.getNextComponent();
