@@ -51,11 +51,11 @@ package com.openexchange.office.ooxml.pptx.operations;
 
 import java.text.ParseException;
 import java.util.ArrayList;
-import java.util.HashMap;
 import java.util.List;
 
 import org.docx4j.dml.CTColorMappingOverride;
 import org.docx4j.dml.CTRegularTextRun;
+import org.docx4j.dml.CTTextField;
 import org.docx4j.dml.CTTextListStyle;
 import org.docx4j.openpackaging.packages.PresentationMLPackage;
 import org.docx4j.openpackaging.parts.Part;
@@ -70,6 +70,7 @@ import org.docx4j.relationships.Relationship;
 import org.json.JSONArray;
 import org.json.JSONException;
 import org.json.JSONObject;
+import org.pptx4j.pml.CTHeaderFooter;
 import org.pptx4j.pml.CTNormalViewPortion;
 import org.pptx4j.pml.CTNormalViewProperties;
 import org.pptx4j.pml.CTSlideMasterTextStyles;
@@ -94,11 +95,11 @@ import com.openexchange.office.ooxml.pptx.components.HardBreakComponent;
 import com.openexchange.office.ooxml.pptx.components.ParagraphComponent;
 import com.openexchange.office.ooxml.pptx.components.RootComponent;
 import com.openexchange.office.ooxml.pptx.components.TextComponent;
+import com.openexchange.office.ooxml.pptx.components.TextFieldComponent;
 
 public class PptxCreateOperationHelper extends CreateOperationHelper {
 
     private final PresentationMLPackage presentationMLPackage;
-    private final HashMap<String, String> relTargetToId = new HashMap<String, String>();
 
     public PptxCreateOperationHelper(PptxOperationDocument _operationDocument, JSONArray mOperationsArray)
     	throws FilterException {
@@ -113,7 +114,9 @@ public class PptxCreateOperationHelper extends CreateOperationHelper {
 	}
 
 	@Override
-	public void createDocumentDefaults(String userLanguage) throws Exception {
+	public void createDocumentDefaults(String userLanguage)
+		throws JSONException  {
+
 		final MainPresentationPart mainPresentationPart = presentationMLPackage.getMainPresentationPart();
 		final Presentation presentation = mainPresentationPart.getJaxbElement();
         final JSONObject documentAttributes = new JSONObject();
@@ -173,18 +176,14 @@ public class PptxCreateOperationHelper extends CreateOperationHelper {
 				final SlideMasterPart slideMasterPart = (SlideMasterPart)mainPresentationPart.getRelationshipsPart().getPart(slideMasterId.getRid());
 				getOperationDocument().setContextPart(slideMasterPart);
 				final String masterTarget = slideMasterId.getId().toString();
-				relTargetToId.put(mainPresentationPart.getRelationshipsPart().getRelationshipByID(slideMasterId.getRid()).getTarget(), masterTarget);
 				createMasterSlideOperations(masterTarget);
 
 				// retrieving layouts
-				final SlideLayoutIdList slideLayoutIds = slideMasterPart.getJaxbElement().getSldLayoutIdLst();
+				final SlideLayoutIdList slideLayoutIds = slideMasterPart.getJaxbElement().getSldLayoutIdLst(false);
 				if(slideLayoutIds!=null) {
 					final List<SldLayoutId> slideLayoutIdList = slideLayoutIds.getSldLayoutId();
 					for(int j=0; j<slideLayoutIdList.size(); j++) {
-						final SldLayoutId slideLayoutId = slideLayoutIdList.get(j);
-						final String layoutTarget = masterTarget + "." + slideLayoutId.getId().toString();
-						relTargetToId.put(slideMasterPart.getRelationshipsPart().getRelationshipByID(slideLayoutId.getRid()).getTarget(), layoutTarget);
-						createLayoutSlideOperations(layoutTarget, masterTarget);
+						createLayoutSlideOperations(slideLayoutIdList.get(j).getId().toString(), masterTarget);
 					}
 				}
 			}
@@ -194,9 +193,7 @@ public class PptxCreateOperationHelper extends CreateOperationHelper {
 	public void createSlides()
 		throws JSONException, ParseException {
 
-		getOperationDocument().setContext(null);
-
-		final RootComponent rootComponent = new RootComponent(getOperationDocument());
+		final RootComponent rootComponent = new RootComponent(getOperationDocument(), null);
         Component slideComponent = rootComponent.getNextChildComponent(null, null);
         while (slideComponent!=null) {
 
@@ -210,7 +207,7 @@ public class PptxCreateOperationHelper extends CreateOperationHelper {
     		// retrieving the layout target that has to be used for this slide
     		final String slideLayoutTarget = slidePart.getRelationshipsPart().getRelationshipByType(Namespaces.PRESENTATIONML_SLIDE_LAYOUT).getTarget();
     		if(slideLayoutTarget!=null) {
-    			final String slideLayoutTargetId = relTargetToId.get(slideLayoutTarget);
+    			final String slideLayoutTargetId = getOperationDocument().getRelTargetToIdMap().get(slideLayoutTarget);
     			if(slideLayoutTargetId!=null) {
     				jsonInsertSlideOperation.put("target", slideLayoutTargetId);
     			}
@@ -223,9 +220,7 @@ public class PptxCreateOperationHelper extends CreateOperationHelper {
 	public void createMasterSlideOperations(String target)
 		throws JSONException, ParseException {
 
-		getOperationDocument().setContext(target);
-
-		final RootComponent rootComponent = new RootComponent(getOperationDocument());
+		final RootComponent rootComponent = new RootComponent(getOperationDocument(), target);
 		final Component slideComponent = rootComponent.getNextChildComponent(null, null);
 		if(slideComponent!=null) {
 			final JSONObject jsonInsertMasterSlideOperation = new JSONObject(3);
@@ -259,9 +254,7 @@ public class PptxCreateOperationHelper extends CreateOperationHelper {
 	public void createLayoutSlideOperations(String target, String referencedMaster)
 		throws JSONException, ParseException {
 
-		getOperationDocument().setContext(target);
-
-		final RootComponent rootComponent = new RootComponent(getOperationDocument());
+		final RootComponent rootComponent = new RootComponent(getOperationDocument(), target);
 		final Component slideComponent = rootComponent.getNextChildComponent(null, null);
 		if(slideComponent!=null) {
 			final JSONObject jsonInsertLayoutSlideOperation = new JSONObject(4);
@@ -288,9 +281,17 @@ public class PptxCreateOperationHelper extends CreateOperationHelper {
 			}
 		}
 		else if(sldElement instanceof SldLayout) {
-			if(!((SldLayout)sldElement).isShowMasterSp()) {
+			final SldLayout sldLayout = (SldLayout)sldElement;
+			if(!sldLayout.isShowMasterSp()) {
 				pageAttrs.put("followMasterShapes", false);
 			}
+			if(sldLayout.getType()!=null) {
+				pageAttrs.put("type", sldLayout.getType().value());
+			}
+			createHeaderFooterOperations(((SldLayout)sldElement).getHf(), pageAttrs);
+		}
+		else if(sldElement instanceof SldMaster) {
+			createHeaderFooterOperations(((SldMaster)sldElement).getHf(), pageAttrs);
 		}
 		if(!pageAttrs.isEmpty()) {
 			attrs.put("slide", pageAttrs);
@@ -320,6 +321,37 @@ public class PptxCreateOperationHelper extends CreateOperationHelper {
 		}
 	}
 
+	private void createHeaderFooterOperations(CTHeaderFooter hf, JSONObject attrs)
+		throws JSONException {
+
+		if(hf!=null) {
+			if(hf.isDt()==null || hf.isDt().booleanValue()) {
+				attrs.put("isDate", true);
+			}
+			else {
+				attrs.put("isDate", false);
+			}
+			if(hf.isFtr()==null || hf.isFtr().booleanValue()) {
+				attrs.put("isFooter", true);
+			}
+			else {
+				attrs.put("isFooter", false);
+			}
+			if(hf.isHdr()==null || hf.isHdr().booleanValue()) {
+				attrs.put("isHeader", true);
+			}
+			else {
+				attrs.put("isHeader", false);
+			}
+			if(hf.isSldNum()==null || hf.isSldNum().booleanValue()) {
+				attrs.put("isSlideNum", true);
+			}
+			else {
+				attrs.put("isSlideNum", false);
+			}
+		}
+	}
+
 	public void createClrMapOvrThemeOperation(String target, CTColorMappingOverride colorOverride)
 		throws JSONException {
 
@@ -376,7 +408,23 @@ public class PptxCreateOperationHelper extends CreateOperationHelper {
 		Component paragraphChild = paragraphComponent.getNextChildComponent(null, null);
 		while(paragraphChild!=null) {
 			if(paragraphChild instanceof TextComponent) {
-				createTextInsertOperation((TextComponent)paragraphChild, position, target);
+				int n = paragraphChild.getComponentNumber();
+				final String[] tokens =
+					(((CTRegularTextRun)(((TextComponent)paragraphChild).getObject())).getT()).split("\\t", -1);
+				for(int i=0; i < tokens.length; i++) {
+					final String t = tokens[i];
+					if(!t.isEmpty()) {
+						createTextInsertOperation(t, n, position, target);
+						n += t.length();
+					}
+					if(tokens.length!=1&&i!=tokens.length-1) {
+						createInsertTabOperation(n, position, target);
+						n++;
+					}
+				}
+			}
+			else if(paragraphChild instanceof TextFieldComponent) {
+				createInsertFieldOperation((TextFieldComponent)paragraphChild, position, target);
 			}
 			else if(paragraphChild instanceof HardBreakComponent) {
 				createHardBreakOperation((HardBreakComponent)paragraphChild, position, target);
@@ -388,27 +436,44 @@ public class PptxCreateOperationHelper extends CreateOperationHelper {
 			if(paragraphChild instanceof TextComponent) {
 				createTextAttributesOperation((TextComponent)paragraphChild, position, target);
 			}
+			else if(paragraphChild instanceof TextFieldComponent) {
+				createTextFieldAttributesOperation((TextFieldComponent)paragraphChild, position, target);
+			}
 			paragraphChild = paragraphChild.getNextComponent();
 		}
 	}
 
-	public void createTextInsertOperation(TextComponent textComponent, List<Integer> parentPosition, String target)
+	public void createTextInsertOperation(String text, int textPosition, List<Integer> parentPosition, String target)
 		throws JSONException, ParseException {
 
 		final List<Integer> position = new ArrayList<Integer>(parentPosition);
-		position.add(textComponent.getComponentNumber());
+		position.add(textPosition);
 
-		final CTRegularTextRun textRun = (CTRegularTextRun)textComponent.getObject();
 		final JSONObject jsonInsertTextOperation = new JSONObject(4);
 		jsonInsertTextOperation.put("name", "insertText");
 		jsonInsertTextOperation.put("start", position);
 		if(target!=null) {
 			jsonInsertTextOperation.put("target", target);
 		}
-		jsonInsertTextOperation.put("text", textRun.getT());
+		jsonInsertTextOperation.put("text", text);
 		operationsArray.put(jsonInsertTextOperation);
 	}
 
+	public void createInsertTabOperation(int textPosition, List<Integer> parentPosition, String target)
+		throws JSONException, ParseException {
+
+		final List<Integer> position = new ArrayList<Integer>(parentPosition);
+		position.add(textPosition);
+
+		final JSONObject jsonInsertTabOperation = new JSONObject(3);
+		jsonInsertTabOperation.put("name", "insertTab");
+		jsonInsertTabOperation.put("start", position);
+		if(target!=null) {
+			jsonInsertTabOperation.put("target", target);
+		}
+		operationsArray.put(jsonInsertTabOperation);
+	}
+
 	public void createTextAttributesOperation(TextComponent textComponent, List<Integer> parentPosition, String target)
 		throws JSONException, ParseException {
 
@@ -436,6 +501,48 @@ public class PptxCreateOperationHelper extends CreateOperationHelper {
 		}
 	}
 
+	public void createTextFieldAttributesOperation(TextFieldComponent textFieldComponent, List<Integer> parentPosition, String target)
+		throws JSONException, ParseException {
+
+		final JSONObject attrs = textFieldComponent.createJSONAttrs(this, new JSONObject());
+		if(!attrs.isEmpty()) {
+
+			final JSONObject jsonSetAttributesOperation = new JSONObject(4);
+			jsonSetAttributesOperation.put("name", "setAttributes");
+
+			final List<Integer> start = new ArrayList<Integer>(parentPosition);
+			start.add(textFieldComponent.getComponentNumber());
+			jsonSetAttributesOperation.put("start", start);
+			if(target!=null) {
+				jsonSetAttributesOperation.put("target", target);
+			}
+			jsonSetAttributesOperation.put("attrs", attrs);
+			operationsArray.put(jsonSetAttributesOperation);
+		}
+	}
+	
+	public void createInsertFieldOperation(TextFieldComponent textFieldComponent, List<Integer> parentPosition, String target)
+		throws JSONException, ParseException {
+
+		final List<Integer> position = new ArrayList<Integer>(parentPosition);
+		position.add(textFieldComponent.getComponentNumber());
+
+		final JSONObject jsonInsertSimpleFieldOperation = new JSONObject(6);
+		jsonInsertSimpleFieldOperation.put("name", "insertField");
+		jsonInsertSimpleFieldOperation.put("start", position);
+		final CTTextField textField = (CTTextField)textFieldComponent.getObject();
+		jsonInsertSimpleFieldOperation.put("type", textField.getType());
+		jsonInsertSimpleFieldOperation.put("representation", textField.getT());
+		if(target!=null) {
+			jsonInsertSimpleFieldOperation.put("target", target);
+		}
+		final JSONObject attrs = textFieldComponent.createJSONAttrs(this, new JSONObject());
+		if(!attrs.isEmpty()) {
+			jsonInsertSimpleFieldOperation.put("attrs", attrs);
+		}
+		operationsArray.put(jsonInsertSimpleFieldOperation);
+	}
+
 	public void createHardBreakOperation(HardBreakComponent hardBreakComponent, List<Integer> parentPosition, String target)
 		throws JSONException, ParseException {
 
