@@ -86,14 +86,14 @@ public class Exporter implements IExporter {
     public InputStream createDocument(Session session, InputStream documentStm, String applyOperations, IResourceManager resourceManager, DocumentProperties documentProperties, boolean createFinalDocument)
         throws FilterException {
 
-        OperationDocument operationDocument = null;
+        XlsxOperationDocument operationDocument = null;
     	try {
-	        operationDocument = new OperationDocument(session, services, documentStm, resourceManager, documentProperties);
+	        operationDocument = new XlsxOperationDocument(session, services, documentStm, resourceManager, documentProperties);
 	        operationDocument.setCreateFinalDocument(createFinalDocument);
 	        return operationDocument.createDocument(applyOperations);
     	}
     	catch(Throwable e) {
-            throw OperationDocument.getRethrowException(e);
+            throw XlsxOperationDocument.getRethrowException(e);
     	}
     	finally {
     	    if(operationDocument!=null) {
