@@ -51,14 +51,15 @@ package com.openexchange.office.ooxml.xlsx;
 
 import java.io.InputStream;
 import java.util.ArrayList;
+import java.util.HashMap;
 import java.util.Iterator;
 import java.util.List;
+import java.util.Map;
 
 import javax.xml.bind.JAXBElement;
 import javax.xml.bind.JAXBException;
 
 import org.apache.commons.lang.mutable.MutableInt;
-import org.docx4j.dml.Theme;
 import org.docx4j.openpackaging.exceptions.InvalidFormatException;
 import org.docx4j.openpackaging.packages.OpcPackage;
 import org.docx4j.openpackaging.packages.SpreadsheetMLPackage;
@@ -77,9 +78,7 @@ import org.json.JSONTokener;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 import org.xlsx4j.jaxb.Context;
-import org.xlsx4j.sml.CTCalcPr;
 import org.xlsx4j.sml.CTDataValidations;
-import org.xlsx4j.sml.CTDataValidations_legacy;
 import org.xlsx4j.sml.CTExtension;
 import org.xlsx4j.sml.CTExtensionList;
 import org.xlsx4j.sml.CTFontSize;
@@ -127,6 +126,7 @@ public class XlsxOperationDocument extends com.openexchange.office.ooxml.Operati
     private XlsxApplyOperationHelper applyOperationHelper = null;
     private XlsxCreateOperationHelper _createOperationHelper = null;
     private Double defaultFontSize = null;
+    private ThemePart themePart = null;
 
 	private final static Logger log = LoggerFactory.getLogger(XlsxOperationDocument.class);
 
@@ -139,18 +139,24 @@ public class XlsxOperationDocument extends com.openexchange.office.ooxml.Operati
         	final long maxAllowedXmlSizeMatchingMemory = _documentProperties.optLong(DocumentProperties.PROP_MAX_MEMORY_USAGE, -1) / FACTOR_FOR_REQUIRED_HEAPSPACE;
         	inputDocumentStream = DocumentComplexity.checkDocumentComplexity(_inputDocumentStream, maxAllowedXmlSizeMatchingComplexity, maxAllowedXmlSizeMatchingMemory);
             opcPackage = (SpreadsheetMLPackage)SpreadsheetMLPackage.load(inputDocumentStream);
+			final PartName themePartName = new PartName("/xl/theme/theme1.xml");
+			themePart = (ThemePart)getPackage().getParts().get(themePartName);
 
             // styles
             final Styles styles = getPackage().getWorkbookPart().getStyles();
-            if(styles!=null)
+            if (styles != null) {
                 stylesheet = styles.getJaxbElement();
+                // apply the default number formats passed in the document properties
+                stylesheet.insertNumberFormats(getInitialFormats());
+            }
 
             // shared strings
             final SharedStrings _sharedStrings = getPackage().getWorkbookPart().getSharedStrings();
-            if(_sharedStrings!=null)
+            if (_sharedStrings != null) {
                 sharedStrings = _sharedStrings.getJaxbElement();
+            }
 
-            final String initialSheetName = getDocumentProperties().optString(DocumentProperties.PROP_INITIAL_SHEETNAME, "Sheet1");
+            final String initialSheetName = getInitialSheetName();
             final Workbook workbook = getPackage().getWorkbookPart().getJaxbElement();
             final Sheet sheet = workbook.getSheets().getSheet().get(0);
             if(sheet.getName().equals("empty_sheet")) {
@@ -170,10 +176,9 @@ public class XlsxOperationDocument extends com.openexchange.office.ooxml.Operati
         super(null, _services, null, null, _documentProperties);
         try {
             opcPackage = SpreadsheetMLPackage.createPackage();
-
-            final ThemePart themePart = getDefaultThemePart(new PartName("/xl/theme/theme1.xml"));
+            themePart = getDefaultThemePart(new PartName("/xl/theme/theme1.xml"));
             getPackage().getWorkbookPart().addTargetPart(themePart);
-            getPackage().createWorksheetPart(new PartName("/xl/worksheets/sheet1.xml"), getDocumentProperties().optString(DocumentProperties.PROP_INITIAL_SHEETNAME, "Sheet1"), 1);
+            getPackage().createWorksheetPart(new PartName("/xl/worksheets/sheet1.xml"), getInitialSheetName(), 1);
 
             // applying the default column width...
             final Sheet sheet = SheetUtils.getSheet(opcPackage, 0);
@@ -196,6 +201,116 @@ public class XlsxOperationDocument extends com.openexchange.office.ooxml.Operati
         }
     }
 
+	/**
+	 * Returns the value of the document property "InitialSheetName".
+	 * 
+	 * @return
+	 * 	The value of the document property "InitialSheetName" (falls back to "Sheet1").
+	 */
+	private String getInitialSheetName() {
+        return getDocumentProperties().optString(DocumentProperties.PROP_INITIAL_SHEETNAME, "Sheet1");
+	}
+
+	/**
+	 * Returns the value of the document property "InitialFormats".
+	 * 
+	 * @return
+	 * 	The value of the document property "InitialFormats".
+	 */
+	private Map<Long, String> getInitialFormats() {
+
+		Map<Long, String> formatsMap = new HashMap<Long, String>();
+	
+		final String formatsStr = getDocumentProperties().optString(DocumentProperties.PROP_INITIAL_FORMATS, null);
+        if (formatsStr != null && !formatsStr.isEmpty()) {
+        	try {
+        		final JSONObject formatsObj = new JSONObject(formatsStr);
+        		for(Iterator<String> iterator = formatsObj.keySet().iterator(); iterator.hasNext(); ) {
+        		    String key = iterator.next();
+        		    long formatId = Long.parseLong(key, 10);
+        		    String formatCode = formatsObj.getString(key);
+        		    formatsMap.put(formatId, formatCode);
+        		}
+        	} catch (Exception e) {
+        	}
+        }
+        
+        return formatsMap;
+	}
+
+    @Override
+    public JSONObject getOperations()
+        throws Exception {
+
+        final XlsxCreateOperationHelper createOperationHelper = getCreateOperationHelper();
+    	createOperationHelper.createOperations();
+
+/*
+        Writer writer = new FileWriter(new File("/tmp/jsonout.txt"));
+        for(int i=0;i<createOperationHelper.getOperationsArray().length();i++) {
+            createOperationHelper.getOperationsArray().getJSONObject(i).write(writer);
+            writer.append(System.getProperty("line.separator"));
+        }
+        writer.close();
+*/
+        final JSONObject aOperations = new JSONObject();
+        aOperations.put("operations", createOperationHelper.getOperationsArray());
+        return aOperations;
+    }
+
+    public JSONObject getPreviewOperations()
+        throws Exception {
+
+        final XlsxCreateOperationHelper createOperationHelper = getCreateOperationHelper();
+    	createOperationHelper.createPreviewOperations(getDocumentProperties());
+        final JSONObject aOperations = new JSONObject();
+        aOperations.put("operations", createOperationHelper.getOperationsArray());
+        return aOperations;
+    }
+
+    public JSONObject getOutstandingOperations()
+        throws Exception {
+
+        final XlsxCreateOperationHelper createOperationHelper = getCreateOperationHelper();
+        final int activeSheetIndex = (Integer)getDocumentProperties().get(DocumentProperties.PROP_SPREADHSEET_ACTIVE_SHEET_INDEX);
+        createOperationHelper.createOutstandingOperations(activeSheetIndex);
+        final JSONObject aOperations = new JSONObject();
+        aOperations.put("operations", createOperationHelper.getOperationsArray());
+        return aOperations;
+    }
+
+	public Map<String, Object> getMetaData()
+		throws Exception {
+
+        final XlsxCreateOperationHelper createOperationHelper = getCreateOperationHelper();
+    	createOperationHelper.createMetaOperations(getDocumentProperties());
+        final HashMap<String, Object> aOperations = new HashMap<String, Object>(1);
+        aOperations.put("operations", createOperationHelper.getOperationsArray());
+        return aOperations;
+	}
+
+	public Map<String, Object> getActivePart()
+		throws Exception {
+
+        final XlsxCreateOperationHelper createOperationHelper = getCreateOperationHelper();
+    	createOperationHelper.createActivePartOperations(getDocumentProperties());
+        final HashMap<String, Object> aOperations = new HashMap<String, Object>(1);
+        aOperations.put("operations", createOperationHelper.getOperationsArray());
+        return aOperations;
+	}
+
+	public Map<String, Object> getNextPart()
+		throws Exception {
+
+        final XlsxCreateOperationHelper createOperationHelper = getCreateOperationHelper();
+    	if(!createOperationHelper.createNextPartOperations(getDocumentProperties())) {
+    		return null;
+    	}
+        final HashMap<String, Object> aOperations = new HashMap<String, Object>(1);
+        aOperations.put("operations", createOperationHelper.getOperationsArray());
+        return aOperations;
+	}
+
     @Override
 	public Part getContextPart() {
     	return contextPart!=null ? contextPart : getPackage().getWorkbookPart();
@@ -297,15 +412,15 @@ public class XlsxOperationDocument extends com.openexchange.office.ooxml.Operati
         if(validations!=null) {
             dataValidations.add(validations);
         }
-        final CTExtensionList extLst = worksheet.getExtLst();
+        final CTExtensionList extLst = worksheet.getExtLst(false);
         if(extLst!=null) {
             for(final CTExtension extension:extLst.getExt()) {
                 final Object any = extension.getAny();
                 if(any instanceof JAXBElement<?>) {
                     if(extension.getUri().equals("{CCE6A557-97BC-4b89-ADB6-D9C93CAAB3DF}")) {
                         final Object value = ((JAXBElement<?>)any).getValue();
-                        if(value instanceof CTDataValidations_legacy) {
-                            dataValidations.add((CTDataValidations_legacy)value);
+                        if(value instanceof org.xlsx4j.schemas.microsoft.com.office.spreadsheetml_2009_9.main.CTDataValidations) {
+                            dataValidations.add((org.xlsx4j.schemas.microsoft.com.office.spreadsheetml_2009_9.main.CTDataValidations)value);
                         }
                     }
                 }
@@ -327,7 +442,8 @@ public class XlsxOperationDocument extends com.openexchange.office.ooxml.Operati
     }
 
     public XlsxCreateOperationHelper getCreateOperationHelper()
-    	throws FilterException {
+   		throws FilterException {
+
     	if(_createOperationHelper==null) {
     		_createOperationHelper = new XlsxCreateOperationHelper(this, new JSONArray());
     	}
@@ -348,40 +464,46 @@ public class XlsxOperationDocument extends com.openexchange.office.ooxml.Operati
                     op = (JSONObject) aOperations.get(i);
                     final String opName = op.getString("name");
                     switch(opName) {
-	                    case "setCellContents": {
-	                        applyOperationHelper.setCellContents(op.getInt("sheet"), op.getJSONArray("start"), op.getJSONArray("contents"));
+                    	case "insertNumberFormat": {
+	                        applyOperationHelper.insertNumberFormat(op.getLong("id"), op.getString("code"));
+                    		break;
+                    	}
+                    	case "deleteNumberFormat": {
+	                        applyOperationHelper.deleteNumberFormat(op.getLong("id"));
+                    		break;
+                    	}
+	                    case "changeCells": {
+	                        applyOperationHelper.changeCells(op.getInt("sheet"), op.getJSONArray("start"), op.getJSONArray("contents"));
 	                        break;
 	                    }
-	                    case "fillCellRange": {
-	                        applyOperationHelper.fillCellRange(op.getInt("sheet"), op.getJSONArray("start"), op.optJSONArray("end"), op.opt("value"), op.opt("result"), op.optJSONObject("attrs"), op.optInt("shared", -1), op.optJSONArray("ref"));
+	                    case "changeRows": {
+	                    	int start = op.getInt("start");
+	                        applyOperationHelper.changeRows(op.getInt("sheet"), start, op.optInt("end", start), op.optJSONObject("attrs"), op.optString("s", null));
 	                        break;
 	                    }
-	                    case "clearCellRange": {
-	                        applyOperationHelper.clearCellRange(op.getInt("sheet"), op.getJSONArray("start"), op.optJSONArray("end"), op.optBoolean("remove", false));
-	                        break;
-	                    }
-	                    case "setRowAttributes": {
-	                        applyOperationHelper.setRowAttributes(op.getInt("sheet"), op.getInt("start"), op.optInt("end", -1), op.getJSONObject("attrs"));
-	                        break;
-	                    }
-	                    case "setColumnAttributes": {
-	                        applyOperationHelper.setColumnAttributes(op.getInt("sheet"), op.getInt("start"), op.optInt("end", -1), op.getJSONObject("attrs"));
+	                    case "changeColumns": {
+	                    	int start = op.getInt("start");
+	                        applyOperationHelper.changeColumns(op.getInt("sheet"), start, op.optInt("end", start), op.optJSONObject("attrs"), op.optString("s", null));
 	                        break;
 	                    }
 	                    case "insertRows": {
-	                        applyOperationHelper.insertRows(op.getInt("sheet"), op.getInt("start"), op.optInt("end", -1));
+	                    	int start = op.getInt("start");
+	                        applyOperationHelper.insertRows(op.getInt("sheet"), start, op.optInt("end", start), op.optJSONObject("attrs"), op.optString("s", null));
 	                        break;
 	                    }
 	                    case "deleteRows": {
-	                        applyOperationHelper.deleteRows(op.getInt("sheet"), op.getInt("start"), op.optInt("end", -1));
+	                    	int start = op.getInt("start");
+	                        applyOperationHelper.deleteRows(op.getInt("sheet"), start, op.optInt("end", start));
 	                        break;
 	                    }
 	                    case "insertColumns": {
-	                        applyOperationHelper.insertColumns(op.getInt("sheet"), op.getInt("start"), op.optInt("end", -1));
+	                    	int start = op.getInt("start");
+	                        applyOperationHelper.insertColumns(op.getInt("sheet"), start, op.optInt("end", start), op.optJSONObject("attrs"), op.optString("s", null));
 	                        break;
 	                    }
 	                    case "deleteColumns": {
-	                        applyOperationHelper.deleteColumns(op.getInt("sheet"), op.getInt("start"), op.optInt("end", -1));
+	                    	int start = op.getInt("start");
+	                        applyOperationHelper.deleteColumns(op.getInt("sheet"), start, op.optInt("end", start));
 	                        break;
 	                    }
 	                    case "insertSheet": {
@@ -397,7 +519,7 @@ public class XlsxOperationDocument extends com.openexchange.office.ooxml.Operati
 	                        break;
 	                    }
 	                    case "copySheet": {
-	                    	applyOperationHelper.copySheet(op.getInt("sheet"), op.getInt("to"), op.getString("sheetName"));
+	                    	applyOperationHelper.copySheet(op.getInt("sheet"), op.getInt("to"), op.getString("sheetName"), op.optJSONObject("tableNames"));
 	                    	break;
 	                    }
 	                    case "setSheetName": {
@@ -425,7 +547,19 @@ public class XlsxOperationDocument extends com.openexchange.office.ooxml.Operati
 	                        break;
 	                    }
 	                    case "insertStyleSheet": {
-	                        applyOperationHelper.insertStyleSheet(op.getString("type"), op.getString("styleId"), op.getString("styleName"), op.getJSONObject("attrs"), op.optString("parent", null), op.optBoolean("hidden", false), op.optInt("uiPriority", 0), op.optBoolean("default", false), op.optBoolean("auto", false));
+	                        applyOperationHelper.insertStyleSheet(op.getString("type"), op.getString("styleId"), op.getString("styleName"), op.getJSONObject("attrs"), op.optBoolean("hidden", false), op.optInt("uiPriority", 0), op.optBoolean("default", false));
+	                        break;
+	                    }
+	                    case "insertAutoStyle": {
+	                        applyOperationHelper.insertAutoStyle(op.getString("type"), op.getString("styleId"), op.getJSONObject("attrs"), op.optBoolean("default", false));
+	                        break;
+	                    }
+	                    case "changeAutoStyle": {
+	                        applyOperationHelper.changeAutoStyle(op.getString("type"), op.getString("styleId"), op.getJSONObject("attrs"));
+	                        break;
+	                    }
+	                    case "deleteAutoStyle": {
+	                        applyOperationHelper.deleteAutoStyle(op.getString("type"), op.getString("styleId"));
 	                        break;
 	                    }
 	                    case "insertChartDataSeries": {
@@ -441,15 +575,15 @@ public class XlsxOperationDocument extends com.openexchange.office.ooxml.Operati
 	                        break;
 	                    }
 	                    case "insertName": {
-	                        applyOperationHelper.insertName(op.optLong("sheet", -1), op.getString("exprName"), op.getString("formula"), null);
+	                        applyOperationHelper.insertName(op.optLong("sheet", -1), op.getString("label"), op.getString("formula"), null);
 	                        break;
 	                    }
 	                    case "changeName": {
-	                        applyOperationHelper.changeName(op.optLong("sheet", -1), op.getString("exprName"), op.optString("formula", null), op.optString("newName", null));
+	                        applyOperationHelper.changeName(op.optLong("sheet", -1), op.getString("label"), op.optString("formula", null), op.optString("newLabel", null));
 	                        break;
 	                    }
 	                    case "deleteName": {
-	                        applyOperationHelper.deleteName(op.optLong("sheet", -1), op.getString("exprName"));
+	                        applyOperationHelper.deleteName(op.optLong("sheet", -1), op.getString("label"));
 	                        break;
 	                    }
 	                    case "setChartAxisAttributes": {
@@ -524,30 +658,18 @@ public class XlsxOperationDocument extends com.openexchange.office.ooxml.Operati
 	                    	}
 	                        break;
 	                    }
-	                    case "insertCondFormat": {
-	                    	ConditionalFormattings.insertCondFormat(this, op.getInt("sheet"), op.getInt("index"), op.getJSONArray("ranges"));
+	                    case "insertCFRule": {
+	                    	ConditionalFormattings.changeOrInsertCondFormatRule(this, true, op.getInt("sheet"), op.getString("id"), op.getString("ranges"), op.optString("type", "formula"),
+	                    		op.has("value1") ? op.get("value1") : "", op.optString("value2", ""), op.optInt("priority"), op.optBoolean("stop", false), op);
 	                    	break;
 	                    }
-	                    case "changeCondFormat": {
-	                    	ConditionalFormattings.changeCondFormat(this, op.getInt("sheet"), op.getInt("index"), op.getJSONArray("ranges"));
+	                    case "changeCFRule": {
+	                    	ConditionalFormattings.changeOrInsertCondFormatRule(this, false, op.getInt("sheet"), op.getString("id"), op.optString("ranges"), op.optString("type", null),
+	                    		op.opt("value1"), op.optString("value2", null), op.optInt("priority"), op.optBoolean("stop"), op);
 	                    	break;
 	                    }
-	                    case "deleteCondFormat": {
-	                    	ConditionalFormattings.deleteCondFormat(this, op.getInt("sheet"), op.getInt("index"));
-	                    	break;
-	                    }
-	                    case "insertCondFormatRule": {
-	                    	ConditionalFormattings.changeOrinsertCondFormatRule(this, true, op.getInt("sheet"), op.getInt("index"), op.getInt("ruleIndex"), op.optString("type", "formula"),
-	                    		op.has("value1") ? op.get("value1") : "", op.optString("value2", ""), op.optInt("priority"), op.optBoolean("stop", false), op.has("attrs") ? op.getJSONObject("attrs") : new JSONObject());
-	                    	break;
-	                    }
-	                    case "changeCondFormatRule": {
-	                    	ConditionalFormattings.changeOrinsertCondFormatRule(this, false, op.getInt("sheet"), op.getInt("index"), op.getInt("ruleIndex"), op.optString("type", null),
-	                    		op.opt("value1"), op.optString("value2", null), op.optInt("priority"), op.optBoolean("stop"), op.optJSONObject("attrs"));
-	                    	break;
-	                    }
-	                    case "deleteCondFormatRule": {
-	                    	ConditionalFormattings.deleteCondFormatRule(this, op.getInt("sheet"), op.getInt("index"), op.getInt("ruleIndex"));
+	                    case "deleteCFRule": {
+	                    	ConditionalFormattings.deleteCondFormatRule(this, op.getInt("sheet"), op.getString("id"));
 	                    	break;
 	                    }
 	                    case "insertHyperlink": {
@@ -568,18 +690,18 @@ public class XlsxOperationDocument extends com.openexchange.office.ooxml.Operati
                     }
                 }
                 successfulAppliedOperations=aOperations.length();
+
                 final WorkbookPart workbookPart = getPackage().getWorkbookPart();
                 final Workbook workbook = workbookPart.getJaxbElement();
-                CTCalcPr calcPr = workbook.getCalcPr();
-                if(calcPr==null) {
-                    calcPr = Context.getsmlObjectFactory().createCTCalcPr();
-                    workbook.setCalcPr(calcPr);
+
+                if(getDocumentProperties().optBoolean(DocumentProperties.PROP_CALCULATE_ON_LOAD, false)) {
+                	workbook.getCalcPr(true).setCalcCompleted(Boolean.TRUE);
                 }
+
                 // our formula updates should be always up to date now, so it is no longer necessary to
                 if(log.isInfoEnabled()) {
                 	checkFormulaResults();
                 }
-                calcPr.setFullCalcOnLoad(true);
 
                 // removing calcChain which might be invalid now
                 final RelationshipsPart workbookRelationshipsPart = workbookPart.getRelationshipsPart();
@@ -643,7 +765,7 @@ public class XlsxOperationDocument extends com.openexchange.office.ooxml.Operati
 	                        while(cellIterator.hasNext()) {
 	                            final Cell cell = cellIterator.next();
 	                            if(cell.getF()!=null&&cell.getV()==null) {
-	                            	log.info("XLSX: Cell:" + cell.getColumn() + " formula without result!");
+	                            	log.debug("XLSX: Cell:" + cell.getColumn() + " formula without result!");
 	                            }
 	                        }
 	                    }
@@ -653,47 +775,6 @@ public class XlsxOperationDocument extends com.openexchange.office.ooxml.Operati
         }
     }
 
-    @Override
-    public JSONObject getOperations()
-        throws Exception {
-
-        final XlsxCreateOperationHelper createOperationHelper = getCreateOperationHelper();
-    	createOperationHelper.createOperations();
-
-/*
-        Writer writer = new FileWriter(new File("/tmp/jsonout.txt"));
-        for(int i=0;i<createOperationHelper.getOperationsArray().length();i++) {
-            createOperationHelper.getOperationsArray().getJSONObject(i).write(writer);
-            writer.append(System.getProperty("line.separator"));
-        }
-        writer.close();
-*/
-        final JSONObject aOperations = new JSONObject();
-        aOperations.put("operations", createOperationHelper.getOperationsArray());
-        return aOperations;
-    }
-
-    public JSONObject getPreviewOperations()
-        throws Exception {
-
-        final XlsxCreateOperationHelper createOperationHelper = getCreateOperationHelper();
-    	createOperationHelper.createPreviewOperations(getDocumentProperties());
-        final JSONObject aOperations = new JSONObject();
-        aOperations.put("operations", createOperationHelper.getOperationsArray());
-        return aOperations;
-    }
-
-    public JSONObject getOutstandingOperations()
-        throws Exception {
-
-        final XlsxCreateOperationHelper createOperationHelper = getCreateOperationHelper();
-        final int activeSheetIndex = (Integer)getDocumentProperties().get(DocumentProperties.PROP_SPREADHSEET_ACTIVE_SHEET_INDEX);
-        createOperationHelper.createOutstandingOperations(activeSheetIndex);
-        final JSONObject aOperations = new JSONObject();
-        aOperations.put("operations", createOperationHelper.getOperationsArray());
-        return aOperations;
-    }
-
     @Override
     public SpreadsheetMLPackage getPackage() {
         return opcPackage;
@@ -705,21 +786,19 @@ public class XlsxOperationDocument extends com.openexchange.office.ooxml.Operati
     }
 
     @Override
-    public Theme getTheme(boolean createIfMissing)
+    public ThemePart getThemePart(boolean createIfMissing)
     	throws FilterException {
 
-    	try {
-    		final PartName themePartName = new PartName("/xl/theme/theme1.xml");
-	    	ThemePart themePart = (ThemePart)getPackage().getParts().get(themePartName);
-	    	if(themePart==null&&createIfMissing) {
-	    		themePart = getDefaultThemePart(themePartName);
-	    		getPackage().getWorkbookPart().addTargetPart(themePart);
-	    	}
-	    	return themePart!=null?themePart.getJaxbElement():null;
-    	}
-    	catch(InvalidFormatException e) {
-    		throw new FilterException("xlsx filter, could not create default theme", ErrorCode.CRITICAL_ERROR, e);
+    	if(themePart==null&&createIfMissing) {
+    		try {
+    			themePart = getDefaultThemePart(new PartName("/xl/theme/theme1.xml"));
+    			getPackage().getWorkbookPart().addTargetPart(themePart);
+    		}
+    		catch(InvalidFormatException e) {
+    			throw new FilterException("xlsx filter, could not create default theme", ErrorCode.CRITICAL_ERROR, e);
+    		}
     	}
+    	return themePart;
     }
 
     public double getDefaultFontSize() {
@@ -855,7 +934,7 @@ public class XlsxOperationDocument extends com.openexchange.office.ooxml.Operati
     }
 
 	@Override
-	public Component getRootComponent() {
+	public Component getRootComponent(String target) {
 		// TODO Auto-generated method stub
 		return null;
 	}
