@@ -65,6 +65,7 @@ import org.json.JSONException;
 import org.json.JSONObject;
 import org.xlsx4j.sml.BookViews;
 import org.xlsx4j.sml.CTBookView;
+import org.xlsx4j.sml.CTCalcPr;
 import org.xlsx4j.sml.CTCellFormula;
 import org.xlsx4j.sml.CTCellStyle;
 import org.xlsx4j.sml.CTCellStyleXfs;
@@ -75,8 +76,9 @@ import org.xlsx4j.sml.CTDrawing;
 import org.xlsx4j.sml.CTFont;
 import org.xlsx4j.sml.CTHyperlink;
 import org.xlsx4j.sml.CTHyperlinks;
+import org.xlsx4j.sml.CTNumFmt;
+import org.xlsx4j.sml.CTNumFmts;
 import org.xlsx4j.sml.CTRst;
-import org.xlsx4j.sml.CTSheetFormatPr;
 import org.xlsx4j.sml.CTStylesheet;
 import org.xlsx4j.sml.CTXf;
 import org.xlsx4j.sml.Cell;
@@ -92,6 +94,7 @@ import org.xlsx4j.sml.Sheet;
 import org.xlsx4j.sml.SheetData;
 import org.xlsx4j.sml.Sheets;
 import org.xlsx4j.sml.SmlUtils;
+import org.xlsx4j.sml.SmlUtils.CellRefRange;
 import org.xlsx4j.sml.Workbook;
 import org.xlsx4j.sml.Worksheet;
 
@@ -124,8 +127,6 @@ public class XlsxCreateOperationHelper extends CreateOperationHelper {
     final int maxSheetCount;
     int currentCellCount = 0;
 
-    private final static int MAX_EMPTY_CELL_REPEAT_CONTENT = 10;
-
     public XlsxCreateOperationHelper(XlsxOperationDocument _operationDocument, JSONArray mOperationsArray)
     	throws FilterException {
 
@@ -174,7 +175,20 @@ public class XlsxCreateOperationHelper extends CreateOperationHelper {
 
         CTStylesheet stylesheet = getOperationDocument().getStylesheet(false);
         if(stylesheet!=null) {
-            // creating styles
+
+        	// create number formats
+        	final CTNumFmts numFmts = stylesheet.getNumberFormats(false);
+            if(numFmts!=null) {
+            	for (CTNumFmt numFmt: numFmts.getNumFmt()) {
+    	            final JSONObject operation = new JSONObject();
+    	            operation.put("name", "insertNumberFormat");
+    	            operation.put("id", numFmt.getNumFmtId());
+    	            operation.put("code", numFmt.getFormatCode());
+                	operationsArray.put(operation);
+            	}
+            }
+
+        	// creating styles
             final CTCellStyleXfs cellStyleXfs = stylesheet.getCellStyleXfs();
             if(cellStyleXfs!=null) {
                 final List<CTXf> cellStyleXfList = cellStyleXfs.getXf();
@@ -187,34 +201,14 @@ public class XlsxCreateOperationHelper extends CreateOperationHelper {
                         Commons.mergeJsonObjectIfUsed("cell", jsonProperties, CellUtils.createCellProperties(cellStyleXf, stylesheet, true));
                         final CTFont ctFont = stylesheet.getFontByIndex(CellUtils.getAttributeIndex(cellStyleXf.getFontId(), cellStyleXf.isApplyFont(), true));
                         Commons.mergeJsonObjectIfUsed("character", jsonProperties, CellUtils.createCharacterProperties(new JSONObject(), stylesheet, ctFont));
-                        final JSONObject jsonApplyProperties = new JSONObject(0);
-                        if(cellStyleXf.isApplyBorder()!=null&&!cellStyleXf.isApplyBorder().booleanValue()) {
-                            jsonApplyProperties.put("border", false);
-                        }
-                        if(cellStyleXf.isApplyAlignment()!=null&&!cellStyleXf.isApplyAlignment().booleanValue()) {
-                            jsonApplyProperties.put("align", false);
-                        }
-                        if(cellStyleXf.isApplyNumberFormat()!=null&&!cellStyleXf.isApplyNumberFormat().booleanValue()) {
-                            jsonApplyProperties.put("number", false);
-                        }
-                        if(cellStyleXf.isApplyProtection()!=null&&!cellStyleXf.isApplyProtection().booleanValue()) {
-                            jsonApplyProperties.put("protect", false);
-                        }
-                        if(cellStyleXf.isApplyFont()!=null&&!cellStyleXf.isApplyFont().booleanValue()) {
-                            jsonApplyProperties.put("font", false);
-                        }
-                        if(cellStyleXf.isApplyFill()!=null&&!cellStyleXf.isApplyFill().booleanValue()) {
-                            jsonApplyProperties.put("fill", false);
-                        }
-                        if(!jsonApplyProperties.isEmpty()) {
-                            jsonProperties.put("apply", jsonApplyProperties);
+                        final JSONObject applyProperties = createApplyProperties(cellStyleXf, true);
+                        if(!applyProperties.isEmpty()) {
+                            jsonProperties.put("apply", applyProperties);
                         }
                         JSONObject attrs = jsonProperties.length()>0?jsonProperties:null;
-                        String parentId = null;
                         Boolean hidden = null;
                         Integer uiPriority = null;
                         Boolean isDefault = null;
-                        Boolean custom = null;
 
                         // check for proper UI styleName
                         CTCellStyles cellStyles = stylesheet.getCellStyles();
@@ -234,7 +228,7 @@ public class XlsxCreateOperationHelper extends CreateOperationHelper {
                             }
                         }
                         if(hidden==null||!hidden.booleanValue()) {
-                        	operationsArray.put(createInsertStyleSheetOperation("cell", styleId, styleName, attrs, parentId, hidden, uiPriority, isDefault, custom, false));
+                        	operationsArray.put(createInsertStyleSheetOperation("cell", styleId, styleName, attrs, null, hidden, uiPriority, isDefault, null));
                         }
                     }
                 }
@@ -247,30 +241,47 @@ public class XlsxCreateOperationHelper extends CreateOperationHelper {
                 for(int i=0;i<cellXfsList.size();i++) {
                     final CTXf xf = cellXfsList.get(i);
                     final String styleId = "a" + Integer.toString(i);
-                    String styleName = "";
                     JSONObject jsonProperties = new JSONObject();
                     Commons.mergeJsonObjectIfUsed("cell", jsonProperties, CellUtils.createCellProperties(xf, stylesheet, false));
                     final CTFont ctFont = stylesheet.getFontByIndex(CellUtils.getAttributeIndex(xf.getFontId(), xf.isApplyFont(), false));
                     Commons.mergeJsonObjectIfUsed("character", jsonProperties, CellUtils.createCharacterProperties(new JSONObject(), stylesheet, ctFont));
-                    JSONObject attrs = jsonProperties.length()>0?jsonProperties:null;
-                    String parentId = null;
-                    final Long xfId = xf.getXfId();
+                    final JSONObject applyProperties = createApplyProperties(xf, false);                   
+                    if(!applyProperties.isEmpty()) {
+                    	jsonProperties.put("apply", applyProperties);
+                   }
+                   final Long xfId = xf.getXfId();
                     if(xfId!=null) {
-                        parentId = indexToStyleId.get(xfId);
+                    	final String parentId = indexToStyleId.get(xfId);
+                        if(parentId!=null) {
+                        	jsonProperties.put("styleId", parentId);
+                        }
                     }
-                    if(parentId == null) {
-                        parentId = "0";
-                    }
-                    Boolean hidden = true;
-                    Integer uiPriority = null;
-                    Boolean isDefault = i==0;
-                    Boolean custom = null;
-                    operationsArray.put(createInsertStyleSheetOperation("cell", styleId, styleName, attrs, parentId, hidden, uiPriority, isDefault, custom, true));
+                    operationsArray.put(createInsertAutoStyleOperation("cell", styleId, jsonProperties.length()>0?jsonProperties:null, i==0));
                 }
             }
         }
     }
 
+    final void createApplyProperty(JSONObject jsonApplyProps, String propName, Boolean xfProperty, boolean defaultValue)
+    	throws JSONException {
+
+    	// OOXML default value depends on XF type (true in styles, false in cells); operation default is always true 
+    	boolean applyValue = (xfProperty == null) ? defaultValue : xfProperty.booleanValue();
+    	if (!applyValue) { jsonApplyProps.put(propName, false); }
+    }
+
+    final JSONObject createApplyProperties(CTXf cellStyleXf, boolean defaultValue)
+    	throws JSONException {
+
+    	final JSONObject jsonApplyProperties = new JSONObject(0);
+    	createApplyProperty(jsonApplyProperties, "border", cellStyleXf.isApplyBorder(), defaultValue);
+    	createApplyProperty(jsonApplyProperties, "align", cellStyleXf.isApplyAlignment(), defaultValue);
+    	createApplyProperty(jsonApplyProperties, "number", cellStyleXf.isApplyNumberFormat(), defaultValue);
+    	createApplyProperty(jsonApplyProperties, "protect", cellStyleXf.isApplyProtection(), defaultValue);
+    	createApplyProperty(jsonApplyProperties, "font", cellStyleXf.isApplyFont(), defaultValue);
+    	createApplyProperty(jsonApplyProperties, "fill", cellStyleXf.isApplyFill(), defaultValue);
+    	return jsonApplyProperties;
+    }	    
 
     public void createOperations()
     	throws Exception {
@@ -282,7 +293,7 @@ public class XlsxCreateOperationHelper extends CreateOperationHelper {
 	    createDocumentSettings(workbook);
 	    createStyleOperations();
 	    createThemeOperations(null, null);
-	    createInsertNameOperations(workbook);
+	    createInsertNameOperations(workbook, null);
 		final Sheets sheets = workbook.getSheets();
 	    final List<Sheet> sheetList = sheets.getSheet();
 	    for(int sheetIndex = 0; sheetIndex < sheetList.size(); sheetIndex++) {
@@ -292,7 +303,8 @@ public class XlsxCreateOperationHelper extends CreateOperationHelper {
 	        createInsertSheetOperation(sheet, sheetType, part, sheetIndex);
 	        if(sheetType.equals("worksheet")) {
 	        	updateCellCount(((WorksheetPart)part).getJaxbElement());
-        		createWorksheetOperations((WorksheetPart)part, sheetIndex, false);
+			    createInsertNameOperations(workbook, new Long(sheetIndex));
+        		createWorksheetOperations((WorksheetPart)part, sheetIndex);
     	        ((WorksheetPart)part).setJaxbElement((Worksheet)null);
 	        }
 	    }
@@ -308,7 +320,7 @@ public class XlsxCreateOperationHelper extends CreateOperationHelper {
 	    final int activeSheetIndex = createDocumentSettings(workbook);
 	    createStyleOperations();
 	    createThemeOperations(null, null);
-	    createInsertNameOperations(workbook);
+	    createInsertNameOperations(workbook, null);
 		final Sheets sheets = workbook.getSheets();
 	    final List<Sheet> sheetList = sheets.getSheet();
 	    for(int sheetIndex = 0; sheetIndex < sheetList.size(); sheetIndex++) {
@@ -318,7 +330,8 @@ public class XlsxCreateOperationHelper extends CreateOperationHelper {
 	        if(sheetType.equals("worksheet")&&(activeSheetIndex==sheetIndex)) {
 	        	updateCellCount(((WorksheetPart)part).getJaxbElement());
 		        createInsertSheetOperation(sheet, sheetType, part, sheetIndex);
-        		createWorksheetOperations((WorksheetPart)part, sheetIndex, true);
+	    	    createInsertNameOperations(workbook, new Long(sheetIndex));
+        		createWorksheetOperations((WorksheetPart)part, sheetIndex);
 		        ((WorksheetPart)part).setJaxbElement((Worksheet)null);
 	        }
 	        else {
@@ -346,12 +359,84 @@ public class XlsxCreateOperationHelper extends CreateOperationHelper {
 	        	final Worksheet worksheet = ((WorksheetPart)part).getJaxbElement();
 	        	updateCellCount(worksheet);
 		        createSetSheetAttributesOperation(sheet, worksheet, sheetIndex);
-        		createWorksheetOperations((WorksheetPart)part, sheetIndex, false);
+	    	    createInsertNameOperations(workbook, new Long(sheetIndex));
+        		createWorksheetOperations((WorksheetPart)part, sheetIndex);
 		        ((WorksheetPart)part).setJaxbElement((Worksheet)null);
 	        }
 	    }
     }
 
+    public void createMetaOperations(DocumentProperties documentProperties)
+    	throws Exception {
+
+    	final WorkbookPart workbookPart = spreadsheetMLPackage.getWorkbookPart();
+	    final Workbook workbook = workbookPart.getJaxbElement();
+
+	    createDocumentDefaults(getOperationDocument().getUserLanguage());
+	    final int activeSheetIndex = createDocumentSettings(workbook);
+	    createStyleOperations();
+	    createThemeOperations(null, null);
+	    createInsertNameOperations(workbook, null);
+        documentProperties.put(DocumentProperties.PROP_SPREADHSEET_ACTIVE_SHEET_INDEX, activeSheetIndex);
+        documentProperties.put(DocumentProperties.PROP_SPREADHSEET_CURRENT_SHEET_INDEX, Integer.valueOf(0));
+    }
+
+    public void createActivePartOperations(DocumentProperties documentProperties)
+    	throws Exception {
+
+    	final WorkbookPart workbookPart = spreadsheetMLPackage.getWorkbookPart();
+	    final Workbook workbook = workbookPart.getJaxbElement();
+
+        final int activeSheetIndex = (Integer)documentProperties.get(DocumentProperties.PROP_SPREADHSEET_ACTIVE_SHEET_INDEX);
+		final Sheets sheets = workbook.getSheets();
+	    final List<Sheet> sheetList = sheets.getSheet();
+	    for(int sheetIndex = 0; sheetIndex < sheetList.size(); sheetIndex++) {
+	    	final Sheet sheet = sheetList.get(sheetIndex);
+	    	final Part part = XlsxOperationDocument.getSheetPart(spreadsheetMLPackage, sheet);
+	    	final String sheetType = XlsxOperationDocument.getSheetType(part);
+	        if(sheetType.equals("worksheet")&&(activeSheetIndex==sheetIndex)) {
+	        	updateCellCount(((WorksheetPart)part).getJaxbElement());
+		        createInsertSheetOperation(sheet, sheetType, part, sheetIndex);
+	    	    createInsertNameOperations(workbook, new Long(sheetIndex));
+        		createWorksheetOperations((WorksheetPart)part, sheetIndex);
+		        ((WorksheetPart)part).setJaxbElement((Worksheet)null);
+	        }
+	        else {
+		        createInsertSheetOperation(sheet, sheetType, null, sheetIndex);
+	        }
+	    }
+        documentProperties.put(DocumentProperties.PROP_SPREADSHEET_SHEET_COUNT, sheetList.size());
+    }
+
+    public boolean createNextPartOperations(DocumentProperties documentProperties)
+    	throws Exception {
+
+    	final WorkbookPart workbookPart = spreadsheetMLPackage.getWorkbookPart();
+	    final Workbook workbook = workbookPart.getJaxbElement();
+
+        final int activeSheetIndex = (Integer)documentProperties.get(DocumentProperties.PROP_SPREADHSEET_ACTIVE_SHEET_INDEX);
+        int currentSheetIndex = (Integer)documentProperties.get(DocumentProperties.PROP_SPREADHSEET_CURRENT_SHEET_INDEX);
+
+        final Sheets sheets = workbook.getSheets();
+	    final List<Sheet> sheetList = sheets.getSheet();
+	    for(; currentSheetIndex < sheetList.size(); currentSheetIndex++) {
+	    	final Sheet sheet = sheetList.get(currentSheetIndex);
+	    	final Part part = XlsxOperationDocument.getSheetPart(spreadsheetMLPackage, sheet);
+	    	final String sheetType = XlsxOperationDocument.getSheetType(part);
+	        if(sheetType.equals("worksheet")&&(activeSheetIndex!=currentSheetIndex)) {
+	        	final Worksheet worksheet = ((WorksheetPart)part).getJaxbElement();
+	        	updateCellCount(worksheet);
+		        createSetSheetAttributesOperation(sheet, worksheet, currentSheetIndex);
+	    	    createInsertNameOperations(workbook, new Long(currentSheetIndex));
+        		createWorksheetOperations((WorksheetPart)part, currentSheetIndex);
+		        ((WorksheetPart)part).setJaxbElement((Worksheet)null);
+		        documentProperties.put(DocumentProperties.PROP_SPREADHSEET_CURRENT_SHEET_INDEX, Integer.valueOf(currentSheetIndex+1));
+		        return true;
+	        }
+	    }
+	    return false;
+    }
+
     private void updateCellCount(Worksheet worksheet)
         throws FilterException {
 
@@ -389,6 +474,13 @@ public class XlsxCreateOperationHelper extends CreateOperationHelper {
     			documentAttrs.put("activeSheet", activeSheet);
     		}
     	}
+
+    	// property calcOnLoad: recalculate all formulas once after import
+    	final CTCalcPr calcPr = workbook.getCalcPr(false);
+        if (calcPr!=null && calcPr.isFullCalcOnLoad()) {
+        	documentAttrs.put("calcOnLoad", true);
+        }
+
 		final JSONObject attrs = new JSONObject(1);
 		attrs.put("document", documentAttrs);
 		addSetDocumentAttributesOperation(attrs);
@@ -396,7 +488,7 @@ public class XlsxCreateOperationHelper extends CreateOperationHelper {
 		return (int)activeSheet;
     }
 
-    private void createInsertNameOperations(Workbook workbook)
+    private void createInsertNameOperations(Workbook workbook, Long sheetIndex)
         throws JSONException {
 
         final DefinedNames definedNames = workbook.getDefinedNames();
@@ -405,91 +497,87 @@ public class XlsxCreateOperationHelper extends CreateOperationHelper {
         }
         final HashMap<String, CTDefinedName> definedNameMap = definedNames.getDefinedNameMap();
         for(CTDefinedName definedName:definedNameMap.values()) {
-            addInsertNameOperation(definedName.getLocalSheetId(), definedName.getName(), definedName.getValue()!=null ? definedName.getValue() : "", definedName.isHidden());
+        	Long localSheetId = definedName.getLocalSheetId();
+        	if ((sheetIndex == null) ? (localSheetId == null) : sheetIndex.equals(localSheetId)) {
+        		addInsertNameOperation(sheetIndex, definedName.getName(), definedName.getValue()!=null ? definedName.getValue() : "", definedName.isHidden());
+        	}
         }
     }
 
-    private JSONObject getCellObject(Row row, Cell cell, boolean preview)
+    private JSONObject getCellObject(Row row, Cell cell)
         throws Exception {
 
-    	Object value = null;
-    	Object formula = null;
-
     	STCellType cellType = cell.getT();
     	if(cellType==null) {
     		cellType = STCellType.N;
     	}
-        final JSONObject cellObject = new JSONObject();
+    	final JSONObject cellObject = new JSONObject();
         final CTCellFormula cellFormula = cell.getF();
-        final boolean isFormula = cellFormula!=null&&(cellFormula.getT()==STCellFormulaType.NORMAL||cellFormula.getT()==STCellFormulaType.SHARED);
-        if(isFormula) {
-        	final boolean hasFormulaText = cellFormula.getValue()!=null&&cellFormula.getValue().length()>0;
-            if(cellFormula.getT()==STCellFormulaType.SHARED) {
-                final Long si = cellFormula.getSi();
-                if(si!=null) {
-                    cellObject.put("shared", si+1);
-                }
-                if(hasFormulaText) {
-                    final SmlUtils.CellRef cellRef = new SmlUtils.CellRef(cell.getColumn(), row.getRow());
-                    cellObject.put("ref", cellRef.getJSONArray());
+        if(cellFormula!=null) {
+        	STCellFormulaType cellFormulaType = cellFormula.getT();
+        	if(cellFormulaType==null) {
+        		cellFormulaType = STCellFormulaType.NORMAL;
+        	}
+        	final String formulaExpr = cellFormula.getValue();
+	    	if (formulaExpr!=null && !formulaExpr.isEmpty()) {
+	    		cellObject.put("f", formulaExpr);
+	    	}
+        	if(cellFormulaType==STCellFormulaType.SHARED) {
+	        	final Long si = cellFormula.getSi();
+	        	if(si!=null) {
+	        		cellObject.put("si", si);
+	        	}
+
+	        	CellRefRange cellRefRange = SmlUtils.createCellRefRange(cellFormula.getRef());
+	        	if (cellRefRange!=null) {
+        			final JSONObject range = new JSONObject(2);
+		            range.put("start", cellRefRange.getStart().getJSONArray());
+					range.put("end", cellRefRange.getEnd().getJSONArray());
+		        	cellObject.put("sr",range);
+	        	}
+        	}
+        }
+        if(cellType==STCellType.INLINE_STR) {
+            final CTRst is = cell.getIs();
+            if(is!=null) {
+                if(is.getT()!=null) {
+                	cellObject.put("v", new String(is.getT().getValue()));;
                 }
             }
-            if(hasFormulaText)
-                formula = new String("=" + cellFormula.getValue());
         }
-        if(preview||!isFormula) {
-        	if (cellType==STCellType.INLINE_STR) {
-	            CTRst is = cell.getIs();
-	            if(is!=null) {
-	                // TODO: CTRst can include formatted text runs, but we will support simple t first.
-	                if(is.getT()!=null) {
-	                	value = new String(is.getT().getValue());
-	                }
-	            }
-	        }
-	        else if(cell.getV()!=null) {
-	            if(cellType==STCellType.N) {
-	                try {
-	                    value = new Double(Double.parseDouble(cell.getV()));
-	                }
-	                catch(NumberFormatException e) {
-	                    // TODO: ups
-	                }
-	            }
-	            else if(cellType==STCellType.S) {
-	                String sharedString = getOperationDocument().getSharedString(cell.getV());
-	                if(sharedString!=null) {
-	                    value = new String(getOperationDocument().escapeString(sharedString));
-	                }
-	            }
-	            else if(cellType==STCellType.B) {
-	                if(cell.getV().equals("0")||cell.getV().toLowerCase().equals("false")) {
-	                	value = new Boolean(false);
-	                }
-	                else if(cell.getV().equals("1")||cell.getV().toLowerCase().equals("true")) {
-	                    value = new Boolean(true);
-	                }
-	            }
-	            else {  // STCellType.STR, STCellType.E or STCellType.F (ARRAY or DATA_TABLE format)
-	            	final String cellValue = cell.getV();
-	                value = new String(cellValue.startsWith("=") ? "'" + cellValue : cellValue);
-	            }
-	        }
-        }
-    	if(isFormula) {
-    		if(formula!=null) {
-    			cellObject.put("value", formula);
-    		}
-        	if(value!=null) {
-        		cellObject.put("result", value);
+        else if(cell.getV()!=null) {
+        	if(cellType==STCellType.N) {
+                try {
+                	cellObject.put("v", new Double(Double.parseDouble(cell.getV())));
+                }
+                catch(NumberFormatException e) {
+                    // TODO: ups
+                }
         	}
-    	}
-    	else if (value!=null) {
-    		cellObject.put("value", value);
-    	}
-        final JSONObject jsonCellAttrs = CellUtils.createCellProperties(cell, getOperationDocument().getStylesheet(true));
-        if(jsonCellAttrs!=null) {
-           cellObject.put("attrs", jsonCellAttrs );
+        	else if(cellType==STCellType.S) {
+                String sharedString = getOperationDocument().getSharedString(cell.getV());
+                if(sharedString!=null) {
+                    cellObject.put("v", sharedString);
+                }
+        	}
+        	else if(cellType==STCellType.B) {
+                if(cell.getV().equals("0")||cell.getV().toLowerCase().equals("false")) {
+                	cellObject.put("v", new Boolean(false));
+                }
+                else if(cell.getV().equals("1")||cell.getV().toLowerCase().equals("true")) {
+                    cellObject.put("v", new Boolean(true));
+                }
+        	}        		
+        	else if(cellType==STCellType.E) {
+        		cellObject.put("e", cell.getV());
+        	}
+        	else {	// STCellType.STR, STCellType.F (ARRAY or DATA_TABLE format)
+        		cellObject.put("v", cell.getV());
+        	}
+        }
+        final long s = cell.getStyle();
+        if ((s > 0) || cellObject.isEmpty()) {
+        	cellObject.put("s", "a" + Long.toString(s));
         }
         return cellObject;
     }
@@ -539,14 +627,14 @@ public class XlsxCreateOperationHelper extends CreateOperationHelper {
     }
 
 
-    private void createWorksheetOperations(final WorksheetPart worksheetPart, int sheetIndex, boolean preview)
+    private void createWorksheetOperations(final WorksheetPart worksheetPart, int sheetIndex)
         throws Exception {
 
     	final Worksheet worksheet = worksheetPart.getJaxbElement();
 
         // column attributes... row attributes ... cells...
         createColumnOperations(worksheet.getCols(), sheetIndex);
-        createRowOperations(worksheet, sheetIndex, preview);
+        createRowOperations(worksheet, sheetIndex);
 
         MergeCellHelper.createMergeCellOperations(operationsArray, sheetIndex, worksheet.getMergeCells());
         AutoFilterHelper.createAutoFilterOperations(operationsArray, sheetIndex, worksheet.getAutoFilter());
@@ -600,7 +688,7 @@ public class XlsxCreateOperationHelper extends CreateOperationHelper {
         }
 
         // conditional formattings
-        ConditionalFormattings.createOperations(operationsArray, worksheet, sheetIndex, getOperationDocument().getStylesheet(false));
+        ConditionalFormattings.createOperations(getOperationDocument(), operationsArray, worksheet, sheetIndex);
     }
 
     private void createDataValidation(int sheetIndex, int validationIndex, IDataValidation dataValidation)
@@ -635,7 +723,7 @@ public class XlsxCreateOperationHelper extends CreateOperationHelper {
     	}
     }
 
-    private void createRowOperations(Worksheet worksheet, int sheetIndex, boolean preview)
+    private void createRowOperations(Worksheet worksheet, int sheetIndex)
         throws Exception {
 
     	final SheetData sheetData = worksheet.getSheetData();
@@ -658,9 +746,10 @@ public class XlsxCreateOperationHelper extends CreateOperationHelper {
             }
             else {
                 if(lastRow!=null) {
-                    final JSONObject attrs = RowUtils.createRowProperties(lastRow, getOperationDocument().getStylesheet(true));
-                    if(attrs!=null) {
-                        addSetRowAttributes(sheetIndex, lastRowNumber, (lastRowNumber - 1) + rowCount, attrs);
+                    final JSONObject attrs = RowUtils.createRowProperties(lastRow);
+                    final Long style = lastRow.getS();
+                    if(attrs!=null || style!=null) {
+                        addChangeRows(sheetIndex, lastRowNumber, (lastRowNumber - 1) + rowCount, attrs, style);
                     }
                 }
                 lastRow = row;
@@ -668,9 +757,10 @@ public class XlsxCreateOperationHelper extends CreateOperationHelper {
                 rowCount = 1;
             }
             if(!rowIterator.hasNext()&&lastRow!=null) {
-                final JSONObject attrs = RowUtils.createRowProperties(lastRow, getOperationDocument().getStylesheet(true));
-                if(attrs!=null) {
-                    addSetRowAttributes(sheetIndex, lastRowNumber, (lastRowNumber - 1) + rowCount, attrs);
+                final JSONObject attrs = RowUtils.createRowProperties(lastRow);
+                final Long style = lastRow.getS();
+                if(attrs!=null || style!=null) {
+                    addChangeRows(sheetIndex, lastRowNumber, (lastRowNumber - 1) + rowCount, attrs, style);
                 }
             }
         }
@@ -701,23 +791,13 @@ public class XlsxCreateOperationHelper extends CreateOperationHelper {
 	                if(cellDifference > 1) {
 	                	// we have empty cells ... at least one
                 		cellArray.put(lastCellObject);
-	                	if(cellDifference<=(MAX_EMPTY_CELL_REPEAT_CONTENT-1)) {
-	                		for(int i = cellDifference-1; i!=0; i--) {
-	                			cellArray.put((Object)null);
-	                		}
-	                	}
-	                	else {
-	                		// too many empty cells, we will create a new setCellContentOperation...
-                        	final JSONArray rowArray = new JSONArray(1);
-                			rowArray.put(cellArray);
-                			addSetCellContentsOperation(sheetIndex, topLeftCellRef, rowArray);
-	                		cellArray = new JSONArray();
-	                		topLeftCellRef = cellRef;
-	                	}
+                		final JSONObject emptyCell = new JSONObject(1);
+                		emptyCell.put("r", cellDifference-1);
+                		cellArray.put(emptyCell);
 	                }
 	                else {
 	                	if(compareCell(lastCell, cell)) {
-	                		lastCellObject.put("repeat", lastCellObject.optInt("repeat", 1) + 1);
+	                		lastCellObject.put("r", lastCellObject.optInt("r", 1) + 1);
 	                		repeat = true;
 	                	}
 	                	else {
@@ -728,16 +808,18 @@ public class XlsxCreateOperationHelper extends CreateOperationHelper {
             	lastCell = cell;
              	lastCellX = cellRef.getColumn();
             	if(repeat==false) {
-	            	lastCellObject = getCellObject(row, cell, preview);
+	            	lastCellObject = getCellObject(row, cell);
             	}
             }
             if(lastCellObject!=null) {
                 cellArray.put(lastCellObject);
             }
             if(!cellArray.isEmpty()) {
+            	final JSONObject rowObject = new JSONObject();
+                rowObject.put("c", cellArray);
             	final JSONArray rowArray = new JSONArray(1);
-                rowArray.put(cellArray);
-                addSetCellContentsOperation(sheetIndex, topLeftCellRef, rowArray);
+            	rowArray.put(rowObject);
+                addChangeCellsOperation(sheetIndex, topLeftCellRef, rowArray);
             }
         }
     }
@@ -752,9 +834,10 @@ public class XlsxCreateOperationHelper extends CreateOperationHelper {
             List<Col> colIter = cols.getCol();
             if(colIter!=null) {
                 for(Col col:colIter) {
-                    JSONObject attrs = ColumnUtils.createColumnProperties(getOperationDocument(), col);
-                    if(attrs!=null) {
-                        addSetColumnAttributes(sheetIndex, col.getMin()-1, col.getMax()-1, attrs);
+                    final JSONObject attrs = ColumnUtils.createColumnProperties(getOperationDocument(), col);
+                    final Long style = col.getStyle();
+                    if(attrs!=null || style!=null) {
+                        addChangeColumns(sheetIndex, col.getMin()-1, col.getMax()-1, attrs, style);
                     }
                 }
             }
@@ -801,11 +884,11 @@ public class XlsxCreateOperationHelper extends CreateOperationHelper {
 
     final static List<Object> objectList = new ArrayList<Object>();
 
-    public void addSetCellContentsOperation(int sheetIndex, SmlUtils.CellRef cellRef, JSONArray cellContent)
+    public void addChangeCellsOperation(int sheetIndex, SmlUtils.CellRef cellRef, JSONArray cellContent)
         throws JSONException {
 
         final JSONObject insertCellsObject = new JSONObject(4);
-        insertCellsObject.put("name", "setCellContents");
+        insertCellsObject.put("name", "changeCells");
         insertCellsObject.put("sheet", sheetIndex);
         insertCellsObject.put("start", cellRef.getJSONArray());
         insertCellsObject.put("contents", cellContent);
@@ -813,55 +896,49 @@ public class XlsxCreateOperationHelper extends CreateOperationHelper {
         operationsArray.put(insertCellsObject);
     }
 
-    public void addSetCellAttributesOperation(int sheetIndex, SmlUtils.CellRef cellRef, JSONObject attrs)
-        throws Exception {
+    public void addChangeRows(int sheetIndex, int start, int end, JSONObject attrs, Long style)
+        throws JSONException {
 
-        if(attrs!=null&&!attrs.isEmpty()) {
-            final JSONObject fillCellRangeObject = new JSONObject(4);
-            fillCellRangeObject.put("name", "fillCellRange");
-            fillCellRangeObject.put("sheet", sheetIndex);
-            fillCellRangeObject.put("start", cellRef.getJSONArray());
-            fillCellRangeObject.put("attrs", attrs);
+        final JSONObject operation = new JSONObject();
+        if (attrs!=null && attrs.length()>0) {
+        	operation.put("attrs", attrs);
+        }
+        if (style!=null && style.longValue()>0) {
+        	operation.put("s", "a" + Long.toString(style));
+        }
 
-            operationsArray.put(fillCellRangeObject);
+        if (operation.length()>0) {
+	        operation.put("name", "changeRows");
+	        operation.put("sheet", sheetIndex);
+	        operation.put("start", start);
+	        if(end!=start) {
+	            operation.put("end", end);
+	        }
+	        operationsArray.put(operation);
         }
     }
 
-    public void addSetRowAttributes(int sheetIndex, int start, int end, JSONObject attrs)
+    public void addChangeColumns(int sheetIndex, long start, long end, JSONObject attrs, Long style)
         throws JSONException {
 
-        if(attrs==null||attrs.length()==0)
-            return;
-
-        final JSONObject addSetRowAttributesObject = new JSONObject();
-        addSetRowAttributesObject.put("name", "setRowAttributes");
-        addSetRowAttributesObject.put("sheet", sheetIndex);
-        addSetRowAttributesObject.put("start", start);
-        if(end!=start) {
-            addSetRowAttributesObject.put("end", end);
+        final JSONObject operation = new JSONObject();
+        if (attrs!=null && attrs.length()>0) {
+        	operation.put("attrs", attrs);
         }
-        if(attrs!=null)	{
-        	addSetRowAttributesObject.put("attrs", attrs);
+        if (style!=null && style.longValue()>0) {
+        	operation.put("s", "a" + Long.toString(style));
         }
-        operationsArray.put(addSetRowAttributesObject);
-    }
 
-    public void addSetColumnAttributes(int sheetIndex, long start, long end, JSONObject attrs)
-        throws JSONException {
-
-        if(attrs==null||attrs.length()==0)
-            return;
-
-        final JSONObject addSetColumnAttributesObject = new JSONObject();
-        addSetColumnAttributesObject.put("name", "setColumnAttributes");
-        addSetColumnAttributesObject.put("sheet", sheetIndex);
-        addSetColumnAttributesObject.put("start", start);
-        if(end>start) {
-            addSetColumnAttributesObject.put("end", end);
+        if (operation.length()>0) {
+	        operation.put("name", "changeColumns");
+	        operation.put("sheet", sheetIndex);
+	        operation.put("start", start);
+	        if(end>start) {
+	            operation.put("end", end);
+	        }
+	
+	        operationsArray.put(operation);
         }
-        addSetColumnAttributesObject.put("attrs", attrs);
-
-        operationsArray.put(addSetColumnAttributesObject);
     }
 
     public void addInsertNameOperation(Long sheetIndex, String name, String formula, boolean hidden)
@@ -875,7 +952,7 @@ public class XlsxCreateOperationHelper extends CreateOperationHelper {
         if(hidden) {
         	addInsertNameObject.put("hidden", true);
         }
-        addInsertNameObject.put("exprName", name);
+        addInsertNameObject.put("label", name);
         addInsertNameObject.put("formula", formula);
 
         operationsArray.put(addInsertNameObject);
