@@ -5,7 +5,6 @@ import java.util.Map;
 
 import org.docx4j.dml.chart.CTAxDataSource;
 import org.docx4j.dml.chart.CTBubbleSer;
-import org.docx4j.dml.chart.CTChartSpace;
 import org.docx4j.dml.chart.CTNumDataSource;
 import org.docx4j.dml.chart.CTNumRef;
 import org.docx4j.dml.chart.CTSerTx;
@@ -16,17 +15,19 @@ import org.docx4j.dml.spreadsheetdrawing.ICellAnchor;
 import org.docx4j.openpackaging.parts.DrawingML.Drawing;
 import org.xlsx4j.sml.SmlUtils;
 
+import com.openexchange.office.ooxml.OperationDocument;
+import com.openexchange.office.ooxml.drawingml.ChartWrapper;
 import com.openexchange.office.ooxml.drawingml.DMLGraphic;
 
 public class ChartUtils {
 
-	public static void handleInsertDeleteColRow(Drawing drawing, String drawingSheetName, String sheetName, int start, int count, ColRow colrow, int rel) {
+	public static void handleInsertDeleteColRow(OperationDocument operationDocument, Drawing drawing, String drawingSheetName, String sheetName, int start, int count, ColRow colrow, int rel) {
 		final List<ICellAnchor> drawings = drawing.getJaxbElement().getEGAnchor();
 		for (final ICellAnchor ca : drawings) {
-			final Map<String, Object> drawingPropertyMap = DMLGraphic.getDrawingType(drawing, ca);
-			final CTChartSpace chartSpace = (CTChartSpace) drawingPropertyMap.get("chartObject");
-			if (chartSpace != null) {
-				final List<IListSer> series = chartSpace.getChart().getPlotArea().getAreaChartOrArea3DChartOrLineChart();
+			final Map<String, Object> drawingPropertyMap = DMLGraphic.getDrawingType(operationDocument, drawing, ca);
+			final ChartWrapper chart = Drawings.getChart(drawingPropertyMap);
+			if (chart != null) {
+				final List<IListSer> series = chart.getPlotArea().getAreaChartOrArea3DChartOrLineChart();
 				for (final IListSer serie : series) {
 					for (final ISerContent content : serie.getSer()) {
 						handleSeries(sheetName, drawingSheetName, start, count, colrow, rel, content);
