@@ -53,7 +53,6 @@ import java.util.Iterator;
 
 import org.json.JSONException;
 import org.json.JSONObject;
-import org.xlsx4j.sml.CTStylesheet;
 import org.xlsx4j.sml.Col;
 import org.xlsx4j.sml.Worksheet;
 
@@ -63,19 +62,19 @@ import com.openexchange.office.ooxml.xlsx.XlsxOperationDocument;
 public class ColumnUtils {
 
 	public static Double columnWidthToCharacter(XlsxOperationDocument operationDocument, Object width) {
-		if(width instanceof Integer) {
+		if(width instanceof Number) {
             final int defaultFontPixelWidth = operationDocument.getDefaultFontSize() == 12.0 ? 8 : 7;
             final double maxDigitWidthIn100thmm = (defaultFontPixelWidth*2540)/96.0;
-            return new Double((Integer)width / maxDigitWidthIn100thmm);
+            return new Double(((Number)width).doubleValue() / maxDigitWidthIn100thmm);
 		}
 		return null;
 	}
 
-    public static void applyColumnProperties(XlsxOperationDocument operationDocument, JSONObject columnProperties, Col col, Worksheet worksheet, CTStylesheet stylesheet)
+    public static void applyColumnProperties(XlsxOperationDocument operationDocument, JSONObject columnProperties, String style, Col col, Worksheet worksheet)
         throws FilterException, JSONException {
 
         // Column properties
-        final JSONObject jsonColumnProperties = columnProperties.optJSONObject("column");
+        final JSONObject jsonColumnProperties = (columnProperties == null) ? null : columnProperties.optJSONObject("column");
         if(jsonColumnProperties!=null) {
             Iterator<String> keys = jsonColumnProperties.keys();
             while(keys.hasNext()) {
@@ -107,7 +106,14 @@ public class ColumnUtils {
                 }
             }
         }
-        col.setStyle(CellUtils.applyAutoStyle(col.getStyle(), columnProperties));
+
+        // set new auto-style, or delete the 'style' attribute for the default auto-style
+        if (style != null) {
+        	Long index = Utils.parseAutoStyleId(style);
+        	if (index != null) {
+        		col.setStyle(index.longValue() == 0 ? null : index);
+        	}
+        }
 
         // Excel 2013 is having problems with empty columns
         if(col.getWidth()==null) {
@@ -125,7 +131,6 @@ public class ColumnUtils {
     public static JSONObject createColumnProperties(XlsxOperationDocument operationDocument, Col col)
         throws JSONException {
 
-        final JSONObject attrs = new JSONObject();
         final JSONObject columnProperties = new JSONObject();
 
         final Double columnWidth = col.getWidth();
@@ -141,14 +146,11 @@ public class ColumnUtils {
         if(!col.isBestFit()) {
             columnProperties.put("autoFit", false);
         }
-        attrs.put("column", columnProperties);
 
-        long s = col.getStyle();
-        if(s>0) {
-            attrs.put("styleId", "a" + Long.toString(s));
-        }
-        if(attrs.length()==0) {
-            return null;
+        JSONObject attrs = null;
+        if (columnProperties.length()>0) {
+        	attrs = new JSONObject();
+        	attrs.put("column", columnProperties);
         }
         return attrs;
     }
