@@ -55,6 +55,7 @@ import java.util.List;
 import java.util.Map;
 
 import org.docx4j.dml.CTBlipFillProperties;
+import org.docx4j.dml.CTNonVisualDrawingProps;
 import org.docx4j.dml.CTPoint2D;
 import org.docx4j.dml.CTPositiveSize2D;
 import org.docx4j.dml.CTShapeProperties;
@@ -65,7 +66,6 @@ import org.docx4j.dml.chart.CTStyle;
 import org.docx4j.dml.chartStyle2012.CTColorStyle;
 import org.docx4j.dml.spreadsheetdrawing.CTAbsoluteAnchor;
 import org.docx4j.dml.spreadsheetdrawing.CTGraphicalObjectFrame;
-import org.docx4j.dml.spreadsheetdrawing.CTGraphicalObjectFrameNonVisual;
 import org.docx4j.dml.spreadsheetdrawing.CTMarker;
 import org.docx4j.dml.spreadsheetdrawing.CTOneCellAnchor;
 import org.docx4j.dml.spreadsheetdrawing.CTPicture;
@@ -212,7 +212,7 @@ public class Drawings {
                     }
                 }
                 attrs.put("chart", chartProperties);
-                DMLHelper.createJsonFromShapeProperties(attrs, cs.getSpPr(), chartPart.getTheme(), chartPart.getChartStyle().getPlotArea(), chartPart.getChartPart(), false);
+                DMLHelper.createJsonFromShapeProperties(attrs, cs.getSpPr(), chartPart.getThemePart(), chartPart.getChartStyle().getPlotArea(), chartPart.getChartPart(), false);
             }
 
             final JSONObject insertDrawingOperation = new JSONObject(4);
@@ -254,10 +254,12 @@ public class Drawings {
 
         if(anchor.getPic()!=null) {
             DMLHelper.applyNonVisualDrawingProperties(anchor.getPic(), attrs.optJSONObject("drawing"));
+            DMLHelper.applyNonVisualDrawingShapeProperties(anchor.getPic(), attrs.optJSONObject("drawing"));
     	    anchor.getPic().setSpPr(DMLHelper.applyShapePropertiesFromJson(anchor.getPic().getSpPr(), attrs, operationDocument, part));
         }
         else if(anchor.getGraphicFrame()!=null) {
             DMLHelper.applyNonVisualDrawingProperties(anchor.getGraphicFrame(), attrs.optJSONObject("drawing"));
+        	DMLHelper.applyNonVisualDrawingShapeProperties(anchor.getGraphicFrame(), attrs.optJSONObject("drawing"));
         }
     }
 
@@ -300,8 +302,10 @@ public class Drawings {
         throws Exception {
 
         final CTGraphicalObjectFrame graphicalObjectFrame = Context.getDmlSpreadsheetDrawingObjectFactory().createCTGraphicalObjectFrame();
-        graphicalObjectFrame.setNvGraphicFramePr(createGraphicalObjectFrameNonVisual("chart"));
-        graphicalObjectFrame.setXfrm(DMLHelper.createTransform2D(0, 0, 500, 500));
+        graphicalObjectFrame.getNonVisualDrawingShapeProperties(true);
+        final CTNonVisualDrawingProps nonVisualDrawingProperties = graphicalObjectFrame.getNonVisualDrawingProperties(true);
+        nonVisualDrawingProperties.setName("chart");
+        DMLHelper.createTransform2D(graphicalObjectFrame.getXfrm(true), 0, 0, 500, 500);
         graphicalObjectFrame.setGraphic(DMLGraphic.createDrawingMLChart(operationDocument, drawingPart, "/xl/charts/", chartAttrs));
         return graphicalObjectFrame;
     }
@@ -313,11 +317,12 @@ public class Drawings {
 
         // general shape properties
         final CTShapeProperties shapeProperties = Context.getDmlObjectFactory().createCTShapeProperties();
-        shapeProperties.setXfrm(DMLHelper.createTransform2D(0, 0, 500, 500));
-        shapeProperties.setPrstGeom(DMLHelper.createPresetGeometry2D(STShapeType.RECT));
         picture.setSpPr(shapeProperties);
-        picture.setCNvPicPr(Context.getDmlObjectFactory().createCTNonVisualPictureProperties());
-        picture.setCNvPr(DMLHelper.createNonVisualDrawingProps("image"));
+        DMLHelper.createTransform2D(picture.getXfrm(true), 0, 0, 500, 500);
+        shapeProperties.setPrstGeom(DMLHelper.createPresetGeometry2D(STShapeType.RECT));
+        picture.getNonVisualDrawingShapeProperties(true);
+        final CTNonVisualDrawingProps nonVisualDrawingProperties = picture.getNonVisualDrawingProperties(true);
+        nonVisualDrawingProperties.setName("image");
 
         // picture
         final CTBlipFillProperties blipFillProperties = Context.getDmlObjectFactory().createCTBlipFillProperties();
@@ -333,8 +338,8 @@ public class Drawings {
 
         // general shape Properties
         final CTShapeProperties shapeProperties = Context.getDmlObjectFactory().createCTShapeProperties();
-        shapeProperties.setXfrm(DMLHelper.createTransform2D(0, 0, 500, 500));
         shape.setSpPr(shapeProperties);
+        DMLHelper.createTransform2D(shape.getXfrm(true), 0, 0, 500, 500);
         shape.setNvSpPr(createShapeNonVisual("shape"));
 
         // shape properties (preset)
@@ -342,17 +347,12 @@ public class Drawings {
         return shape;
     }
 
-    private static CTGraphicalObjectFrameNonVisual createGraphicalObjectFrameNonVisual(String name) {
-        final CTGraphicalObjectFrameNonVisual graphicalObjectFrameNonVisual = Context.getDmlSpreadsheetDrawingObjectFactory().createCTGraphicalObjectFrameNonVisual();
-        graphicalObjectFrameNonVisual.setCNvGraphicFramePr(Context.getDmlObjectFactory().createCTNonVisualGraphicFrameProperties());
-        graphicalObjectFrameNonVisual.setCNvPr(DMLHelper.createNonVisualDrawingProps(name));
-        return graphicalObjectFrameNonVisual;
-    }
-
     private static CTShapeNonVisual createShapeNonVisual(String name) {
         final CTShapeNonVisual shapeNonVisual = Context.getDmlSpreadsheetDrawingObjectFactory().createCTShapeNonVisual();
         shapeNonVisual.setCNvSpPr(Context.getDmlObjectFactory().createCTNonVisualDrawingShapeProps());
-        shapeNonVisual.setCNvPr(DMLHelper.createNonVisualDrawingProps(name));
+        final CTNonVisualDrawingProps nonVisualDrawingProps = Context.getDmlObjectFactory().createCTNonVisualDrawingProps();
+        nonVisualDrawingProps.setName(name);
+        shapeNonVisual.setCNvPr(nonVisualDrawingProps);
         return shapeNonVisual;
     }
 
