@@ -53,7 +53,6 @@ import java.util.Iterator;
 
 import org.json.JSONException;
 import org.json.JSONObject;
-import org.xlsx4j.sml.CTStylesheet;
 import org.xlsx4j.sml.Row;
 
 import com.openexchange.office.FilterException;
@@ -61,11 +60,11 @@ import com.openexchange.office.ooxml.xlsx.XlsxOperationDocument;
 
 public class RowUtils {
 
-    public static void applyRowProperties(XlsxOperationDocument operationDocument, JSONObject rowProperties, Row row, CTStylesheet stylesheet)
+    public static void applyRowProperties(XlsxOperationDocument operationDocument, JSONObject rowProperties, String style, Row row)
         throws FilterException, JSONException {
 
         // Row properties
-        JSONObject jsonRowProperties = rowProperties.optJSONObject("row");
+        JSONObject jsonRowProperties = (rowProperties == null) ? null : rowProperties.optJSONObject("row");
         if(jsonRowProperties!=null) {
             Iterator<String> keys = jsonRowProperties.keys();
             while(keys.hasNext()) {
@@ -101,7 +100,14 @@ public class RowUtils {
                 }
             }
         }
-        row.setS(Long.valueOf(CellUtils.applyAutoStyle(row.getStyle(), rowProperties)));
+
+        // set new auto-style, or delete the 's' attribute for the default auto-style
+        if (style != null) {
+        	Long index = Utils.parseAutoStyleId(style);
+        	if (index != null) {
+        		row.setS(index.longValue() == 0 ? null : index);
+        	}
+        }
     }
 
     public static double map100thmmToPoint(double rowHeight) {
@@ -132,10 +138,9 @@ public class RowUtils {
         return true;
     }
 
-    public static JSONObject createRowProperties(Row row, CTStylesheet stylesheet)
+    public static JSONObject createRowProperties(Row row)
         throws JSONException {
 
-        final JSONObject attrs = new JSONObject();
         final JSONObject rowProperties = new JSONObject();
 
         final Double rowHeight = row.getHt();
@@ -149,16 +154,12 @@ public class RowUtils {
         if(row.isCustomFormat()!=null&&row.isCustomFormat().booleanValue()) {
             rowProperties.put("customFormat", true);
         }
-        if(rowProperties.length()>0) {
+
+        JSONObject attrs = null;
+        if (rowProperties.length()>0) {
+            attrs = new JSONObject();
             attrs.put("row", rowProperties);
         }
-        long s = row.getStyle();
-        if(s>0) {
-            attrs.put("styleId", "a" + Long.toString(s));
-        }
-        if(attrs.length()==0) {
-            return null;
-        }
         return attrs;
     }
 
