@@ -65,13 +65,10 @@ import org.xlsx4j.sml.CTPane;
 import org.xlsx4j.sml.CTSelection;
 import org.xlsx4j.sml.CTSheetFormatPr;
 import org.xlsx4j.sml.CTSheetProtection;
-import org.xlsx4j.sml.Cell;
-import org.xlsx4j.sml.Row;
 import org.xlsx4j.sml.STPane;
 import org.xlsx4j.sml.STPaneState;
 import org.xlsx4j.sml.STSheetState;
 import org.xlsx4j.sml.Sheet;
-import org.xlsx4j.sml.SheetData;
 import org.xlsx4j.sml.SheetView;
 import org.xlsx4j.sml.SheetViews;
 import org.xlsx4j.sml.SmlUtils;
@@ -178,32 +175,44 @@ public class SheetUtils {
 	        }
         	if(splitWidth!=null) {
         		if(splitWidth instanceof Number) {
-        			if(pane.getState()==STPaneState.SPLIT) {
-        				pane.setXSplit((((Number)splitWidth).doubleValue()*1440.0)/2540);	// 100thmm to TWIP
+        			double width = ((Number)splitWidth).doubleValue();
+        			if (width == 0.0) {
+        				pane.setXSplit(null);
+        			} else if (pane.getState() == STPaneState.SPLIT) {
+        				pane.setXSplit(width * 1440.0 / 2540.0); // 100thmm to TWIP
+        			} else {
+        				pane.setXSplit(width);
         			}
-        			else {
-        				pane.setXSplit(((Number)splitWidth).doubleValue());
-        			}
-        		}
-        		else {
+        		} else {
         			pane.setXSplit(null);
         		}
         	}
         	if(splitHeight!=null) {
         		if(splitHeight instanceof Number) {
-        			if(pane.getState()==STPaneState.SPLIT) {
-        				pane.setYSplit((((Number)splitHeight).doubleValue()*1440.0)/2540);	// 100thmm to TWIP
+    				double height = ((Number)splitHeight).doubleValue();
+    				if (height == 0.0) {
+        				pane.setYSplit(null);
+    				} else if (pane.getState() == STPaneState.SPLIT) {
+        				pane.setYSplit(height * 1440.0 / 2540.0); // 100thmm to TWIP
+        			} else {
+        				pane.setYSplit(height);
         			}
-        			else {
-        				pane.setYSplit(((Number)splitHeight).doubleValue());
-        			}
-        		}
-        		else {
+        		} else {
         			pane.setYSplit(null);
         		}
         	}
         }
 
+        if(pane==null||pane.getXSplit()==0.0) {
+        	// remove selection topRight & bottomRight
+        	removeSelection(sheetView, STPane.TOP_RIGHT);
+        	removeSelection(sheetView, STPane.BOTTOM_RIGHT);
+        }
+        if(pane==null||pane.getYSplit()==0.0) {
+        	// remove selection bottomLeft & bottomRight
+        	removeSelection(sheetView, STPane.BOTTOM_LEFT);
+        	removeSelection(sheetView, STPane.BOTTOM_RIGHT);
+        }
 
         boolean hasPane = pane!=null&&(pane.getXSplit()!=0.0D||pane.getYSplit()!=0.0D);
         if(!hasPane) {
@@ -213,21 +222,19 @@ public class SheetUtils {
         	STPane activePane = pane.getActivePane();
         	final Object aPane = sheetProperties.opt("activePane");
 	        if(aPane!=null) {
-	        	activePane = STPane.BOTTOM_RIGHT;
+	        	activePane = STPane.TOP_LEFT;
 	        	if(aPane instanceof String) {
 	        		if(((String)aPane).equals("topLeft")) {
 	        			activePane = STPane.TOP_LEFT;
 	        		} else if(((String)aPane).equals("topRight")) {
 	            		activePane = STPane.TOP_RIGHT;
 	        		} else if(((String)aPane).equals("bottomRight")) {
-	        			activePane = STPane.TOP_RIGHT;
-	        		} else if(((String)aPane).equals("bottomLeftLeft")) {
+	        			activePane = STPane.BOTTOM_RIGHT;
+	        		} else if(((String)aPane).equals("bottomLeft")) {
 	        			activePane = STPane.BOTTOM_LEFT;
 	        		}
 	        	}
-	        	else {
-	        		pane.setActivePane(activePane);
-	        	}
+	        	pane.setActivePane(activePane);
 	        }
 	        final Object scrollRight = sheetProperties.opt("scrollRight");
 	        final Object scrollBottom  = sheetProperties.opt("scrollBottom");
@@ -342,7 +349,18 @@ public class SheetUtils {
 		return null;
 	}
 
-    private static SheetView getOrCreateSheetView(Worksheet worksheet) {
+	private static void removeSelection(SheetView sheetView, STPane paneToBeRemoved) {
+		final Iterator<CTSelection> selectionIter = sheetView.getSelection().iterator();
+		while(selectionIter.hasNext()) {
+			final CTSelection selection = selectionIter.next();
+			if(selection.getPane().equals(paneToBeRemoved)) {
+				selectionIter.remove();
+				return;
+			}
+		}
+	}
+
+	private static SheetView getOrCreateSheetView(Worksheet worksheet) {
 
     	SheetViews sheetViews = worksheet.getSheetViews();
     	if(sheetViews==null) {
@@ -458,7 +476,7 @@ public class SheetUtils {
         			}
         		}
     			final STPane activePane = pane!=null?pane.getActivePane():STPane.TOP_LEFT;
-    			if(activePane!=STPane.BOTTOM_RIGHT) {
+    			if(activePane!=STPane.TOP_LEFT) {
     				if(activePane==STPane.BOTTOM_LEFT) {
     					attrs.put("activePane", "bottomLeft");
     				} else if(activePane==STPane.BOTTOM_RIGHT) {
@@ -664,40 +682,4 @@ public class SheetUtils {
         }
         return rowProperties;
     }
-
-    /*
-     * applying attrs to each physical available cell within the row
-     *
-     */
-    public static void applyRowProperties(XlsxOperationDocument operationDocument, SheetData sheetData, int start, JSONObject attrs)
-        throws Exception {
-
-        Row row = sheetData.getRow(start, false);
-        if(row==null) {
-            return;
-        }
-        final Iterator<Cell> cellIterator = row.createCellIterator();
-        while(cellIterator.hasNext()) {
-            CellUtils.applyCellPropertiesToCell(operationDocument, null, sheetData, attrs, row, cellIterator.next());
-        }
-    }
-
-    /*
-     * applying attrs to each physical available cell within the column
-     *
-     */
-    public static void applyColumnProperties(XlsxOperationDocument operationDocument, SheetData sheetData, int start, int end, JSONObject attrs)
-        throws Exception {
-
-        final Iterator<Row> rowIterator = sheetData.createRowIterator();
-        while(rowIterator.hasNext()) {
-            final Row row = rowIterator.next();
-            for(int i=start; i<=end; i++) {
-                final Cell cell = row.getCell(i, false);
-                if(cell!=null) {
-                    CellUtils.applyCellPropertiesToCell(operationDocument, null, sheetData, attrs, row, cell);
-                }
-            }
-        }
-    }
 }
