@@ -196,7 +196,7 @@ public class TableHelper {
     	// What to do ?
     }
 
-    private static CTTable getTable(WorksheetPart worksheetPart, String tableName) {
+    public static CTTable getTable(WorksheetPart worksheetPart, String tableName) {
         final Worksheet worksheet = worksheetPart.getJaxbElement();
         final CTTableParts tableParts = worksheet.getTableParts();
         if(tableParts!=null) {
