@@ -51,22 +51,34 @@ package com.openexchange.office.ooxml.xlsx.tools;
 
 import java.util.ArrayList;
 import java.util.List;
+import java.util.regex.Pattern;
+import java.util.regex.Matcher;
 
 import org.docx4j.dml.BaseStyles;
 import org.docx4j.dml.CTColorScheme;
 import org.docx4j.dml.Theme;
+import org.docx4j.openpackaging.parts.ThemePart;
 import org.json.JSONArray;
 import org.json.JSONException;
 import org.json.JSONObject;
 import org.xlsx4j.jaxb.Context;
+import org.xlsx4j.schemas.microsoft.com.office.spreadsheetml_2009_9.main.CTCfIcon;
+import org.xlsx4j.schemas.microsoft.com.office.spreadsheetml_2009_9.main.CTCfvo;
+import org.xlsx4j.schemas.microsoft.com.office.spreadsheetml_2009_9.main.CTColorScale;
+import org.xlsx4j.schemas.microsoft.com.office.spreadsheetml_2009_9.main.STCfvoType;
+import org.xlsx4j.schemas.microsoft.com.office.spreadsheetml_2009_9.main.STDataBarAxisPosition;
+import org.xlsx4j.schemas.microsoft.com.office.spreadsheetml_2009_9.main.STDataBarDirection;
 import org.xlsx4j.sml.CTBorder;
 import org.xlsx4j.sml.CTBorderPr;
 import org.xlsx4j.sml.CTCellAlignment;
 import org.xlsx4j.sml.CTCellProtection;
+import org.xlsx4j.sml.CTCfRule;
 import org.xlsx4j.sml.CTColor;
 import org.xlsx4j.sml.CTColors;
+import org.xlsx4j.sml.CTDataBar;
 import org.xlsx4j.sml.CTFill;
 import org.xlsx4j.sml.CTGradientStop;
+import org.xlsx4j.sml.CTIconSet;
 import org.xlsx4j.sml.CTIndexedColors;
 import org.xlsx4j.sml.CTNumFmt;
 import org.xlsx4j.sml.CTPatternFill;
@@ -74,6 +86,11 @@ import org.xlsx4j.sml.CTRgbColor;
 import org.xlsx4j.sml.CTStylesheet;
 import org.xlsx4j.sml.Col;
 import org.xlsx4j.sml.Cols;
+import org.xlsx4j.sml.ICfRule;
+import org.xlsx4j.sml.ICfvo;
+import org.xlsx4j.sml.IColorScale;
+import org.xlsx4j.sml.IDataBar;
+import org.xlsx4j.sml.IIconSet;
 import org.xlsx4j.sml.STBorderStyle;
 import org.xlsx4j.sml.STHorizontalAlignment;
 import org.xlsx4j.sml.STPatternType;
@@ -87,25 +104,6 @@ import com.openexchange.office.ooxml.xlsx.XlsxOperationDocument;
 
 public class Utils {
 
-    // CTNumFmt
-
-    public static void createNumberFormat(JSONObject dest, long numberFormatId, CTNumFmt numberFormat)
-        throws JSONException {
-
-        if(numberFormatId<0&&numberFormat==null) {
-            return;
-        }
-        JSONObject jsonNumberFormatObject = new JSONObject();
-        jsonNumberFormatObject.put("id", numberFormatId);
-        if(numberFormat!=null) {
-            String code = numberFormat.getFormatCode();
-            if(code!=null) {
-                jsonNumberFormatObject.put("code", code);
-            }
-        }
-        dest.put("numberFormat", jsonNumberFormatObject);
-    }
-
     public static void createFill(JSONObject dest, CTStylesheet stylesheet, CTFill fill)
         throws JSONException {
 
@@ -204,6 +202,363 @@ public class Utils {
         "3366FF","33CCCC","99CC00","FFCC00","FF9900","FF6600","666699","969696",
         "003366","339966","003300","333300","993300","993366","333399","333333"
     };
+    
+	public static JSONArray createColorScaleSteps(IColorScale iColorScale, int minColorScaleSize, int maxColorScaleSize)
+			throws JSONException {
+		JSONArray jsonColorScaleSteps = new JSONArray();
+		if (iColorScale != null && iColorScale.getCfvo().size() == iColorScale.getColor().size()
+				&& iColorScale.getCfvo().size() >= minColorScaleSize
+				&& iColorScale.getCfvo().size() <= maxColorScaleSize) {
+
+			for (int i = 0; i < iColorScale.getCfvo().size(); i++) {
+				final JSONObject colorScaleStep = createRuleOperation(iColorScale.getCfvo().get(i));
+				colorScaleStep.put("c", createColor(null, iColorScale.getColor().get(i)));
+				jsonColorScaleSteps.put(colorScaleStep);
+			}
+		}
+
+		return jsonColorScaleSteps;
+	}
+	
+	/**
+	 * Add the CTColorScale Object to the given CfRule.
+	 * @throws JSONException
+	 */
+	public static void addColorScaleObjectToCfRule(XlsxOperationDocument operationDocument, ICfRule iCfRule,  JSONArray jsonColorScales) throws JSONException {
+		if (iCfRule instanceof org.xlsx4j.schemas.microsoft.com.office.spreadsheetml_2009_9.main.CTCfRule) {
+			CTColorScale colorScale = new CTColorScale();
+			for (int i = 0; i < jsonColorScales.length(); i++) {
+				JSONObject jsonRule = jsonColorScales.getJSONObject(i);
+				colorScale.getCfvo().add((CTCfvo) createRuleObject(new CTCfvo(), jsonRule));
+				colorScale.getColor().add(getColorByJson(operationDocument, jsonRule.getJSONObject("c")));
+			}
+			((org.xlsx4j.schemas.microsoft.com.office.spreadsheetml_2009_9.main.CTCfRule) iCfRule).setColorScale(colorScale);
+		} else {
+			org.xlsx4j.sml.CTColorScale colorScale = new org.xlsx4j.sml.CTColorScale();
+			for (int i = 0; i < jsonColorScales.length(); i++) {
+				JSONObject jsonRule = jsonColorScales.getJSONObject(i);
+				colorScale.getCfvo().add((org.xlsx4j.sml.CTCfvo) createRuleObject(new org.xlsx4j.sml.CTCfvo(), jsonRule));
+				colorScale.getColor().add(getColorByJson(operationDocument, jsonRule.getJSONObject("c")));
+			}
+			((CTCfRule) iCfRule).setColorScale(colorScale);
+		}
+	}
+
+	public static JSONObject createDataBarOperation(IDataBar dataBar, IDataBar dataBar1) throws JSONException {
+		JSONObject jsonDataBar = new JSONObject();
+		if (dataBar != null) {
+			jsonDataBar.put("r1", createRuleOperation(dataBar.getCfvo().get(0)));
+			if (dataBar.getCfvo().size() > 1) {
+				jsonDataBar.put("r2", createRuleOperation(dataBar.getCfvo().get(1)));				
+			}
+			
+			JSONObject color;
+			if (dataBar.getColor() == null && dataBar1 != null) {
+				color = createColor(null, dataBar1.getColor());
+			} else {
+				color = createColor(null, dataBar.getColor());
+			}
+			jsonDataBar.put("c", color);
+			jsonDataBar.put("s", dataBar.isShowValue());
+			jsonDataBar.put("min", dataBar.getMinLength());
+			jsonDataBar.put("max", dataBar.getMaxLength());
+			
+			if (dataBar instanceof org.xlsx4j.schemas.microsoft.com.office.spreadsheetml_2009_9.main.CTDataBar) {
+				org.xlsx4j.schemas.microsoft.com.office.spreadsheetml_2009_9.main.CTDataBar dataBar2009 = (org.xlsx4j.schemas.microsoft.com.office.spreadsheetml_2009_9.main.CTDataBar) dataBar;
+				
+				jsonDataBar.put("b", dataBar2009.isBorder());
+				jsonDataBar.put("bc", createColor(null, dataBar2009.getBorderColor()));
+				
+				jsonDataBar.put("ncs", dataBar2009.isNegativeBarColorSameAsPositive());
+				jsonDataBar.put("nc", createColor(null, dataBar2009.getNegativeFillColor()));
+				
+				jsonDataBar.put("nbs", dataBar2009.isNegativeBarBorderColorSameAsPositive());
+			    jsonDataBar.put("nbc", createColor(null, dataBar2009.getNegativeBorderColor()));
+				
+				jsonDataBar.put("ap", dataBar2009.getAxisPosition().value());				
+				jsonDataBar.put("ac", createColor(null, dataBar2009.getAxisColor()));
+				
+				jsonDataBar.put("g", dataBar2009.isGradient());
+				jsonDataBar.put("d", dataBar2009.getDirection().value());
+			}
+		}
+
+		return jsonDataBar;
+	}
+	
+	private static CTColor getColorByJson(XlsxOperationDocument operationDocument, JSONObject jsonColor) throws FilterException, JSONException {
+		CTColor color = Context.getsmlObjectFactory().createCTColor();
+		if (jsonColor != null) {
+			applyColor(operationDocument, color, jsonColor);			
+		}
+		return color;
+	}
+	
+	/**
+	 * Add the CTDataBar to the CfRule Object.
+	 * @throws JSONException
+	 */
+	public static void addDataBarObjectToCfRule(XlsxOperationDocument operationDocument, ICfRule iCfRule,  JSONObject jsonDataBar, boolean hasBothRules, Integer priority) throws JSONException {
+		
+		if (jsonDataBar != null) {
+			if (iCfRule instanceof org.xlsx4j.schemas.microsoft.com.office.spreadsheetml_2009_9.main.CTCfRule) {
+				/**
+				 * Documentation for DataBar.
+				 * 	https://msdn.microsoft.com/en-us/library/dd948147%28v=office.12%29.aspx
+				 */
+				org.xlsx4j.schemas.microsoft.com.office.spreadsheetml_2009_9.main.CTDataBar dataBar = new org.xlsx4j.schemas.microsoft.com.office.spreadsheetml_2009_9.main.CTDataBar();
+				addDefaultDataBarAttributes(dataBar, jsonDataBar);
+				dataBar.getCfvo().add((CTCfvo) createRuleObject(new CTCfvo(), jsonDataBar.getJSONObject("r1")));
+				dataBar.getCfvo().add((CTCfvo) createRuleObject(new CTCfvo(), jsonDataBar.getJSONObject("r2")));
+
+				// Fill Color and Priority only if org.xlsx4j.sml.CTCfRule not exists.
+				if (!hasBothRules) {
+					dataBar.setFillColor(getColorByJson(operationDocument, jsonDataBar.getJSONObject("c")));					
+			  		if(priority!=null) {
+			  			iCfRule.setPriority(priority.intValue());
+			  		}
+				}
+				
+				if (!jsonDataBar.isNull("b")) {
+					dataBar.setBorder(jsonDataBar.getBoolean("b"));
+				}
+				
+				if (dataBar.isBorder()) {
+				    if (!jsonDataBar.isNull("bc")) {
+						dataBar.setBorderColor(getColorByJson(operationDocument, jsonDataBar.getJSONObject("bc")));
+				    }						
+					if (!jsonDataBar.isNull("nbs")) {
+						dataBar.setNegativeBarBorderColorSameAsPositive(jsonDataBar.getBoolean("nbs"));
+					}
+				}
+				
+				if (!dataBar.isNegativeBarBorderColorSameAsPositive()) {
+					if (!jsonDataBar.isNull("nbc")) {
+						dataBar.setNegativeBorderColor(getColorByJson(operationDocument, jsonDataBar.getJSONObject("nbc")));
+					}					
+				}
+				
+				if (!jsonDataBar.isNull("ncs")) {
+					dataBar.setNegativeBarBorderColorSameAsPositive(jsonDataBar.getBoolean("ncs"));
+				}
+				
+				if (!dataBar.isNegativeBarColorSameAsPositive()) {
+					if (!jsonDataBar.isNull("nc")) {
+						dataBar.setNegativeFillColor(getColorByJson(operationDocument, jsonDataBar.getJSONObject("nc")));
+					}
+				}
+				
+				if (!jsonDataBar.isNull("ap")) {
+					dataBar.setAxisPosition(STDataBarAxisPosition.fromValue(jsonDataBar.getString("ap")));
+				}
+				
+				if (!jsonDataBar.isNull("ac")) {
+					dataBar.setAxisColor(getColorByJson(operationDocument, jsonDataBar.getJSONObject("ac")));
+				}					
+
+
+				if (!jsonDataBar.isNull("g")) {
+					dataBar.setGradient(jsonDataBar.getBoolean("g"));
+				}
+
+				if (!jsonDataBar.isNull("d")) {
+					dataBar.setDirection(STDataBarDirection.fromValue(jsonDataBar.getString("d")));
+				}
+				
+				((org.xlsx4j.schemas.microsoft.com.office.spreadsheetml_2009_9.main.CTCfRule) iCfRule).setDataBar(dataBar);
+			} else {
+				CTDataBar dataBar = new CTDataBar();
+		  		if(priority!=null) {
+		  			iCfRule.setPriority(priority.intValue());
+		  		}
+				dataBar.getCfvo().add((org.xlsx4j.sml.CTCfvo) createRuleObject(new org.xlsx4j.sml.CTCfvo(), jsonDataBar.getJSONObject("r1")));
+		  		dataBar.getCfvo().add((org.xlsx4j.sml.CTCfvo) createRuleObject(new org.xlsx4j.sml.CTCfvo(), jsonDataBar.getJSONObject("r2")));
+
+				dataBar.setColor(getColorByJson(operationDocument, jsonDataBar.getJSONObject("c")));
+
+				addDefaultDataBarAttributes(dataBar, jsonDataBar);
+
+				((org.xlsx4j.sml.CTCfRule)iCfRule).setDataBar(dataBar);
+			}
+		}
+
+	}
+	
+	private static void addDefaultDataBarAttributes(IDataBar dataBar, JSONObject jsonDataBar) throws JSONException {
+		if (!jsonDataBar.isNull("s")) {
+			dataBar.setShowValue(jsonDataBar.getBoolean("s"));
+		}
+		if (!jsonDataBar.isNull("min")) {
+			dataBar.setMinLength(jsonDataBar.getLong("min"));
+		}
+		if (!jsonDataBar.isNull("max")) {
+			dataBar.setMaxLength(jsonDataBar.getLong("max"));
+		}
+	}
+			
+	
+	public static JSONObject createIconSet(IIconSet iconSet)  throws JSONException {
+		org.xlsx4j.schemas.microsoft.com.office.spreadsheetml_2009_9.main.CTIconSet iconSet2009;
+		JSONObject jsonIconSet = new JSONObject();
+		jsonIconSet.put("is", iconSet.getIconSet());
+		jsonIconSet.put("s", iconSet.isShowValue());
+		jsonIconSet.put("r", iconSet.isReverse());
+		jsonIconSet.put("p", iconSet.isPercent());
+		if (iconSet instanceof org.xlsx4j.schemas.microsoft.com.office.spreadsheetml_2009_9.main.CTIconSet) {
+			iconSet2009 = (org.xlsx4j.schemas.microsoft.com.office.spreadsheetml_2009_9.main.CTIconSet)iconSet;
+			jsonIconSet.put("c", iconSet2009.isCustom());
+		} else {
+			iconSet2009 = null;
+		}
+		
+		JSONArray jsonRules = new JSONArray();
+		List<CTCfIcon> cfIcons = null;
+		if (iconSet2009 != null) {
+			cfIcons = iconSet2009.getCfIcon();
+		}
+		
+		for (int i = 0; i < iconSet.getCfvo().size(); i++) {
+			ICfvo cfvo = iconSet.getCfvo().get(i);
+			final JSONObject rule = createRuleOperation(cfvo);
+			rule.put("gte", cfvo.isGte());
+			if (cfIcons != null && i < cfIcons.size()) {
+				CTCfIcon icon = iconSet2009.getCfIcon().get(i);
+				rule.put("is", icon.getIconSet());
+				rule.put("id", icon.getIconId());
+			}
+			jsonRules.put(rule);
+		}
+		
+		jsonIconSet.put("ir", jsonRules);
+		
+		return jsonIconSet;
+	}
+	
+	/**
+	 * Add CTIconSet to the CfRule Object.
+	 * @throws JSONException
+	 */
+	public static void addIconSetObjectCfRule(XlsxOperationDocument operationDocument, ICfRule iCfRule,  JSONObject jsonIconSet) throws JSONException {
+		if (jsonIconSet != null) {
+			if (iCfRule instanceof org.xlsx4j.schemas.microsoft.com.office.spreadsheetml_2009_9.main.CTCfRule) {
+				org.xlsx4j.schemas.microsoft.com.office.spreadsheetml_2009_9.main.CTIconSet iconSet = new org.xlsx4j.schemas.microsoft.com.office.spreadsheetml_2009_9.main.CTIconSet();
+				if (!jsonIconSet.isNull("c")) {
+					iconSet.setCustom(jsonIconSet.getBoolean("c"));
+				}
+				addDefaultIconSetAttributes(iconSet, jsonIconSet);
+				
+				JSONArray jsonRules = jsonIconSet.getJSONArray("ir");
+				for (int i = 0; i < jsonRules.length(); i++) {
+					JSONObject jsonRule = jsonRules.getJSONObject(i);
+					CTCfvo rule = (CTCfvo) createRuleObject(new CTCfvo(), jsonRule);
+					iconSet.getCfvo().add(rule);
+					if (jsonRule.has("is") && jsonRule.has("id")) {
+						CTCfIcon icon = new CTCfIcon();
+						icon.setIconSet(jsonRule.getString("is"));
+						icon.setIconId(jsonRule.getInt("id"));				
+						iconSet.getCfIcon().add(icon);
+					}
+				}
+				
+				((org.xlsx4j.schemas.microsoft.com.office.spreadsheetml_2009_9.main.CTCfRule) iCfRule).setIconSet(iconSet);
+			} else {
+				CTIconSet iconSet = new CTIconSet();
+				
+				((org.xlsx4j.sml.CTCfRule)iCfRule).setIconSet(iconSet);
+				addDefaultIconSetAttributes(iconSet, jsonIconSet);
+				
+				
+				JSONArray jsonRules = jsonIconSet.getJSONArray("ir");
+				for (int i = 0; i < jsonRules.length(); i++) {
+					JSONObject jsonRule = jsonRules.getJSONObject(i);
+					org.xlsx4j.sml.CTCfvo rule = (org.xlsx4j.sml.CTCfvo) createRuleObject(new org.xlsx4j.sml.CTCfvo(), jsonRule);
+					iconSet.getCfvo().add(rule);
+				}
+			}
+		}
+	}
+	
+	private static void addDefaultIconSetAttributes(IIconSet iconSet, JSONObject jsonIconSet) throws JSONException {
+		iconSet.setIconSet(jsonIconSet.getString("is"));
+		if (jsonIconSet.isNull("s")) {
+			iconSet.setShowValue(jsonIconSet.getBoolean("s"));
+		}
+		if (jsonIconSet.isNull("r")) {
+			iconSet.setReverse(jsonIconSet.getBoolean("r"));
+		}
+		if (jsonIconSet.isNull("p")) {
+			iconSet.setPercent(jsonIconSet.getBoolean("p"));
+		}
+	}
+
+	private static JSONObject createRuleOperation(ICfvo cfvo) throws JSONException {
+		JSONObject jsonRule = new JSONObject();
+
+		if (cfvo.getType() != null) {
+			String type;
+			switch (cfvo.getType().ordinal()) {
+			case 0 :
+				type = "formula";
+				break;
+			case 1 :
+				type = "percent";
+				break;
+			case 2:
+				type = "max";
+				break;
+			case 3:
+				type = "min";
+				break;
+			case 4:
+				type = "formula";
+				break;
+			case 5:
+				type = "percentile";
+				break;
+			case 6:
+				type = "automin";
+				break;
+			case 7:
+				type = "automax";
+				break;
+			default:
+				type = null;
+			}
+			if (type != null) {
+				jsonRule.put("t", type);
+				jsonRule.put("v", cfvo.getVal());
+			}
+		}
+
+		return jsonRule;
+	}
+	
+	private static ICfvo createRuleObject(ICfvo iCfvo, JSONObject jsonRule) throws JSONException {
+		if (jsonRule != null) {
+			String typeName = jsonRule.getString("t");
+			if (iCfvo  instanceof CTCfvo) {
+				((CTCfvo)iCfvo).setType(STCfvoType.fromValue(typeName));
+			} else {
+				org.xlsx4j.sml.STCfvoType type = org.xlsx4j.sml.STCfvoType.fromValue(typeName);
+				if (type == null) {
+					if (typeName.equalsIgnoreCase("automin")) {
+						typeName = "min";
+					} else if (typeName.equalsIgnoreCase("automax")) {
+						typeName = "max";
+					}
+				}
+				((org.xlsx4j.sml.CTCfvo)iCfvo).setType(org.xlsx4j.sml.STCfvoType.fromValue(typeName));
+			}
+			if (jsonRule.has("v")) {
+				iCfvo.setVal(jsonRule.getString("v"));				
+			}
+			if (!jsonRule.isNull("gte")) {
+				iCfvo.setGte(jsonRule.getBoolean("gte"));				
+			}
+
+		}
+		return iCfvo;
+	}
 
     public static JSONObject createColor(CTStylesheet stylesheet, CTColor color)
         throws JSONException {
@@ -492,66 +847,69 @@ public class Utils {
             jsonDest.put("unlocked", false);
     }
 
-    public static byte[] themeColorToBytes(Theme theme, String themeColor) {
+    public static byte[] themeColorToBytes(ThemePart themePart, String themeColor) {
         byte[] rgbValue = null;
-        if(theme!=null) {
-            BaseStyles themeElements = theme.getThemeElements();
-            if(themeElements!=null) {
-                CTColorScheme clrScheme = themeElements.getClrScheme();
-                if(clrScheme!=null) {
-                    org.docx4j.dml.CTColor ctColor = null;
-                    if(themeColor.equals("light1")) {
-                        ctColor = clrScheme.getLt1();
-                    }
-                    else if(themeColor.equals("dark1")) {
-                        ctColor = clrScheme.getDk1();
-                    }
-                    else if(themeColor.equals("light2")) {
-                        ctColor = clrScheme.getLt1();
-                    }
-                    else if(themeColor.equals("dark2")) {
-                        ctColor = clrScheme.getDk2();
-                    }
-                    else if(themeColor.equals("accent1")) {
-                        ctColor = clrScheme.getAccent1();
-                    }
-                    else if(themeColor.equals("accent2")) {
-                        ctColor = clrScheme.getAccent2();
-                    }
-                    else if(themeColor.equals("accent3")) {
-                        ctColor = clrScheme.getAccent3();
-                    }
-                    else if(themeColor.equals("accent4")) {
-                        ctColor = clrScheme.getAccent4();
-                    }
-                    else if(themeColor.equals("accent5")) {
-                        ctColor = clrScheme.getAccent5();
-                    }
-                    else if(themeColor.equals("accent6")) {
-                        ctColor = clrScheme.getAccent6();
-                    }
-                    else if(themeColor.equals("hyperlink")) {
-                        ctColor = clrScheme.getHlink();
-                    }
-                    else if(themeColor.equals("followedHyperlink")) {
-                        ctColor = clrScheme.getFolHlink();
-                    }
-                    else if(themeColor.equals("text1")) {
-                        ctColor = clrScheme.getDk1();
-                    }
-                    else if(themeColor.equals("text2")) {
-                        ctColor = clrScheme.getDk2();
-                    }
-                    else if(themeColor.equals("background1")) {
-                        ctColor = clrScheme.getLt1();
-                    }
-                    else if(themeColor.equals("background2")) {
-                        ctColor = clrScheme.getLt2();
-                    }
-                    if(ctColor!=null) {
-                        rgbValue = Commons.ctColorToBytes(ctColor);
-                    }
-                }
+        if(themePart!=null) {
+        	final Theme theme = themePart.getJaxbElement();
+        	if(theme!=null) {
+	            BaseStyles themeElements = theme.getThemeElements();
+	            if(themeElements!=null) {
+	                CTColorScheme clrScheme = themeElements.getClrScheme();
+	                if(clrScheme!=null) {
+	                    org.docx4j.dml.CTColor ctColor = null;
+	                    if(themeColor.equals("light1")) {
+	                        ctColor = clrScheme.getLt1();
+	                    }
+	                    else if(themeColor.equals("dark1")) {
+	                        ctColor = clrScheme.getDk1();
+	                    }
+	                    else if(themeColor.equals("light2")) {
+	                        ctColor = clrScheme.getLt1();
+	                    }
+	                    else if(themeColor.equals("dark2")) {
+	                        ctColor = clrScheme.getDk2();
+	                    }
+	                    else if(themeColor.equals("accent1")) {
+	                        ctColor = clrScheme.getAccent1();
+	                    }
+	                    else if(themeColor.equals("accent2")) {
+	                        ctColor = clrScheme.getAccent2();
+	                    }
+	                    else if(themeColor.equals("accent3")) {
+	                        ctColor = clrScheme.getAccent3();
+	                    }
+	                    else if(themeColor.equals("accent4")) {
+	                        ctColor = clrScheme.getAccent4();
+	                    }
+	                    else if(themeColor.equals("accent5")) {
+	                        ctColor = clrScheme.getAccent5();
+	                    }
+	                    else if(themeColor.equals("accent6")) {
+	                        ctColor = clrScheme.getAccent6();
+	                    }
+	                    else if(themeColor.equals("hyperlink")) {
+	                        ctColor = clrScheme.getHlink();
+	                    }
+	                    else if(themeColor.equals("followedHyperlink")) {
+	                        ctColor = clrScheme.getFolHlink();
+	                    }
+	                    else if(themeColor.equals("text1")) {
+	                        ctColor = clrScheme.getDk1();
+	                    }
+	                    else if(themeColor.equals("text2")) {
+	                        ctColor = clrScheme.getDk2();
+	                    }
+	                    else if(themeColor.equals("background1")) {
+	                        ctColor = clrScheme.getLt1();
+	                    }
+	                    else if(themeColor.equals("background2")) {
+	                        ctColor = clrScheme.getLt2();
+	                    }
+	                    if(ctColor!=null) {
+	                        rgbValue = Commons.ctColorToBytes(ctColor);
+	                    }
+	                }
+	            }
             }
         }
         return rgbValue;
@@ -598,7 +956,7 @@ public class Utils {
                     JSONArray transformations = jsonColor.getJSONArray("transformations");
                     addTransformationsToColor(color, transformations);
                 }
-                color.setRgb(themeColorToBytes(operationDocument.getTheme(true), themeColor));
+                color.setRgb(themeColorToBytes(operationDocument.getThemePart(true), themeColor));
             } else if (type.equals("auto")) {
                 color.setAuto(true);
                 color.setTheme(null);
@@ -732,4 +1090,24 @@ public class Utils {
 	    }
 	    return cellRefRangeList;
     }
+
+	private static Pattern autoStyleIdPattern = Pattern.compile("a\\d+");
+
+    /**
+     * Parses the passed identifier of an auto-style, and returns the array index of the
+     * corresponding cell XF element.
+     * 
+     * @param styleId
+     * 	The identifier of an auto-style, as used in document operations. MUST NOT be null!
+     *  Can be the empty string to refer to the default auto-style "a0".
+     * 
+     * @return
+     * 	The zero-based index of the specified auto-style (e.g. the number 3 for the style
+     * 	identifier "a3"); or null, if the passed string is not a valid auto-style identifier.
+     */
+    public static Long parseAutoStyleId(String styleId) {
+    	if (styleId.length() == 0) { return 0L; }
+    	Matcher matcher = autoStyleIdPattern.matcher(styleId);
+    	return matcher.matches() ? Long.parseLong(styleId.substring(1)) : null;
+    }
 }
