@@ -214,7 +214,7 @@ abstract public class OperationDocument {
     }
 
     private void notifyLowMemory() {
-        log.info("OOXML Filter: Low memory notification received");
+        log.debug("OOXML Filter: Low memory notification received");
         Context.setLowMemoryAbort(true);
         final OpcPackage opcPackage = getPackage();
         if(opcPackage!=null) {
@@ -268,7 +268,6 @@ abstract public class OperationDocument {
         	throw e;
         }
         catch(Throwable e) {
-            log.error("OOXML Filter could not save the given document:", e);
             throw (e instanceof FilterException) ? (FilterException)e : new FilterException(e, ErrorCode.CRITICAL_ERROR);
         }
     }
@@ -444,8 +443,7 @@ abstract public class OperationDocument {
                 outputStream.flush();
             }
         } catch (Throwable e) {
-            log.error("OOXML Filter could not save the given document:", e);
-            throw new FilterException(e, ErrorCode.CRITICAL_ERROR);
+            throw new FilterException("OOXML Filter could not save the given document:", e, ErrorCode.CRITICAL_ERROR);
         } finally {
             IOUtils.closeQuietly(inputStream);
             IOUtils.closeQuietly(outputStream);
@@ -456,12 +454,12 @@ abstract public class OperationDocument {
 
     abstract public void setPackage(OpcPackage opcPackage);
 
-    abstract public Theme getTheme(boolean createIfMissing)
+    abstract public ThemePart getThemePart(boolean createIfMissing)
     	throws FilterException;
 
     public ThemeFonts getThemeFonts() {
     	if(themeFonts==null) {
-            themeFonts = new ThemeFonts(getTheme(true));
+            themeFonts = new ThemeFonts(getThemePart(true));
     	}
     	return themeFonts;
     }
@@ -484,13 +482,6 @@ abstract public class OperationDocument {
             ret = new FilterException("FilterException...", ErrorCode.MEMORY_USAGE_MIN_FREE_HEAP_SPACE_REACHED);
         }
         else if(e instanceof FilterException) {
-    		final FilterException filterException = (FilterException)e;
-    		if(filterException.getErrorcode()==ErrorCode.COMPLEXITY_TOO_HIGH) {
-    			log.warn("could not load/save document, the document complexity is too high");
-    		}
-    		else if(filterException.getErrorcode()==ErrorCode.CRITICAL_ERROR) {
-    			log.error(e.getMessage(), e);
-    		}
     		ret = (FilterException)e;
     	}
     	else if (e instanceof OutOfMemoryError) {
@@ -507,7 +498,6 @@ abstract public class OperationDocument {
             ret = new FilterException(e, errorCode);
     	}
     	else {
-    		log.error(e.getMessage(), e);
     		ret = new FilterException(e, ErrorCode.CRITICAL_ERROR);
     	}
     	ret.setOperationCount(OperationDocument.successfulAppliedOperations);
@@ -625,7 +615,7 @@ abstract public class OperationDocument {
 
     public abstract Part getContextPart();
 
-    public abstract Component getRootComponent();
+    public abstract Component getRootComponent(String target);
 
     public void setContextPart(Part part) {
     	contextPart = part;
