@@ -72,7 +72,6 @@ import org.docx4j.dml.CTTextParagraph;
 import org.docx4j.dml.CTTextParagraphProperties;
 import org.docx4j.dml.ITextCharacterProperties;
 import org.docx4j.dml.STLineCap;
-import org.docx4j.dml.Theme;
 import org.docx4j.dml.chart.CTArea3DChart;
 import org.docx4j.dml.chart.CTAreaChart;
 import org.docx4j.dml.chart.CTAxDataSource;
@@ -80,6 +79,7 @@ import org.docx4j.dml.chart.CTAxPos;
 import org.docx4j.dml.chart.CTBar3DChart;
 import org.docx4j.dml.chart.CTBarChart;
 import org.docx4j.dml.chart.CTBarDir;
+import org.docx4j.dml.chart.CTBarSer;
 import org.docx4j.dml.chart.CTBoolean;
 import org.docx4j.dml.chart.CTBubbleChart;
 import org.docx4j.dml.chart.CTBubbleSer;
@@ -89,6 +89,7 @@ import org.docx4j.dml.chart.CTChartLines;
 import org.docx4j.dml.chart.CTChartSpace;
 import org.docx4j.dml.chart.CTDLbls;
 import org.docx4j.dml.chart.CTDPt;
+import org.docx4j.dml.chart.CTDateAx;
 import org.docx4j.dml.chart.CTDoughnutChart;
 import org.docx4j.dml.chart.CTFirstSliceAng;
 import org.docx4j.dml.chart.CTGapAmount;
@@ -151,6 +152,7 @@ import org.docx4j.dml.chartStyle2012.CTStyleReference;
 import org.docx4j.jaxb.Context;
 import org.docx4j.openpackaging.exceptions.InvalidFormatException;
 import org.docx4j.openpackaging.exceptions.PartUnrecognisedException;
+import org.docx4j.openpackaging.parts.ThemePart;
 import org.json.JSONArray;
 import org.json.JSONException;
 import org.json.JSONObject;
@@ -177,7 +179,7 @@ final public class DMLChartSpace {
 		// MSO2012 chartStyles can be zero...
 		final CTChartStyle chartStyle = chartPart.getChartStyle();
 		// final CTColorStyle chartColorStyle = chartPart.getChartColorStyle();
-		final Theme theme = chartPart.getTheme();
+		final ThemePart themePart = chartPart.getThemePart();
 
 		final CTChart chart = chartSpace.getChart();
 		if (chart == null) {
@@ -312,14 +314,14 @@ final public class DMLChartSpace {
                         }
                     }
 
-					DMLHelper.createJsonFromShapeProperties(attrs, shape, theme, chartStyle.getDataPoint(), chartPart.getChartPart(), false);
+					DMLHelper.createJsonFromShapeProperties(attrs, shape, themePart, chartStyle.getDataPoint(), chartPart.getChartPart(), false);
 
 					if (marker != null){
 						final CTShapeProperties shapePr = marker.getSpPr();
 						if(shapePr!=null) {
 							final CTStyleEntry styleRef = chartStyle.getDataPointMarker();
 							final CTStyleReference fillRef = styleRef != null ? styleRef.getFillRef() : null;
-							DMLHelper.createJsonFromFillProperties(attrs, marker.getSpPr(), theme, fillRef, chartPart.getChartPart());
+							DMLHelper.createJsonFromFillProperties(attrs, marker.getSpPr(), themePart, fillRef, chartPart.getChartPart());
 						}
 					}
 
@@ -456,6 +458,9 @@ final public class DMLChartSpace {
 		final CTChartSpace chartSpace = chart.getChartSpace();
 
 		if (chartProperties.has("type")) {
+			// indirect call of getThemePart(createIfMissing=true) (Bug 46806)
+			chart.getThemePart();
+
 			final IListSer oldListSer = plotArea.getAreaChartOrArea3DChartOrLineChart().get(0);
 			final IListSer newListSer = createChartType(chartProperties);
 
@@ -485,7 +490,7 @@ final public class DMLChartSpace {
 
                         }
 					}
-				} else {
+				} else if (axes.size() == 0){
 					axes.add(createCatAx(0,1));
 					axes.add(createValAx(1,0));
 				}
@@ -610,18 +615,40 @@ final public class DMLChartSpace {
 		if (fill != null) {
 			final JSONObject fillHolder = new JSONObject();
 			fillHolder.put("fill", fill);
-			
+
 			plotArea.setSpPr(applyShapePropertiesFromJson(plotArea.getSpPr(), fillHolder));
 			chartSpace.setSpPr(applyShapePropertiesFromJson(chartSpace.getSpPr(), fillHolder));
-			
+
 			chartSpace.setRoundedCorners(getBoolean(false));
-			
+
 		}
 
 		if (listSer instanceof CTScatterChart) {
 			handleStandardScatterChart((CTScatterChart) listSer, chartProperties);
 
 		}
+
+		// reset generic axis numbers
+		// for Bug 46441
+		if (chartProperties.has("stacking") || chartProperties.has("type")) {
+			for (IAxisDescription axis : plotArea.getValAxOrCatAxOrDateAx()) {
+				if (axis instanceof CTDateAx) {
+					((CTDateAx)axis).setMajorUnit(null);
+					((CTDateAx)axis).setMinorUnit(null);
+					((CTDateAx)axis).setMajorTimeUnit(null);
+					((CTDateAx)axis).setMinorTimeUnit(null);
+				} else if (axis instanceof CTValAx) {
+					((CTValAx)axis).setMajorUnit(null);
+					((CTValAx)axis).setMinorUnit(null);
+				}
+
+				CTScaling scaling = axis.getScaling();
+				if (null != scaling) {
+					scaling.setMin(null);
+					scaling.setMax(null);
+				}
+			}
+		}
 	}
 
     private static void copy(
@@ -740,6 +767,8 @@ final public class DMLChartSpace {
 		final List<ISerContent> serContentList = listSer.getSer();
 		final ISerContent serContent = listSer.createSer();
 
+		disableInvertIfNegative(serContent);
+
 		boolean curved = isCurved(listSer);
 		setCurved(serContent, curved);
 
@@ -751,7 +780,15 @@ final public class DMLChartSpace {
 
 	}
 
-	private static void setDataseriesAttrs(List<ISerContent> serContentList, ISerContent serContent, String sheetName, JSONObject attrs)
+	private static void disableInvertIfNegative(ISerContent serContent) {
+	    if (serContent instanceof CTBarSer) {
+            ((CTBarSer)serContent).setInvertIfNegative(getBoolean(false));
+        } else if (serContent instanceof CTBubbleSer) {
+            ((CTBubbleSer)serContent).setInvertIfNegative(getBoolean(false));
+        }
+    }
+
+    private static void setDataseriesAttrs(List<ISerContent> serContentList, ISerContent serContent, String sheetName, JSONObject attrs)
 		throws JSONException, InvalidFormatException, PartUnrecognisedException {
 
 		if (attrs != null) {
@@ -763,12 +800,13 @@ final public class DMLChartSpace {
 				CTSerTx serTx = serContent.getTx();
 				if (title != null)
 				{
-					serTx = Context.getDmlChartObjectFactory().createCTSerTx();
+					if (null == serTx) {
+						serTx = Context.getDmlChartObjectFactory().createCTSerTx();
+					}
 					if (title instanceof String)
 					{
-						final CTStrRef strRef = Context.getDmlChartObjectFactory().createCTStrRef();
+						final CTStrRef strRef = serTx.getStrRef(true);
 						strRef.setF(getRef(sheetName, (String) title));
-						serTx.setStrRef(strRef);
 					}
 					else if (title instanceof JSONArray && !((JSONArray) title).isEmpty())
 					{
@@ -791,19 +829,18 @@ final public class DMLChartSpace {
 				CTAxDataSource cat = serContent.getCat();
 				if (names != null)
 				{
-
-					cat = Context.getDmlChartObjectFactory().createCTAxDataSource();
+					if (null == cat) {
+						cat = Context.getDmlChartObjectFactory().createCTAxDataSource();
+					}
 					if (names instanceof String)
 					{
-						final CTStrRef strRef = Context.getDmlChartObjectFactory().createCTStrRef();
+						final CTStrRef strRef = cat.getStrRef(true);
 						strRef.setF(getRef(sheetName, (String) names));
-						cat.setStrRef(strRef);
 					}
 					else if (names instanceof JSONArray)
 					{
 						final JSONArray titleArray = (JSONArray) names;
-						final CTStrData strData = Context.getDmlChartObjectFactory().createCTStrData();
-						cat.setStrLit(strData);
+						final CTStrData strData = cat.getStrLit(true);
 						strData.setPtCount(getUnsignedInt(titleArray.length()));
 						for (int i = 0; i < titleArray.length(); i++)
 						{
@@ -825,7 +862,9 @@ final public class DMLChartSpace {
 				final Object values = attrSeries.opt("values");
 				if (values != null)
 				{
-					val = Context.getDmlChartObjectFactory().createCTNumDataSource();
+					if (null == val) {
+						val = Context.getDmlChartObjectFactory().createCTNumDataSource();
+					}
 					insertSeriesAttribute(sheetName, val, values);
 				}
 				serContent.setVal(val);
@@ -834,7 +873,10 @@ final public class DMLChartSpace {
 				// bubbles
 				final Object bubbles = attrSeries.opt("bubbles");
 				if (bubbles != null && serContent instanceof CTBubbleSer) {
-					final CTNumDataSource bub = Context.getDmlChartObjectFactory().createCTNumDataSource();
+					CTNumDataSource bub = ((CTBubbleSer) serContent).getBubbleSize();
+					if (null == bub) {
+						bub = Context.getDmlChartObjectFactory().createCTNumDataSource();
+					}
 					((CTBubbleSer) serContent).setBubbleSize(bub);
 
 					insertSeriesAttribute(sheetName, bub, bubbles);
@@ -850,14 +892,14 @@ final public class DMLChartSpace {
 			updateIndexAndOrder(serContentList);
 		}
 	}
-	
-	private static CTShapeProperties applyShapePropertiesFromJson(CTShapeProperties shape, JSONObject attrs) 
+
+	private static CTShapeProperties applyShapePropertiesFromJson(CTShapeProperties shape, JSONObject attrs)
 			throws InvalidFormatException, PartUnrecognisedException, JSONException {
-		
+
 		// workaround for Bug 43983 & 44012
-		// normal fill behavior works fine, but not for Dark Chart, then they will be invisible, 
+		// normal fill behavior works fine, but not for Dark Chart, then they will be invisible,
 		// but without any fill info everything looks fine
-		
+
 		JSONObject fill = attrs.optJSONObject("fill");
 		if (fill != null) {
 			if (fill.optString("type", "").equals("solid")) {
@@ -865,17 +907,16 @@ final public class DMLChartSpace {
 				if (color == null || color.optString("type", "").equals("auto")) {
 					attrs.remove("fill");
 				}
-			}			
-		}		
-		
+			}
+		}
+
 		return DMLHelper.applyShapePropertiesFromJson(shape, attrs, null, null);
 	}
 
 	private static void insertSeriesAttribute(String sheetName, CTNumDataSource source, Object attribute) {
 		if (attribute instanceof String) {
-			final CTNumRef numRef = Context.getDmlChartObjectFactory().createCTNumRef();
+			final CTNumRef numRef = source.getNumRef(true);
 			numRef.setF(getRef(sheetName, (String) attribute));
-			source.setNumRef(numRef);
 		} else if (attribute instanceof JSONArray) {
 			final JSONArray bubblesArray = (JSONArray) attribute;
 			final CTNumData numData = Context.getDmlChartObjectFactory().createCTNumData();
@@ -1233,9 +1274,9 @@ final public class DMLChartSpace {
 		}
 		return dirString + view;
 	}
-	
-	// workaround for Bug 43959 
-	public static CTTextBody setTextBodyFromAttrs(CTTextBody textBody, JSONObject attrs) 
+
+	// workaround for Bug 43959
+	public static CTTextBody setTextBodyFromAttrs(CTTextBody textBody, JSONObject attrs)
 			throws JSONException {
 		JSONObject character = attrs.optJSONObject("character");
 		if (character == null || character.length() == 0) {
@@ -1243,8 +1284,8 @@ final public class DMLChartSpace {
 		} else {
 			if (textBody == null) {
 				textBody = new CTTextBody();
-				DMLHelper.handleStandardTypes(textBody);	
-			}			
+				DMLHelper.handleStandardTypes(textBody);
+			}
 			setCharacterFromAttrs(textBody, attrs);
 		}
 		return textBody;
@@ -1586,7 +1627,7 @@ final public class DMLChartSpace {
     		final JSONObject gridOp = new JSONObject();
     		final CTShapeProperties shape = grid.getSpPr();
     		if (shape != null) {
-    			DMLHelper.createJsonFromShapeProperties(gridOp, shape, chart.getTheme(), chart.getChartStyle().getGridlineMajor(), chart.getChartPart(), false);
+    			DMLHelper.createJsonFromShapeProperties(gridOp, shape, chart.getThemePart(), chart.getChartStyle().getGridlineMajor(), chart.getChartPart(), false);
     		}
     		if (!gridOp.has("line")) {
     		    //FIXME: nessecary?
@@ -1601,24 +1642,18 @@ final public class DMLChartSpace {
     	}
     }
 
-    public static void setChartGridlineAttributes(ChartWrapper chart, String axis, JSONObject attrs)
-    	throws JSONException, InvalidFormatException, PartUnrecognisedException {
-
-    	final IAxisDescription ax = getAxis(chart, axis);
-    	if (ax == null) {
-    		return;
-    	}
-
-    	CTChartLines grids = ax.getMajorGridlines();
-    	if (grids == null) {
-    		grids = new CTChartLines();
-    		ax.setMajorGridlines(grids);
-    	}
-    	grids.setSpPr(DMLHelper.applyShapePropertiesFromJson(grids.getSpPr(), attrs, null, null));
-    }
-
     static IAxisDescription getAxis(ChartWrapper chart, String axis) {
         CTPlotArea plotArea = chart.getPlotArea();
+
+        try {
+        	// workaround for Bug 46915
+			if (plotArea.getAreaChartOrArea3DChartOrLineChart().get(0) instanceof NoAxIdChart) {
+				return null;
+			}
+		} catch (Exception e) {
+			e.printStackTrace();
+		}
+
     	final int index;
     	if (axis.equals("x")) {
     		index = 0;
@@ -1631,29 +1666,27 @@ final public class DMLChartSpace {
     	}
     	final List<IAxisDescription> axes = plotArea.getValAxOrCatAxOrDateAx();
 
-    	if (index >= axes.size()) {
-    		return null;
+    	IAxisDescription res = null;
+    	if (index < axes.size()) {
+    		res = axes.get(index);
     	}
 
-    	IAxisDescription res = axes.get(index);
-
     	if (res == null) {
     		if (axis.equals("x")) {
-    			final CTCatAx cat = new CTCatAx();
+    			final CTCatAx cat = createCatAx(0,1);
     			cat.setMinorGridlines(getHiddenChartLines());
     			cat.setMinorTickMark(getHiddenTickMark());
     			cat.setNumFmt(createNumFmt());
     			res = cat;
     		} else {
-    			final CTValAx val = new CTValAx();
+    			final CTValAx val = createValAx(1,0);
     			val.setMinorGridlines(getHiddenChartLines());
     			val.setMinorTickMark(getHiddenTickMark());
     			val.setNumFmt(createNumFmt());
     			res = val;
     		}
-
-    		res.getAxId().setVal(index);
-    		axes.set(index, res);
+    		res.setAxId(getUnsignedInt(index));
+    		axes.add(index, res);
     	}
     	if (res.getDelete() == null || res.getDelete().isVal()) {
     		hideAxis(res);
@@ -1690,11 +1723,11 @@ final public class DMLChartSpace {
     	if (rich == null) {
     		return null;
     	}
-    	
+
     	final JSONObject attrs = new JSONObject();
     	final StringBuffer buf = new StringBuffer();
     	CTTextCharacterProperties characterProb = null;
-    	
+
 		final List<Object> paras = rich.getContent();
 		for (int i = 0; i < paras.size(); i++) {
 			final CTTextParagraph p = (CTTextParagraph)paras.get(i);
@@ -1709,7 +1742,7 @@ final public class DMLChartSpace {
 				else if (text instanceof CTTextLineBreak) {
 					addTo((CTTextLineBreak)text, buf);
 				}
-				
+
 				if (characterProb == null) {
 					characterProb = ((ITextCharacterProperties)text).getRPr(false);
 				}
@@ -1719,8 +1752,8 @@ final public class DMLChartSpace {
 				buf.append("\n");
 			}
 		}
-    	
-    	
+
+
     	final JSONArray link = new JSONArray();
     	link.put(buf.toString());
     	final JSONObject text = new JSONObject();
@@ -1870,6 +1903,8 @@ final public class DMLChartSpace {
     static final void getAxeOperation(ChartWrapper chart, IAxisDescription axe, JSONArray operations, String axisParam, JSONArray position) throws Exception {
 
     	final JSONObject axis = new JSONObject();
+
+    	/* disabled for Bug 46441, if we want to support scaling,w e also must support major & minor units!
         final CTScaling scaling = axe.getScaling();
         if(scaling!=null) {
             if (scaling.getMin()!=null) {
@@ -1879,6 +1914,7 @@ final public class DMLChartSpace {
                 axis.put("max", scaling.getMax().getVal());
             }
         }
+        */
         JSONObject character = null;
     	final JSONObject axisOp = new JSONObject();
     	final CTBoolean del = axe.getDelete();
@@ -1889,7 +1925,7 @@ final public class DMLChartSpace {
     	} else {
     		final CTShapeProperties shape = axe.getSpPr();
     		if (shape != null) {
-                DMLHelper.createJsonFromShapeProperties(axisOp, shape, chart.getTheme(), chart.getChartStyle().getSeriesAxis(), chart.getChartPart(), false);
+                DMLHelper.createJsonFromShapeProperties(axisOp, shape, chart.getThemePart(), chart.getChartStyle().getSeriesAxis(), chart.getChartPart(), false);
     		}
     		if (!axisOp.has("line")) {
     		    //FIXME: nessecary?
@@ -1930,6 +1966,7 @@ final public class DMLChartSpace {
     	if (ax == null) {
     		return;
     	}
+
     	final CTShapeProperties shape = DMLHelper.applyShapePropertiesFromJson(ax.getSpPr(), attrs, null, null);
     	ax.setSpPr(shape);
     	CTTickMark tickmark = ax.getMajorTickMark();
@@ -1966,6 +2003,22 @@ final public class DMLChartSpace {
     	}
     }
 
+    public static void setChartGridlineAttributes(ChartWrapper chart, String axis, JSONObject attrs)
+    	throws JSONException, InvalidFormatException, PartUnrecognisedException {
+
+    	final IAxisDescription ax = getAxis(chart, axis);
+    	if (ax == null) {
+    		return;
+    	}
+
+    	CTChartLines grids = ax.getMajorGridlines();
+    	if (grids == null) {
+    		grids = new CTChartLines();
+    		ax.setMajorGridlines(grids);
+    	}
+    	grids.setSpPr(DMLHelper.applyShapePropertiesFromJson(grids.getSpPr(), attrs, null, null));
+    }
+
     public static CTNumFmt createNumFmt()
     {
     	final CTNumFmt res = new CTNumFmt();
@@ -1994,7 +2047,7 @@ final public class DMLChartSpace {
     	mark.setVal(STTickMark.NONE);
     	return mark;
     }
-    
+
 
 	public static void setCharacterFromAttrs(CTTextBody txPr, JSONObject attrs) throws JSONException {
 		final List<Object> ps = txPr.getContent();
@@ -2005,7 +2058,7 @@ final public class DMLChartSpace {
 	}
 
 	public static void setCharacterFromAttrs(CTTextParagraph p, JSONObject attrs) throws JSONException {
-		
+
 		final JSONObject character = attrs.optJSONObject("character");
 
 		if (character != null) {
@@ -2013,7 +2066,7 @@ final public class DMLChartSpace {
 			prop.setDefRPr(setCharacterFromAttrs(prop.getDefRPr(false), attrs));
 		}
 	}
-	
+
 	public static CTTextCharacterProperties setCharacterFromAttrs(CTTextCharacterProperties t, JSONObject attrs)
 			throws JSONException {
 		final JSONObject character = attrs.optJSONObject("character");
@@ -2022,7 +2075,7 @@ final public class DMLChartSpace {
 			if (t == null) {
 				t = Context.getDmlObjectFactory().createCTTextCharacterProperties();
 			}
-			DMLHelper.applyTextCharacterPropertiesFromJson(t, attrs);
+			DMLHelper.applyTextCharacterPropertiesFromJson(t, attrs, null);
 
 		}
 		return t;
@@ -2047,8 +2100,8 @@ final public class DMLChartSpace {
     	shape.put("color", color);
     	return shape;
     }
-    
-    
+
+
     public static void addTo(CTRegularTextRun textRun, StringBuffer stringBuffer) {
     	stringBuffer.append(textRun.getT());
     }
