@@ -65,8 +65,10 @@ import org.docx4j.dml.CTGradientFillProperties;
 import org.docx4j.dml.CTGradientStop;
 import org.docx4j.dml.CTGradientStopList;
 import org.docx4j.dml.CTHslColor;
+import org.docx4j.dml.CTHyperlink;
 import org.docx4j.dml.CTLineProperties;
 import org.docx4j.dml.CTLineStyleList;
+import org.docx4j.dml.CTLockingBase;
 import org.docx4j.dml.CTNoFillProperties;
 import org.docx4j.dml.CTNonVisualDrawingProps;
 import org.docx4j.dml.CTPatternFillProperties;
@@ -90,19 +92,23 @@ import org.docx4j.dml.CTTextBodyProperties;
 import org.docx4j.dml.CTTextCharBullet;
 import org.docx4j.dml.CTTextCharacterProperties;
 import org.docx4j.dml.CTTextListStyle;
+import org.docx4j.dml.CTTextNoAutofit;
+import org.docx4j.dml.CTTextNormalAutofit;
 import org.docx4j.dml.CTTextParagraph;
 import org.docx4j.dml.CTTextParagraphProperties;
 import org.docx4j.dml.CTTextShapeAutofit;
 import org.docx4j.dml.CTTextSpacing;
 import org.docx4j.dml.CTTextSpacingPercent;
 import org.docx4j.dml.CTTextSpacingPoint;
-import org.docx4j.dml.CTTransform2D;
 import org.docx4j.dml.IColorChoice;
 import org.docx4j.dml.IFillProperties;
-import org.docx4j.dml.INonVisualDrawingProperties;
+import org.docx4j.dml.ILocksAccess;
+import org.docx4j.dml.INonVisualDrawingPropertyAccess;
+import org.docx4j.dml.INonVisualDrawingShapePropertyAccess;
 import org.docx4j.dml.IShapeStyle;
 import org.docx4j.dml.IStyleMatrixReference;
 import org.docx4j.dml.ITransform2D;
+import org.docx4j.dml.ITransform2DAccessor;
 import org.docx4j.dml.STPresetColorVal;
 import org.docx4j.dml.STPresetLineDashVal;
 import org.docx4j.dml.STSchemeColorVal;
@@ -113,6 +119,7 @@ import org.docx4j.dml.STTextAutonumberScheme;
 import org.docx4j.dml.STTextHorzOverflowType;
 import org.docx4j.dml.STTextUnderlineType;
 import org.docx4j.dml.STTextVertOverflowType;
+import org.docx4j.dml.STTextVerticalType;
 import org.docx4j.dml.STTextWrappingType;
 import org.docx4j.dml.TextFont;
 import org.docx4j.dml.Theme;
@@ -120,6 +127,7 @@ import org.docx4j.jaxb.Context;
 import org.docx4j.openpackaging.exceptions.InvalidFormatException;
 import org.docx4j.openpackaging.exceptions.PartUnrecognisedException;
 import org.docx4j.openpackaging.parts.Part;
+import org.docx4j.openpackaging.parts.ThemePart;
 import org.docx4j.relationships.Relationship;
 import org.json.JSONException;
 import org.json.JSONObject;
@@ -173,7 +181,7 @@ final public class DMLHelper {
 			final JSONObject initialDrawingAttrs = attrs.optJSONObject("drawing");
 			final JSONObject drawingAttrs = initialDrawingAttrs!=null ? initialDrawingAttrs : new JSONObject();
 
-            final CTPoint2D point2D = xFrm.getOff();
+            final CTPoint2D point2D = xFrm.getOff(false);
             if(point2D!=null) {
                 if(point2D.getX()!=0) {
                     if(!drawingAttrs.hasAndNotNull("left")) {
@@ -186,7 +194,7 @@ final public class DMLHelper {
                     }
                 }
             }
-            final CTPositiveSize2D positiveSize2D = xFrm.getExt();
+            final CTPositiveSize2D positiveSize2D = xFrm.getExt(false);
             if(positiveSize2D!=null) {
                 if(!drawingAttrs.hasAndNotNull("width")) {
                 	drawingAttrs.put("width", Commons.coordinateTo100TH_MM(positiveSize2D.getCx()));
@@ -204,6 +212,10 @@ final public class DMLHelper {
                 if(!drawingAttrs.hasAndNotNull("flipV")) {
                 	drawingAttrs.put("flipV", true );
                 }
+            }
+            final int rotation = xFrm.getRot();
+            if(rotation!=0) {
+            	drawingAttrs.put("rotation", ((double)rotation)/60000.0);
             }
 	        if(initialDrawingAttrs==null&&!drawingAttrs.isEmpty()) {
 				attrs.put("drawing", drawingAttrs);
@@ -211,76 +223,80 @@ final public class DMLHelper {
         }
     }
 
-    public static void applyTransform2DFromJson(ITransform2D transform2D, JSONObject attrs) {
+    public static void applyTransform2DFromJson(ITransform2DAccessor transformAccessor, JSONObject attrs) {
+        
+        
 
     	final JSONObject drawingAttrs = attrs.optJSONObject("drawing");
     	if(drawingAttrs!=null) {
-			final Object width = drawingAttrs.opt("width");
+    	    
+    	    final Object width = drawingAttrs.opt("width");
 			if(width!=null) {
 	            if(width instanceof Integer) {
-	                CTPositiveSize2D extend = transform2D.getExt();
-	                if(extend==null) {
-	                	extend = Context.getDmlObjectFactory().createCTPositiveSize2D();
-	                	transform2D.setExt(extend);
-	                }
-	                extend.setCx(((Integer)width).intValue()*360);
+	                ITransform2D transform2D = transformAccessor.getXfrm(true);	                
+	                transform2D.getExt(true).setCx(((Integer)width).intValue()*360);
 	            }
 			}
 			final Object height = drawingAttrs.opt("height");
 			if(height!=null) {
 				if(height instanceof Integer) {
-	                CTPositiveSize2D extend = transform2D.getExt();
-	                if(extend==null) {
-	                	extend = Context.getDmlObjectFactory().createCTPositiveSize2D();
-	                	transform2D.setExt(extend);
-	                }
-	                extend.setCy(((Integer)height).intValue()*360);
+				    ITransform2D transform2D = transformAccessor.getXfrm(true);                    
+                    transform2D.getExt(true).setCy(((Integer)height).intValue()*360);
 				}
 			}
 			if(width==JSONObject.NULL&&height==JSONObject.NULL) {
-				transform2D.setExt(null);
+			    ITransform2D transform2D = transformAccessor.getXfrm(true);                 
+                transform2D.setExt(null);
 			}
 			final Object left = drawingAttrs.opt("left");
 			if(left!=null) {
 			    if(left instanceof Integer) {
-			        CTPoint2D pos = transform2D.getOff();
-			        if(pos==null) {
-			            pos = Context.getDmlObjectFactory().createCTPoint2D();
-			            transform2D.setOff(pos);
-			        }
-			        pos.setX(((Integer)left).longValue()*360);
+			        ITransform2D transform2D = transformAccessor.getXfrm(true);                 
+                    transform2D.getOff(true).setX(((Integer)left).longValue()*360);
 			    }
 			}
             final Object top = drawingAttrs.opt("top");
             if(top!=null) {
                 if(top instanceof Integer) {
-                    CTPoint2D pos = transform2D.getOff();
-                    if(pos==null) {
-                        pos = Context.getDmlObjectFactory().createCTPoint2D();
-                        transform2D.setOff(pos);
-                    }
-                    pos.setY(((Integer)top).longValue()*360);
+                    ITransform2D transform2D = transformAccessor.getXfrm(true);                    
+                    transform2D.getOff(true).setY(((Integer)top).longValue()*360);
                 }
             }
             if(left==JSONObject.NULL&&top==JSONObject.NULL) {
-            	transform2D.setOff(null);
+                ITransform2D transform2D = transformAccessor.getXfrm(true);                    
+                transform2D.setOff(null);
             }
 			final Object flipH = drawingAttrs.opt("flipH");
 			if(flipH!=null) {
 				if(flipH instanceof Boolean) {
-	                transform2D.setFlipH((Boolean)flipH);
+				    ITransform2D transform2D = transformAccessor.getXfrm(true);                    
+                    transform2D.setFlipH((Boolean)flipH);
 				}
 				else {
-					transform2D.setFlipH(null);
+				    ITransform2D transform2D = transformAccessor.getXfrm(true);                    
+                    transform2D.setFlipH(null);
 				}
 			}
 			final Object flipV = drawingAttrs.opt("flipV");
 			if(flipV!=null) {
 				if(flipV instanceof Boolean) {
-	                transform2D.setFlipV((Boolean)flipV);
+				    ITransform2D transform2D = transformAccessor.getXfrm(true);                    
+                    transform2D.setFlipV((Boolean)flipV);
 				}
 				else {
-					transform2D.setFlipV(null);
+				    ITransform2D transform2D = transformAccessor.getXfrm(true);                    
+                    transform2D.setFlipV(null);
+				}
+			}
+			final Object rotation = drawingAttrs.opt("rotation");
+			if(rotation!=null) {
+				if(rotation instanceof Number) {
+				    ITransform2D transform2D = transformAccessor.getXfrm(true);                    
+                    transform2D.setRot(Integer.valueOf((int)((((Number)rotation).doubleValue()*60000)+0.5))); ;
+				}
+				else {
+				    ITransform2D transform2D = transformAccessor.getXfrm(true);                    
+                    transform2D.setRot(null);
 				}
 			}
     	}
@@ -348,22 +364,26 @@ final public class DMLHelper {
     			fillProperties.setBlipFill(null);
     			fillProperties.setGrpFill(null);
     		}
-    		if(fillProperties.getSolidFill()!=null) {
-				final JSONObject color = fillAttrs.optJSONObject("color");
-				if(color!=null) {
-					createSolidColorFillPropertiesFromJson(fillProperties.getSolidFill(), color);
-				}
-    		}
-    		else if(fillProperties.getBlipFill()!=null) {
-    			final String imageUrl = fillAttrs.optString("imageUrl", null);
-    			final CTBlipFillProperties blipFillProperties = fillProperties.getBlipFill();
-    			if(imageUrl!=null && operationDocument!=null && part!=null) {
-    				blipFillProperties.setBlip(createCTBlip(operationDocument, part, imageUrl));
-        			blipFillProperties.setStretch(Context.getDmlObjectFactory().createCTStretchInfoProperties());
-    			}
-    		}
-    		else if(fillProperties.getGradFill()!=null) {
-
+    		if (fillProperties!=null) {
+        		if(fillProperties.getSolidFill()!=null) {
+    				final JSONObject color = fillAttrs.optJSONObject("color");
+    				if(color!=null) {
+    					createSolidColorFillPropertiesFromJson(fillProperties.getSolidFill(), color);
+    				}
+        		}
+        		else if(fillProperties.getBlipFill()!=null) {
+        			final String imageUrl = fillAttrs.optString("imageUrl", null);
+        			final CTBlipFillProperties blipFillProperties = fillProperties.getBlipFill();
+        			if(imageUrl!=null && operationDocument!=null && part!=null) {
+        				blipFillProperties.setBlip(createCTBlip(operationDocument, part, imageUrl));
+            			blipFillProperties.setStretch(Context.getDmlObjectFactory().createCTStretchInfoProperties());
+        			}
+        		}
+        		else if(fillProperties.getGradFill()!=null) {
+    
+        		}
+    		} else {
+    		    Logger.getAnonymousLogger().warning("DMLHelper.applyFillPropertiesFromJson() no fillProperties assigned");
     		}
     	}
     }
@@ -454,12 +474,16 @@ final public class DMLHelper {
         }
     }
 
-    private static void createJsonFromFillStyleMatrix(Theme theme, IStyleMatrixReference fillStyleReference, JSONObject dest, Part part)
+    private static void createJsonFromFillStyleMatrix(ThemePart themePart, IStyleMatrixReference fillStyleReference, JSONObject dest)
         throws JSONException {
 
-        if(fillStyleReference==null||theme==null) {
+        if(fillStyleReference==null||themePart==null) {
             return;
         }
+        final Theme theme = themePart.getJaxbElement();
+        if(theme==null) {
+        	return;
+        }
         final BaseStyles themeElements = theme.getThemeElements();
         if(themeElements==null) {
             return;
@@ -490,19 +514,23 @@ final public class DMLHelper {
             if(fillMatrix!=null) {
                 final int index = (int)(idx>1000?idx-1001:idx-1);
                 if(index<fillMatrix.size()) {
-                    createJsonFromFillStyle(fillMatrix.get(index), fillStyleReference, dest, part);
+                    createJsonFromFillStyle(fillMatrix.get(index), fillStyleReference, dest, themePart);
                 }
             }
         }
         return;
     }
 
-    private static void createJsonFromLineStyleMatrix(Theme theme, IStyleMatrixReference lineStyleReference, JSONObject dest, Part part)
+    private static void createJsonFromLineStyleMatrix(ThemePart themePart, IStyleMatrixReference lineStyleReference, JSONObject dest)
         throws JSONException {
 
-        if(lineStyleReference==null||theme==null) {
+        if(lineStyleReference==null||themePart==null) {
             return;
         }
+        final Theme theme = themePart.getJaxbElement();
+        if(theme==null) {
+        	return;
+        }
         final BaseStyles themeElements = theme.getThemeElements();
         if(themeElements==null) {
             return;
@@ -516,18 +544,18 @@ final public class DMLHelper {
        if(lineStyleList!=null) {
            final List<CTLineProperties> lineMatrix = lineStyleList.getLn();
            if(idx>=0&&idx<lineMatrix.size()) {
-               createJsonFromLineStyle(lineMatrix.get(idx), lineStyleReference, dest, part);
+               createJsonFromLineStyle(lineMatrix.get(idx), lineStyleReference, dest, themePart);
            }
        }
        return;
     }
 
-    public static void createJsonFromShapeProperties(JSONObject attrs, CTShapeProperties shapeProperties, Theme theme, IShapeStyle shapeStyle, Part part, boolean createTransform)
+    public static void createJsonFromShapeProperties(JSONObject attrs, CTShapeProperties shapeProperties, ThemePart themePart, IShapeStyle shapeStyle, Part part, boolean createTransform)
             throws JSONException {
 
         if(shapeProperties!=null) {
             if(createTransform) {
-                createJsonFromTransform2D(attrs, shapeProperties.getXfrm());
+                createJsonFromTransform2D(attrs, shapeProperties.getXfrm(false));
             }
             if(shapeProperties.getPrstGeom()!=null) {
             	DMLGeometry.createJsonFromPresetGeometry(attrs, shapeProperties.getPrstGeom());
@@ -536,11 +564,11 @@ final public class DMLHelper {
             	DMLGeometry.createJsonFromCustomGeometry(attrs, shapeProperties.getCustGeom());
             }
         }
-        createJsonFromLineProperties(attrs, theme, shapeStyle!=null ? shapeStyle.getLnRef() : null, shapeProperties!=null ? shapeProperties.getLn(): null, part);
-        createJsonFromFillProperties(attrs, shapeProperties, theme, shapeStyle!=null ? shapeStyle.getFillRef() : null, part);
+        createJsonFromLineProperties(attrs, themePart, shapeStyle!=null ? shapeStyle.getLnRef() : null, shapeProperties!=null ? shapeProperties.getLn(): null, part);
+        createJsonFromFillProperties(attrs, shapeProperties, themePart, shapeStyle!=null ? shapeStyle.getFillRef() : null, part);
     }
 
-    public static void createJsonFromFillProperties(JSONObject attrs, IFillProperties fillProperties, Theme theme, IStyleMatrixReference fillStyleReference, Part part)
+    public static void createJsonFromFillProperties(JSONObject attrs, IFillProperties fillProperties, ThemePart themePart, IStyleMatrixReference fillStyleReference, Part part)
         throws JSONException {
 
         final JSONObject initialFillAttrs = attrs.optJSONObject("fill");
@@ -548,7 +576,7 @@ final public class DMLHelper {
 
         if(fillStyleReference!=null) {
             // try to apply the style first...
-            createJsonFromFillStyleMatrix(theme, fillStyleReference, fillAttrs, part);
+            createJsonFromFillStyleMatrix(themePart, fillStyleReference, fillAttrs);
         }
 
         if(fillProperties!=null) {
@@ -586,15 +614,7 @@ final public class DMLHelper {
 		if(shapeProperties==null) {
 			shapeProperties = Context.getDmlObjectFactory().createCTShapeProperties();
 		}
-		CTTransform2D transform2d = shapeProperties.getXfrm();
-		if(transform2d==null) {
-		    transform2d = Context.getDmlObjectFactory().createCTTransform2D();
-		    shapeProperties.setXfrm(transform2d);
-		}
-		applyTransform2DFromJson(transform2d, attrs);
-		if(transform2d.getExt()==null&&transform2d.getOff()==null) {
-			shapeProperties.setXfrm(null);
-		}
+		applyTransform2DFromJson(shapeProperties, attrs);
 		shapeProperties.setLn(applyLinePropertiesFromJson(shapeProperties.getLn(), attrs));
 		applyFillPropertiesFromJson(shapeProperties, attrs, operationDocument, part);
 
@@ -605,7 +625,7 @@ final public class DMLHelper {
 		return shapeProperties;
 	}
 
-    public static void createJsonFromLineProperties(JSONObject attrs, Theme theme, IStyleMatrixReference lineStyleReference, CTLineProperties lineProperties, Part part)
+    public static void createJsonFromLineProperties(JSONObject attrs, ThemePart themePart, IStyleMatrixReference lineStyleReference, CTLineProperties lineProperties, Part part)
         throws JSONException {
 
         final JSONObject initialLineAttrs = attrs.optJSONObject("line");
@@ -613,7 +633,7 @@ final public class DMLHelper {
 
         if(lineStyleReference!=null) {
             // try to apply the style first...
-            createJsonFromLineStyleMatrix(theme, lineStyleReference, lineAttrs, part);
+            createJsonFromLineStyleMatrix(themePart, lineStyleReference, lineAttrs);
         }
     	if(lineProperties!=null) {
     	    createJsonFromLineStyle(lineProperties, null, lineAttrs, part);
@@ -884,15 +904,116 @@ final public class DMLHelper {
         dest.put("color", JSONHelper.makeColor("preset", color.getVal().value(), color.getEGColorTransform()));
     }
 
-    public static CTNonVisualDrawingProps createNonVisualDrawingProps(String name) {
-        final CTNonVisualDrawingProps nonVisualDrawingProps = Context.getDmlObjectFactory().createCTNonVisualDrawingProps();
-        nonVisualDrawingProps.setName(name);
-        return nonVisualDrawingProps;
-    }
-
-    public static void createJsonFromNonVisualDrawingProperties(JSONObject attrs, CTNonVisualDrawingProps nonVisualDrawingProps)
+    public static void createJsonFromNonVisualDrawingShapeProperties(JSONObject attrs, INonVisualDrawingShapePropertyAccess iNonVisualDrawingShapePropertyAccess)
         throws JSONException {
 
+    	final ILocksAccess iLocksAccess = iNonVisualDrawingShapePropertyAccess.getNonVisualDrawingShapeProperties(false);
+        if(iLocksAccess==null) {
+            return;
+        }
+        final CTLockingBase lockingBase = iLocksAccess.getLocks(false);
+        if(lockingBase==null) {
+        	return;
+        }
+		final JSONObject initialDrawingAttrs = attrs.optJSONObject("drawing");
+		final JSONObject drawingAttrs = initialDrawingAttrs!=null ? initialDrawingAttrs : new JSONObject();
+
+		if(lockingBase.isNoChangeAspect()) {
+			drawingAttrs.put("noChangeAspect", true);
+		}
+		if(lockingBase.isNoMove()) {
+			drawingAttrs.put("noMove", true);
+		}
+		if(lockingBase.isNoResize()) {
+			drawingAttrs.put("noResize", true);
+		}
+		if(lockingBase.isNoSelect()) {
+			drawingAttrs.put("noSelect", true);
+		}
+		if(lockingBase.isNoGrp()) {
+			drawingAttrs.put("noGroup", true);
+		}
+		if(lockingBase instanceof CTLockingBase.INoRot) {
+			if(((CTLockingBase.INoRot)lockingBase).isNoRot()) {
+				drawingAttrs.put("noRotation", true);
+			}
+		}
+		if(initialDrawingAttrs==null&&!drawingAttrs.isEmpty()) {
+			attrs.put("drawing", drawingAttrs);
+		}
+    }
+
+    public static void applyNonVisualDrawingShapeProperties(INonVisualDrawingShapePropertyAccess iNonVisualDrawingShapePropertyAccess, JSONObject drawingProperties) {
+    	if(drawingProperties==null) {
+    		return;
+    	}
+    	Object o = drawingProperties.opt("noChangeAspect");
+    	if(o!=null) {
+    		if(o instanceof Boolean) {
+    			getLockingBase(iNonVisualDrawingShapePropertyAccess).setNoChangeAspect((Boolean)o);
+    		}
+    		else {
+    			getLockingBase(iNonVisualDrawingShapePropertyAccess).setNoChangeAspect(null);
+    		}
+    	}
+    	o = drawingProperties.opt("noMove");
+    	if(o!=null) {
+    		if(o instanceof Boolean) {
+    			getLockingBase(iNonVisualDrawingShapePropertyAccess).setNoMove((Boolean)o);
+    		}
+    		else {
+    			getLockingBase(iNonVisualDrawingShapePropertyAccess).setNoMove(null);
+    		}
+    	}
+    	o = drawingProperties.opt("noResize");
+    	if(o!=null) {
+    		if(o instanceof Boolean) {
+    			getLockingBase(iNonVisualDrawingShapePropertyAccess).setNoResize((Boolean)o);
+    		}
+    		else {
+    			getLockingBase(iNonVisualDrawingShapePropertyAccess).setNoResize(null);
+    		}
+    	}
+    	o = drawingProperties.opt("noSelect");
+    	if(o!=null) {
+    		if(o instanceof Boolean) {
+    			getLockingBase(iNonVisualDrawingShapePropertyAccess).setNoSelect((Boolean)o);
+    		}
+    		else {
+    			getLockingBase(iNonVisualDrawingShapePropertyAccess).setNoSelect(null);
+    		}
+    	}
+    	o = drawingProperties.opt("noGroup");
+    	if(o!=null) {
+    		if(o instanceof Boolean) {
+    			getLockingBase(iNonVisualDrawingShapePropertyAccess).setNoGrp((Boolean)o);
+    		}
+    		else {
+    			getLockingBase(iNonVisualDrawingShapePropertyAccess).setNoGrp(null);
+    		}
+    	}
+    	o = drawingProperties.opt("noRotation");
+    	if(o!=null) {
+    		final CTLockingBase lockingBase = getLockingBase(iNonVisualDrawingShapePropertyAccess);
+    		if(lockingBase instanceof CTLockingBase.INoRot) {
+	    		if(o instanceof Boolean) {
+	    			((CTLockingBase.INoRot)lockingBase).setNoRot((Boolean)o);
+	    		}
+	    		else {
+	    			((CTLockingBase.INoRot)lockingBase).setNoRot(null);
+	    		}
+    		}
+    	}
+    }
+
+    private static CTLockingBase getLockingBase(INonVisualDrawingShapePropertyAccess iNonVisualDrawingShapePropertyAccess) {
+    	return iNonVisualDrawingShapePropertyAccess.getNonVisualDrawingShapeProperties(true).getLocks(true);
+    }
+
+    public static void createJsonFromNonVisualDrawingProperties(JSONObject attrs, INonVisualDrawingPropertyAccess iNonVisualDrawingProps)
+        throws JSONException {
+
+    	final CTNonVisualDrawingProps nonVisualDrawingProps = iNonVisualDrawingProps.getNonVisualDrawingProperties(false);
         if(nonVisualDrawingProps==null) {
             return;
         }
@@ -915,19 +1036,14 @@ final public class DMLHelper {
 		}
     }
 
-    public static void applyNonVisualDrawingProperties(INonVisualDrawingProperties iNonVisualDrawingProperties, JSONObject drawingProperties) {
-
+    public static void applyNonVisualDrawingProperties(INonVisualDrawingPropertyAccess iNonVisualDrawingProperties, JSONObject drawingProperties) {
     	if(drawingProperties==null) {
     		return;
     	}
     	final Object optName = drawingProperties.opt("name");
         final Object optDescription = drawingProperties.opt("description");
         if(optName!=null||optDescription!=null) {
-        	CTNonVisualDrawingProps nonVisualDrawingProperties = iNonVisualDrawingProperties.getCNvPr();
-        	if(nonVisualDrawingProperties==null) {
-        		nonVisualDrawingProperties = Context.getDmlObjectFactory().createCTNonVisualDrawingProps();
-        		iNonVisualDrawingProperties.setCNvPr(nonVisualDrawingProperties);
-        	}
+        	CTNonVisualDrawingProps nonVisualDrawingProperties = iNonVisualDrawingProperties.getNonVisualDrawingProperties(true);
         	if(optName!=null) {
 	            if(optName instanceof String) {
 	            	nonVisualDrawingProperties.setName((String)optName);
@@ -948,9 +1064,8 @@ final public class DMLHelper {
         }
     }
 
-    public static CTTransform2D createTransform2D(int x100thmm, int y100thmm, int width100thmm, int height100thmm) {
+    public static void createTransform2D(ITransform2D transform2D, int x100thmm, int y100thmm, int width100thmm, int height100thmm) {
         final org.docx4j.dml.ObjectFactory dmlObjectFactory = Context.getDmlObjectFactory();
-        final CTTransform2D transform2D = dmlObjectFactory.createCTTransform2D();
         final CTPoint2D point2D = dmlObjectFactory.createCTPoint2D();
         point2D.setX(Commons.coordinateFrom100TH_MM(x100thmm));
         point2D.setY(Commons.coordinateFrom100TH_MM(y100thmm));
@@ -958,7 +1073,6 @@ final public class DMLHelper {
         final CTPositiveSize2D positiveSize2D = dmlObjectFactory.createCTPositiveSize2D();
         positiveSize2D.setCx(Commons.coordinateFrom100TH_MM(width100thmm));
         positiveSize2D.setCy(Commons.coordinateFrom100TH_MM(height100thmm));
-        return transform2D;
     }
 
     public static CTPresetGeometry2D createPresetGeometry2D(STShapeType presetType) {
@@ -1279,7 +1393,7 @@ final public class DMLHelper {
         	}
         }
     	if(attrs.hasAndNotNull("character")) {
-    		applyTextCharacterPropertiesFromJson(paragraphProperties.getDefRPr(true), attrs);
+    		applyTextCharacterPropertiesFromJson(paragraphProperties.getDefRPr(true), attrs, part);
     	}
         if(paragraphAttrs==null) {
         	return;
@@ -1403,12 +1517,12 @@ final public class DMLHelper {
 		if(textSpacing.getSpcPct()!=null) {
 			final CTTextSpacingPercent spacing = textSpacing.getSpcPct();
 			jsonLineHeight.put("type", "percent");
-			jsonLineHeight.put("value", (int)(spacing.getVal() / 1000));
+			jsonLineHeight.put("value", (int)(spacing.getVal() / 1000.0));
 		}
 		else if(textSpacing.getSpcPts()!=null) {
 			final CTTextSpacingPoint spacing = textSpacing.getSpcPts();
 			jsonLineHeight.put("type", "fixed");
-			jsonLineHeight.put("value", (int)((spacing.getVal() * 2.54) / 72));
+			jsonLineHeight.put("value", (int)((spacing.getVal() * 25.4) / 72.0));
 		}
 		return jsonLineHeight;
     }
@@ -1428,7 +1542,7 @@ final public class DMLHelper {
         		else if(type.equals("fixed")) {
         			final CTTextSpacingPoint textSpacingFixed = Context.getDmlObjectFactory().createCTTextSpacingPoint();
         			spacing.setSpcPts(textSpacingFixed);
-        			textSpacingFixed.setVal((int)((((Integer)value).intValue() * 72.0) / 2.54));
+        			textSpacingFixed.setVal((int)((((Integer)value).intValue() * 72.0) / 25.4));
         			return spacing;
         		}
         		return spacing;
@@ -1608,13 +1722,23 @@ final public class DMLHelper {
 					break;
 				}
 			}
+			final CTHyperlink hyperlink = textCharacterProperties.getHlinkClick(false);
+			if(hyperlink!=null) {
+				final String rId = hyperlink.getId();
+				if(rId!=null&&!rId.isEmpty()) {
+					final String hLink = Commons.getUrl(part, rId);
+					if(hLink!=null&&!hLink.isEmpty()) {
+						characterAttrs.put("url", hLink);
+					}
+				}
+			}
 	        if(initialCharacterAttrs==null&&!characterAttrs.isEmpty()) {
 				attrs.put("character", characterAttrs);
 			}
     	}
     }
 
-    public static void applyTextCharacterPropertiesFromJson(CTTextCharacterProperties characterProperties, JSONObject attrs)
+    public static void applyTextCharacterPropertiesFromJson(CTTextCharacterProperties characterProperties, JSONObject attrs, Part part)
     	throws JSONException {
 
     	if(attrs==null) {
@@ -1679,12 +1803,24 @@ final public class DMLHelper {
         			}
         			break;
         		}
+        		case "url": {
+        			if(value instanceof String) {
+        				if(part!=null) {
+	        				final CTHyperlink hyperlink = characterProperties.getHlinkClick(true);
+	        				hyperlink.setId(Commons.setUrl(part, null, (String)value));
+        				}
+        			}
+        			else if(value==JSONObject.NULL) {
+        				characterProperties.setHlinkClick(null);
+        			}
+        			break;
+        		}
         	}
         }
     }
 
     // applying the properties to the listStyle
-	public static void applyTextCharacterPropertiesFromJson(CTTextBody textBody, int level, JSONObject attrs)
+	public static void applyTextCharacterPropertiesFromJson(CTTextBody textBody, int level, JSONObject attrs, Part part)
 		throws JSONException {
 
 		if(attrs==null||attrs.optJSONObject("character")==null) {
@@ -1695,7 +1831,7 @@ final public class DMLHelper {
 			textListStyle = Context.getDmlObjectFactory().createCTTextListStyle();
 			textBody.setLstStyle(textListStyle);
 		}
-		applyTextCharacterPropertiesFromJson(textListStyle.getPPr(level, true).getDefRPr(true), attrs);
+		applyTextCharacterPropertiesFromJson(textListStyle.getPPr(level, true).getDefRPr(true), attrs, part);
 	}
 
 	public static JSONObject createJsonFromTextListStyle(CTTextListStyle textListStyle, Part part)
@@ -1740,7 +1876,6 @@ final public class DMLHelper {
 			final JSONObject initialTextBodyAttrs = attrs.optJSONObject("shape");
 			final JSONObject textBodyAttrs = initialTextBodyAttrs!=null ? initialTextBodyAttrs : new JSONObject();
 
-			textBodyProperties.getSpAutoFit();
 			// top is default
 			final STTextAnchoringType anchor = textBodyProperties.getAnchor();
 			if(anchor!=null) {
@@ -1770,75 +1905,93 @@ final public class DMLHelper {
 				if(a!=null) {
 					textBodyAttrs.put("anchor", a);
 				}
+			}
 
-				// false is default
-				final Boolean anchorCentered = textBodyProperties.isAnchorCtr();
-				if(anchorCentered!=null) {
-					textBodyAttrs.put("anchorCentered", anchorCentered.booleanValue());
-				}
-	
-				// default 2,5mm
-				final Integer marginLeft = textBodyProperties.getLIns();
-				if(marginLeft!=null) {
-					textBodyAttrs.put("paddingLeft", marginLeft.intValue() / 360);
-				}
-	
-				// default 2,5mm
-				final Integer marginRight = textBodyProperties.getRIns();
-				if(marginRight!=null) {
-					textBodyAttrs.put("paddingRight", marginRight.intValue() / 360);
-				}
-	
-				// default 1,25mm
-				final Integer marginTop = textBodyProperties.getTIns();
-				if(marginTop!=null) {
-					textBodyAttrs.put("paddingTop", marginTop.intValue() / 360);
-				}
-	
-				// default 1,25mm
-				final Integer marginBottom = textBodyProperties.getBIns();
-				if(marginBottom!=null) {
-					textBodyAttrs.put("paddingBottom", marginBottom.intValue() / 360);
-				}
-				
-				// default is square
-	 			final STTextWrappingType wrap = textBodyProperties.getWrap();
-				if(wrap!=null) {
-					textBodyAttrs.put("wordWrap", wrap==STTextWrappingType.NONE ? false : true);
-				}
+			// false is default
+			final Boolean anchorCentered = textBodyProperties.isAnchorCtr();
+			if(anchorCentered!=null) {
+				textBodyAttrs.put("anchorCentered", anchorCentered.booleanValue());
+			}
 
-				// default is overflow
-				final STTextHorzOverflowType horzOverflow = textBodyProperties.getHorzOverflow();
-				if(horzOverflow!=null) {
-					textBodyAttrs.put("horzOverflow", horzOverflow==STTextHorzOverflowType.CLIP ? "clip" : "overflow");
-				}
+			// default 2,5mm
+			final Integer marginLeft = textBodyProperties.getLIns();
+			if(marginLeft!=null) {
+				textBodyAttrs.put("paddingLeft", marginLeft.intValue() / 360);
+			}
 
-				final CTTextShapeAutofit spAutoFit = textBodyProperties.getSpAutoFit();
-                if(spAutoFit!=null) {
-                	textBodyAttrs.put("autoResizeHeight", true);
-                }
+			// default 2,5mm
+			final Integer marginRight = textBodyProperties.getRIns();
+			if(marginRight!=null) {
+				textBodyAttrs.put("paddingRight", marginRight.intValue() / 360);
+			}
 
-				// default is overflow
-				final STTextVertOverflowType vertOverflow = textBodyProperties.getVertOverflow();
-				if(vertOverflow!=null) {
-					String o = null;
-					switch(vertOverflow) {
-						case CLIP: {
-							o = "clip";
-							break;
-						}
-						case ELLIPSIS: {
-							o = "ellipsis";
-							break;
-						}
-						case OVERFLOW : {
-							o = "overflow";
-							break;
-						}
+			// default 1,25mm
+			final Integer marginTop = textBodyProperties.getTIns();
+			if(marginTop!=null) {
+				textBodyAttrs.put("paddingTop", marginTop.intValue() / 360);
+			}
+
+			// default 1,25mm
+			final Integer marginBottom = textBodyProperties.getBIns();
+			if(marginBottom!=null) {
+				textBodyAttrs.put("paddingBottom", marginBottom.intValue() / 360);
+			}
+			
+			// default is square
+ 			final STTextWrappingType wrap = textBodyProperties.getWrap();
+			if(wrap!=null) {
+				textBodyAttrs.put("wordWrap", wrap==STTextWrappingType.NONE ? false : true);
+			}
+
+			// default is overflow
+			final STTextHorzOverflowType horzOverflow = textBodyProperties.getHorzOverflow();
+			if(horzOverflow!=null) {
+				textBodyAttrs.put("horzOverflow", horzOverflow==STTextHorzOverflowType.CLIP ? "clip" : "overflow");
+			}
+
+			final CTTextShapeAutofit spAutoFit = textBodyProperties.getSpAutoFit();
+            if(spAutoFit!=null) {
+            	textBodyAttrs.put("autoResizeHeight", true);
+            }
+            
+            final CTTextNoAutofit noAutoFit = textBodyProperties.getNoAutofit();
+            if(noAutoFit!=null) {
+                textBodyAttrs.put("noAutoResize", true);
+            }
+
+            final CTTextNormalAutofit normAutoFit = textBodyProperties.getNormAutofit();
+            if( normAutoFit != null) {
+                textBodyAttrs.put("autoResizeText", true);
+                
+                textBodyAttrs.put("fontScale", ((double)normAutoFit.getFontScale()) / 100000.0);
+                textBodyAttrs.put("lineReduction", ((double)normAutoFit.getLnSpcReduction()) / 100000.0);
+            }
+
+            final STTextVerticalType textVerticalType = textBodyProperties.getVert();
+            if(textVerticalType!=null) {
+            	textBodyAttrs.put("vert", textVerticalType.value());
+            }
+
+            // default is overflow
+			final STTextVertOverflowType vertOverflow = textBodyProperties.getVertOverflow();
+			if(vertOverflow!=null) {
+				String o = null;
+				switch(vertOverflow) {
+					case CLIP: {
+						o = "clip";
+						break;
 					}
-					if(o!=null) {
-						textBodyAttrs.put("vertOverflow", o);
+					case ELLIPSIS: {
+						o = "ellipsis";
+						break;
 					}
+					case OVERFLOW : {
+						o = "overflow";
+						break;
+					}
+				}
+				if(o!=null) {
+					textBodyAttrs.put("vertOverflow", o);
 				}
 			}
 	        if(initialTextBodyAttrs==null&&!textBodyAttrs.isEmpty()) {
@@ -1899,14 +2052,64 @@ final public class DMLHelper {
 	    			break;
 	    		}
 	    		case "autoResizeHeight" : {
-	                if(value instanceof Boolean) {
-	                    bodyPr.setSpAutoFit(((Boolean)value).booleanValue()?Context.getDmlObjectFactory().createCTTextShapeAutofit():null);
+	                if(value instanceof Boolean && ((Boolean)value).booleanValue()) {
+	                    bodyPr.setSpAutoFit(Context.getDmlObjectFactory().createCTTextShapeAutofit());
 	                }
 	                else {
 	                    bodyPr.setSpAutoFit(null);
 	                }
 	    			break;
 	    		}
+	    		case "autoResizeText" : {
+                    if(value instanceof Boolean && ((Boolean)value).booleanValue()) {
+                        if (null == bodyPr.getNormAutofit()) {
+                            bodyPr.setNormAutofit(Context.getDmlObjectFactory().createCTTextNormalAutofit());
+                        }
+                    }
+                    else {
+                        bodyPr.setNormAutofit(null);
+                    }
+                    break;
+                }
+	    		case "noAutoResize" : {
+                    if(value instanceof Boolean && ((Boolean)value).booleanValue()) {
+                        bodyPr.setNoAutofit(Context.getDmlObjectFactory().createCTTextNoAutofit());
+                    }
+                    else {
+                        bodyPr.setNoAutofit(null);
+                    }
+                    break;
+                }
+	    		case "fontScale" : {
+                    CTTextNormalAutofit fit = bodyPr.getNormAutofit();
+                    if (null == fit) {
+                        fit = Context.getDmlObjectFactory().createCTTextNormalAutofit();
+                        bodyPr.setNormAutofit(fit);
+                    }
+                    
+                    if(value instanceof Number) {
+                        fit.setFontScale((int) (((Number)value).doubleValue() * 100000.0));
+                    }
+                    else {
+                        fit.setFontScale(null);
+                    }
+                    break;
+                }
+	    		case "lineReduction" : {
+                    CTTextNormalAutofit fit = bodyPr.getNormAutofit();
+                    if (null == fit) {
+                        fit = Context.getDmlObjectFactory().createCTTextNormalAutofit();
+                        bodyPr.setNormAutofit(fit);
+                    }
+                    
+                    if(value instanceof Number) {
+                        fit.setLnSpcReduction((int) (((Number)value).doubleValue() * 100000.0));
+                    }
+                    else {
+                        fit.setLnSpcReduction(null);
+                    }
+                    break;
+                }
 	    		case "anchor" : {
 	    			STTextAnchoringType anchor = null;
 	    			if(value instanceof String) {
@@ -1952,6 +2155,14 @@ final public class DMLHelper {
 	    			bodyPr.setWrap(wordWrap);
 	    			break;
 	    		}
+	    		case "vert" : {
+	    			STTextVerticalType textVerticalType = null;
+	                if(value instanceof String) {
+	                	textVerticalType = STTextVerticalType.fromValue((String)value);
+	                }
+	                bodyPr.setVert(textVerticalType);
+	                break;
+	    		}
 	    		case "horzOverflow" : {
 	    			STTextHorzOverflowType horzOverflowType = null;
 	    			if(value instanceof String) {
