@@ -51,8 +51,6 @@ package com.openexchange.office.ooxml.drawingml;
 
 import org.docx4j.dml.CTGroupShapeProperties;
 import org.docx4j.dml.CTGroupTransform2D;
-import org.docx4j.dml.CTPoint2D;
-import org.docx4j.dml.CTPositiveSize2D;
 import org.docx4j.dml.IGroupShape;
 import org.docx4j.jaxb.Context;
 import org.docx4j.openpackaging.exceptions.InvalidFormatException;
@@ -68,39 +66,25 @@ public class GroupShape {
 		throws JSONException, InvalidFormatException, PartUnrecognisedException {
 
         DMLHelper.applyNonVisualDrawingProperties(group, attrs.optJSONObject("drawing"));
+        DMLHelper.applyNonVisualDrawingShapeProperties(group, attrs.optJSONObject("drawing"));
 	    CTGroupShapeProperties groupProperties = group.getGrpSpPr();
 		if(groupProperties==null) {
 			groupProperties = Context.getDmlObjectFactory().createCTGroupShapeProperties();
 			group.setGrpSpPr(groupProperties);
 		}
-		CTGroupTransform2D groupTransform2d = groupProperties.getXfrm();
-		if(groupTransform2d==null) {
-		    groupTransform2d = Context.getDmlObjectFactory().createCTGroupTransform2D();
-		    groupProperties.setXfrm(groupTransform2d);
-		}
-		DMLHelper.applyTransform2DFromJson(groupTransform2d, attrs);
-		// now applying the size and pos of the childs
-		final CTPoint2D chPos = Context.getDmlObjectFactory().createCTPoint2D();
-		chPos.setX(0);
-		chPos.setY(0);
-		groupTransform2d.setChOff(chPos);
-		final CTPositiveSize2D ex = groupTransform2d.getExt();
-		if(ex!=null) {
-		    final CTPositiveSize2D chEx = Context.getDmlObjectFactory().createCTPositiveSize2D();
-		    chEx.setCx(ex.getCx());
-		    chEx.setCy(ex.getCy());
-		    groupTransform2d.setChExt(chEx);
-		}
+		DMLHelper.applyTransform2DFromJson(groupProperties, attrs);
 		DMLHelper.applyFillPropertiesFromJson(groupProperties, attrs, null, null);
 	}
 
     public static void createJSONAttrs(OperationDocument operationDocument, JSONObject attrs, IGroupShape groupShape)
     	throws JSONException {
 
-        DMLHelper.createJsonFromNonVisualDrawingProperties(attrs, groupShape.getCNvPr());
+        DMLHelper.createJsonFromNonVisualDrawingProperties(attrs, groupShape);
+        DMLHelper.createJsonFromNonVisualDrawingShapeProperties(attrs, groupShape);
+
         final CTGroupShapeProperties groupProperties = groupShape.getGrpSpPr();
 		if(groupProperties!=null) {
-	        final CTGroupTransform2D groupTransform =groupProperties.getXfrm();
+	        final CTGroupTransform2D groupTransform =groupProperties.getXfrm(false);
 	        if(groupTransform!=null) {
 	        	DMLHelper.createJsonFromTransform2D(attrs, groupTransform);
 	        }
