@@ -51,7 +51,6 @@ package com.openexchange.office.ooxml.drawingml;
 
 import org.docx4j.dml.CTBlip;
 import org.docx4j.dml.CTBlipFillProperties;
-import org.docx4j.dml.CTNonVisualDrawingProps;
 import org.docx4j.dml.IPicture;
 import org.docx4j.jaxb.Context;
 import org.docx4j.openpackaging.exceptions.InvalidFormatException;
@@ -72,6 +71,7 @@ public class Picture {
     	    throws JSONException, InvalidFormatException, PartUnrecognisedException {
 
         DMLHelper.applyNonVisualDrawingProperties(pic, attrs.optJSONObject("drawing"));
+        DMLHelper.applyNonVisualDrawingShapeProperties(pic, attrs.optJSONObject("drawing"));
 	    pic.setSpPr(DMLHelper.applyShapePropertiesFromJson(pic.getSpPr(), attrs, operationDocument, part));
         final JSONObject imageAttrs = attrs.optJSONObject("image");
         if(imageAttrs!=null) {
@@ -110,10 +110,8 @@ public class Picture {
     public static void createJSONAttrs(OperationDocument operationDocument, JSONObject attrs, Part part, IPicture pic)
     	throws JSONException, FilterException {
 
-    	final CTNonVisualDrawingProps nonVisualDrawingProps = pic.getCNvPr();
-        if(nonVisualDrawingProps!=null) {
-            DMLHelper.createJsonFromNonVisualDrawingProperties(attrs, nonVisualDrawingProps);
-        }
+        DMLHelper.createJsonFromNonVisualDrawingProperties(attrs, pic);
+        DMLHelper.createJsonFromNonVisualDrawingShapeProperties(attrs, pic);
         final CTBlipFillProperties blipFillProperties = pic.getBlipFill();
         if(blipFillProperties!=null) {
 			final JSONObject imageAttrs = new JSONObject();
@@ -122,6 +120,6 @@ public class Picture {
             	attrs.put("image", imageAttrs);
             }
         }
-        DMLHelper.createJsonFromShapeProperties(attrs, pic.getSpPr(), operationDocument.getTheme(true), pic.getStyle(), part, true);
+        DMLHelper.createJsonFromShapeProperties(attrs, pic.getSpPr(), operationDocument.getThemePart(true), pic.getStyle(), part, true);
     }
 }
