@@ -65,6 +65,7 @@ public class Shape {
 
     	DMLHelper.applyTextBodyPropertiesFromJson(shape.getTextBodyProperties(true), attrs);
         DMLHelper.applyNonVisualDrawingProperties(shape, attrs.optJSONObject("drawing"));
+        DMLHelper.applyNonVisualDrawingShapeProperties(shape, attrs.optJSONObject("drawing"));
 	    shape.setSpPr(DMLHelper.applyShapePropertiesFromJson(shape.getSpPr(), attrs, operationDocument, operationDocument.getContextPart()));
     }
 
@@ -72,7 +73,8 @@ public class Shape {
     	throws JSONException, FilterException {
 
     	DMLHelper.createJsonFromTextBodyProperties(attrs, shape.getTextBodyProperties(false));
-    	DMLHelper.createJsonFromNonVisualDrawingProperties(attrs, shape.getCNvPr());
-        DMLHelper.createJsonFromShapeProperties(attrs, shape.getSpPr(), operationDocument.getTheme(true), shape.getStyle(), operationDocument.getContextPart(), true);
+    	DMLHelper.createJsonFromNonVisualDrawingProperties(attrs, shape);
+    	DMLHelper.createJsonFromNonVisualDrawingShapeProperties(attrs, shape);
+        DMLHelper.createJsonFromShapeProperties(attrs, shape.getSpPr(), operationDocument.getThemePart(true), shape.getStyle(), operationDocument.getContextPart(), true);
     }
 }
