@@ -53,6 +53,7 @@ import org.docx4j.dml.CTColorMapping;
 import org.docx4j.dml.CTColorScheme;
 import org.docx4j.dml.STColorSchemeIndex;
 import org.docx4j.dml.Theme;
+import org.docx4j.openpackaging.exceptions.InvalidFormatException;
 import org.json.JSONArray;
 import org.json.JSONException;
 import org.json.JSONObject;
@@ -78,12 +79,12 @@ abstract public class CreateOperationHelper {
     abstract public OperationDocument getOperationDocument();
 
     abstract public void createDocumentDefaults(String userLanguage)
-        throws Exception;
+    	throws InvalidFormatException, JSONException;
 
     public void createThemeOperations(String target, CTColorMapping colorMapping)
         throws FilterException, JSONException {
 
-    	final Theme theme = getOperationDocument().getTheme(true);
+    	final Theme theme = getOperationDocument().getThemePart(true).getJaxbElement();
 
     	String themeName = theme.getName();
         CTColorScheme colorScheme = theme.getThemeElements().getClrScheme();
@@ -125,7 +126,7 @@ abstract public class CreateOperationHelper {
             final JSONObject setDocumentAttributesObject = new JSONObject(2);
             setDocumentAttributesObject.put("name", "setDocumentAttributes");
             setDocumentAttributesObject.put("attrs", attrs);
-            operationsArray.put(0, setDocumentAttributesObject);
+            operationsArray.put(setDocumentAttributesObject);
         }
     }
 
@@ -144,7 +145,7 @@ abstract public class CreateOperationHelper {
         operationsArray.put(insertThemeObject);
     }
 
-    public JSONObject createInsertStyleSheetOperation(String type, String styleId, String styleName, JSONObject attrs, String parentId, Boolean hidden, Integer uipriority, Boolean isDefault, Boolean custom, boolean auto)
+    public JSONObject createInsertStyleSheetOperation(String type, String styleId, String styleName, JSONObject attrs, String parentId, Boolean hidden, Integer uipriority, Boolean isDefault, Boolean custom)
         throws JSONException {
 
         final JSONObject insertStylesheetObject = new JSONObject();
@@ -162,12 +163,23 @@ abstract public class CreateOperationHelper {
             insertStylesheetObject.put("uiPriority", uipriority);
         if(isDefault!=null&&isDefault)
             insertStylesheetObject.put("default", true);
-        if(auto==true) {
-            insertStylesheetObject.put("auto", auto);
-        }
         if(custom!=null) {
             insertStylesheetObject.put("custom", custom);
         }
         return insertStylesheetObject;
     }
+
+    public JSONObject createInsertAutoStyleOperation(String type, String styleId, JSONObject attrs, boolean isDefault)
+        throws JSONException {
+
+        final JSONObject insertStylesheetObject = new JSONObject(5);
+        insertStylesheetObject.put("name", "insertAutoStyle");
+        insertStylesheetObject.put("type", type);
+        insertStylesheetObject.put("styleId", styleId);
+        if(attrs!=null)
+            insertStylesheetObject.put("attrs", attrs);
+        if(isDefault)
+            insertStylesheetObject.put("default", true);
+        return insertStylesheetObject;
+    }
 }
