@@ -90,10 +90,10 @@ public class OfficeActivator extends HousekeepingActivator {
     protected void startBundle() throws Exception {
         boolean registered = false;
 
-        LOG.info("Starting Operation bundle: " + m_serviceName);
+        LOG.debug("Starting Operation bundle: " + m_serviceName);
 
         try {
-            LOG.info("Starting OOXML filter: " + m_serviceName);
+            LOG.debug("Starting OOXML filter: " + m_serviceName);
 
             // register docx4j im- and exporter
             final com.openexchange.office.ooxml.docx.Importer docxImporter = new com.openexchange.office.ooxml.docx.Importer(this);
@@ -120,12 +120,12 @@ public class OfficeActivator extends HousekeepingActivator {
             // set flag for successful registering
             registered = true;
         } catch (Throwable e) {
-            LOG.info("FAILED - Starting OOXML filter: " + m_serviceName + e);
+            LOG.debug("FAILED - Starting OOXML filter: " + m_serviceName + e);
             LOG.error("Office bundle was not completly loaded", e);
             throw new Exception(e);
         }
         try {
-            LOG.info("Starting ODF filter: " + m_serviceName);
+            LOG.debug("Starting ODF filter: " + m_serviceName);
             // register ODFDOM im- and exporter
             final com.openexchange.office.odf.Importer odfImporter = new com.openexchange.office.odf.Importer(this);
             registerService(com.openexchange.office.odf.Importer.class, odfImporter);
@@ -133,18 +133,18 @@ public class OfficeActivator extends HousekeepingActivator {
             final com.openexchange.office.odf.Exporter odfExporter = new com.openexchange.office.odf.Exporter(this);
             registerService(com.openexchange.office.odf.Exporter.class, odfExporter);
         } catch (Throwable e) {
-            LOG.info("FAILED - Starting ODF filter: " + m_serviceName + e);
+            LOG.debug("FAILED - Starting ODF filter: " + m_serviceName + e);
             LOG.error("Office bundle was not completly loaded", e);
             throw new Exception(e);
         }
         try {
 
-            LOG.info("Starting Resource Provider: " + m_serviceName);
+            LOG.debug("Starting Resource Provider: " + m_serviceName);
             // register resource provider
             final ResourceProvider resourceProvider = new ResourceProvider();
             registerService(IResourceProvider.class, resourceProvider);
         } catch (Throwable e) {
-            LOG.info("FAILED - Starting Resource Provider: " + m_serviceName + e);
+            LOG.debug("FAILED - Starting Resource Provider: " + m_serviceName + e);
             LOG.error("Office bundle was not completly loaded", e);
             throw new Exception(e);
         }
