@@ -115,7 +115,7 @@ public class PresenterActivator extends HousekeepingActivator {
     protected void stopBundle() throws Exception {
         if (!shutdownProcessed) {
 
-            LOG.info("stopping bundle: " + serviceName);
+            LOG.debug("stopping bundle: " + serviceName);
 
             if (null != component) {
             	component.shutdown();
@@ -137,7 +137,7 @@ public class PresenterActivator extends HousekeepingActivator {
         lock.lock();
         try {
             if (!shutdownProcessed) {
-                LOG.info("bundle: " + serviceName + " detected that a required service was removed.");
+                LOG.debug("bundle: " + serviceName + " detected that a required service was removed.");
                 stopBundle();
                 shutdownProcessed = true;
             }
