@@ -853,6 +853,31 @@ abstract class Connection extends GroupDispatcher {
         }
     }
 
+    /**
+     * Sends a "alive" message to the client losing edit rights. This must be acknowledged by the client
+     * to extend the switching timeout to save/calculate the document.
+     *
+     * @param fromId the client that sends the "alive" message - normally the client that loses edit rights
+     * @param toId the client that loses edit rights
+     * @param statusToSend the status to be sent to the client
+     */
+    protected void sendAliveMsg(final ID fromId, final ID toId, final ConnectionStatus statusToSend) throws Exception {
+        Validate.notNull(fromId, "Without fromId no send alive message!");
+        Validate.notNull(toId, "Without toId no send alive message!");
+        Validate.notNull(statusToSend, "Connection status to be sent must be set!");
+
+        final MessageData messageData = new MessageData(null, statusToSend, null);
+        final Message returnMessage = new Message();
+
+        returnMessage.setFrom(fromId);
+        returnMessage.addPayload(new PayloadTree(PayloadTreeNode.builder().withPayload(
+            new PayloadElement(messageData, MessageData.class.getName(), m_componentID, "alive")).build()));
+
+        LOG.debug("RT connection: send alive message to : " + toId.toString());
+
+        relayToID(returnMessage, toId);
+    }
+
     /**
      * Logs optional performance data.
      *
