@@ -184,7 +184,7 @@ public abstract class ConnectionComponent extends AbstractRealtimeJanitor implem
             m_openConnections.put(id, connection);
             onConnectionCreated(id);
 
-            LOG.debug("RT connection: New document created with ID: " + id.toString() + ", connection count: " + m_openConnections.size());
+            LOG.debug("RT connection: New document created with ID: " + id.toString() + ", connection instance count: " + m_openConnections.size());
         }
 
         return connection;
