@@ -58,15 +58,18 @@ import com.openexchange.office.IImporter;
 import com.openexchange.office.doc.imexport.ImExportHelper;
 import com.openexchange.office.doc.imexport.ImporterPropertyHelper;
 import com.openexchange.office.realtime.doc.DocumentEventHelper;
+import com.openexchange.office.realtime.impl.ChunkableDocLoader;
 import com.openexchange.office.realtime.impl.ConnectionStatus;
 import com.openexchange.office.realtime.impl.DocumentConnection;
 import com.openexchange.office.realtime.tools.DebugHelper;
 import com.openexchange.office.realtime.tools.MessageData;
 import com.openexchange.office.tools.doc.DocContextLogger;
+import com.openexchange.office.tools.doc.DocumentMetaData;
 import com.openexchange.office.tools.doc.OXDocument;
 import com.openexchange.office.tools.doc.OXDocumentException;
 import com.openexchange.office.tools.error.ErrorCode;
 import com.openexchange.office.tools.error.FilterExceptionToErrorCode;
+import com.openexchange.office.tools.htmldoc.GenericHtmlDocumentBuilder;
 import com.openexchange.office.tools.message.MessageChunk;
 import com.openexchange.office.tools.message.MessageHelper;
 import com.openexchange.office.tools.message.MessagePropertyKey;
@@ -85,11 +88,11 @@ import com.openexchange.server.ServiceLookup;
 import com.openexchange.tools.session.ServerSession;
 
 /**
- * Text-specific implementation of a DocumentConection. This class provides methods
+ * Presentation-specific implementation of a DocumentConection. This class provides methods
  * to handle the text-specific requests, loading/saving text documents.
  *
  * @author Carsten Driesner
- * @since 7.8.0
+ * @since 7.8.2
  */
 public class PresentationConnection extends DocumentConnection {
     @SuppressWarnings( "deprecation" )
@@ -123,7 +126,7 @@ public class PresentationConnection extends DocumentConnection {
             // which cannot be processed correctly in some cases, if the session storage hazelcast bundle
             // is not started!!
             if ((null == serverSession) || (!isSessionIdAccessbile(userData.getSessionId()))) {
-                return impl_handleError4Welcome(onBehalfOf, serverSession, ErrorCode.GENERAL_SERVER_COMPONENT_NOT_WORKING_ERROR, userData.getFolderId(), userData.getFileId());
+                return impl_handleError4Welcome(onBehalfOf, serverSession, ErrorCode.GENERAL_SESSION_COMPONENT_NOT_WORKING_ERROR, userData.getFolderId(), userData.getFileId());
             }
 
             // Check global save state - stop and provide error message, if global save is set!
@@ -174,8 +177,20 @@ public class PresentationConnection extends DocumentConnection {
                     final IImporter importer = ImExportHelper.getImporter(getServices(), getFileHelper());
                     ImporterPropertyHelper.setMemoryImporterProperties(importerProps);
 
-                    // load the whole document as a fall back for missing preview capabilities
-                    final JSONObject documentOperations = oxDocument.getOperations(importer, importerProps, null);
+                    final JSONObject documentOperations = new JSONObject();
+                    final ChunkableDocLoader chunkDocLoader = new ChunkableDocLoader(oxDocument, importer, importerProps);
+                    chunkDocLoader.prepareLoad();
+
+                    // presentation loads the complete document - will be changed in the future
+                    OperationHelper.appendJSON(documentOperations, chunkDocLoader.getGlobalOperations());
+                    OperationHelper.appendJSON(documentOperations, chunkDocLoader.getActiveOperations());
+                    OperationHelper.appendJSON(documentOperations,  chunkDocLoader.getRemainingOperations());
+
+                    final String module = "presentation";
+                    final ServiceLookup services = getServices();
+                    if (GenericHtmlDocumentBuilder.isFastLoadActive(module, services, serverSession)) {
+                        genericHtmlDocument = GenericHtmlDocumentBuilder.buildHtmlDocument(module, documentOperations, oxDocument.getMetaData(), services, serverSession);
+                    }
                     OperationHelper.appendJSON(operations, documentOperations);
                 } catch (final FilterException e) {
                     errorCode = ErrorCode.LOADDOCUMENT_CANNOT_RETRIEVE_OPERATIONS_ERROR;
@@ -197,7 +212,7 @@ public class PresentationConnection extends DocumentConnection {
                             final String freeMemString = (memInfo == null) ? "unknown" : ((Long) ((memInfo.maxHeapSize - memInfo.usedHeapSize) / SystemInfoHelper.MBYTES)).toString();
                             LOG.info("Document could not be loaded, because current available heap space is not sufficient. Current free heap space: " + freeMemString + " MB");
                         }                    }
-                } catch (final Exception e) {
+                } catch (final Throwable e) {
                     errorCode = ErrorCode.LOADDOCUMENT_FAILED_ERROR;
                     LOG.warn("RT connection: getWelcomeMessage, Exception caught", e);
                 }
@@ -209,7 +224,7 @@ public class PresentationConnection extends DocumentConnection {
                 return welcomeMessage;
             }
 
-            welcomeMessage = impl_createWelcomeMessage(onBehalfOf, operations, documentOSN, false, genericHtmlDocument, -1, false, oxDocument.getDocumentMetaData());
+            welcomeMessage = impl_createWelcomeMessage(onBehalfOf, operations, documentOSN, false, genericHtmlDocument, 0, oxDocument.getDocumentMetaData());
 
             // update recent file list on open file now
             impl_addToRecentFileList(oxDocument.getDocumentMetaData(), serverSession);
@@ -410,7 +425,7 @@ public class PresentationConnection extends DocumentConnection {
             final UserData userData = this.getUserData(id);
 
             if (isSaveOnDispose()) {
-                flushDocument(MessageHelper.getServerSession(null, id), userData, true, true, false, false);
+                flushDocument(MessageHelper.getServerSession(null, id), userData, true, true, false, false, false);
             }
             impl_resetConnectionStatusOnDispose();
         } catch (Throwable e) {
