@@ -58,6 +58,7 @@ import com.openexchange.office.IImporter;
 import com.openexchange.office.doc.imexport.ImExportHelper;
 import com.openexchange.office.doc.imexport.ImporterPropertyHelper;
 import com.openexchange.office.realtime.doc.DocumentEventHelper;
+import com.openexchange.office.realtime.impl.ChunkableDocLoader;
 import com.openexchange.office.realtime.impl.ConnectionStatus;
 import com.openexchange.office.realtime.impl.DocumentConnection;
 import com.openexchange.office.realtime.tools.DebugHelper;
@@ -124,7 +125,7 @@ public class TextConnection extends DocumentConnection {
             // which cannot be processed correctly in some cases, if the session storage hazelcast bundle
             // is not started!!
             if ((null == serverSession) || (!isSessionIdAccessbile(userData.getSessionId()))) {
-                return impl_handleError4Welcome(onBehalfOf, serverSession, ErrorCode.GENERAL_SERVER_COMPONENT_NOT_WORKING_ERROR, userData.getFolderId(), userData.getFileId());
+                return impl_handleError4Welcome(onBehalfOf, serverSession, ErrorCode.GENERAL_SESSION_COMPONENT_NOT_WORKING_ERROR, userData.getFolderId(), userData.getFileId());
             }
 
             // Check global save state - stop and provide error message, if global save is set!
@@ -175,12 +176,19 @@ public class TextConnection extends DocumentConnection {
                     final IImporter importer = ImExportHelper.getImporter(getServices(), getFileHelper());
                     ImporterPropertyHelper.setMemoryImporterProperties(importerProps);
 
-                    // load the whole document as a fall back for missing preview capabilities
-                    final JSONObject documentOperations = oxDocument.getOperations(importer, importerProps, null);
+                    final JSONObject documentOperations = new JSONObject();
+                    final ChunkableDocLoader chunkDocLoader = new ChunkableDocLoader(oxDocument, importer, importerProps);
+                    chunkDocLoader.prepareLoad();
 
+                    // text loads the complete document
+                    OperationHelper.appendJSON(documentOperations, chunkDocLoader.getGlobalOperations());
+                    OperationHelper.appendJSON(documentOperations, chunkDocLoader.getActiveOperations());
+                    OperationHelper.appendJSON(documentOperations, chunkDocLoader.getRemainingOperations());
+
+                    final String module = "text";
                     final ServiceLookup services = getServices();
-                    if (GenericHtmlDocumentBuilder.isFastLoadActive(services, serverSession)) {
-                        genericHtmlDocument = GenericHtmlDocumentBuilder.buildHtmlDocument(documentOperations, oxDocument.getMetaData(), services, serverSession);
+                    if (GenericHtmlDocumentBuilder.isFastLoadActive(module, services, serverSession)) {
+                        genericHtmlDocument = GenericHtmlDocumentBuilder.buildHtmlDocument(module, documentOperations, oxDocument.getMetaData(), services, serverSession);
                     }
                     OperationHelper.appendJSON(operations, documentOperations);
                 } catch (final FilterException e) {
@@ -203,7 +211,7 @@ public class TextConnection extends DocumentConnection {
                         // all other exceptions are mapped by general aspects
                         errorCode = FilterExceptionToErrorCode.map(e, errorCode);
                     }
-                } catch (final Exception e) {
+                } catch (final Throwable e) {
                     errorCode = ErrorCode.LOADDOCUMENT_FAILED_ERROR;
                     LOG.warn("RT connection: getWelcomeMessage, Exception caught", e);
                 }
@@ -215,7 +223,7 @@ public class TextConnection extends DocumentConnection {
                 return welcomeMessage;
             }
 
-            welcomeMessage = impl_createWelcomeMessage(onBehalfOf, operations, documentOSN, false, genericHtmlDocument, -1, false, oxDocument.getDocumentMetaData());
+            welcomeMessage = impl_createWelcomeMessage(onBehalfOf, operations, documentOSN, false, genericHtmlDocument, 0, oxDocument.getDocumentMetaData());
 
             // update recent file list on open file now
             impl_addToRecentFileList(oxDocument.getDocumentMetaData(), serverSession);
@@ -413,7 +421,7 @@ public class TextConnection extends DocumentConnection {
             final UserData userData = this.getUserData(id);
 
             if (isSaveOnDispose()) {
-                flushDocument(MessageHelper.getServerSession(null, id), userData, true, true, false, false);
+                flushDocument(MessageHelper.getServerSession(null, id), userData, true, true, false, false, false);
             }
             impl_resetConnectionStatusOnDispose();
         } catch (Throwable e) {
