@@ -51,14 +51,12 @@ package com.openexchange.office.realtime.osgi;
 
 import java.util.concurrent.locks.Lock;
 import java.util.concurrent.locks.ReentrantLock;
-
 import org.apache.commons.logging.Log;
-
 import com.openexchange.capabilities.CapabilityService;
 import com.openexchange.config.ConfigurationService;
 import com.openexchange.context.ContextService;
 import com.openexchange.conversion.simple.SimplePayloadConverter;
-import com.openexchange.documentconverter.IManager;
+import com.openexchange.documentconverter.IDocumentConverter;
 import com.openexchange.file.storage.composition.IDBasedFileAccessFactory;
 import com.openexchange.file.storage.composition.IDBasedFolderAccessFactory;
 import com.openexchange.filemanagement.DistributedFileManagement;
@@ -67,7 +65,8 @@ import com.openexchange.folderstorage.FolderService;
 import com.openexchange.jslob.JSlobService;
 import com.openexchange.office.IResourceProvider;
 import com.openexchange.office.backup.manager.DocumentBackupController;
-import com.openexchange.office.calcengine.client.CalcEngineClientFactory;
+// TODO: rm calcengine code
+// import com.openexchange.office.calcengine.client.CalcEngineClientFactory;
 import com.openexchange.office.hazelcast.doc.DocSaveStateDirectory;
 import com.openexchange.office.hazelcast.doc.DocumentDirectory;
 import com.openexchange.office.realtime.impl.ConnectionBackgroundProcessorManager;
@@ -110,7 +109,6 @@ public class ConnectionActivator extends HousekeepingActivator {
             FolderService.class,
             ManagedFileManagement.class,
             DistributedFileManagement.class,
-            CalcEngineClientFactory.class,
             UserService.class,
             TimerService.class,
             com.openexchange.sessiond.SessiondService.class,
@@ -130,7 +128,7 @@ public class ConnectionActivator extends HousekeepingActivator {
     @Override
     protected Class<?>[] getOptionalServices() {
         return new Class<?>[] {
-            IManager.class
+            IDocumentConverter.class
         };
     }
 
@@ -141,7 +139,7 @@ public class ConnectionActivator extends HousekeepingActivator {
     protected void startBundle() throws Exception {
         Services.setServiceLookup(this);
 
-        LOG.info("starting bundle: " + m_serviceName);
+        LOG.debug("starting bundle: " + m_serviceName);
 
         // Register the components
         registerService(Component.class, textComponent = new TextComponent(this));
@@ -182,7 +180,7 @@ public class ConnectionActivator extends HousekeepingActivator {
     protected void stopBundle() throws Exception {
         if (!shutdownProcessed) {
 
-            LOG.info("stopping bundle: " + m_serviceName);
+            LOG.debug("stopping bundle: " + m_serviceName);
 
             if (null != m_backgroundProcesses) {
                 m_backgroundProcesses.shutdown();
@@ -214,7 +212,7 @@ public class ConnectionActivator extends HousekeepingActivator {
         lock.lock();
         try {
             if (!shutdownProcessed) {
-                LOG.info("bundle: " + m_serviceName + " detected that a required service was removed.");
+                LOG.debug("bundle: " + m_serviceName + " detected that a required service was removed.");
                 stopBundle();
                 shutdownProcessed = true;
             }
@@ -238,6 +236,6 @@ public class ConnectionActivator extends HousekeepingActivator {
     private ConnectionComponent textComponent = null;
 
     private ConnectionComponent calcComponent = null;
-    
+
     private ConnectionComponent presComponent = null;
 }
