@@ -76,7 +76,8 @@ import com.openexchange.office.IResourceProvider;
  */
 public class ResourceProvider implements IResourceProvider {
 
-    private ArrayList<IResourceEntry> entries = new ArrayList<IResourceEntry>();
+    private volatile boolean          initialized = false;
+    private ArrayList<IResourceEntry> entries     = new ArrayList<IResourceEntry>();
 
     /**
      * Initializes a new {@link ResourceProvider}.
@@ -85,50 +86,69 @@ public class ResourceProvider implements IResourceProvider {
     }
 
     /**
-     * @return true in case the entry list has been correctly initialized
+     * @return true in case the entry list has been initialized
      */
     protected boolean initEntries() {
-        if (entries.isEmpty()) {
-            InputStream inputStm = null;
+        boolean isInit = initialized;
 
-            try {
-                final DocumentBuilderFactory factory = DocumentBuilderFactory.newInstance();
+        if (!isInit) {
+            synchronized(this) {
+                isInit = initialized;
+                if (!isInit) {
+                    fillEntries();
+                    isInit = initialized = true;
+                }
+            }
+        }
 
-                if (null != factory) {
-                    final DocumentBuilder builder = factory.newDocumentBuilder();
-                    inputStm = this.getClass().getClassLoader().getResourceAsStream("/com/openexchange/office/resource/content.xml");
-                    final Document doc = ((null != builder) && (null != inputStm)) ? builder.parse(inputStm) : null;
+        return isInit;
+    }
 
-                    if (null != doc) {
-                        doc.getDocumentElement().normalize();
+    /**
+     * Fill the entries list - must be called thread-safe as the resource provider
+     * is used by several Grizzly instances in parallel.
+     * See #44066
+     */
+    protected void fillEntries() {
+        InputStream inputStm = null;
 
-                        final NodeList modules = doc.getElementsByTagName("module");
+        try {
+            final DocumentBuilderFactory factory = DocumentBuilderFactory.newInstance();
 
-                        for (int i = 0; i < modules.getLength(); ++i) {
-                            final Node module = modules.item(i);
+            if (null != factory) {
+                final DocumentBuilder builder = factory.newDocumentBuilder();
+                inputStm = this.getClass().getClassLoader().getResourceAsStream("/com/openexchange/office/resource/content.xml");
+                final Document doc = ((null != builder) && (null != inputStm)) ? builder.parse(inputStm) : null;
 
-                            if (Node.ELEMENT_NODE == module.getNodeType()) {
-                                final String moduleName = module.getAttributes().getNamedItem("name").getNodeValue();
-                                final NodeList groups = ((Element) module).getElementsByTagName("group");
+                if (null != doc) {
+                    doc.getDocumentElement().normalize();
 
-                                for (int j = 0; j < groups.getLength(); ++j) {
-                                    final Node group = groups.item(j);
+                    final NodeList modules = doc.getElementsByTagName("module");
 
-                                    if (Node.ELEMENT_NODE == group.getNodeType()) {
-                                        final String groupName = group.getAttributes().getNamedItem("name").getNodeValue();
-                                        final NodeList resources = ((Element) group).getElementsByTagName("resource");
+                    for (int i = 0; i < modules.getLength(); ++i) {
+                        final Node module = modules.item(i);
 
-                                        for (int k = 0; k < resources.getLength(); ++k) {
-                                            final Node resource = resources.item(k);
+                        if (Node.ELEMENT_NODE == module.getNodeType()) {
+                            final String moduleName = module.getAttributes().getNamedItem("name").getNodeValue();
+                            final NodeList groups = ((Element) module).getElementsByTagName("group");
 
-                                            if (Node.ELEMENT_NODE == resource.getNodeType()) {
-                                                final NamedNodeMap attribs = resource.getAttributes();
-                                                final String location = attribs.getNamedItem("location").getNodeValue();
-                                                final String name = attribs.getNamedItem("name").getNodeValue();
-                                                final String description = resource.getTextContent();
+                            for (int j = 0; j < groups.getLength(); ++j) {
+                                final Node group = groups.item(j);
 
-                                                entries.add(new ResourceEntry(moduleName, groupName, location, name, description));
-                                            }
+                                if (Node.ELEMENT_NODE == group.getNodeType()) {
+                                    final String groupName = group.getAttributes().getNamedItem("name").getNodeValue();
+                                    final NodeList resources = ((Element) group).getElementsByTagName("resource");
+
+                                    for (int k = 0; k < resources.getLength(); ++k) {
+                                        final Node resource = resources.item(k);
+
+                                        if (Node.ELEMENT_NODE == resource.getNodeType()) {
+                                            final NamedNodeMap attribs = resource.getAttributes();
+                                            final String location = attribs.getNamedItem("location").getNodeValue();
+                                            final String name = attribs.getNamedItem("name").getNodeValue();
+                                            final String description = resource.getTextContent();
+
+                                            entries.add(new ResourceEntry(moduleName, groupName, location, name, description));
                                         }
                                     }
                                 }
@@ -136,14 +156,12 @@ public class ResourceProvider implements IResourceProvider {
                         }
                     }
                 }
-            } catch (Exception e) {
-                //
-            } finally {
-                IOUtils.closeQuietly(inputStm);
             }
+        } catch (Exception e) {
+            //
+        } finally {
+            IOUtils.closeQuietly(inputStm);
         }
-
-        return !entries.isEmpty();
     }
 
     @Override
