@@ -53,7 +53,6 @@ import java.io.ByteArrayInputStream;
 import java.io.ByteArrayOutputStream;
 import java.io.IOException;
 import java.io.InputStream;
-import java.nio.charset.Charset;
 import java.util.Arrays;
 import java.util.Hashtable;
 import java.util.List;
@@ -96,6 +95,7 @@ import com.openexchange.office.tools.files.DocFileHelper.WriteInfo;
 import com.openexchange.office.tools.files.FileHelper;
 import com.openexchange.office.tools.json.JSONHelper;
 import com.openexchange.office.tools.message.MessageChunk;
+import com.openexchange.office.tools.message.MessagePropertyKey;
 import com.openexchange.office.tools.message.OperationHelper;
 import com.openexchange.office.tools.resource.Resource;
 import com.openexchange.office.tools.resource.ResourceManager;
@@ -132,6 +132,7 @@ public class OXDocument {
     private Session m_session = null;
     private DocumentFormat m_documentFormat = null;
     private boolean m_isTemplateDoc = false;
+    private boolean m_isRescueDoc = false;
     private final ServiceLookup m_services;
     private IPreviewImporter m_previewImporter = null;
     private DocumentProperties m_docProperties = null;
@@ -373,6 +374,7 @@ public class OXDocument {
                     } else if (entryName.equals(DocFileHelper.OX_RESCUEDOCUMENT_DOCUMENTSTREAM_NAME)) {
                         try {
                             // read original document
+                            m_isRescueDoc = true;
                             docBuffer = IOUtils.toByteArray(zipInputStm);
                         } catch (IOException e) {
                             LOG.error("RT connection: unable to retrieve original document stream, exception caught", e);
@@ -384,6 +386,7 @@ public class OXDocument {
                             // non continuous osn numbers lead to a load error in the frontend, so we have to remove them as some
                             // operations are filtered by the calcengine
                             operationsBuffer = op.replaceAll("\\\"osn\\\":[0-9]+,?", "").getBytes();
+                            m_isRescueDoc = true;
                         } catch (IOException e) {
                             LOG.error("RT connection: unable to retrieve operations stream, exception caught", e);
                         }
@@ -454,7 +457,7 @@ public class OXDocument {
             // set last error code using the stream info from the file helper getDocumentStream()
             m_lastErrorCode = streamInfo.getErrorCode();
             if (m_lastErrorCode.isNoError()) {
-                m_lastErrorCode = ErrorCode.GENERAL_UNKNOWN_ERROR;
+                m_lastErrorCode = ErrorCode.LOADDOCUMENT_FAILED_ERROR;
             }
             m_lastErrorCode = ErrorCode.setErrorClass(m_lastErrorCode, ErrorCode.ERRORCLASS_FATAL_ERROR);
             LOG.warn("OXDocument Ctor: could not retrieve a valid document buffer/meta data from given document file.");
@@ -482,7 +485,7 @@ public class OXDocument {
             // always higher or equal than the document osn
             boolean versionOk = (version==null)? (version == docVersion) : (version.equals(docVersion));
             boolean consistent = (versionOk && (docOSN <= osn));
-            LOG.info("RT connection: Consistency check between document file and last known version. Consistency result: " + consistent + " with last known version: " + version + ", osn: " + osn + " and document version: " + docVersion + ", osn: " + docOSN);
+            LOG.debug("RT connection: Consistency check between document file and last known version. Consistency result: " + consistent + " with last known version: " + version + ", osn: " + osn + " and document version: " + docVersion + ", osn: " + docOSN);
 
             return consistent;
         } else {
@@ -490,82 +493,6 @@ public class OXDocument {
         }
     }
 
-    /**
-     * Prepares the preview operations access which is mandatory if preview functions should be used.
-     *
-     * @param importer The importer instance to be used for the preview. The instance must support the IPreviewImporter interface otherwise
-     *            preview is not possible.
-     * @return TRUE if preview operations are possible otherwise FALSE.
-     */
-    public boolean preparePreviewOperations(IImporter importer, JSONObject importerProps) throws FilterException {
-        boolean result = false;
-
-        final Session session = m_session;
-
-        if ((importer instanceof IPreviewImporter) && (null != session)) {
-            final DocumentProperties documentProperties = new DocumentProperties();
-            m_previewImporter = (IPreviewImporter) importer;
-            m_docProperties = documentProperties;
-
-            // provide properties for the importer
-            documentProperties.put(DocumentProperties.PROP_USER_LANGUAGE, getUserLangCode(session));
-            documentProperties.put(DocumentProperties.PROP_MAX_MEMORY_USAGE, importerProps.opt("maxMemoryUsage"));
-            documentProperties.put(DocumentProperties.PROP_MEMORYOBSERVER, importerProps.opt(DocumentProperties.PROP_MEMORYOBSERVER));
-
-            if (null != m_documentBuffer) {
-                final InputStream documentStm = new ByteArrayInputStream(m_documentBuffer);
-                m_previewImporter.createDocumentModel(session, documentStm, documentProperties);
-                result = true;
-            }
-        }
-
-        return result;
-    }
-
-    /**
-     * @return
-     */
-    public JSONObject getPreviewOperations() throws FilterException {
-        JSONObject result = null;
-
-        final IPreviewImporter importer = m_previewImporter;
-        final DocumentProperties documentProperties = m_docProperties;
-        final Session session = m_session;
-
-        if ((null != session) && (null != importer) && (null != documentProperties)) {
-
-            result = importer.createPreviewOperations(documentProperties);
-
-            // retrieve properties from the document properties and set member
-            m_activeSheetIndex = documentProperties.optInteger(DocumentProperties.PROP_SPREADHSEET_ACTIVE_SHEET_INDEX, 0);
-            m_sheetCount = documentProperties.optInteger(DocumentProperties.PROP_SPREADSHEET_SHEET_COUNT, 0);
-        }
-
-        return result;
-    }
-
-    /**
-     * @return
-     */
-    public JSONObject getRemainingOperations(JSONObject appendOperations) throws FilterException {
-        JSONObject result = null;
-
-        final IPreviewImporter importer = m_previewImporter;
-        final DocumentProperties documentProperties = m_docProperties;
-        final Session session = m_session;
-
-        if ((null != session) && (null != importer) && (null != documentProperties)) {
-
-            result = importer.createOutstandingOperations(documentProperties);
-
-            // retrieve properties from the document properties and set member
-            m_activeSheetIndex = documentProperties.optInteger(DocumentProperties.PROP_SPREADHSEET_ACTIVE_SHEET_INDEX, 0);
-            m_sheetCount = documentProperties.optInteger(DocumentProperties.PROP_SPREADSHEET_SHEET_COUNT, 0);
-        }
-
-        return result;
-    }
-
     /**
      * Retrieves the operations from the document and optional additional operations.
      *
@@ -590,7 +517,6 @@ public class OXDocument {
 
                 DocumentProperties docProps = new DocumentProperties();
                 docProps.put(DocumentProperties.PROP_USER_LANGUAGE, userLangCode);
-                docProps.put(DocumentProperties.PROP_MAX_MEMORY_USAGE, importerProps.opt("maxMemoryUsage"));
                 docProps.put(DocumentProperties.PROP_MEMORYOBSERVER, importerProps.opt(DocumentProperties.PROP_MEMORYOBSERVER));
 
                 // request the document operations, preview data will be provided via callback
@@ -610,7 +536,7 @@ public class OXDocument {
                 m_activeSheetIndex = docProps.optInteger(DocumentProperties.PROP_SPREADHSEET_ACTIVE_SHEET_INDEX, 0);
                 m_sheetCount = docProps.optInteger(DocumentProperties.PROP_SPREADSHEET_SHEET_COUNT, 0);
 
-                LOG.info("RT connection: TIME getOperations: " + (System.currentTimeMillis() - startTime) + "ms");
+                LOG.debug("RT connection: TIME getOperations: " + (System.currentTimeMillis() - startTime) + "ms");
             } finally {
                 IOUtils.closeQuietly(documentStm);
             }
@@ -669,6 +595,17 @@ public class OXDocument {
         return m_lastErrorCode;
     }
 
+    /**
+     * Provides the session used to load/save the document stream.
+     *
+     * @return
+     *  the session of the client requested to load/save the document stream or
+     *  null, if there was no session
+     */
+    public Session getSession() {
+    	return m_session;
+    }
+
     /**
      * Retrieves the resource manager used by this document.
      *
@@ -799,14 +736,45 @@ public class OXDocument {
     }
 
     /**
+     * Provides possible rescue document operations which caused a filter exception.
+     *
+     * @return
+     *  the JSONObject containing the rescue operations or null if there are no
+     *  rescue operations.
+     */
+    public JSONArray getRescueOperations() {
+        JSONArray result = null;
+
+        if (null != m_documentOperations) {
+            result = m_documentOperations.optJSONArray(MessagePropertyKey.KEY_OPERATIONS);
+        }
+
+        return result;
+    }
+
+    /**
+     * Provides the rescue state of this document.
+     *
+     * @return
+     *  TRUE if the document is a rescue document, otherwise FALSE.
+     */
+    public boolean isRescueDocument() {
+        return m_isRescueDoc;
+    }
+
+    /**
+    * Initalizes a document properties object with properties required for saving
+    * a document.
     *
-    * @param session
-    * @param version
-    * @param saveAsTemplate
-    * @return
+    * @param session the session of the client requested to save the document
+    * @param version the version to be used for saving the document
+    * @param saveAsTemplate TRUE if the document should be saved as template, otherwise FALSE
+    * @param dirty TRUE if the export filter should set the dirty flag to ensure recalculating formulars
+    *              on loading.
+    * @return a document properties instance with initialized properties
     * @throws Exception
     */
-    private DocumentProperties setupDocumentPropertiesForSave(final Session session, final String version, boolean saveAsTemplate) throws Exception {
+    private DocumentProperties setupDocumentPropertiesForSave(final Session session, final String version, boolean saveAsTemplate, boolean dirty) throws Exception {
         final User user = SessionUtils.getUserInfo(session, m_services);
         String userLangCode = null;
         String userName = "";
@@ -820,6 +788,9 @@ public class OXDocument {
         docProps.put(DocumentProperties.PROP_USER_LANGUAGE, userLangCode);
         docProps.put(DocumentProperties.PROP_LAST_MODIFIED_BY, userName);
         docProps.put(DocumentProperties.PROP_SAVE_TEMPLATE_DOCUMENT, saveAsTemplate);
+        docProps.put(DocumentProperties.PROP_CALCULATE_ON_LOAD, dirty);
+        LOG.debug("RT connection: DocumentProperties used for filter = " + docProps.toString());
+
         int documentOSN = this.getUniqueDocumentId();
         if (documentOSN != -1) {
             docProps.put(DocumentProperties.PROP_UNIQUE_DOCUMENT_IDENTIFIER, String.valueOf(documentOSN));
@@ -833,10 +804,13 @@ public class OXDocument {
     }
 
    /**
+    * Create a combined operations array with the document operations
+    * object and pending operations array.
     *
-    * @param docOperations
-    * @param messageChunkList
-    * @return
+    * @param docOpsObject a operations object with a property "operations" with the operations array
+    * @param operations pending operations to be combined with the document operations
+    * @return An array with the combined document and pending operations. Can be empty if none
+    *         of the provided arguments contains operations.
     */
     private final JSONArray createCombinedOperations(final JSONObject docOpsObject, final JSONArray operations) {
         final JSONArray combinedOperations = new JSONArray();
@@ -847,7 +821,7 @@ public class OXDocument {
                final JSONArray docOperations = docOpsObject.getJSONArray(PROP_OPERATIONS);
                JSONHelper.appendArray(combinedOperations, docOperations);
             } catch (JSONException e) {
-                // TODO:
+                LOG.error("RT connection: Couldn't append document operations to array.", e);
             }
         }
 
@@ -856,7 +830,7 @@ public class OXDocument {
             try {
                 JSONHelper.appendArray(combinedOperations, operations);
             } catch (JSONException e) {
-                // TODO:
+                LOG.error("RT connection: Couldn't append pending operations to array.", e);
             }
         }
 
@@ -925,7 +899,7 @@ public class OXDocument {
                 final JSONArray goodOperations = JSONHelper.subArray(operations, 0, goodOpsCount);
                 opsString = goodOperations.toString();
             } catch (JSONException e) {
-                // TODO:
+                LOG.error("RT connection: Couldn't retrieve the good operations from the operations array.", e);
             }
         }
 
@@ -942,11 +916,13 @@ public class OXDocument {
     * @param saveAsTemplate
     * @return
     */
-    private DocumentStreamInfo createDocumentStream(final IExporter exporter, final ResourceManager resourceManager, final JSONArray operations, final String version, boolean finalSave, boolean saveAsTemplate) {
+    private DocumentStreamInfo createDocumentStream(final IExporter exporter, final ResourceManager resourceManager, final JSONArray operations, final String version,
+    		                                        boolean finalSave, boolean saveAsTemplate, boolean dirty) {
         final int MAX_TRY_COUNT = 2;
         final Session session = m_session;
         final boolean hasOperations = (operations != null) && (!operations.isEmpty());
         final JSONArray combinedOperations = createCombinedOperations(m_documentOperations, operations);
+        final boolean isRescueDoc = this.isRescueDocument();
 
         int opsApplied = 0;
         JSONArray badOperations = null;
@@ -962,8 +938,8 @@ public class OXDocument {
 
             do {
                 try {
-                    final DocumentProperties docProps = setupDocumentPropertiesForSave(session, version, saveAsTemplate);
-                    final String mergeOperations = (tryCount == 0) ? getOperationsString(combinedOperations) : getGoodOperationsString(combinedOperations, opsApplied);
+                    final DocumentProperties docProps = setupDocumentPropertiesForSave(session, version, saveAsTemplate, dirty);
+                    final String mergeOperations = ((tryCount == 0) || isRescueDoc) ? getOperationsString(combinedOperations) : getGoodOperationsString(combinedOperations, opsApplied);
 
                     combinedStm = exporter.createDocument(session, currDocStream, mergeOperations, resourceManager, docProps, finalSave);
                     tryCount++;
@@ -984,6 +960,7 @@ public class OXDocument {
 
                         errorCode = filterInfo.errorCode;
                     } else {
+                        LOG.error("Document export filter threw an exception while exporting the document", e);
                         // exception on second try is always a fatal error
                         errorCode = ErrorCode.SAVEDOCUMENT_FAILED_FILTER_OPERATION_ERROR;
                         // setErrorClass provides a clone with changed error class!
@@ -1040,7 +1017,8 @@ public class OXDocument {
      * @param saveAsTemplate
      * @return
      */
-    public ResolvedStreamInfo getResolvedDocumentStream(final IExporter exporter, final ResourceManager resourceManager, final JSONArray operations, final String version, boolean finalSave, boolean saveAsTemplate) {
+    public ResolvedStreamInfo getResolvedDocumentStream(final IExporter exporter, final ResourceManager resourceManager, final JSONArray operations, final String version,
+    		                                            boolean finalSave, boolean saveAsTemplate, boolean dirty) {
         InputStream resolvedDocumentStream = null;
         InputStream debugDocumentStream = null;
 
@@ -1050,7 +1028,7 @@ public class OXDocument {
 
         // create document stream -
         long startTime = System.currentTimeMillis();
-        DocumentStreamInfo docStreamInfo = createDocumentStream(exporter, resourceManager, operations, version, finalSave, saveAsTemplate);
+        DocumentStreamInfo docStreamInfo = createDocumentStream(exporter, resourceManager, operations, version, finalSave, saveAsTemplate, dirty);
         LOG.trace("RT connection: TIME createDocument: " + (System.currentTimeMillis() - startTime) + "ms");
 
         errorCode = docStreamInfo.errorCode;
@@ -1186,15 +1164,17 @@ public class OXDocument {
      * @param version The version of the document used for document properties.
      * @param finalSave Specifies if the new document stream should be handled as the final save. This can be used by the exporter to
      *            optimize the document, e.g. finally remove non-referenced resources.
+     * @param dirty Specifies
      * @return The stream of the new document containing the message chunk operations. Can be null if the creation of the stream failed or
      *         contains a debug document stream. The result depends on the errorCode.
      */
-    public ResolvedStreamInfo getResolvedDocumentStream(final IExporter exporter, final ResourceManager resourceManager, final List<MessageChunk> messageChunkList, final String version, boolean finalSave, boolean saveAsTemplate) {
+    public ResolvedStreamInfo getResolvedDocumentStream(final IExporter exporter, final ResourceManager resourceManager, final List<MessageChunk> messageChunkList, final String version,
+    		                                            boolean finalSave, boolean saveAsTemplate, boolean dirty) {
         final JSONArray operations = new JSONArray();
         for (final MessageChunk chunk : messageChunkList) {
             OperationHelper.appendOperationsFromMessageChunk(operations, chunk);
         }
-        return this.getResolvedDocumentStream(exporter, resourceManager, operations, version, finalSave, saveAsTemplate);
+        return this.getResolvedDocumentStream(exporter, resourceManager, operations, version, finalSave, saveAsTemplate, dirty);
     }
 
     /**
@@ -1211,11 +1191,13 @@ public class OXDocument {
      * @param finalSave
      *   Specifies if the new document stream should be handled as the final save. This can be used by the exporter to
      *   optimize the document, e.g. finally remove non-referenced resources.
+     * @param dirty
+     *   Specifies if calculated document content is valid or dirty (means must be calculated on load).
      * @return
      *   The result of the save operation stored in the SaveResult instance. The different properties (error code, version)
      *   can be retrieved from the instance.
      */
-     public SaveResult save(final IExporter exporter, final ResourceManager resourceManager, final List<MessageChunk> messageChunkList, boolean revisionless, boolean finalSave) throws OXDocumentException {
+     public SaveResult save(final IExporter exporter, final ResourceManager resourceManager, final List<MessageChunk> messageChunkList, boolean revisionless, boolean finalSave, boolean dirty) throws OXDocumentException {
         final SaveResult saveResult = new SaveResult(null, ErrorCode.NO_ERROR);
         String lastVersion = m_metaData.getVersion();
         String fileVersion = null;
@@ -1296,7 +1278,7 @@ public class OXDocument {
 
             // Normal save, retrieve stream with latest actions applied. This includes
             // creating a rescue file, if saving failed due to filter problems.
-            resolvedStreamInfo = getResolvedDocumentStream(exporter, resourceManager, messageChunkList, FileStorageFileAccess.CURRENT_VERSION, finalSave, m_isTemplateDoc);
+            resolvedStreamInfo = getResolvedDocumentStream(exporter, resourceManager, messageChunkList, FileStorageFileAccess.CURRENT_VERSION, finalSave, m_isTemplateDoc, dirty);
 
             // debug helper code - to simulate a slow save due to long running filter code
             if ((null != m_debugProperties) && (m_debugProperties.slowSave(false) && (m_debugProperties.slowSaveUser(false)))) {
