@@ -76,8 +76,9 @@ public class ErrorCode implements Cloneable {
     public static final ErrorCode GENERAL_FILE_LOCKED_ERROR = new ErrorCode(18, "GENERAL_FILE_LOCKED_ERROR", "The document is locked and cannot be modified.", 2);
     public static final ErrorCode GENERAL_FILE_CORRUPT_ERROR = new ErrorCode(19, "GENERAL_FILE_CORRUPT_ERROR", "The document is corrupt and cannot read.", 2);
     public static final ErrorCode GENERAL_SERVER_COMPONENT_NOT_WORKING_ERROR = new ErrorCode(20, "GENERAL_SERVER_COMPONENT_NOT_WORKING_ERROR", "A server component is not working correctly, therefore the request couldn't be processed.", 2);
-    public static final ErrorCode GENERAL_BACKGROUNDSAVE_IN_PROGRESS_ERROR = new ErrorCode(20, "GENERAL_BACKGROUNDSAVE_IN_PROGRESS_ERROR", "The document is stored by a background save process. Editing is not allowed.", 2);
-    public static final ErrorCode CREATEDOCUMENT_CONVERSION_FAILED_ERROR = new ErrorCode(200, "CREATEDOCUMENT_CONVERSION_FAILED_ERROR", "The document couldn't be created because of an conversion error!", 2);
+    public static final ErrorCode GENERAL_BACKGROUNDSAVE_IN_PROGRESS_ERROR = new ErrorCode(21, "GENERAL_BACKGROUNDSAVE_IN_PROGRESS_ERROR", "The document is stored by a background save process. Editing is not allowed.", 2);
+    public static final ErrorCode GENERAL_SESSION_COMPONENT_NOT_WORKING_ERROR = new ErrorCode(22, "GENERAL_SESSION_COMPONENT_NOT_WORKING_ERROR", "The session component is not working correctly, therefore the request couldn't be processed.", 2);
+    public static final ErrorCode CREATEDOCUMENT_CONVERSION_FAILED_ERROR = new ErrorCode(200, "CREATEDOCUMENT_CONVERSION_FAILED_ERROR", "The document couldn't be created because of a conversion error!", 2);
     public static final ErrorCode CREATEDOCUMENT_CANNOT_READ_TEMPLATEFILE_ERROR = new ErrorCode(201, "CREATEDOCUMENT_CANNOT_READ_TEMPLATEFILE_ERROR", "The document couldn't be created because the template file couldn't be read!", 2);
     public static final ErrorCode CREATEDOCUMENT_CANNOT_READ_DEFAULTTEMPLATEFILE_ERROR = new ErrorCode(202, "CREATEDOCUMENT_CANNOT_READ_DEFAULTTEMPLATEFILE_ERROR", "The document coulnd't be created because the default template file couldn't be read!", 2);
     public static final ErrorCode RENAMEDOCUMENT_FAILED_ERROR = new ErrorCode(300, "RENAMEDOCUMENT_FAILED_ERROR", "Renaming the document failed!", 2);
@@ -153,6 +154,8 @@ public class ErrorCode implements Cloneable {
     private final int m_code;
     private final String m_codeAsStringConstant;
     private final String m_description;
+    private String m_value;
+
     // can be changed by client code to change severity dependent on the context
     private int m_errorClass;
 
@@ -174,6 +177,28 @@ public class ErrorCode implements Cloneable {
         this.m_codeAsStringConstant = codeAsString;
         this.m_description = description;
         this.m_errorClass = errorClass;
+        this.m_value = null;
+    }
+
+    /**
+     * Creates a ErrorCode instance with the code, a unique constant string for the
+     * code and a description.
+     *
+     * @param code
+     *  The error code.
+     *
+     * @param codeAsString
+     *  The code as a unique constant string.
+     *
+     * @param description
+     *  The description of the error.
+     */
+    private ErrorCode(int code, final String codeAsString, final String description, int errorClass, final String value) {
+        this.m_code = code;
+        this.m_codeAsStringConstant = codeAsString;
+        this.m_description = description;
+        this.m_errorClass = errorClass;
+        this.m_value = value;
     }
 
     /**
@@ -247,6 +272,34 @@ public class ErrorCode implements Cloneable {
         return m_errorClass;
     }
 
+    /**
+     * Provides an optional value to the error code. This value must
+     * be interpreted dependent on the specific case. For example the
+     * value can be the illegal character which prevents a rename
+     * operation for a file.
+     *
+     * @return
+     *  The optional value for this error. Can be null if the value is
+     *  not set.
+     */
+    public String getValue() {
+        return m_value;
+    }
+
+    /**
+     * Provides an optional value to the error code. This value must
+     * be interpreted dependent on the specific case. For example the
+     * value can be the illegal character which prevents a rename
+     * operation for a file.
+     *
+     * @return
+     *  The optional value for this error. Can be null if the value is
+     *  not set.
+     */
+    public void setValue(final String value) {
+        m_value = value;
+    }
+
     /**
      * Creates a new error class instance which contains the same values
      * as this instance.
@@ -298,6 +351,9 @@ public class ErrorCode implements Cloneable {
             jsonObject.put("errorCode", this.getCode());
             jsonObject.put("error", this.getCodeAsStringConstant());
             jsonObject.put("errorDescription", this.getDescription());
+            if (m_value != null) {
+                jsonObject.put("errorValue", this.getValue());
+            }
         } catch (final JSONException e) {
             //
         }
