@@ -107,6 +107,11 @@ public class ExceptionToErrorCode {
                 // file not found error
                 errorCode = ErrorCode.GENERAL_FILE_NOT_FOUND_ERROR;
                 msg = "RT connection: File not found error detected!";
+            } else if (code == FileStorageExceptionCodes.ILLEGAL_CHARACTERS.getNumber()) {
+                errorCode = ErrorCode.RENAMEDOCUMENT_VALIDATION_FAILED_CHARACTERS_ERROR;
+                msg = "RT connection: Rename not possible due to illegal characters!";
+                // try to retrieve the illegal character from the exception
+                errorCode.setValue(getFirstArg(e));
             }
         } else if (prefix.equalsIgnoreCase("IFO")) {
             if (code == InfostoreExceptionCodes.NO_READ_PERMISSION.getNumber()) {
@@ -129,6 +134,12 @@ public class ExceptionToErrorCode {
                 // file is locked now
                 errorCode = ErrorCode.GENERAL_FILE_LOCKED_ERROR;
                 msg = "RT connection: The document is locked and cannot be modified";
+            } else if (code == InfostoreExceptionCodes.VALIDATION_FAILED_CHARACTERS.getNumber()) {
+                // illegal character in file name
+                errorCode = ErrorCode.RENAMEDOCUMENT_VALIDATION_FAILED_CHARACTERS_ERROR;
+                msg = "RT connection: Renamed failed due to invalid character in file name";
+                // try to retrieve the illegal character from the exception
+                errorCode.setValue(getFirstArg(e));
             }
         } else if (prefix.equalsIgnoreCase("DROPBOX")) {
             // special code to detect specific dropbox errors
@@ -144,4 +155,26 @@ public class ExceptionToErrorCode {
 
         return errorCode;
     }
+
+    /**
+     * Retrieve the first display argument from the exception.
+     *
+     * @param e the exception 
+     * @return
+     */
+    static private String getFirstArg(final OXException e) {
+    	String result = null;
+    	
+    	final Object[] dispArgs = e.getDisplayArgs();
+
+    	if (dispArgs.length > 0) {
+    		if (dispArgs[0] instanceof String)
+    			result = (String)dispArgs[0];
+    		else if (dispArgs[0] != null) {
+    			result = dispArgs[0].toString();
+    		}
+    	}
+
+    	return result;
+    }
 }
