@@ -683,7 +683,7 @@ public class DocFileHelper {
 
                 modifiedColumns.add(com.openexchange.file.storage.File.Field.FILENAME);
                 renameResult.newFileId = fileAccess.saveFileMetadata(metadata, FileStorageFileAccess.DISTANT_FUTURE, modifiedColumns);
-                LOG.info("RT connection: Renamed document file-id: " + renameResult.newFileId);
+                LOG.debug("RT connection: Renamed document file-id: " + renameResult.newFileId);
                 fileAccess.commit();
 
                 // retrieve the real filename from the metadata, it may have
@@ -700,14 +700,9 @@ public class DocFileHelper {
                 }
             } catch (Exception e) {
                 result = ErrorCode.RENAMEDOCUMENT_FAILED_ERROR;
-                // try to find out if there is a more specific error message
                 if (e instanceof OXException) {
-                    OXException ox = (OXException)e;
-                    if (ox.isPrefix("IFO")) {
-                        if (ox.getCode() == InfostoreExceptionCodes.VALIDATION_FAILED_CHARACTERS.getNumber()) {
-                            result = ErrorCode.RENAMEDOCUMENT_VALIDATION_FAILED_CHARACTERS_ERROR;
-                        }
-                    }
+                	// map possible exceptions to our error codes
+                    result = ExceptionToErrorCode.map((OXException)e, ErrorCode.RENAMEDOCUMENT_FAILED_ERROR, false);
                 }
                 LOG.error(result.getDescription(), e);
             }
