@@ -2,6 +2,8 @@ package com.openexchange.office.tools.htmldoc;
 
 import java.util.concurrent.atomic.AtomicInteger;
 
+import org.apache.commons.lang.StringEscapeUtils;
+import org.apache.commons.lang.StringUtils;
 import org.json.JSONArray;
 import org.json.JSONObject;
 
@@ -31,14 +33,17 @@ public class Drawing
     private final String         folderId;
     private final String         fileId;
 
-    private boolean              emptySpans          = true;                                                                                                                          ;
+    private boolean              emptySpans          = true;
+    private boolean              emptySpanStyle       = true;
     private boolean              havePlaceholder     = true;
 
     private String               src                 = null;
+    private boolean              presentation;
+    private String target;
 
     public Drawing(
             String type, String fileId, String folderId, String fileVersion)
-        throws Exception
+                throws Exception
     {
         this.fileId = fileId;
         this.folderId = folderId;
@@ -48,37 +53,59 @@ public class Drawing
 
     }
 
+    public Drawing setPresentation(
+        boolean presentation)
+    {
+        this.presentation = presentation;
+        if (presentation) {
+            havePlaceholder = false;
+        }
+        return this;
+    }
+
     @Override
     public boolean setAttribute(
         JSONArray start,
         JSONArray end,
         JSONObject assignedAttrs)
-        throws Exception
+            throws Exception
     {
+        if (assignedAttrs != null && assignedAttrs.has("image")) {
+            JSONObject drawing = assignedAttrs.getJSONObject("image");
+            String imageUrl = drawing.optString("imageUrl", "");
+            if (imageUrl.contains("://")) {
+                imageUrl = imageUrl.replaceAll("_REPLACE_SESSION_ID_", "_REPLACESESSIONID_"); // avoiding session ID replacement on client side for remote URLs (54403)
+                drawing.put("imageUrl", imageUrl);
+            }
+        }
+
         super.setAttribute(start, end, assignedAttrs);
-        
-        if (start.length() == 0) {
-	        // type must be checked now, because we support more than image
-	        if ((null != type) && (type.equalsIgnoreCase("image")))
-	        {
-	            JSONObject attrs = getAttribute();
-	            if (attrs != null)
-	            {
-	                JSONObject drawing = attrs.getJSONObject("image");
-	                String imageUrl = drawing.getString("imageUrl");
-	                if (imageUrl.contains("://"))
-	                {
-	                    src = imageUrl;
-	                }
-	                else
-	                {
-	                    src = "/appsuite/api/oxodocumentfilter?session=_REPLACE_SESSION_ID_&id=" + fileId + "&folder_id=" + folderId + "&action=getfile&get_filename=" + imageUrl + "&version=" + fileVersion + "&filename=drawing";
-	                    // /appsuite/api/oxodocumentfilter?session=a8d5e5d2454447eebf1419a19fb72dd1&uid=1405331293709.2453&id=500&folder_id=103&filename=kleinertest.docx&version=16&action=getfile&get_filename=word/media/uid267d2855268d.jpg
-	                }
-	            }
-	        }      
-            return false;        	
-        } else {
+
+        if (start.length() == 0)
+        {
+            // type must be checked now, because we support more than image
+            if ((null != type) && (type.equalsIgnoreCase("image")))
+            {
+                JSONObject attrs = getAttribute();
+                if (attrs != null)
+                {
+                    JSONObject drawing = attrs.getJSONObject("image");
+                    String imageUrl = drawing.getString("imageUrl");
+                    if (imageUrl.contains("://"))
+                    {
+                        src = imageUrl;
+                    }
+                    else
+                    {
+                        src = "/appsuite/api/oxodocumentfilter?session=_REPLACE_SESSION_ID_&id=" + fileId + "&folder_id=" + folderId + "&action=getfile&get_filename=" + imageUrl + "&version=" + fileVersion + "&filename=drawing";
+                        // /appsuite/api/oxodocumentfilter?session=a8d5e5d2454447eebf1419a19fb72dd1&uid=1405331293709.2453&id=500&folder_id=103&filename=kleinertest.docx&version=16&action=getfile&get_filename=word/media/uid267d2855268d.jpg
+                    }
+                }
+            }
+            return false;
+        }
+        else
+        {
             return true;
         }
 
@@ -87,12 +114,12 @@ public class Drawing
     @Override
     public boolean appendContent(
         StringBuilder document)
-        throws Exception
+            throws Exception
     {
 
         if (emptySpans)
         {
-            GenDocHelper.addEmptySpan(document);
+            GenDocHelper.addEmptySpan(document, emptySpanStyle);
         }
 
         document.append(CONTENT_START);
@@ -114,6 +141,17 @@ public class Drawing
         // System.out.println("Drawing.appendContent() " + this.type);
 
         String content = START;
+
+        if (presentation)
+        {
+            content = "";
+            if (null != target) {
+                content += " target='" + target + "'";                
+            }
+            
+            content += " class='drawing absolute' style='" + getAbsoluteCSS() + "'>";
+        }
+
         document.append(content);
         // System.out.println("Drawing.appendContent() " + content);
         if (type.equalsIgnoreCase("image"))
@@ -122,7 +160,11 @@ public class Drawing
             document.append(DRAWING_CONTENT);
 
             String image = CONTENT_IMAGE_START;
-            image += src;
+
+            String srcStr = StringEscapeUtils.escapeHtml(src);
+            srcStr = srcStr.replaceAll("'", "&#39;"); // escaping all single quotes (49847)
+
+            image += srcStr;
             image += CONTENT_IMAGE_END;
 
             document.append(image);
@@ -149,7 +191,7 @@ public class Drawing
         }
         else
         {
-            //default behavior for types we cant handle yet (chart)
+            // default behavior for types we cant handle yet (chart)
             document.append(PLACEHOLDER_CONTENT);
             super.appendContent(document);
         }
@@ -157,12 +199,66 @@ public class Drawing
         document.append(DIV_END);
         document.append(DIV_END);
 
-        if (emptySpans)
+        if (!presentation && emptySpans)
         {
-            GenDocHelper.addEmptySpan(document);
+            GenDocHelper.addEmptySpan(document, emptySpanStyle);
         }
         return false;
     }
+    
+    public String getPHType(){
+        JSONObject attrs = getAttribute();
+        if (null == attrs) {
+            return null;
+        }
+        
+        JSONObject pres = attrs.optJSONObject("presentation");
+        if (null == pres) {
+            return null;
+        }
+        String phType = pres.optString("phType");
+        if (StringUtils.isEmpty(phType)) {
+            return null;
+        }
+        return phType;
+    }
+
+    private String getAbsoluteCSS()
+        throws Exception
+    {
+
+        if (getAttribute() != null) {
+            JSONObject drawing = getAttribute().optJSONObject("drawing");
+            if (drawing != null) {
+                StringBuilder res = new StringBuilder();
+                //res.append("border: 1px solid blue; ");
+                res.append("border: none; ");
+                append(drawing, res, "width");
+                append(drawing, res, "height");
+                append(drawing, res, "left");
+                append(drawing, res, "top");
+                return res.toString();
+            }
+        }
+        
+//        System.out.println("Drawing.getAbsoluteCSS()         " + getAttribute().getJSONObject("drawing"));
+//        if (null != phAttrs) {
+//            System.out.println("Drawing.getAbsoluteCSS() phAttrs " + phAttrs.getJSONObject("drawing"));
+//        }
+
+        return "width: 50px; height: 50px; border: none;";
+    }
+
+    private void append(
+        JSONObject drawing,
+        StringBuilder res,
+        String key)
+    {
+        long value = drawing.optLong(key, -1);
+        if (value > -1) {
+            res.append(key + ": " + Math.round(GenDocHelper.convertHmmToPx(value)) + "px; ");
+        } 
+    }
 
     @Override
     public boolean needsEmptySpan()
@@ -180,7 +276,7 @@ public class Drawing
     public void insert(
         JSONArray start,
         INode newChild)
-        throws Exception
+            throws Exception
     {
         // System.out.println("Drawing.insert() " + start + " " + newChild.getClass());
         if (start.length() == 1)
@@ -200,5 +296,17 @@ public class Drawing
     public void disableEmptySpans()
     {
         this.emptySpans = false;
+    }    
+
+    public void disableEmptySpanStyle()
+    {
+        this.emptySpanStyle = false;
+    }
+
+    public Drawing setTarget(
+        String target)
+    {
+        this.target = target;
+        return this;
     }
 }
