@@ -1,6 +1,8 @@
 package com.openexchange.office.tools.htmldoc;
 
+import java.util.HashMap;
 import java.util.List;
+import java.util.Map;
 import org.apache.commons.lang.StringEscapeUtils;
 import org.json.JSONArray;
 import org.json.JSONException;
@@ -9,6 +11,7 @@ import org.json.JSONObject;
 public class GenDocHelper
 {
     private final static String EMPTYSPAN = "<span nonjquerydata=\"{&quot;isempty&quot;:true}\" style=\"font-family: Arial, Helvetica, sans-serif; font-weight: normal; font-style: normal; text-decoration: none; color: rgb(0, 0, 0); font-size: 11pt; vertical-align: baseline; line-height: 20px; background-color: transparent;\"></span>";
+    private final static String EMPTYSPAN_NOSTYLE = "<span nonjquerydata=\"{&quot;isempty&quot;:true}\"></span>";
 
     static JSONArray shiftedCopy(
         JSONArray input)
@@ -21,7 +24,7 @@ public class GenDocHelper
     public static void appendAttributes(
         JSONObject attrs,
         StringBuilder document)
-        throws JSONException
+            throws JSONException
     {
 
         appendAttributes(attrs, document, false);
@@ -30,7 +33,7 @@ public class GenDocHelper
 
     public static JSONObject getJQueryData(
         JSONObject attrs)
-        throws JSONException
+            throws JSONException
     {
         return getJQueryData(attrs, false);
     }
@@ -39,7 +42,7 @@ public class GenDocHelper
         JSONObject attrs,
         StringBuilder document,
         boolean implicit)
-        throws JSONException
+            throws JSONException
     {
         final JSONObject adapter = getJQueryData(attrs, implicit);
         appendJQueryData(document, adapter);
@@ -48,7 +51,7 @@ public class GenDocHelper
     public static void appendJQueryData(
         StringBuilder document,
         JSONObject jquerydata)
-        throws JSONException
+            throws JSONException
     {
 
         if (jquerydata.length() > 0)
@@ -64,7 +67,7 @@ public class GenDocHelper
     public static JSONObject getJQueryData(
         JSONObject attrs,
         boolean implicit)
-        throws JSONException
+            throws JSONException
     {
         final JSONObject adapter = new JSONObject();
         if (attrs != null)
@@ -94,12 +97,54 @@ public class GenDocHelper
     }
 
     public static void addEmptySpan(
-        StringBuilder doc)
+        StringBuilder doc, boolean style)
     {
-        doc.append(EMPTYSPAN);
+        if (style) {
+            doc.append(EMPTYSPAN);
+        } else {
+            doc.append(EMPTYSPAN_NOSTYLE);
+        }
     }
 
-    public static final String escapeSingleQuote(final String text) {
-        return text.replaceAll("'","&#39");
+    public static final String escapeSingleQuote(
+        final String text)
+    {
+        return text.replaceAll("'", "&#39");
     }
+
+    private static final Map<String, Float> FACTORS;
+
+    static
+    {
+        FACTORS = new HashMap<String, Float>();
+        FACTORS.put("px", 1F);
+        FACTORS.put("pc", 1F / 9F);
+        FACTORS.put("pt", 4F / 3F);
+        FACTORS.put("in", 96F);
+        FACTORS.put("cm", 96F / 2.54F);
+        FACTORS.put("mm", 96F / 25.4F);
+    }
+
+    public static float convertLength(
+        float value,
+        String fromUnit,
+        String toUnit)
+    {
+        value *= FACTORS.get(fromUnit) / FACTORS.get(toUnit);
+        return value;
+    }
+
+    public static float convertHmmToLength(
+        float value,
+        String toUnit)
+    {
+        return convertLength(value / 100, "mm", toUnit);
+    };
+
+    public static float convertHmmToPx(
+        float value)
+    {
+        return convertHmmToLength(value, "px");
+    };
+
 }
