@@ -17,14 +17,11 @@ public class Paragraph
 
     // private final static Logger LOG = LoggerFactory.getLogger(Paragraph.class);
 
-    public final static String  EMPTYSPAN             = "<span nonjquerydata=\"{&quot;isempty&quot;:true}\"></span><br jquerydata=\"{&quot;dummy&quot;:true}\">";
+    public final static String  EMPTYSPAN             = "<span nonjquerydata=\"{&quot;isempty&quot;:true}\"></span><br jquerydata=\"{&quot;dummy&quot;:true}\"/>";
     public final static String  PARASTART             = "<div class=\"p\" ";
     private static final String PARASTARTWITHOUTCLASS = "<div class=\"p";
-    private final static String DEFPARAATTRS          = " style=\"text-align: left; border: none; padding: 0px 0px 0px 0mm; margin: 0mm 0mm 3.52mm; text-indent: 0mm; background-color: transparent;\">";
-    private final static String DEFPARAATTRSINTABLE   = " style=\"text-align: left; border: none; padding: 0px 0px 0px 0mm; margin: 0mm 0mm 0mm; text-indent: 0mm; background-color: transparent;\">";
-    
-    // private final static String DEFWITHOUTALIGNMENT = " border: none; padding: 0px 0px 0px 0mm; margin: 0mm 0mm 3.52mm; text-indent: 0mm; background-color: transparent;\">";
-    // private final static String DEFSPANATTRS = "\"style=\"font-family: Arial, Helvetica, sans-serif; font-weight: normal; font-style: normal; text-decoration: none; color: rgb(0, 0, 0); font-size: 11pt; vertical-align: baseline; line-height: 20px; background-color: transparent;\"";
+    private final static String DEFPARAATTRS          = "text-align: left; border: none; padding: 0px 0px 0px 0mm; margin: 0mm 0mm 3.52mm; text-indent: 0mm; background-color: transparent;";
+    private final static String DEFPARAATTRSINTABLE   = "text-align: left; border: none; padding: 0px 0px 0px 0mm; margin: 0mm 0mm 0mm; text-indent: 0mm; background-color: transparent;";
 
     // ///////////////////////////////////////////////////////////////////////////////////////////
 
@@ -37,27 +34,34 @@ public class Paragraph
 
     public Paragraph()
     {
+
     }
 
     @Override
-    public final boolean isSplitpoint()
+    public final
+            boolean
+            isSplitpoint()
     {
         return splitpoint;
     }
 
     @Override
-    public final void setSplitpoint(
-        boolean splitpoint)
+    public final
+            void
+            setSplitpoint(
+                boolean splitpoint)
     {
         this.splitpoint = splitpoint;
     }
 
     @Override
-    public boolean setAttribute(
-        JSONArray subStartIndex,
-        JSONArray subEndIndex,
-        JSONObject attrs)
-        throws Exception
+    public final
+            boolean
+            setAttribute(
+                JSONArray subStartIndex,
+                JSONArray subEndIndex,
+                JSONObject attrs)
+                throws Exception
     {
 
         if (subEndIndex.length() == 0)
@@ -80,7 +84,7 @@ public class Paragraph
             for (final INode node : nodes)
             {
                 if (current == startTextIndex)
-                {                    
+                {
                     final JSONObject na = node.getAttribute();
                     final int awaitedEnd = current + node.getTextLength() - 1;
                     if (endTextIndex < awaitedEnd)
@@ -98,10 +102,10 @@ public class Paragraph
                         {
                             if (attrs.has(key))
                             {
-                                Logger log = GenericHtmlDocumentBuilder.getLogger();
-                                log.warn("FASTLOAD: Merging of attributes not supported - ignoring setAttributes!");
-                                return true;
-                                // throw new Exception("problem merging attrs!");
+                                Logger log = TextHtmlDocumentBuilder.getLogger();
+                                log.debug("FASTLOAD: Merging of attributes not supported");
+                                // return true;
+                                throw new Exception("FASTLOAD: Merging of attributes not supported");
                             }
                             attrs.put(key, na.get(key));
                         }
@@ -131,10 +135,12 @@ public class Paragraph
     }
 
     @Override
-    public void insert(
-        JSONArray start,
-        INode newChild)
-        throws Exception
+    public 
+            void
+            insert(
+                JSONArray start,
+                INode newChild)
+                throws Exception
     {
         if (start.length() == 1)
         {
@@ -171,8 +177,10 @@ public class Paragraph
         }
     }
 
-    public void shrinkTextes()
-        throws Exception
+    public final
+            void
+            shrinkTextes()
+                throws Exception
     {
 
         final int nodeCount = nodes.size();
@@ -216,16 +224,12 @@ public class Paragraph
         }
     }
 
-    @Override
-    public boolean appendContent(
-        StringBuilder document)
-        throws Exception
+    protected
+            void
+            appendHTMLCLasses(
+                StringBuilder document)
+                throws Exception
     {
-
-        document.append(PARASTARTWITHOUTCLASS);
-
-        int len = getTextLength();
-
         if (splitpoint && manualPageBreak)
         {
             document.append(" splitpoint manual-page-break");
@@ -238,9 +242,23 @@ public class Paragraph
         {
             document.append(" splitpoint");
         }
-        document.append("\"");
+    }
 
-        GenDocHelper.appendAttributes(myAttrs, document, isImplicit);
+    protected
+            void
+            appendHTMLAttributes(
+                StringBuilder document)
+                throws Exception
+    {
+
+    }
+
+    protected
+            void
+            appendHTMLStyles(
+                StringBuilder document)
+                throws Exception
+    {
 
         if (inTable)
         {
@@ -251,6 +269,32 @@ public class Paragraph
             document.append(DEFPARAATTRS);
         }
 
+    }
+
+    @Override
+    public final
+            boolean
+            appendContent(
+                StringBuilder document)
+                throws Exception
+    {
+
+        document.append(PARASTARTWITHOUTCLASS);
+
+        appendHTMLCLasses(document);
+
+        document.append("\"");
+
+        appendHTMLAttributes(document);
+
+        GenDocHelper.appendAttributes(myAttrs, document, isImplicit);
+
+        document.append(" style=\"");
+        appendHTMLStyles(document);
+        document.append("\">");
+
+        int len = getTextLength();
+
         if (len > 0)
         {
             shrinkTextes();
@@ -280,7 +324,7 @@ public class Paragraph
             }
             if (addEmptySpan || !contentAdded)
             {
-                GenDocHelper.addEmptySpan(document);
+                addEmptySpan(document);
             }
         }
         else
@@ -291,28 +335,40 @@ public class Paragraph
         document.append("</div>");
         return true;
     }
+    
+    protected void addEmptySpan(StringBuilder document) {
+        GenDocHelper.addEmptySpan(document, true);
+    }
 
     @Override
-    public String toString()
+    public
+            String
+            toString()
     {
         return "Paragraph " + nodes;
     }
 
-    public void setInTable(
-        boolean inTable)
+    public final
+            void
+            setInTable(
+                boolean inTable)
     {
         this.inTable = inTable;
     }
 
-    public void setImplicit(
-        boolean isImplicit)
+    public final
+            void
+            setImplicit(
+                boolean isImplicit)
     {
         this.isImplicit = isImplicit;
     }
 
-    public List<JSONObject> getReducedOps(
-        JSONArray paraPos)
-        throws Exception
+    public final
+            List<JSONObject>
+            getReducedOps(
+                JSONArray paraPos)
+                throws Exception
     {
         final int currentCount = nodes.size();
 
@@ -377,7 +433,9 @@ public class Paragraph
     }
 
     @Override
-    public int getTextLength()
+    public final
+            int
+            getTextLength()
     {
         int res = 0;
         for (INode sn : nodes)
@@ -388,13 +446,17 @@ public class Paragraph
     }
 
     @Override
-    public boolean needsEmptySpan()
+    public final
+            boolean
+            needsEmptySpan()
     {
         return false;
     }
 
     @Override
-    public JSONObject getAttribute()
+    public final
+            JSONObject
+            getAttribute()
     {
         return myAttrs;
     }
