@@ -12,6 +12,7 @@ public class Text
     // ////////////////////////////////////////////////////
 
     private final String        text;
+    private boolean style = true;
 
     public Text(
             String text, int position)
@@ -32,7 +33,12 @@ public class Text
     {
         document.append(SPANBEFORE);
         GenDocHelper.appendAttributes(getAttribute(), document);
-        document.append(SPANMIDDLE);
+        if (isStyle()) {
+            document.append(SPANMIDDLE);            
+        } else {
+            document.append(">");
+        }
+
         document.append(StringEscapeUtils.escapeHtml(text));
         document.append(SPANEND);
         return true;
@@ -49,4 +55,12 @@ public class Text
     {
         return false;
     }
+
+    public boolean isStyle() {
+        return style;
+    }
+
+    public void disableEmptySpanStyle() {
+        this.style = false;
+    }
 }
