@@ -83,7 +83,7 @@ public class JobPool implements IJobPool
             }
         });
 
-		LOG.info("register shutdown hook for job pool ...");
+		LOG.debug("register shutdown hook for job pool ...");
         Runtime.getRuntime().addShutdownHook(aHook);
 	}
 
@@ -256,7 +256,7 @@ public class JobPool implements IJobPool
 	 */
 	private synchronized void impl_shutdownPoolHard ()
 	{
-		LOG.info("shutdown hook reached job pool ["+m_aType+"] ...");
+		LOG.debug("shutdown hook reached job pool ["+m_aType+"] ...");
 		try
 		{
 			final Map< Integer, JobDescriptor > aPool = mem_Pool ();
@@ -277,7 +277,7 @@ public class JobPool implements IJobPool
 				{
 					if (aJob.aJob != null)
 					{
-						LOG.info("... deactivate job '"+aJob.nJobId+"'");
+						LOG.debug("... deactivate job '"+aJob.nJobId+"'");
 						aJob.aJob.deactivateJob();
 					}
 				}
@@ -295,7 +295,7 @@ public class JobPool implements IJobPool
 			// log but ignore errors !
 			LOG.error(ex.getMessage(), ex);
 		}
-		LOG.info("... OK");
+		LOG.debug("... OK");
 	}
 
 	//-------------------------------------------------------------------------
@@ -331,12 +331,12 @@ public class JobPool implements IJobPool
 			Thread.sleep (250); // TODO fix me : find better solution (e.g. notify on freeJob ...)
 
 			final long nNow = System.currentTimeMillis();
-			LOG.info("lease job pools ..."   );
-			LOG.info("now       = "+nNow     );
-			LOG.info("game over = "+nGameOver);
+			LOG.debug("lease job pools ..."   );
+			LOG.debug("now       = "+nNow     );
+			LOG.debug("game over = "+nGameOver);
 			if (nNow > nGameOver)
 			{
-				LOG.info ("... GIVE UP.");
+				LOG.debug ("... GIVE UP.");
 				break;
 			}
 		}
