@@ -63,9 +63,14 @@ public class FilterException extends RuntimeException {
         COMPLEXITY_TOO_HIGH,
         MEMORY_USAGE_TOO_HIGH,
         MEMORY_USAGE_MIN_FREE_HEAP_SPACE_REACHED,
-        UNSUPPORTED_OPERATION_USED
+        UNSUPPORTED_OPERATION_USED,
+        STRICT_OOXML_NOT_SUPPORTED,
+        FEATURE_NOT_SUPPORTED
     };
 
+    public static String ST_MAX_SHEET_COUNT_EXCEEDED = "MAX_SHEET_COUNT_EXCEEDED";
+    public static String ST_FRAME_ATTACHED_TO_FRAME_NOT_SUPPORTED = "FRAME_ATTACHED_TO_FRAME_IS_NOT_SUPPORTED";
+    
     final private ErrorCode errorCode;
     final private Object value;
     private String subType = null;
