@@ -54,7 +54,7 @@ package com.openexchange.office;
  *
  * @author <a href="mailto:kai.ahrens@open-xchange.com">Kai Ahrens</a>
  */
-public interface IMonitoring extends IMonitoringCommon, IMonitoringText, IMonitoringSpreadsheet, IMonitoringCalcEngine {
+public interface IMonitoring extends IMonitoringCommon, IMonitoringText, IMonitoringSpreadsheet {
     // Collecting all sub interfaces
 
 }
